#
# spec file for package kernel-pae
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# This makes the OBS store the project cert as %_sourcedir/_projectcert.crt
# needssslcertforbuild

%define srcversion 3.16
%define patchversion 3.16.7
%define variant %{nil}
%define vanilla_only 0

%include %_sourcedir/kernel-spec-macros

%define build_flavor	pae
%define build_default	("%build_flavor" == "default")
%define build_xen	("%build_flavor" == "xen" || "%build_flavor" == "ec2")
%define build_vanilla	("%build_flavor" == "vanilla")

%define build_src_dir %my_builddir/linux-%srcversion
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%define obj_install_dir %src_install_dir-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %build_src_dir/linux-obj

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,find-provides,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,configtool.pl,log.sh,try-disable-staging-driver,compress-vmlinux.sh})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SPLIT_PACKAGE CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_base (%CONFIG_SPLIT_PACKAGE == "y")
%define split_extra (%CONFIG_SPLIT_PACKAGE == "y" && %CONFIG_SUSE_KERNEL_SUPPORTED == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-pae
Summary:        Kernel with PAE Support
License:        GPL-2.0
Group:          System/Kernel
Version:        3.16.7
%if 0%{?is_kotd}
Release:        21.1.g93c1539
%else
Release:        21.1
%endif
Url:            http://www.kernel.org/
BuildRequires:  bc
BuildRequires:  coreutils
BuildRequires:  fdupes
%if 0%{?suse_version} > 1310
BuildRequires:  hmaccalc
%endif
BuildRequires:  modutils
# Used to sign the kernel in the buildservice
BuildRequires:  pesign-obs-integration openssl
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%release
Provides:       multiversion(kernel)
%if %split_base
Provides:       kernel-base = %version-%source_rel
# Obsolete the -base subpackage from 11.1 and 11.2 development phase
Obsoletes:      %name-base <= 2.6.31
%endif
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools m4 udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
%if %build_xen
#!BuildIgnore:  xen
%endif

Obsoletes:      microcode_ctl

%if %build_vanilla
# force bzip2 instead of lzma compression to allow install on older dist versions
%define _binary_payload w9.bzdio
%endif
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
%ifarch %ix86
Provides:       kernel-bigsmp = 2.6.17
Obsoletes:      kernel-bigsmp <= 2.6.17
Provides:       kernel-vmi = 2.6.38
Obsoletes:      kernel-vmi <= 2.6.38
%endif
Source0:        http://www.kernel.org/pub/linux/kernel/v3.x/linux-%srcversion.tar.xz
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source44:       find-provides
Source45:       split-modules
Source46:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source66:       configtool.pl
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source107:      patches.xen.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source112:      patches.trace.tar.bz2
Source113:      patches.kabi.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86
%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif
%endif

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       8
NoSource:       9
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       39
NoSource:       40
NoSource:       44
NoSource:       45
NoSource:       46
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       66
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       107
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       112
NoSource:       113
NoSource:       120
NoSource:       121

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# sle11
%obsolete_kmp ocfs2 1.6_4
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp   wacom 0.8.1_3
%obsolete_kmp   btrfs 0_3
%obsolete_kmp   brocade-bna 2.1.0.0_3
%obsolete_kmp   hyper-v 0_3
%obsolete_kmp   intel-e1000e 2.2.14
%obsolete_kmp   drm 3.7_3.1
Obsoletes:      firewire <= 3.0
Provides:       firewire = 3.0
%obsolete_kmp   firewire 3.0
%obsolete_kmp   iwlagn 3.0
Obsoletes:      compat-ath9k <= 3.0
Provides:       compat-ath9k = 3.0
%obsolete_kmp   compat-ath9k 3.0
%obsolete_kmp   realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp   realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp   rt3090 2.4.0.4_3
%obsolete_kmp   rt3592 2.4.1.1_3
%obsolete_kmp   rt5390 2.4.0.4_3
%obsolete_kmp   ath3k 1.0_3
Obsoletes:      ath3k-firmware <= 1.0
Provides:       ath3k-firmware = 1.0

# Provide the exported symbols as "ksym(symbol) = hash"
%define __find_provides %_sourcedir/find-provides %name

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.


%source_timestamp
%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 107 -a 108 -a 109 -a 110 -a 111 -a 112 -a 113 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/^\+(base|yes) / {
		print $(NF);
		next;
	}
	/^\+external / {
		print $(NF) " external";
		next;
	}
	/^[-+]/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
%_sourcedir/guards --default=0 base < %_sourcedir/supported.conf | \
	sed 's,.*/,,; s,\.ko$,,' | sort -u >%kernel_build_dir/Module.base

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	%_sourcedir/configtool.pl %my_builddir/config{,.addon}/%cpu_arch_flavor >.config
else
	cp %my_builddir/config/%cpu_arch_flavor .config
fi
%build_src_dir/scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO \
	--disable  CONFIG_DEBUG_INFO_REDUCED
%else
	--disable CONFIG_DEBUG_INFO
%endif

MAKE_ARGS="$MAKE_ARGS -C %build_src_dir O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS
else
    cp .config .config.orig
    make silentoldconfig $MAKE_ARGS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d -printf '%%P\n' > %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy optional module signing files:
# *.x509, *.crt
#  - certificates with pubkeys used to verify module and firmware signatures
#    at runtime. *.crt files assumed to be in the PEM format.
# signing_key.priv
#  - unencrypted private key used to sign modules and firmware during build
# x509.genkey
#  - openssl req config to generate a new signing_key.{x509,priv} pair for the
#    build
for f in %_sourcedir/*.x509 %_sourcedir/{signing_key.priv,x509.genkey}; do
    if test -e "$f"; then
        cp "$f" .
    fi
done
for f in %_sourcedir/*.crt; do
    if ! test -e "$f"; then
        continue
    fi
    out=${f##*/}
    out=${out%.crt}.x509
    openssl x509 -inform PEM -in "$f" -outform DER -out "$out"
done
# Convince kernel/Makefile not to generate a new keypair
touch x509.genkey
touch signing_key.x509

# The %{_smp_mflags} macro is defined to a number, make will spawn that many jobs.
# There are several ways how to define it:
# If you are using the build script:
#     build --jobs=N kernel-$flavor.spec
# With plain rpmbuild:
#     rpmbuild -ba --define 'jobs N' kernel-$flavor.spec
# To spawn as many jobs as there are cpu cores:
#     rpmbuild -ba --define "%_smp_mflags -j 0$(grep -Ec 'cpu[0-9]' /proc/stat)" \
#         kernel-$flavor.spec
# You can also set this permanently in ~/.rpmmacros:
#     %_smp_mflags -j 0%(grep -Ec 'cpu[0-9]' /proc/stat)
%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

while true; do
    make %{?_smp_mflags} all $MAKE_ARGS CONFIG_DEBUG_SECTION_MISMATCH=y 2>&1 \
        | tee buildlog
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver buildlog; then
        echo "Retrying make"
    else
        exit 1
    fi
done

%install

# sign the modules, firmware and possibly the kernel in the buildservice
export BRP_PESIGN_FILES="*.ko"
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES /boot/vmlinuz-%kernelrelease-%build_flavor"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.gz
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
%if %build_xen
    test -f arch/x86/boot/$image || image=vmlinuz
%endif
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
    image=vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    image=zImage
    cp -p arch/arm/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    image=Image
    cp -p arch/arm64/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/$image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in *.x509; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform DER -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            cp "$f" %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base' | '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_xen || %build_vanilla
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot/lib/modules/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

%if %split_base
    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir/Module.base \
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i
%endif
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    dd if=/dev/zero of=%buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep ibs=`stat -c%s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep` count=1

%else
    (   cd %buildroot
	find lib/modules/%kernelrelease-%build_flavor -type f -name '*.ko' -printf '/%%p\n'
    ) > %my_builddir/base-modules
%endif

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # arch/powerpc/lib/crtsavres.o is required for building external
    # modules on powerpc
    if [ -f %kernel_build_dir/arch/powerpc/lib/crtsavres.o ]; then
	echo arch/powerpc/lib/crtsavres.o >> %my_builddir/obj-files
    fi

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Recreate the generated Makefile with correct path
    sh ../scripts/mkmakefile ../../../linux-%kernelrelease%variant \
        %rpm_install_dir/%cpu_arch_flavor \
        $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
fi

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/symtypes* %buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    for f in boot/*; do
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.gz)
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                echo "%%ghost /$f"
                continue
            fi
            ;;
        boot/symtypes*)
            continue
            ;;
        esac
        echo "%%attr(0644, root, root) /$f"
    done

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -type f -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y"; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    test -d lib/firmware/%kernelrelease-%build_flavor && \
    find lib/firmware/%kernelrelease-%build_flavor \
	-type d -o \
	-printf '/%%p\n'
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

%if %split_base
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules} \
	> %my_builddir/kernel-main.files
%endif
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%endif

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%if %split_base

%files -f kernel-main.files
%defattr(-, root, root)
%else

%files -f kernel-base.files
%defattr(-, root, root)
%endif

%package base
Summary:        Kernel with PAE Support - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%release
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch %ix86
Provides:       kernel-vmi-base = 2.6.38
Obsoletes:      kernel-vmi-base <= 2.6.38
%endif
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%if %split_base

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        Kernel with PAE Support - Unsupported kernel modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%release
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%release
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd

Supplements:    packageand(product(SUSE_SLED):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
This kernel supports up to 64GB of main memory. It requires Physical
Addressing Extensions (PAE), which were introduced with the Pentium Pro
processor.

PAE is not only more physical address space but also important for the
"no execute" feature which disables execution of code that is marked as
non-executable. Therefore, the PAE kernel should be used on any systems
that support it, regardless of the amount of main memory.

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script.
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       kernel-devel%variant = %version-%source_rel
Supplements:    packageand(%name:kernel-devel%variant)

PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp
%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%if %kmp_target_cpu != %cpu_arch
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif
%endif

%changelog
* Tue Apr 14 2015 tiwai@suse.de
- kabi: fix for move of d_rcu (bnc#903640 CVE-2014-8559
  boo#927018).
- commit 93c1539
* Tue Apr 14 2015 jlee@suse.com
- Update config files. (boo#925479)
  Do not set CONFIG_SYSTEM_TRUSTED_KEYRING until we need it in future
  openSUSE version:
  e.g. MODULE_SIG, IMA, PKCS7(new), KEXEC_BZIMAGE_VERIFY_SIG(new)
- commit 55df6c2
* Thu Apr  9 2015 bp@suse.de
- x86/asm/entry/64: Remove a bogus 'ret_from_fork' optimization
  (bsc#926240, CVE-2015-2830).
- commit 3a397b8
* Thu Apr  9 2015 mkubecek@suse.cz
- net: rds: use correct size for max unacked packets and bytes
  (bsc#919018 CVE-2015-2042).
- commit a7793ed
* Thu Apr  9 2015 bp@suse.de
- eCryptfs: Remove buggy and unnecessary write in file name
  decode routine (bsc#918333, CVE-2014-9683).
- commit 8629f98
* Wed Apr  8 2015 dsterba@suse.cz
- btrfs: simplify insert_orphan_item (boo#926385).
- btrfs: set proper message level for skinny metadata.
- Btrfs: make sure we wait on logged extents when fsycning
  two subvols.
- btrfs: fix lost return value due to variable shadowing.
- btrfs: fix leak of path in btrfs_find_item.
- Btrfs: fix fsync data loss after adding hard link to inode.
- Btrfs: fix fs corruption on transaction abort if device
  supports discard.
- Btrfs: fix data loss in the fast fsync path.
- Btrfs: don't delay inode ref updates during log replay.
- Btrfs: do not move em to modified list when unpinning.
- commit b3e6aaf
* Wed Apr  8 2015 dsterba@suse.cz
- Btrfs:__add_inode_ref: out of bounds memory read when looking
  for extended ref.
- Btrfs: fix inode eviction infinite loop after cloning into it
  (boo#905088).
- commit 02270f6
* Wed Apr  8 2015 jack@suse.cz
- Add CVE reference to
  patches.fixes/ext4-allocate-entire-range-in-zero-range.patch
  (bnc#919032 CVE-2015-0275).
- commit 059ac72
* Wed Apr  8 2015 jack@suse.cz
- ext4: allocate entire range in zero range (bnc#919032).
- commit 6f1dee9
* Wed Apr  8 2015 jack@suse.cz
- ext4: fix ZERO_RANGE bug hidden by flag aliasing.
- commit 9d6a4be
* Wed Apr  8 2015 oneukum@suse.de
- Input: xpad - use proper endpoint type (bnc#926397).
- commit 07617fe
* Mon Mar 23 2015 bp@suse.de
- Update
  patches.arch/x86-microcode-intel-guard-against-stack-overflow-in-the-loader.patch
  (bsc#922944, CVE-2015-2666).
- commit 04be35a
* Mon Mar 23 2015 neilb@suse.de
- md: don't require sync_min to be a multiple of chunk_size
  (bnc#910500).
- commit fde41e8
* Wed Mar 18 2015 agraf@suse.de
- powerpc/pci: Fix IO space breakage after of_pci_range_to_resource() change (bnc#922542).
- commit ba2afab
* Wed Mar 18 2015 bp@suse.de
- x86/microcode/intel: Guard against stack overflow in the loader
  (bsc#922944).
- commit fbca1cd
* Wed Mar 18 2015 jbohac@suse.cz
- net: sctp: fix slab corruption from use after free on INIT
  collisions (bsc#915577, CVE-2015-1421).
- commit db3fcca
* Wed Mar 18 2015 ddiss@suse.de
- cifs: fix use-after-free bug in find_writable_file (bnc#909477).
- commit 06d2d93
* Mon Mar 16 2015 jbeulich@suse.com
- x86: use custom dma_get_required_mask().
- x86-64/MCE: flip CPU and bank numbers in log message.
- scsifront: avoid acquiring same lock twice if ring is full.
- scsifront: don't use bitfields for indicators modified under
  different locks.
- MSI: also reject resource with flags all clear.
- xen-pciback: limit guest control of command register (bsc#919463
  CVE-2015-2150 XSA-120).
- usbback: copy only filled buffers to guest (bsc#917830
  CVE-2015-0777).
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- x86_64, traps: Stop using IST for #SS (bsc#907818,
  CVE-2014-9090, CVE-2014-9322).
- Refresh other Xen patches.
- commit c477d30
* Mon Mar 16 2015 dmueller@suse.com
- ARM64: Enable CONFIG_COMPAT
- commit 23df5ff
* Sun Mar 15 2015 dmueller@suse.com
- ARM64: Fix support for ARMv7 userspace
- commit e18816f
* Thu Mar 12 2015 tiwai@suse.de
- ALSA: hda - Fix built-in mic on Compaq Presario CQ60
  (bnc#920604).
- commit c2a5753
* Mon Mar  9 2015 tiwai@suse.de
- ALSA: hda - Fix regression of HD-audio controller fallback modes
  (bsc#921313).
- commit 08c92cf
* Wed Mar  4 2015 tiwai@suse.de
- usb: Do not allow usb_alloc_streams on unconfigured devices
  (bsc#920581).
- commit ccae9ec
* Tue Mar  3 2015 mszeredi@suse.cz
- fuse: honour max_read and max_write in direct_io mode
  (bnc#918954).
- switch iov_iter_get_pages() to passing maximal number of pages
  (bnc#918954).
- commit ea5ed8c
* Thu Feb 26 2015 oneukum@suse.de
- bcache: fix a livelock in btree lock v2 (bnc#910440)
  (bnc#910440).
  Updated because another version went upstream
- commit 803fc4f
* Mon Feb 23 2015 bp@suse.de
- x86, mm/ASLR: Fix stack randomization on 64-bit systems
  (bsc#917839, CVE-2015-1593).
- commit bcfd218
* Mon Feb 23 2015 tiwai@suse.de
- drm/i915: Initialise userptr mmu_notifier serial to 1
  (bnc#918970).
- commit efba994
* Fri Feb 20 2015 neilb@suse.de
- NFS: Don't try to reclaim delegation open state if recovery
  failed (boo#909634).
- NFSv4: Ensure that we call FREE_STATEID when NFSv4.x stateids
  are revoked (boo#909634).
- NFSv4: Fix races between nfs_remove_bad_delegation() and
  delegation return (boo#909634).
- NFSv4: Ensure that we remove NFSv4.0 delegations when state
  has expired (boo#909634).
- Fixing lease renewal (boo#909634).
- commit 267ab8f
* Thu Feb 19 2015 oneukum@suse.de
- bcache: Fix a bug when detaching (bsc#908582).
- commit ae25846
* Tue Feb 10 2015 tiwai@suse.de
- fix a leak in bch_cached_dev_run() (bnc#910440).
- bcache: unregister reboot notifier when bcache fails to register
  a block device (bnc#910440).
- bcache: fix a livelock in btree lock (bnc#910440).
- bcache: [BUG] clear BCACHE_DEV_UNLINK_DONE flag when attaching
  a backing device (bnc#910440).
- bcache: Add a cond_resched() call to gc (bnc#910440).
- commit f9c15b3
* Tue Feb 10 2015 tiwai@suse.de
- storvsc: ring buffer failures may result in I/O freeze
  (bnc#914175).
- commit 69fb65d
* Sat Feb  7 2015 bp@suse.de
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- commit aa0e49f
* Fri Feb  6 2015 tiwai@suse.de
- ALSA: seq-dummy: remove deadlock-causing events on close
  (boo#916608).
- ALSA: pcm: Zero-clear reserved fields of PCM status ioctl in
  compat mode (boo#916608).
- ALSA: bebob: Uninitialized id returned by
  saffirepro_both_clk_src_get (boo#916608).
- commit b9b9dfa
* Fri Feb  6 2015 tiwai@suse.de
- [media] sound: Update au0828 quirks table (boo#916608).
- [media] sound: simplify au0828 quirk table (boo#916608).
- commit 49ee9b5
* Fri Feb  6 2015 tiwai@suse.de
- ALSA: usb-audio: Add mic volume fix quirk for Logitech Webcam
  C210 (boo#916608).
- ALSA: usb-audio: extend KEF X300A FU 10 tweak to Arcam rPAC
  (boo#916608).
- ALSA: usb-audio: Add ctrl message delay quirk for Marantz/Denon
  devices (boo#916608).
- ALSA: usb-audio: Fix memory leak in FTU quirk (boo#916608).
- ALSA: usb-audio: Fix device_del() sysfs warnings at disconnect
  (boo#916608).
- commit 4818128
* Fri Feb  6 2015 tiwai@suse.de
- ALSA: hda - Add new GPU codec ID 0x10de0072 to snd-hda
  (boo#916608).
- ALSA: hda - Fix wrong gpio_dir & gpio_mask hint setups for
  IDT/STAC codecs (boo#916608).
- ALSA: hda/realtek - New codec support for ALC298 (boo#916608).
- ALSA: hda/realtek - New codec support for ALC256 (boo#916608).
- ALSA: hda/realtek - Add new Dell desktop for ALC3234 headset
  mode (boo#916608).
- ALSA: hda - Add EAPD fixup for ASUS Z99He laptop (boo#916608).
- ALSA: hda - Fix built-in mic at resume on Lenovo Ideapad S210
  (boo#916608).
- ALSA: hda/realtek - Add headset Mic support for new Dell machine
  (boo#916608).
- ALSA: hda_intel: Add DeviceIDs for Sunrise Point-LP
  (boo#916608).
- ALSA: hda_intel: Add Device IDs for Intel Sunrise Point PCH
  (boo#916608).
- ALSA: hda - add codec ID for Braswell display audio codec
  (boo#916608).
- ALSA: hda - add PCI IDs for Intel Braswell (boo#916608).
- ALSA: hda - Add dock support for Thinkpad T440 (17aa:2212)
  (boo#916608).
- commit df0c642
* Thu Feb  5 2015 tiwai@suse.de
- ALSA: hda - Set up GPIO for Toshiba Satellite S50D (bnc#915858).
- commit 4506afc
* Thu Feb  5 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix build if there is no *.crt file
- commit c5b1275
* Thu Feb  5 2015 vbabka@suse.cz
- mm, vmscan: prevent kswapd livelock due to pfmemalloc-throttled
  process being killed (VM Functionality bnc#910150).
- commit 998f343
* Wed Feb  4 2015 jslaby@suse.cz
- Input: evdev - fix EVIOCG{type} ioctl (bnc#904899).
- commit 1c8e5bf
* Wed Feb  4 2015 jbohac@suse.cz
- batman-adv: Calculate extra tail size based on queued fragments
  (bsc#912429, CVE-2014-9428).
- commit fa16c95
* Mon Feb  2 2015 jlee@suse.com
- mnt: Implicitly add MNT_NODEV on remount when it was implicitly
  added by mount (bsc#907988).
- commit 2684bcc
* Mon Feb  2 2015 jbohac@suse.cz
- netfilter: conntrack: disable generic tracking for known
  protocols (bsc#913059, CVE-2014-8160).
- commit 05d4053
* Fri Jan 30 2015 jlee@suse.com
- KEYS: close race between key lookup and freeing (bnc#912202).
- commit b0191b2
* Fri Jan 30 2015 mmarek@suse.cz
- rpm/constraints.in: Lower the requirement to 4 CPUs on POWER
- commit 9e50821
* Thu Jan 29 2015 fdmanana@suse.com
- Btrfs: fix scrub race leading to use-after-free (bnc#915456).
- Btrfs: fix setup_leaf_for_split() to avoid leaf corruption
  (bnc#915454).
- Btrfs: fix fsync log replay for inodes with a mix of regular
  refs and extrefs (bnc#915425).
- Btrfs: fix fsync when extend references are added to an inode
  (bnc#915425).
- Btrfs: fix directory inconsistency after fsync log replay
  (bnc#915425).
- Btrfs: make xattr replace operations atomic (bnc#913466).
- Btrfs: fix directory recovery from fsync log (bnc#895797).
- commit 22eab43
* Wed Jan 28 2015 oneukum@suse.de
- bcache: add mutex lock for bch_is_open (bnc#908612).
- bcache: Correct printing of btree_gc_max_duration_ms
  (bnc#908610).
- bcache: fix crash with incomplete cache set (bnc#908608).
- bcache: fix memory corruption in init error path (bnc#908606).
- bcache: Fix more early shutdown bugs (bnc#908605).
- bcache: fix use-after-free in btree_gc_coalesce() (bnc#908604).
- bcache: Fix an infinite loop in journal replay (bnc#908603).
- bcache: fix typo in bch_bkey_equal_header (bnc#908598).
- bcache: Make sure to pass GFP_WAIT to mempool_alloc()
  (bnc#908596).
- bcache: fix crash on shutdown in passthrough mode (bnc#908594).
- bcache: fix lockdep warnings on shutdown (bnc#908593).
- bcache allocator: send discards with correct size (bnc#908592).
- bcache: Fix to remove the rcu_sched stalls (bnc#908589).
- bcache: Fix a journal replay bug (bnc#908588).
- commit d05ac88
* Tue Jan 27 2015 jack@suse.cz
- Add CVE reference to
  patches.fixes/isofs-Fix-unchecked-printing-of-ER-records.patch
  (CVE-2014-9584).
- commit ba87edb
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not generate pdf documents
  This has only recently been fixed in master
- commit 0743539
* Mon Jan 26 2015 mmarek@suse.cz
- DocBook: Do not exceed argument list limit.
- commit db3629e
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not ignore errors from make
- commit 86ebfa7
* Sat Jan 24 2015 jdelvare@suse.de
- Update x86_64 config files: CONFIG_SENSORS_NCT6683=m
  The nct6683 driver is already enabled on i386 and history suggests
  that it not being enabled on x86_64 is by mistake.
- commit ba6ed63
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop sparse from BuildRequires
- commit 9777c26
* Fri Jan 23 2015 bp@suse.de
- x86_64, vdso: Fix the vdso address randomization algorithm
  (bsc#912705, CVE-2014-9585).
- commit ccbc68b
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Update the comment about NO_BRP_STALE_LINK_ERROR
  There is no stale symlink in the installed system anymore, but there is
  one during build.
- commit e575cce
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the modules directory in the devel
  package (bnc#910322)
- commit d89b963
* Wed Jan 21 2015 mszeredi@suse.cz
- deal with deadlock in d_walk() (bnc#903640 CVE-2014-8559).
- move d_rcu from overlapping d_child to overlapping d_alias
  (bnc#903640 CVE-2014-8559).
- commit 449de11
* Tue Jan 20 2015 tiwai@suse.de
- Revert "iwlwifi: mvm: treat EAPOLs like mgmt frames wrt rate"
  (bnc#900811).
- commit fbf7004
* Mon Jan 19 2015 mhocko@suse.cz
- mm: free compound page with correct order (bnc#913695).
- commit 555c991
* Fri Jan 16 2015 tiwai@suse.de
- drm/i915: More cautious with pch fifo underruns (boo#907039).
- commit d1575f1
* Wed Jan 14 2015 agraf@suse.de
- Refresh patches.arch/arm64-0039-generic-pci.patch (fix PCI bridge support)
- commit 8e7639a
* Mon Jan 12 2015 bp@suse.de
- x86/microcode/intel: Fish out the stashed microcode for the BSP
  (bsc#903589).
- x86, microcode: Reload microcode on resume (bsc#903589).
- x86, microcode: Don't initialize microcode code on paravirt
  (bsc#903589).
- x86, microcode, intel: Drop unused parameter (bsc#903589).
- x86, microcode, AMD: Do not use smp_processor_id() in preemtible
  context (bsc#903589).
- x86, microcode: Update BSPs microcode on resume (bsc#903589).
- x86, microcode, AMD: Fix ucode patch stashing on 32-bit
  (bsc#903589).
- x86, microcode: Fix accessing dis_ucode_ldr on 32-bit
  (bsc#903589).
- x86, microcode, AMD: Fix early ucode loading on 32-bit
  (bsc#903589).
- commit 6aba379
* Thu Jan  8 2015 tiwai@suse.de
- Bluetooth: Add support for Broadcom BCM20702A0 variants firmware
  download (bnc#911311).
- commit 2b91b9f
* Thu Jan  8 2015 tiwai@suse.de
- drm/radeon: fix sad_count check for dce3 (bnc#911356).
- commit 8ed1206
* Wed Jan  7 2015 bp@suse.de
- x86, kvm: Clear paravirt_enabled on KVM guests for espfix32's
  benefit (bsc#909078, CVE-2014-8134).
- commit a510f76
* Tue Jan  6 2015 tiwai@suse.de
- drm/i915: Don't call intel_prepare_page_flip() multiple times
  on gen2-4 (bnc#911835).
- commit 4b26661
* Tue Jan  6 2015 jack@suse.cz
- patches.fixes/udf-Verify-i_size-when-loading-inode.patch: Fixup
  compilation failure
- commit a6bfb5e
* Tue Jan  6 2015 jack@suse.cz
- udf: Check component length before reading it.
- udf: Check path length when reading symlink.
- udf: Verify symlink size before loading it.
- udf: Verify i_size when loading inode.
- isofs: Fix unchecked printing of ER records.
- isofs: Fix infinite looping over CE entries (bnc#911325
  CVE-2014-9420).
- commit 6235bda
* Tue Jan  6 2015 agraf@suse.de
- arm64: Enable DRM
- commit 218facf
* Mon Jan  5 2015 agraf@suse.de
- arm64: Enable generic PHB driver (bnc#912061).
- commit e59c836
* Mon Jan  5 2015 tiwai@suse.de
- ACPI / video: Add some Samsung models to
  disable_native_backlight list (boo#905681).
- commit 6c84285
* Mon Jan  5 2015 jdelvare@suse.de
- asus-nb-wmi: Add another wapf=4 quirk (boo#911438).
- asus-nb-wmi: Add wapf4 quirk for the X550VB (boo#911438).
- asus-nb-wmi: Add wapf4 quirk for the U32U (boo#911438).
- asus-nb-wmi: Add wapf4 quirk for the X550CC (boo#911438).
- asus-nb-wmi: Constify asus_quirks DMI table (boo#911438).
- asus-nb-wmi: Add wapf4 quirk for the X550CL (boo#911438).
- asus-nb-wmi.c: Rename x401u quirk to wapf4 (boo#911438).
- asus-nb-wmi: Add ASUSTeK COMPUTER INC. X200CA (boo#911438).
- WAPF 4 for ASUSTeK COMPUTER INC. X75VBP WLAN ON (boo#911438).
- commit ff74a34
* Sat Jan  3 2015 tiwai@suse.de
- Input: synaptics - gate forcepad support by DMI check
  (bnc#911578).
- commit 6749a22
* Wed Dec 17 2014 jack@suse.cz
- ext4: introduce aging to extent status tree (bnc#893428).
- ext4: cleanup flag definitions for extent status tree
  (bnc#893428).
- ext4: limit number of scanned extents in status tree shrinker
  (bnc#893428).
- ext4: move handling of list of shrinkable inodes into extent
  status code (bnc#893428).
- ext4: change LRU to round-robin in extent status tree shrinker
  (bnc#893428).
- ext4: cache extent hole in extent status tree for
  ext4_da_map_blocks() (bnc#893428).
- ext4: fix block reservation for bigalloc filesystems
  (bnc#893428).
- ext4: track extent status tree shrinker delay statictics
  (bnc#893428).
- ext4: improve extents status tree trace point (bnc#893428).
- commit 99d827e
* Wed Dec 17 2014 bp@suse.de
- x86/tls: Validate TLS entries to protect espfix
  (bsc#909077,CVE-2014-8133).
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#907818,CVE-2014-9090).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- x86_64, traps: Stop using IST for #SS (bsc#907818,
  CVE-2014-9090, CVE-2014-9322).
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh patches.xen/xen3-patch-2.6.31.
- commit 762f27a
* Tue Dec 16 2014 tiwai@suse.de
- parport: parport_pc, do not remove parent devices early
  (bnc#856659).
- commit 09edb4e
* Mon Dec 15 2014 jack@suse.cz
- reiserfs: destroy allocated commit workqueue.
- commit 46da3bf
* Sun Dec 14 2014 tiwai@suse.de
- blk-mq: Fix uninitialized kobject at CPU hotplugging
  (bnc#908794).
- commit f0adeec
* Thu Dec 11 2014 dchang@suse.com
- ax88179_178a: fix bonding failure (bsc#908253).
- commit 4643cc3
* Sun Dec  7 2014 bpoirier@suse.de
- net: sctp: fix remote memory pressure from excessive queueing
  (bnc#902351 CVE-2014-3688).
- commit a77c407
* Sat Dec  6 2014 tiwai@suse.de
- ALSA: usb-audio: Don't resubmit pending URBs at MIDI error
  recovery.
- commit 06e8b4e
* Fri Dec  5 2014 tiwai@suse.de
- drm/i915: Keep vblank interrupts enabled while
  enabling/disabling planes (bnc#904097).
- commit 6ba27fb
* Fri Dec  5 2014 tiwai@suse.de
- drm: Implement O_NONBLOCK support on /dev/dri/cardN
  (bnc#904097).
- commit 15eeb8b
* Fri Dec  5 2014 tiwai@suse.de
- KEYS: Fix stale key registration at error path (bnc#908163).
- commit bf7d9a8
* Fri Dec  5 2014 bpoirier@suse.de
- net: sctp: fix panic on duplicate ASCONF chunks (bnc#902349
  CVE-2014-3687).
- commit 3407ac4
* Wed Dec  3 2014 dsterba@suse.cz
- btrfs: fix lockups from btrfs_clear_path_blocking.
- Btrfs: fix kfree on list_head in btrfs_lookup_csums_range
  error cleanup.
- Btrfs: fix race that makes btrfs_lookup_extent_info miss skinny
  extent items.
- Btrfs: fix invalid leaf slot access in btrfs_lookup_extent().
- Btrfs: send, don't delay dir move if there's a new parent inode.
- Btrfs: fix crash of btrfs_release_extent_buffer_page.
- btrfs: Fix the wrong condition judgment about subset extent map.
- btrfs: Fix and enhance merge_extent_mapping() to insert best
  fitted extent map.
- commit 1e10ffa
* Mon Dec  1 2014 tiwai@suse.de
- drm/radeon: add locking around atombios scratch space usage
  (bnc#904932).
- drm/radeon: fix endian swapping in vbios fetch for tdp table
  (bnc#904932).
- drm/radeon: add missing crtc unlock when setting up the MC
  (bnc#904932).
- drm/radeon: use gart for DMA IB tests (bnc#904932).
- drm/radeon: make sure mode init is complete in bandwidth_update
  (bnc#904932).
- drm/radeon: set correct CE ram size for CIK (bnc#904932).
- drm/radeon: Use drm_malloc_ab instead of kmalloc_array
  (bnc#904932).
- drm/radeon/dpm: disable ulv support on SI (bnc#904932).
- drm/radeon: use gart memory for DMA ring tests (bnc#904932).
- drm/radeon: fix speaker allocation setup (bnc#904932).
- drm/radeon: initialize sadb to NULL in the audio code
  (bnc#904932).
- commit b834837
* Thu Nov 27 2014 tiwai@suse.de
- Refresh tags in patches.drivers/Input-synaptics-add-min-max-quirk-for-Lenovo-T440s
- commit 6308ab8
* Thu Nov 27 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB of disk space also on 32bit POWER
- commit 33a282b
* Wed Nov 26 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB disk space on POWER
  A debuginfo build currently requires about 8.5 GB on POWER. Also,
  require at least 8 CPUs, so that builds do not get accidentally
  scheduled on slow machines.
- commit 596d9cf
* Tue Nov 25 2014 tiwai@suse.de
- drm/radeon: report disconnected for LVDS/eDP with PX if ddc
  fails (bnc#904417).
- commit 11d32cc
* Tue Nov 25 2014 mmarek@suse.cz
- tags.sh: Fixup regex definition for etags.
- scripts/tags.sh: fix DEFINE_HASHTABLE in emacs case.
- scripts/tags.sh: Don't specify kind-spec for emacs' ctags/etags.
- commit f5019fd
* Tue Nov 25 2014 neilb@suse.de
- KEYS: request_key() should reget expired keys rather than give
  EKEYEXPIRED (bnc#904717).
- KEYS: Simplify KEYRING_SEARCH_{NO,DO}_STATE_CHECK flags
  (bnc#904717).
- KEYS: Fix the size of the key description passed to/from
  userspace (bnc#904717).
- KEYS: Increase root_maxkeys and root_maxbytes sizes
  (bnc#904717).
- KEYS: Allow special keys (eg. DNS results) to be invalidated
  by CAP_SYS_ADMIN (bnc#904717).
- commit b26a99a
* Mon Nov 17 2014 oneukum@suse.de
- ttusb-dec: buffer overflow in ioctl (bnc#905739).
- commit 6c0cda9
* Sat Nov 15 2014 bpoirier@suse.de
- net: sctp: fix skb_over_panic when receiving malformed ASCONF
  chunks (bnc#902346 CVE-2014-3673).
- commit f802e13
* Fri Nov 14 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide name-version-release for kgraft
  packages (bnc#901925)
- commit c9157ee
* Fri Nov 14 2014 dsterba@suse.cz
- btrfs: fix wrong accounting of raid1 data profile in statfs.
- commit 99176ab
* Thu Nov 13 2014 tiwai@suse.de
- hp_accel: Add support for HP ZBook 15 (bnc#905329).
- commit b5646aa
* Thu Nov 13 2014 jbohac@suse.cz
- net: sctp: fix NULL pointer dereference in af->from_addr_param
  on (bnc#905100, CVE-2014-7841).
- commit 842c87a
* Thu Nov 13 2014 tiwai@suse.de
- ALSA: hda - Add mute LED control for Lenovo Ideapad Z560
  (bnc#665315).
- commit 71b7661
* Wed Nov 12 2014 tiwai@suse.de
- ALSA: hda/realtek - Change EAPD to verb control (bnc#905068).
- ALSA: hda/realtek - Restore default value for ALC668
  (bnc#905068).
- ALSA: hda/realtek - Update Initial AMP for EAPD control
  (bnc#905068).
- ALSA: hda/realtek - Update restore default value for ALC283
  (bnc#905068).
- ALSA: hda/realtek - Update restore default value for ALC282
  (bnc#905068).
- ALSA: hda/realtek - Use tables for batch COEF writes/updtes
  (bnc#905068).
- ALSA: hda/realtek - Add alc_update_coef*_idx() helper
  (bnc#905068).
- ALSA: hda/realtek - Use alc_write_coef_idx() in
  alc269_quanta_automake() (bnc#905068).
- ALSA: hda/realtek - Optimize alc888_coef_init() (bnc#905068).
- commit 99f7ba8
* Mon Nov 10 2014 bp@suse.de
- tracing/syscalls: Ignore numbers outside NR_syscalls' range
  (bsc#904013, CVE-2014-7826).
- commit 8c53623
* Mon Nov 10 2014 tiwai@suse.de
- drm/nv50/disp: fix dpms regression on certain boards
  (bnc#902728).
- commit b22ee37
* Sun Nov  9 2014 tiwai@suse.de
- [media] media: usb: uvc: add a quirk for Dell XPS M1330 webcam
  (bnc#904539).
- commit b648071
* Fri Nov  7 2014 tiwai@suse.de
- quirk for Lenovo Yoga 3: no rfkill switch (bnc#904289).
- ideapad-laptop: Change Lenovo Yoga 2 series rfkill handling
  (bnc#904289).
- commit dc3f10c
* Fri Nov  7 2014 tiwai@suse.de
- iwlwifi: dvm: drop non VO frames when flushing (bnc#900786).
- commit 1859cd7
* Fri Nov  7 2014 tiwai@suse.de
- Input: synaptics - add min/max quirk for Lenovo T440s
  (bnc#903748).
- commit 495c4f9
* Wed Nov  5 2014 mhocko@suse.cz
- drm/tilcdc: Fix the error path in tilcdc_load() (bko#86071).
- commit bc5366c
* Wed Nov  5 2014 tiwai@suse.de
- Delete patches.rpmify/chipidea-clean-up-dependencies (bnc#903986)
- commit 48f37e1
* Wed Nov  5 2014 tiwai@suse.de
- [media] uvc: Fix destruction order in uvc_delete() (bnc#897736).
- commit 4459eca
* Sun Nov  2 2014 agraf@suse.de
- Limit xgbe a0 driver to arm64
- commit 7f242a3
* Thu Oct 30 2014 jslaby@suse.cz
- Linux 3.16.7.
- commit dfcb69e
* Thu Oct 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix including the secure boot cert in /etc/uefi/certs
- commit 72255c9
* Wed Oct 29 2014 jslaby@suse.cz
- Input: i8042 - also set the firmware id for MUXed ports
  (bnc#897112).
- commit 2b88256
* Wed Oct 29 2014 jslaby@suse.cz
- Refresh patches.fixes/input-add-acer-aspire-5710-to-nomux.patch.
  Fix patch-mainline.
- commit 0a83ce3
* Wed Oct 29 2014 jslaby@suse.cz
- Input: psmouse - add support for detecting FocalTech PS/2
  touchpads (bnc#897112).
- Input: psmouse - add psmouse_matches_pnp_id helper function
  (bnc#897112).
- commit 3616094
* Tue Oct 28 2014 agraf@suse.de
- Backport proper arm64 support:
  - usb: Add support for Synopsis H20AHB EHCI host controller
    (bnc#902632).
  - usb: fix hcd h20ahb driver depends (bnc#902632).
  - cpufreq: arm_big_little: fix module license spec (bnc#902632).
  - ahci: Check and set 64-bit DMA mask for platform AHCI driver
    (bnc#902632).
  - rtc: ia64: allow other architectures to use EFI RTC
    (bnc#902632).
  - arm64: fix VTTBR_BADDR_MASK (bnc#902632).
  - KVM: ARM: Add "arm,gic-400" compatible support (bnc#902632).
  - net/xgbe: Add A0 silicon support (bnc#902632).
  - KVM: ARM: Hack to enable VGIC mapping on 64k PAGE_SIZE kernels
    (bnc#902633).
  - ARM: Add APM Mustang network driver (bnc#902632).
  - ahci_xgene: Skip the PHY and clock initialization if already
    configured by the firmware (bnc#902632).
  - arm64: adjust el0_sync so that a function can be called
    (bnc#902632).
  - arm/arm64: KVM: Fix and refactor unmap_range (bnc#902632).
  - arm64: fpsimd: fix a typo in fpsimd_save_partial_state ENDPROC
    (bnc#902632).
  - arm64: fix bug for reloading FPSIMD state after cpu power off
    (bnc#902632).
  - ahci/xgene: Remove logic to set 64-bit DMA mask (bnc#902632).
  - arm64: dts: Add X-Gene reboot driver dts node (bnc#902632).
  - power: reset: Add generic SYSCON register mapped reset
    (bnc#902632).
  - arm64: Select reboot driver for X-Gene platform (bnc#902632).
  - power: reset: Remove X-Gene reboot driver (bnc#902632).
  - irqchip: gic: preserve gic V2 bypass bits in cpu ctrl register
    (bnc#902632).
  - arm64/efi: efistub: cover entire static mem footprint in
    PE/COFF .text (bnc#902632).
  - arm64/efi: efistub: don't abort if base of DRAM is occupied
    (bnc#902632).
  - asm-generic/io.h: Fix ioport_map() for !CONFIG_GENERIC_IOMAP
    (bnc#902632).
  - of/pci: Add pci_register_io_range() and pci_pio_to_address()
    (bnc#902632).
  - ARM: Define PCI_IOBASE as the base of virtual PCI IO space
    (bnc#902632).
  - of/pci: Move of_pci_range_to_resource() to of/address.c
    (bnc#902632).
  - of/pci: Fix the conversion of IO ranges into IO resources
    (bnc#902632).
  - PCI: Add generic domain handling (bnc#902632).
  - of/pci: Add pci_get_new_domain_nr() and of_get_pci_domain_nr()
    (bnc#902632).
  - of/pci: Add support for parsing PCI host bridge resources from
    DT (bnc#902632).
  - PCI: Add pci_remap_iospace() to map bus I/O resources
    (bnc#902632).
  - arm64: Add architectural support for PCI (bnc#902632).
  - PCI: xgene: Add APM X-Gene PCIe driver (bnc#902632).
  - arm64: Do not call enable PCI resources when specify
    PCI_PROBE_ONLY (bnc#902632).
  - drivers/net/fddi/skfp/h/skfbi.h: Remove useless PCI_BASE_2ND
    macros (bnc#902632).
  - arm64/mustang: Disable sgenet and xgenet (bnc#902632).
  - Update config files.
  - Refresh patches.xen/xen-x86-EFI.
- commit 6c383ae
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv7hl: Disable CONFIG_USB_MUSB_TUSB6010 (bnc#906914)
  TUSB6010 is not used by any of our JeOSes*, but introduces issues
  with USB on BeagleBone (and all other boards utilizing musb_hdrc).
  The way to resolve the issues is currently unknown, so temporarily
  disable it.
  See for details: http://marc.info/?l=linux-usb&m=141088564307331&w=2
- commit f0b1c10
* Thu Oct 23 2014 dmueller@suse.com
- Disable Exynos cpufreq modules
  They seem to be printing tons of warnings that
  they can't set anything, so we can as well remove
  them for now.
- commit d5441c7
* Mon Oct 20 2014 agraf@suse.de
- Delete patches.arch/cubox-configuration.patch.
  - cubox should be used via device tree now
- commit feb42ea
* Mon Oct 20 2014 agraf@suse.de
- arm64/crypto: fix makefile rule for aes-glue-%%.o.
- commit 3dd5f2c
* Mon Oct 20 2014 agraf@suse.de
- config: ARM: Backport 3.17 config changes to 3.16
- commit a532a40
* Mon Oct 20 2014 tiwai@suse.de
- firmware loader: allow disabling of udev as firmware loader
  (bnc#901767).
- Update config files.
- commit cc3f8b9
* Thu Oct 16 2014 jbeulich@suse.com
- Update Xen patches to 3.16.6 and c/s 1266.
- commit cfbe55c
* Thu Oct 16 2014 dsterba@suse.cz
- Delete patches.suse/btrfs-0027-race-free-update-of-commit-root-for-ro-snapsho.patch.
  Reverted upstream.
- commit a549afb
* Thu Oct 16 2014 jack@suse.cz
- Removing RICHACL support since it never went upstream and noone seems
  to really care (bnc#892834)
- Refresh patches.suse/ovl01-vfs-add-i_op-dentry_open.patch.
- Delete
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- Delete
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch.
- Delete
  patches.suse/0003-vfs-Add-IS_RICHACL-test-for-richacl-support.patch.
- Delete
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch.
- Delete
  patches.suse/0005-richacl-Permission-mapping-functions.patch.
- Delete
  patches.suse/0006-richacl-Compute-maximum-file-masks-from-an-acl.patch.
- Delete
  patches.suse/0007-richacl-Update-the-file-masks-in-chmod.patch.
- Delete
  patches.suse/0008-richacl-Permission-check-algorithm.patch.
- Delete
  patches.suse/0009-richacl-Helper-functions-for-implementing-richacl-in.patch.
- Delete patches.suse/0010-richacl-Create-time-inheritance.patch.
- Delete
  patches.suse/0011-richacl-Check-if-an-acl-is-equivalent-to-a-file-mode.patch.
- Delete patches.suse/0012-richacl-Automatic-Inheritance.patch.
- Delete
  patches.suse/0013-richacl-Restrict-access-check-algorithm.patch.
- Delete patches.suse/0014-richacl-xattr-mapping-functions.patch.
- Delete
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch.
- commit d98bee0
* Wed Oct 15 2014 jslaby@suse.cz
- Linux 3.16.6.
- commit 3d7c857
* Sat Oct 11 2014 dsterba@suse.cz
- Btrfs: set inode's logged_trans/last_log_commit after ranged
  fsync.
- Btrfs: use insert_inode_locked4 for inode creation.
- Btrfs: fix fsync data loss after a ranged fsync.
- Btrfs: kfree()ing ERR_PTRs.
- Btrfs: fix crash while doing a ranged fsync.
- Btrfs: fix corruption after write/fsync failure + fsync +
  log recovery.
- Btrfs: fix autodefrag with compression.
- btrfs: fix leak in qgroup_subtree_accounting() error path.
- btrfs: Use right extent length when inserting overlap extent
  map.
- Btrfs: clone, don't create invalid hole extent map.
- Btrfs: fix hole detection during file fsync.
- Btrfs: race free update of commit root for ro snapshots.
- Btrfs: fix regression of btrfs device replace.
- Btrfs: don't consider the missing device when allocating
  new chunks.
- Btrfs: Fix wrong device size when we are resizing the device.
- Btrfs: don't write any data into a readonly device when scrub.
- Btrfs: Fix the problem that the replace destroys the seed
  filesystem.
- Btrfs: fix wrong missing device counter decrease.
- Btrfs: fix unzeroed members in fs_devices when creating a fs
  from seed fs.
- Btrfs: fix put dio bio twice when we submit dio bio fail.
- btrfs: correctly handle return from ulist_add.
- btrfs: qgroup: account shared subtrees during snapshot delete.
- Btrfs: __btrfs_mod_ref should always use no_quota.
- btrfs: adjust statfs calculations according to raid profiles.
- commit 6e97eef
* Fri Oct 10 2014 jack@suse.cz
- xfs: mark all internal workqueues as freezable (bnc#899785).
- commit c082ec8
* Fri Oct 10 2014 jslaby@suse.cz
- rpm/config.sh: build against 13.2 update
- commit a1906f8
* Fri Oct 10 2014 jslaby@suse.cz
- README.BRANCH: make it to correspond to 13.2
- commit 73c5928
* Fri Oct 10 2014 jslaby@suse.cz
- Linux 3.16.5.
- commit 232dc6e
* Thu Oct  9 2014 jeffm@suse.com
- block: copy bi_vcnt in __bio_clone_fast (boo#888259).
- commit c95271b
* Mon Oct  6 2014 jslaby@suse.cz
- Linux 3.16.4.
- commit 7a8842b
* Wed Sep 17 2014 jslaby@suse.cz
- Linux 3.16.3 (bnc#890096).
- Delete
  patches.fixes/reiserfs-fix-corruption-introduced-by-balance_leaf-refactor.
- Delete patches.fixes/rtsx_usb-export-device-table.
- Update config files.
  Set CONFIG_SMS_SIANO_DEBUGFS=n as it is in master.
- commit d2bbe7f
* Wed Sep 17 2014 jeffm@suse.com
- blk-merge: fix blk_recount_segments (bnc#888259).
- commit 5fca623
* Mon Sep  8 2014 agraf@suse.de
- kernel-obs-build: Force load kernel modules
  - fixes QEMU kiwi builds
- commit 3ef8771
* Mon Sep  8 2014 agraf@suse.de
- rpm/kernel-obs-build.spec.in: Enable 32bit ARM builds
- commit 7aad1ad
* Sun Sep  7 2014 jslaby@suse.cz
- Linux 3.16.2 (bko#81111 bnc#887046 bnc#889790).
- Update config files.
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen-x86-bzImage.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.37.
- Delete
  patches.fixes/Btrfs-Fix-memory-corruption-by-ulist_add_merge-on-32.
- Delete patches.fixes/drm-omapdrm-fix-compiler-errors.
- Delete
  patches.fixes/nfs-nfs3_list_one_acl-check-get_acl-result-with-is_err_or_null.
- Delete
  patches.suse/btrfs-0003-read-lock-extent-buffer-while-walking-backrefs.patch.
- Delete
  patches.suse/btrfs-0006-fix-compressed-write-corruption-on-enospc.patch.
- Delete
  patches.suse/btrfs-0008-fix-csum-tree-corruption-duplicate-and-outdate.patch.
- Delete
  patches.suse/btrfs-0033-fix-task-hang-under-heavy-compressed-write.patch.
- commit dcee397
* Sat Sep  6 2014 dmueller@suse.com
- config: armv7hl/lpae: Reenable support for Hugepages
  This was apparently accidentally disabled, but we need
  hugepages support for improved performance and stability
  of the KVM build workers.
- commit 9cd3bb7
* Fri Sep  5 2014 agraf@suse.de
- rpm/kernel-binary.spec.in: Always build zImage for ARM
- commit 828cca8
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Create a kernel-macros package with the KMP macros
  This package does not have multiversion(kernel) and is not built in the
  - rt tree (bnc#867595).
- commit 9b6a6fe
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install doc files in a versioned directory (bnc#867595)
- commit deb25bc
* Wed Aug 27 2014 mmarek@suse.cz
- rpm/config.sh Use the same repository setup as the master branch
- commit 90bc0f1
* Tue Aug 26 2014 jslaby@suse.cz
- rpm/config.sh: build against factory
- commit 768ed24
* Tue Aug 26 2014 dsterba@suse.cz
- Btrfs stable updates.
  Pending or future 3.16.y fixes
- Btrfs: read lock extent buffer while walking backrefs.
- Btrfs: fix compressed write corruption on enospc.
- Btrfs: fix csum tree corruption, duplicate and outdated
  checksums.
- Btrfs: fill_holes: Fix slot number passed to hole_mergeable()
  call.
- Btrfs: fix wrong write range for filemap_fdatawrite_range().
- Btrfs: fix wrong extent mapping for DirectIO.
- btrfs: Return right extent when fiemap gives unaligned offset
  and len.
- Btrfs: ensure tmpfile inode is always persisted with link
  count of 0.
- Btrfs: don't monopolize a core when evicting inode.
- Btrfs: fix task hang under heavy compressed write.
- Refresh
  patches.fixes/Btrfs-Fix-memory-corruption-by-ulist_add_merge-on-32.
- commit c40eb71
* Thu Aug 21 2014 tiwai@suse.de
- Btrfs: Fix memory corruption by ulist_add_merge() on 32bit arch
  (bnc#887046).
- commit b1e2a41
* Thu Aug 21 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix the version variables in the generated
  Makefile (bnc#892973)
- commit 8331f47
* Wed Aug 20 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Do not duplicate the job of brp-99-compress-vmlinux
- commit e561498
* Wed Aug 20 2014 afaerber@suse.de
- config: arm64: Enable RTC_DRV_HID_SENSOR_TIME
  For consistency across ARM configs.
  This drags in IIO. For consistency, in turn use:
  CONFIG_IIO_SIMPLE_DUMMY=m
  CONFIG_HID_SENSOR_IIO_TRIGGER=m
  CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
  CONFIG_IIO_INTERRUPT_TRIGGER=m
  CONFIG_IIO_SYSFS_TRIGGER=m
  CONFIG_IIO_BUFFER=y
  CONFIG_IIO_KFIFO_BUF=m
  CONFIG_HID_SENSOR_*=m
- commit 7a6e5f7
* Wed Aug 20 2014 afaerber@suse.de
- config: armv6hl: Re-enable DWC2 USB support
  The config update/cleanup for v3.16-rc3 mistakenly disabled USB_DWC2,
  which is needed for the Raspberry Pi.
  Fixes: d2f49e165ca3 ("config: armv6hl: Update config for 3.16-rc3")
- commit cc9f241
* Wed Aug 20 2014 afaerber@suse.de
- config: ARM: Change RTC drivers to built-in
  Consistently do not build RTC drivers as modules. This fixes subtle
  differences between armv7hl default and lpae flavors and avoids any
  timing-related driver initialization issues.
  To make RTC_DRV_88PM80X built-in, make MFD_88PM800 built-in, too.
  To make RTC_DRV_PM8XXX built-in, make MFD_PM8921_CORE built-in, too.
- commit cf526c8
* Mon Aug 18 2014 mmarek@suse.cz
- rpm/config.sh: Drop the ARM repo, it is covered by the ports repo
- commit 84ffa90
* Mon Aug 18 2014 schwab@suse.de
- rpm/kernel-binary.spec.in: Fix missing quotes around %%build_flavor
  %%build_flavor can be an arbitrary string, so it needs to be quoted for
  string comparison.
- commit 0134440
* Mon Aug 18 2014 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in: Use dracut for SLE12
- commit ec64eaf
* Mon Aug 18 2014 afaerber@suse.de
- config: armv6hl: Enable DMA_BCM2835
  Only bcm2835 option missing.
- commit 1fd2cdd
* Mon Aug 18 2014 afaerber@suse.de
- config: armv7hl: Enable DWMAC_SUNXI for lpae flavor as well
  Without this, the Cubietruck has no network in LPAE mode.
- commit 4f16280
* Sun Aug 17 2014 jslaby@suse.cz
- Linux 3.16.1.
- commit 9353bcb
* Wed Aug 13 2014 tiwai@suse.de
- Revert "config: armv7hl: Disable OMAP DRM"
  This reverts commit f92487dbd7a305531e4cc54c41609b8f77a1bc30.
  The previous commit should fix the build error of omapdrm.
- commit 07174c1
* Wed Aug 13 2014 tiwai@suse.de
- drm: omapdrm: fix compiler errors.
- commit ee3abc8
* Wed Aug 13 2014 afaerber@suse.de
- config: armv7hl: Disable OMAP DRM
  To avoid errors such as:
  ../drivers/gpu/drm/omapdrm/omap_plane.c: In function 'omap_plane_pre_apply':
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 5 has type 'dma_addr_t' [-Werror=format=]
    DBG("%%d,%%d %%08x %%08x", info->pos_x, info->pos_y,
    ^
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 6 has type 'dma_addr_t' [-Werror=format=]
  cc1: all warnings being treated as errors
  disable OMAP DRM for now.
  Two patches were sent upstream by Matwey V. Kornilov but didn't find
  their way into v3.16. Once patches are applied, revert this commit.
- commit f92487d
* Wed Aug 13 2014 afaerber@suse.de
- config: arm64: Disable ARM64 crypto extensions
  To avoid build errors such as:
  ld: cannot find arch/arm64/crypto/aes-glue-ce.o: No such file or directory
  ../scripts/Makefile.build:411: recipe for target 'arch/arm64/crypto/aes-ce-blk.o' failed
  disable support for ARM64 crypto extensions for now.
  A patch was submitted upstream by Andreas Schwab but didn't make it into
  v3.16. Once that is available, this commit should be reverted.
- commit 5f99cfd
* Tue Aug 12 2014 schwab@suse.de
- config: arm64/default: make rtc-pl03[01] built-in
- commit 1b1d9da
* Fri Aug  8 2014 jeffm@suse.com
- rtsx_usb: export device table (bnc#890096).
- commit a29135e
* Fri Aug  8 2014 tiwai@suse.de
- Delete patches.drivers/drm-cirrus-Use-16bpp-as-default (bnc#890599).
- commit 820d92f
* Wed Aug  6 2014 jbeulich@suse.com
- Update Xen patches to 3.16-final.
- vscsi: support larger transfer sizes (bnc#774818).
- commit 0e31675
* Tue Aug  5 2014 jeffm@suse.com
- nfs: nfs3_list_one_acl(): check get_acl() result with
  IS_ERR_OR_NULL (bko#81111 bnc#889790).
- commit 258e3b0
* Tue Aug  5 2014 jeffm@suse.com
- nfs: nfs3_list_one_acl(): check get_acl() result with
  IS_ERR_OR_NULL (bko#81111 bnc#889790).
- commit c485b2b
* Tue Aug  5 2014 jeffm@suse.com
- reiserfs: fix corruption introduced by balance_leaf refactor.
- commit 37d2234
* Mon Aug  4 2014 jeffm@suse.com
- config: disable CONFIG_PPC_PS3 on ppc64le
  The PS3 hardware is big-endian.
- commit a9046ed
* Mon Aug  4 2014 jeffm@suse.com
- config: resync vanilla configs (no actual changes)
- commit 2821f4c
* Mon Aug  4 2014 jeffm@suse.com
- Update to 3.16.
- commit bf5b385
* Fri Aug  1 2014 jslaby@suse.cz
- Linux 3.15.8.
- Refresh patches.suse/stack-unwind.
- commit 1bbc06d
* Thu Jul 31 2014 jkosina@suse.cz
- Refresh patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: update
  upstream reference.
- commit 7690e04
* Wed Jul 30 2014 jdelvare@suse.de
- Revert "config: disable USB_UAS (bnc#888069)."
  This reverts commit f509af67eb3a98665e0134eaadb91e93420d9e04. The uas
  driver works fine since kernel v3.15, the problem was that the
  module was blacklisted so it would not load when needed.
- commit 9b5a5f0
* Wed Jul 30 2014 jbeulich@suse.com
- Update Xen patches to 3.16-rc7 and c/s 1263.
- netbk: Don't destroy the netdev until the vif is shut down
  (bnc#881008).
- commit a2720a7
* Tue Jul 29 2014 jeffm@suse.com
- config: disable USB_UAS (bnc#888069).
  uas is already blacklisted in /etc/modprobe.d/50-blacklist.conf as
  being hopelessly broken, but there are parts of usb-storage that are
  ifdef'd around it being configured at all. Let's disable it completely.
- commit f509af6
* Tue Jul 29 2014 jeffm@suse.com
- Update to 3.16-rc7.
- commit 47ebc04
* Mon Jul 28 2014 jslaby@suse.cz
- Linux 3.15.7 (bnc#879071).
- Delete
  patches.fixes/don-t-trigger-congestion-wait-on-dirty-but-not-write.patch.
- Update config files.
- commit 972d9a6
* Mon Jul 28 2014 schwab@suse.de
- config: arm64/default: increase LOG_BUF_SHIFT to 18
- commit f45208d
* Mon Jul 28 2014 lpechacek@suse.cz
- doc/README.SUSE: update Solid Driver team contacts
- commit a90946c
* Thu Jul 24 2014 jdelvare@suse.de
- Update config files: disable CONFIG_STE_MODEM_RPROC
  I was told by Dmitry Tarnyagin and Linus Walleij that there exists no
  public hardware that needs this driver, so there is no point in
  building it and shipping it.
- commit 85b815c
* Mon Jul 21 2014 jslaby@suse.cz
- Don't trigger congestion wait on dirty-but-not-writeout pages
  (bnc#879071).
- commit edc5ddf
* Mon Jul 21 2014 jeffm@suse.com
- config: sync vanilla configs
- commit a0523f2
* Mon Jul 21 2014 jeffm@suse.com
- Update to 3.16-rc6.
- Eliminated 1 patch.
- commit 2736eea
* Mon Jul 21 2014 jdelvare@suse.de
- Update armv7hl config files for 3.16-rc5
  New driver CONFIG_USB_EHCI_MSM=m.
- commit f1230bd
* Fri Jul 18 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign firmware files (bnc#867199)
- commit 38f105d
* Fri Jul 18 2014 jslaby@suse.cz
- Linux 3.15.6.
- commit fdb2dde
* Mon Jul 14 2014 jeffm@suse.de
- Update to 3.16-rc5.
- Eliminated 1 patch.
- commit e709184
* Fri Jul 11 2014 jdelvare@suse.de
- Update ppc config files: Disable ChromeOS drivers
  No Chromebook is based on PowerPC so these drivers are useless on ppc.
- commit aa23827
* Thu Jul 10 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.15.4-5 (bnc#878489 bnc#882648
  bnc#883750).
- Delete
  patches.fixes/xhci-Use-correct-SLOT-ID-when-handling-a-reset-devic.patch.
  bah, one should run sequence_patch after rebase.
- commit 01d2774
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/package-descriptions: Drop descriptions for dropped flavors
- commit aa68ae6
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/post(un).sh: Drop checks for dropped archs/flavors
- commit bd6afed
* Wed Jul  9 2014 jslaby@suse.cz
- Linux 3.15.5 (bnc#882648 bnc#883750).
- Refresh patches.xen/xen3-patch-3.6.
- Delete
  patches.drivers/drm-i915-HD-audio-Don-t-continue-probing-when-nomode.
- Delete
  patches.fixes/cifs-fix-broken-pathnames-with-mapchars.patch.
- commit b151807
* Mon Jul  7 2014 jslaby@suse.cz
- xhci: Use correct SLOT ID when handling a reset device command
  (bnc#878489).
- commit 2b59ae6
* Mon Jul  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Delete the build-id links created by vdso_install
- commit ca040af
* Mon Jul  7 2014 jeffm@suse.com
- Update to 3.16-rc4.
- commit 45467d6
* Mon Jul  7 2014 jslaby@suse.cz
- Linux 3.15.4.
- commit ca33e5b
* Sun Jul  6 2014 afaerber@suse.de
- config: armv7hl: Update configs for 3.16-rc3
  * Samsung Exynos is now in default flavor, drop exynos flavor
  * Enable Freescale/Xilinx for default flavor only
  * Enable Qualcomm/LSI for both default and lpae flavors
  * Enable Allwinner A20+ in lpae flavor, A10+ in default flavor
  * Enable Hisilicon Hi3xxx in default flavor
  * Enable Renesas RZ/A in default flavor
  * Enable big.LITTLE switcher module
  * Enable PCI for Freescale/Marvell/Nvidia/Samsung
  but keep device drivers to minimum, as known boards are mini PCIe only
  * Build in some more serial drivers for console use
  * Enable some missing USB media device driver modules
  * Disable OMAP4 V4L as it cannot be built as module (Matwey K.)
- commit ca6193e
* Sun Jul  6 2014 afaerber@suse.de
- config: arm64: Update config for 3.16-rc3
- commit 28b0756
* Sun Jul  6 2014 afaerber@suse.de
- config: armv6hl: Update config for 3.16-rc3
- commit d2f49e1
* Fri Jul  4 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_DRM_I2C_NXP_TDA998X
  Disable the TDA998x driver in all flavors where is not needed.
- commit 267d4c1
* Fri Jul  4 2014 mmarek@suse.cz
- kbuild: Do not print the build directory with make -s.
- commit 6bf8303
* Thu Jul  3 2014 jbeulich@suse.com
- Update Xen patches to 3.16-rc3 and c/s 1261.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 56ffa43
* Wed Jul  2 2014 jeffm@suse.com
- Delete
  patches.fixes/drm-msm-replace-type-of-paddr-to-uint32_t.patch.
- commit 29c1c05
* Wed Jul  2 2014 jeffm@suse.com
- Update to 3.16-rc3.
- Eliminated 1 patch.
- commit d86449f
* Tue Jul  1 2014 jdelvare@suse.de
- net: fix circular dependency in of_mdio code.
- commit 66576dd
* Tue Jul  1 2014 jdelvare@suse.de
- drm/msm: Replace type of paddr to uint32_t.
  This fixes the build on armv7l.
- commit d43d97e
* Tue Jul  1 2014 jslaby@suse.cz
- Linux 3.15.3.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- Refresh patches.xen/xen3-patch-2.6.37.
- Update config files.
- commit 42bf625
* Mon Jun 30 2014 schwab@suse.de
- rpm/kernel-obs-build.spec.in: add support for aarch64
  Use Image for kernel_name on aarch64 and add virtio_mmio to KERNEL_MODULES.
- commit 6024dc9
* Fri Jun 27 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Compress vmlinux after find-debuginfo.sh (bnc#884459)
- commit 381a192
* Fri Jun 27 2014 jslaby@suse.cz
- Linux 3.15.2.
- commit fb7c781
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Obsolete kernel-trace-base by kernel-default
  (bnc#884364)
- commit 568f3cc
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Explicitly list subpackages to obsolete
- commit 5595ce2
* Wed Jun 25 2014 jbeulich@suse.com
- patches.fixes/bridge-module-get-put.patch,
  patches.suse/stack-unwind: Update Patch-mainline tag.
- commit a0f93ad
* Tue Jun 24 2014 jeffm@suse.com
- config: disable X86_GOLDFISH
  It seems to be built-in and generates loads of messages like:
  genirq: Flags mismatch irq 4. 00000000 (serial) vs. 00000080 (goldfish_pdev_bus)
- commit 37599aa
* Tue Jun 24 2014 jeffm@suse.com
- patches.suse/stack-unwind: VSYSCALL_START replaced with VSYSCALL_ADDR.
- commit f5ee8e7
* Tue Jun 24 2014 jeffm@suse.de
- Update to 3.16-rc2.
- Config changes:
  - Generic config options:
  * RANDOMIZE_BASE=n (default n)
  - With only 9 bits of entropy on 64-bit systems, is it worthwhile?
  - System z:
  * DIAG288_WATCHDOG=m
  - New options specific to ARM (I think), all disabled:
  * I2C_RK3X (SoC)
- commit f93db59
* Tue Jun 24 2014 ddiss@suse.de
- Refresh patch-mainline tags
  patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
  patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- commit 9b8b77a
* Mon Jun 23 2014 jslaby@suse.cz
- asus-wmi: Set WAPF to 4 for Asus X550CA (bnc#882234).
- commit 7d71861
* Mon Jun 23 2014 mmarek@suse.cz
- rpm/post.sh: Also check for grub2 config
- commit 0844541
* Mon Jun 23 2014 mmarek@suse.cz
- Port ppc64le packaging fixes from 'SLE12' to 'packaging'
- commit c233eb3
* Mon Jun 23 2014 ddiss@suse.de
- fs/cifs: Fix broken pathnames with mapchars (bnc#883750).
- commit 44c0fc3
* Mon Jun 23 2014 jdelvare@suse.de
- Update config files: Enable Realtek RTL8723AU support
  This wireless network chipset is found in hybrid notebooks/tablets
  such as the first Lenovo Yoga 13.
- commit 0cf7afd
* Tue Jun 17 2014 jslaby@suse.cz
- Linux 3.15.1.
- commit fb8e7ed
* Mon Jun 16 2014 jeffm@suse.de
- Update to 3.16-rc1.
- Eliminated 10 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * UEVENT_HELPER=y (default y)
  - It should be obsolete - needs review
  * SGETMASK_SYSCALL=y/n
  - default varies by architecture, used default
  * DEBUG_PI_LIST=n (default n)
  * TRACEPOINT_BENCHMARK=n (default n)
  - Only needed if developing tracepoint infrastructure
  * TEST_BPF=n (default n)
  - New options for existing drivers:
  * QLCNIC_HWMON=y (default y)
  * ISDN_CAPI_CAPIDRV_VERBOSE=y (helpful messages, cost only in capi.ko)
  - New modules:
  * SERIAL_SC16IS7XX (i2c)
  * SENSORS_SHTC1 (i2c)
  * USB_GSPCA_DTCS033 (usb)
  * SND_BCD2000 (firewire)
  * SND_FIREWORKS (firewire)
  * SND_BEBOB (firewire)
  * HID_RMI (usb)
  * MMC_USDHI6ROL0 (usb)
  * MMC_REALTEK_USB (usb)
  * MEMSTICK_REALTEK_USB (usb)
  * R8192EE (pci)
  * INPUT_GPIO_BEEPER (generic gpio)
  * NFT_BRIDGE_META (netfilter)
  * CAN_GS_USB (USB)
  * MTD_SPI_NOR (SPI)
  * AMD_XGBE (PCI)
  - x86/x86_64:
  * DELL_SMO8800=m
  * SENSORS_NCT6683=m (found on Intel DQ87PG motherboards)
  * INTEL_SOC_DTS_THERMAL=m
  * X86_GOLDFISH=y (platform driver, used for virtual Android development)
  - KEYBOARD_GOLDFISH_EVENTS=m
  - GOLDFISH_TTY=m
  - BATTERY_GOLDFISH=m
  - MMC_GOLDFISH=m
  - GOLDFISH_AUDIO=m
  - MTD_GOLDFISH_NAND=m
  - GOLDFISH_PIPE=m
  * CRYPTO_SKEIN=n (default n)
  - staging, only available on 64-bit x86 - usefulness?)
  * CRYPTO_THREEFISH=n (same)
  * I2C_CROS_EC_TUNNEL=m (also available on ARM)
  * X86_16BIT=y (default y, required for wine, minimal runtime savings)
  - ppc64le:
  * VIRTUALIZATION=y
  - KVM_BOOK3S_64=m
  - KVM_BOOK3S_64_PR=m
  - KVM_XICS=y
  - New options specific to ARM (I think), all disabled:
  * NFC_ST21NFCA (datasheet says intended for mobile phone use)
  * USB_DWC2
  * SYSTEMPORT
  * KEYBOARD_OMAP4
  * PINCTRL_APQ8064
  * PINCTRL_IPQ8064
  * GENERIC_CPUFREQ_CPU0
  * RTC_DRV_XGENE
  * MFD_AXP20X
- commit 6ff907a
* Mon Jun 16 2014 tiwai@suse.de
- drm/i915, HD-audio: Don't continue probing when nomodeset is
  given (bnc#882648).
- commit cc07b60
* Mon Jun 16 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_8723AU_P2P
  Disable this as it is reported to be totally broken and can cause
  a kernel oops.
- commit a014268
* Fri Jun 13 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build in a subdirectory of the source tree
  So that the build can use relative paths.
- commit 8eb070a
* Tue Jun 10 2014 jbeulich@suse.com
- swiotlb: don't assume PA 0 is invalid (bnc#865882).
- Update Xen patches to 3.15 final.
- Update x86-64 Xen config files.
- commit 0a9fc1a
* Tue Jun 10 2014 jslaby@suse.cz
- Update config files.
  Disable the reverted CONFIG_ACPI_PROCFS_POWER. Nobody seems to
  complain, so do not enable it.
- commit 0592a75
* Tue Jun 10 2014 jslaby@suse.cz
- Linux 3.14.6 (bnc#880613).
- Delete
  patches.drivers/ALSA-hda-Fix-onboard-audio-on-Intel-H97-Z97-chipsets.
- commit f0d0e23
* Mon Jun  9 2014 jeffm@suse.de
- Update to 3.15.
- commit 91a9a36
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/package-descriptions: kernel-vmi is gone
- rpm/mkspec: Obsolete $flavor-{devel,extra} $flavor-base is obsolete
  (bnc#881490)
- rpm/kernel-module-subpackage: Obsolete -trace KMPs (bnc#881490)
- rpm/old-flavors: Obsolete also kernel-trace-base (bnc#881490)
- commit 38d4d09
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require hmaccalc on 13.1 and earlier
- commit d7a84f7
* Wed Jun  4 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Allow find-debuginfo.sh to create vmlinux.debug
- commit 9b3c48f
* Wed Jun  4 2014 jslaby@suse.cz
- Linux 3.14.5.
- commit 3ee48e0
* Mon Jun  2 2014 tiwai@suse.de
- usb: musb: tusb6010: Use musb->tusb_revision instead of
  tusb_get_revision call (bnc#872715).
- usb: musb: tusb6010: Add tusb_revision to struct musb to store
  the revision (bnc#872715).
- commit 6141be1
* Mon Jun  2 2014 jeffm@suse.de
- Update to 3.15-rc8.
- commit 93f605c
* Mon Jun  2 2014 mmarek@suse.cz
- Obsolete kernel-trace by kernel-default
- commit 1eb3f59
* Mon Jun  2 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_XO15_EBOOK
  The xo15-ebook driver is useless without the rest of OLPC support. So
  I left it enabled only in i386/default and i386/vanilla.
- commit 9694fd3
* Fri May 30 2014 tiwai@suse.de
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  (bnc#880613).
- commit 0de0f93
* Wed May 28 2014 jdelvare@suse.de
- Update config files: Disable gpio-fan and ntc_thermistor drivers
  Disable the gpio-fan and ntc_thermistor hwmon drivers on all
  architectures where they are not used.
- commit 96f5b60
* Wed May 28 2014 jbeulich@suse.com
- Update Xen patches to 3.15-rc7.
- commit f8382bf
* Tue May 27 2014 jeffm@suse.de
- Update to 3.15-rc7.
- Eliminated 1 patch.
- Config changes:
  - CX_ECAT=m (default n) for i386/x86_64
  - The vendor supplying this hardware only uses 32/64-bit Atom CPUs.
    This may need to be revisited if the hardware extends to different
    architectures (ARM, probably).
  - SENSORS_NTC_THERMISTOR=m (default n)
  - Sensor chip that could be found essentially anywhere.
- commit e9c45a3
* Mon May 26 2014 ddiss@suse.de
- cifs: fix client guid reuse logic
  Client guid reuse across multiple protocol versions causes mount
  failures against Windows 2012 servers (bnc#879932).
- patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
- commit 289f0e9
* Fri May 23 2014 jeffm@suse.de
- config: sync vanilla configs for 3.15-rc6.
- commit acf7dab
* Fri May 23 2014 jeffm@suse.de
- Update to 3.15-rc6.
- Config changes:
  - ACPI_PROCFS_POWER=y (default n)
  - Should eventually be =n once userspace tools have been audited.
- commit d2be7e3
* Fri May 23 2014 jdelvare@suse.de
- Update ppc config files: Disable SH_MOBILE media drivers
  These are useless on PowerPC.
- commit cacd723
* Fri May 23 2014 ddiss@suse.de
- Update config files: enable CONFIG_CIFS_SMB2
  cifs.ko is currently built with support for the base SMB1/CIFS dialect
  only. SMB1/CIFS support can be disabled in Windows 8.1 and Windows
  Server 2012 R2, and is completely unsupported with the Microsoft Azure
  File service, leaving cifs.ko users unable to access files on such
  servers without this change (fate#317480).
- commit 837860b
* Fri May 23 2014 jdelvare@suse.de
- Update config files: Disable remaining R-CAR drivers
  These drivers are useless except on arm/shmobile.
- commit 2dd69e8
* Wed May 21 2014 jdelvare@suse.de
- Fix a typo in config/ppc/vanilla, sorry
- commit cc68f12
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable unused RTC platform drivers
- commit 85c0b8b
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable the rtc-moxart driver
  This driver is only needed on Moxa ART systems, which we do not
  support.
- commit 9939e8f
* Tue May 20 2014 jbeulich@suse.com
- supported.conf: Take care of a few driver renames/splits/etc.
- commit ed5e591
* Tue May 20 2014 jbeulich@suse.com
- Update Xen config files: Set compatibility level back to 4.1
  (bnc#851338).
- commit 22da852
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/default config file: CONFIG_DRM_PTN3460=y
  Align on what exynos has, in anticipation of both files being
  merged someday.
- commit 8ba853c
* Mon May 19 2014 jdelvare@suse.de
- Update config files: Disable DRM_PTN3460
  Currently it's only needed on arm/exynos.
- commit 6f380e7
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/exynos config file: CONFIG_DRM_PTN3460=y
  DRM_EXYNOS_DP depends on DRM_PTN3460, and we have the former built-in,
  so the latter must be built-in as well. Otherwise we get a linker
  failure like:
  .../linux-3.15-rc5/drivers/gpu/drm/exynos/exynos_dp_core.c:1004:
  undefined reference to `ptn3460_init'
- commit bb0a6e6
* Fri May 16 2014 jdelvare@suse.de
- Update config files: Disable all EG20T drivers except on i386
  EG20T (aka Topcliff PCH) is a chipset for 32-bit x86 processors, so
  we only need these drivers on i386.
- commit 923c7d2
* Fri May 16 2014 mhocko@suse.cz
- memcg: fix swapcache charge from kernel thread context (bnc#878306).
- commit 8eaaed7
* Fri May 16 2014 jdelvare@suse.de
- Update arm64 config file to fix the build
- commit beb76a8
* Fri May 16 2014 afaerber@suse.de
- config: armv6hl: Update config to 3.15-rc5
- commit 15546e3
* Fri May 16 2014 afaerber@suse.de
- config: armv7hl: Update configs to 3.15-rc5
- commit de0d16f
* Thu May 15 2014 jdelvare@suse.de
- Update armv7hl/lpae config file: Enable SERIAL_TEGRA
  Despite what the Kconfig text says, the serial-tegra driver works on
  all Tegra platforms.
- commit 222a09f
* Thu May 15 2014 jdelvare@suse.de
- Update ppc64le config files: Disable DA903x support completely
  It makes no sense to support some sub-drivers and not the rest.
- commit 269e033
* Thu May 15 2014 duwe@suse.de
- Update config files:
  i386/x86_64/ppc64/ppc64le disable:
  timeriomem-rng
  pwm-pca9685
  unsupported RTC drivers
  ssd1307fb/da903x_bl
- commit 7725871
* Wed May 14 2014 afaerber@suse.de
- config: arm64: Update config for 3.15
- commit 2d96bf1
* Wed May 14 2014 jbeulich@suse.com
- Update Xen patches to 3.15-rc5.
- privcmd: actually batch hypercalls for batch ioctls.
- Refresh patches.xen/xen-blkfront-indirect (bnc#876786).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 9ebd57d
* Wed May 14 2014 jbeulich@suse.com
- Refresh patches.suse/stack-unwind (dump_trace_unwind() can be static).
- commit 47a05b6
* Tue May 13 2014 jdelvare@suse.de
- Update ec2 config files: Disable CAN support
  It was enabled by accident.
- commit 4f49dd9
* Tue May 13 2014 jslaby@suse.cz
- Linux 3.14.4 (bnc#871252 bnc#875690 CVE-2014-0196).
- Refresh patches.xen/xen-pcpu.
- Delete
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
- commit bebeb6f
* Tue May 13 2014 jbeulich@suse.com
- patches.suse/stack-unwind: Drop bogus (redundant) asmlinkage from
  unwind_init_running() definition.
- commit d2673c3
* Mon May 12 2014 tiwai@suse.de
- pvpanic: Set high notifier priority (bnc#875220).
- commit da0842c
* Mon May 12 2014 tiwai@suse.de
- fbcon: Clean up fbcon data in fb_info on FB_EVENT_FB_UNBIND
  with 0 fbs (bnc#875687).
- commit b8d699a
* Mon May 12 2014 jeffm@suse.de
- Update to 3.15-rc5.
- Eliminated 2 patches.
- Config changes:
  - CAN_C_CAN_STRICT_FRAME_ORDERING=n (default)
- commit 7f2c6bf
* Mon May 12 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not keep debug symbols in vmlinux-*.gz
  (bnc#877267)
- commit f928d60
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package .vmlinuz-*.hmac as well
- commit 3375bd7
* Wed May  7 2014 jdelvare@suse.de
- Update x86 config files: Disable unused CAN drivers
  Disable platform, grcan and tscan1 CAN drivers. Disable ISA and EG20T
  CAN drivers on x86_64. These are believed to be useless, and will
  only be enabled upon explicit request.
- commit dab25a2
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Exclude /boot/symtypes* from the base/main package
  Also, get rid of the comparison of the base and devel filelist.
- commit f1e303f
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Add dock pin setups for Thinkpad T440 (bnc#876699).
- commit efc8676
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Add dock pin setups for Thinkpad T440 (bnc#876699).
- commit 8292525
* Tue May  6 2014 jslaby@suse.cz
- Linux 3.14.3.
- commit 2a280a3
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix packaging of vmlinux debuginfo
  (bnc#875946)
  Add the uncompressed vmlinux image as ghost file to the main package, so
  that the vmlinux debuginfo generated by rpm natively and put into the
  right package.
- commit 26b7a64
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Simplify filelist for files in /boot
- commit ef040ff
* Mon May  5 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on i586 as well (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit 403ada2
* Mon May  5 2014 jslaby@suse.cz
- Refresh
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
  Add commit SHA
- commit 4f0c42a
* Mon May  5 2014 jslaby@suse.cz
- n_tty: Fix n_tty_write crash when echoing in raw mode
  (bnc#871252 bnc#875690 CVE-2014-0196).
- commit e72b790
* Tue Apr 29 2014 guillaume.gardet@oliseo.fr
- Re-eanble ARM kernel in config.conf file and update all ARM configs:
  * config/arm64/default:
  - Add SATA/PATA support
  - Add voltage and regulator support
  * config/armv6hl/default:
  - Add external I2C controllers
  - Add usermode SPI driver
  * config/armv7hl/default:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra support with MFD_NVEC and KEYBOARD_TEGRA
  - Add OMAP4 video input support
  - Add IR receiver
  - Add iMX HDMI support
  - Add Serial support for Tegra SoC
  * config/armv7hl/exynos:
  - Trivial update
  * config/armv7hl/lpae:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Remove unused Terga20/Tegra30 SPI support
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra supprt with MFD_NVEC and KEYBOARD_TEGRA
  - Add IR receiver
  - Add iMX HDMI support
- commit fcd7b3d
* Tue Apr 29 2014 jeffm@suse.com
- Update to 3.15-rc3.
- commit 62b5593
* Tue Apr 29 2014 jeffm@suse.com
- config: sync PCI changes to s390x/vanilla
- commit 807a685
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm config files: Enable all USB-to-serial drivers
  Specifically, enable USB_SERIAL_WISHBONE, USB_SERIAL_MXUPORT and
  USB_SERIAL_QT2 on all arm flavors.
- commit 589f44f
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm64 config file: Disabled 3 unneeded drivers
  Align the arm64 config file with the rest of the config files:
  CONFIG_ATMEL_SSC is not set
  CONFIG_FB_TMIO is not set
  CONFIG_FB_GOLDFISH is not set
- commit aaf60ce
* Tue Apr 29 2014 jdelvare@suse.de
- Update config files: Enable CONFIG_USB_SERIAL_SIMPLE
  This is a unified driver replacing several drivers we were shipping
  so far, so we should ship it too.
- commit 0d558c9
* Tue Apr 29 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on x86_64 (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit 8f9c4ac
* Mon Apr 28 2014 jeffm@suse.com
- unwind: remove check for vdso32 compat range.
  This fixes a build failure introduced in 3.15-rc1.
- commit 66cfb7b
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Require only perl-Bootloader
- commit 573fc1b
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Use per-flavor path for the logfile
- commit 717e968
* Mon Apr 28 2014 jeffm@suse.com
- powerpc: export flush_icache_range.
- commit f47acdb
* Sun Apr 27 2014 jeffm@suse.com
- s390: enable PCI to match SLE12 kernel configs
- PCI=y
- HOTPLUG_PCI=y
- HOTPLUG_PCI_S390=y
- PCI_IOV=y
- INFINIBAND=m
- INFINIBAND_USER_ACCESS=m
- MLX4_INFINIBAND=m
- MLX4_EN=m
- RDS_RDMA=m
  New devices since 3.12:
- MLX5_CORE=m
- MLX5_INFINIBAND=m
- SUNRPC_XPRT_RDMA_CLIENT=m
- SUNRPC_XPRT_RDMA=m
- SUNRPC_XPRT_RDMA_SERVER=m
- All others defaulted to No.
- commit ae2780e
* Sun Apr 27 2014 jeffm@suse.com
- s390: add slab.h for kzalloc/kfree.
- commit 7e349ea
* Sun Apr 27 2014 jeffm@suse.com
- patches.suse/ovl05-overlay-filesystem.patch: fix vfs_rename call due to changed prototype
- commit 0a26d0b
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc2.
- Config changes:
  - Generic config options:
  * IPMI_SI_PROBE_DEFAULTS=y (default=n)
  - older hardware only works with boot option
  - New options specific to ARM:
  * PINCTRL_BCM281XX=n (default)
- commit c35b255
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc1.
- Xen is disabled.
- ARM is disabled.
- Eliminated 3 patches.
- Config changes:
  - Generic config options:
  * USELIB=y (default) - only used for libc5 users, do we care?
  * SYSFS_SYSCALL=y (default) - libc doesn't even supported it anymore,
  do we care?
  * ACPI_REDUCED_HARDWARE_ONLY=n (default)
  * CGROUP_NET_PRIO=y (new feature, do we want it?)
  * LOCK_TORTURE_TEST=n (default)
  * EVM=n (default)
  - New options for existing drivers:
  * BATMAN_ADV_MCAST=y (default=n) -- optimization w/ better reliability
  * BT_6LOWPAN=y (default=n) -- new feature
  * MTD_UBI_BLOCK=n (default -- do we even care about UBI?)
  * ZRAM_LZ4_COMPRESS=y (new feature)
  * BE2NET_VXLAN=y (default)
  * MLX4_EN_VXLAN=y (default)
  * QLCNIC_VXLAN=y (default=n) - enabled for other drivers
  * IWLWIFI_BCAST_FILTERING=n (default)
  - New modules:
  * IP_SET_HASH_IPMARK
  * INTEL_MEI_TXE
  * DM_ERA
  * ALTERA_TSE
  * RTL8723BE
  * RSI_91X
  - RSI_DEBUGFS=n
  - RSI_SDIO=m
  - RSI_USB=m
  * INPUT_PWM_BEEPER
  * SENSORS_LTC2945
  * SENSORS_LTC4222
  * SENSORS_LTC4260
  * SENSORS_ADC128D818
  * MFD_RTSX_USB
  * IR_SHARP_DECODER
  * IR_IMG
  - IR_IMG_RAW=n (documented as performance degrading and for debugging)
  - IR_IMG_NEC=y
  - IR_IMG_JVC=y
  - IR_IMG_SONY=y
  - IR_IMG_SHARP=y
  - IR_IMG_SANYO=y
  * DRM_PTN3460
  * USB_UAS
  * DVB_RTL2832_SDR (USB)
  * ALIENWARE_WMI
  * PWM_LPSS
  * SUNRPC_XPRT_RDMA_CLIENT=m (default)
  * SUNRPC_XPRT_RDMA_SERVER=m (default)
  - x86_64:
  * EFI_MIXED=n (default) -- do we use a bootloader that can support it?
  - ppc/ppc64le:
  * HV_PERF_CTRS=y (default)
  * POWERNV_CPUFREQ=y (default)
  - Probably ARM but looks generic, all modules:
  * SPMI
  * GPIO_DWAPB
  * HID_CP2112
  * MFD_TPS65218
  * GPIO_SYSCON (depends on MFD_SYSCON, which looks to be only used by ARM)
  - New options specific to ARM (I think), all disabled:
  * IMX_THERMAL
  * AHCI_IMX
  * PWM_FSL_FTM
  * OMAP_CONTROL_PHY
  * PHY_SAMSUNG_USB2
  * FSL_EDMA
  * XILINX_WATCHDOG
  * GS_FPGABOOT
  * BCMGENET
  * SXGBE_ETH
  * MFD_BCM590XX
  * BCM7XXX_PHY
  - New options specific to tablets, all disabled:
  * INPUT_SOC_BUTTON_ARRAY (windows tablet)
  * R8723AU (Lenovo Yogi)
  - Other weird hardware:
  * CONFIG_MCB=n (specific to MEN Mikroelektronik FGPA devices)
  - Changes undocumented here were changed automatically.
- commit c0815d2
* Sun Apr 27 2014 jslaby@suse.cz
- Linux 3.14.2.
- commit 91d5ef4
* Thu Apr 24 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_NFC on s390x and ppc64le
  NFC support makes little sense on server-class hardware.
- commit 5cbf723
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not store the buildroot in the .hmac file
- commit ce5bd7a
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add hmaccalc to buildrequires
- commit 9cca2fa
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Generate a hmac singature for the kernel
  (fate#316930, bnc#856310)
- commit 2659f6f
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop conditionals for -kdump and -ps3
- commit 01fab08
* Wed Apr 23 2014 adrian@suse.de
- require kernel-obs-build
  It must be also configured as VMinstall, but is a build requires
  as well to avoid that qa and build package build parallel after kernel-default
  or kernel-xen have changed.
- commit 7a16a4e
* Wed Apr 23 2014 adrian@suse.de
- improve error logging in case the kernel module could not get loaded
- commit 3811667
* Wed Apr 23 2014 adrian@suse.de
- add block device modules for xen kernel-obs-build image
- commit 04fbb81
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file
  I'm an idiot :-(
- commit 6e9f0a1
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_IIO
  It is disabled in all other non-ARM configuration files.
- commit 8cbbb4c
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_RTC_DRV_HID_SENSOR_TIME
  It forcibly selects CONFIG_IIO, which we don't want.
- commit 9afef89
* Tue Apr 15 2014 jdelvare@suse.de
- Update arm config files: Disable Cadence network drivers
  Disable ARM_AT91_ETHER in all arm config files, it is only needed on
  Atmel AT91 which we don't support.
  CONFIG_MACB is useful on armv6hl/default (for ARCH_PICOXCELL) and
  armv7hl/default (for ARCH_ZYNQ.) Disable it in all other config files.
- commit 43063d0
* Tue Apr 15 2014 jdelvare@suse.de
- Disable CONFIG_NET_CADENCE on non-ARM
- commit 00acb46
* Tue Apr 15 2014 guillaume.gardet@opensuse.org
- Update armv7hl configs
  * config/armv7hl/default :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone SoC only
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
  * config/armv7hl/exynos :
  - Enable CONFIG_USB_DWC3* to add USB3 support for Exynos SoC only
  * config/armv7hl/lpae :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone boards
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
- commit 4337939
* Mon Apr 14 2014 mmarek@suse.cz
- Add kernel-obs-qa-xen.spec
- commit f73cebd
* Mon Apr 14 2014 jslaby@suse.cz
- Update config files.
- commit 13cc815
* Mon Apr 14 2014 jslaby@suse.cz
- Linux 3.14.1.
- commit 117c27b
* Fri Apr 11 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Only sign the kernel on x86_64
- commit e0d4304
* Thu Apr 10 2014 jeffm@suse.com
- config: eliminate trace flavor
  With the tracing options synced to the other flavors, we can eliminate
  the trace flavor entirely.
  This implicitly disables the following options that used to be set
  in the trace flavors:
  IRQSOFF_TRACER: carries a substantial runtime overhead
  MMIOTRACE: really only needed for driver development
  FTRACE_SELFTEST: introduces noticible delays during boot
  FTRACE_STARTUP_TEST: introduces noticible delays during tracer startup
- commit 8020846
* Thu Apr 10 2014 jeffm@suse.com
- config: sync RING_BUFFER_BENCHMARK=m on s390x configs
  It is enabled as a module on every other config.
- commit 0b42220
* Thu Apr 10 2014 jeffm@suse.com
- config: enable STACK_TRACER on all flavors
  It carries no runtime overhead when disabled (and it is by default).
- commit fea9446
* Thu Apr 10 2014 jeffm@suse.com
- config: enable FTRACE_SYSCALLS on all flavor files
  It incurs no runtime overhead other than a few KB of memory.
- commit 3427d84
* Thu Apr 10 2014 jeffm@suse.com
- config: enable SCHED_TRACER on all flavors
  It doesn't have any runtime overhead except for a few KB of memory.
- commit 9125183
* Thu Apr 10 2014 jeffm@suse.com
- config: enable ftrace features on all flavors
  We enable the following function tracing options:
- FUNCTION_TRACER
- DYNAMIC_FTRACE
- FUNCTION_PROFILER
- FUNCTION_GRAPH_TRACER
  With dynamic ftrace, there is very little runtime overhead.
  FUNCTION_GRAPH_TRACER is disabled only on ARM because it enables
  frame pointers there, so there is a real runtime cost even when it
  is disabled.
- commit ce4047b
* Thu Apr 10 2014 mmarek@suse.cz
- Generate kernel-obs-*.spec from templates
- commit b2e5f7c
* Wed Apr  9 2014 jdelvare@suse.de
- Update debug config files: enable TTY_PRINTK
  Enabled only in debug kernels for now, as it can't be modular yet.
  Once it can be built as a module, we can enable it in other flavors
  as well.
- commit 043a9a9
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm64 config file: disable CONFIG_USB_DWC3_KEYSTONE
  This driver is only needed on Texas Instruments Keystone2 platforms.
- commit 4e4e502
* Tue Apr  8 2014 jdelvare@suse.de
- Update ppc config files: disble HW_RANDOM_ATMEL
  This driver is only needed on Atmel AT91 systems.
- commit 2cac896
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm/exynos config file: disable AHCI_IMX
  This driver is only used on Freescale i.MX systems so it isn't needed
  on Exynos.
- commit 45d6387
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm config files: Disable exynos support
  Disable exynos support in all non-exynos configuration files, as we
  have a dedicated kernel flavor for exynos.
- commit c65cb20
* Fri Apr  4 2014 mmarek@suse.cz
- rpm/kernel-module-subpackage: Regenerated the initrd in %%posttrans
  (fate#313506)
- commit c0b6219
* Fri Apr  4 2014 jbeulich@suse.com
- Refresh Xen patches (bnc#870874, bnc#871827).
- commit 00dd4e3
* Fri Apr  4 2014 jdelvare@suse.de
- Update x86_64 config files: disable CONFIG_SBC8360_WDT
  The sbc8360 driver is for a Socket 370-based single-board computer,
  so it's useless on x86-64.
- commit 47efdd9
* Fri Apr  4 2014 adrian@suse.de
- fix building initrd for SLE 12
  It does provided and load the critical kernel modules
  for building some kiwi images and cross architecture
  builds like used for aarch64.
  The kernel-obs-build.spec still contains the bits to allow
  to use it also for SLE 11.
- commit e9868b7
* Thu Apr  3 2014 guillaume.gardet@oliseo.fr
- Refresh patches.rpmify/chipidea-clean-up-dependencies
  Replace OF_DEVICE by OF (OF_DEVICE does not exist anymore.)
- commit 299b9cd
* Thu Apr  3 2014 jdelvare@suse.de
- Update config files: disable all of Timberdale support
  Timberdale is a companion chip for Atom CPUs in embedded in-car
  infotainment systems. We don't need that in openSUSE, really.
- commit 47e54c8
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_SI470X
  I2C access to the SI470X radio chip is only needed on embedded systems
  so it makes no sense to enable it in most of our kernel configuration
  files.
- commit b60e271
* Wed Apr  2 2014 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7 (fix another AR build issue).
- commit 59b27eb
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: re-enable twofish crypto support
  Software twofish crypto support was disabled in several architectures
  since openSUSE 10.3. For i386 and x86_64 it was on purpose, because
  hardware-accelerated alternatives exist. However for all other
  architectures it was by accident.
  Re-enable software twofish crypto support in all configuration files,
  to guarantee that at least one implementation is always available,
  (bnc#871325).
- commit 8f37fd4
* Wed Apr  2 2014 mmarek@suse.cz
- rpm/kernel-syms.spec.in: Require pesign-obs-integration for signing KMPs
- commit e68d5fc
* Tue Apr  1 2014 jslaby@suse.cz
- Delete patches.arch/arm-omap3isp.patch.
  superseded by 31036441d785359999e45bf410c778f64ffcab64
- commit fd18f9e
* Tue Apr  1 2014 ohering@suse.de
- Fix typo in netfront, in type check of unplug code
- commit 6623a43
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: disable CONFIG_TOUCHSCREEN_W90X900
  The w90p910_ts driver only makes sense on the W90x900 architecture,
  which we do not support.
- commit 4ebef59
* Tue Apr  1 2014 jbeulich@suse.com
- Update Xen patches to 3.14-final and c/s 1256.
- blkback: allow using indirect request segment descriptors
  (fate#316871).
- blkfront: allow using indirect request segment descriptors
  (fate#316871).
- commit fbd23cd
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: CONFIG_HID_BATTERY_STRENGTH=y
  CONFIG_HID_BATTERY_STRENGTH was already enabled on i386, x86_64 and
  most of arm. Enable this feature on all other architectures which can
  benefit from it.
- commit aec4432
* Mon Mar 31 2014 jeffm@suse.de
- Update to 3.14.
- commit 5795bd9
* Fri Mar 28 2014 jdelvare@suse.de
- Update i386/desktop config file: enable CONFIG_RCU_FAST_NO_HZ
  All other x86 kernels have CONFIG_RCU_FAST_NO_HZ enabled so the
  i386/desktop kernel should too.
- commit 05ea8f5
* Fri Mar 28 2014 jdelvare@suse.de
- Update ppc config files: adjust filesystems modularity
  Build reiserfs, fat and vfat support as modules as we do on every
  other architecture. Also align the reiserfs debugging features on
  x86_64.
- commit 0985b71
* Wed Mar 26 2014 jdelvare@suse.de
- Update ec2 config files: disable HID device drivers
  I don't think the HID drivers for non-standard keyboards and mice
  are needed at all on EC2.
- commit 9fdef61
* Tue Mar 25 2014 jeffm@suse.com
- Update to 3.14-rc8.
- commit b356c6a
* Tue Mar 25 2014 jdelvare@suse.de
- Update x86 config files: enable CONFIG_HID_BATTERY_STRENGTH
  Looks like a cool feature to support on desktop systems. As it has
  to be built-in, I'm only enabling it on x86 for now, because I don't
  know for sure how useful it would be on other architectures. Feel
  free to enable on any other architecture where it would be useful.
- commit 1edfe71
* Tue Mar 25 2014 jdelvare@suse.de
- Update ec2 config files: disable CONFIG_INPUT_FF_MEMLESS
  This helper module is useless on EC2.
- commit c2808f3
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: Modularize all HID device drivers
  HID device drivers are modularized in all config files except arm*
  and desktop, so i386/pae, i386/trace and i386/xen should do the same.
- commit 3c2834b
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: CONFIG_HID=y
  Align the CONFIG_HID setting of the i386/debug, i386/default and
  i386/vanilla config files with what is done in every other config
  file (but s390x and ec2.)
- commit 177a262
* Mon Mar 24 2014 jdelvare@suse.de
- Refresh patches.suse/kconfig-automate-kernel-desktop.
  Options CGROUPS and CGROUP_SCHED are no longer disabled in desktop
  kernel.
- commit 148e111
* Mon Mar 24 2014 jslaby@suse.cz
- Linux 3.13.7.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete patches.arch/ppc64le-ibmveth.patch.
- commit a68bc7c
* Thu Mar 20 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_INPUT_FF_MEMLESS
  It was set by mistake, obviously.
- commit 89fa272
* Wed Mar 19 2014 tiwai@suse.de
- Enable Socketcan again for i386 and x86_64 (bnc#858607)
- commit d1f1027
* Tue Mar 18 2014 jdelvare@suse.de
- Update vanilla config files: enable console rotation
  It's enabled in all other kernel flavors so it should be enabled in
  vanilla too.
- commit 1384611
* Tue Mar 18 2014 jdelvare@suse.de
- config: set CONFIG_X86_INTEL_LPSS in trace and vanilla
  Trying to keep the trace and vanilla kernels in sync with default.
- commit 09e4895
* Tue Mar 18 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  For real this time.
- commit 0b5593a
* Mon Mar 17 2014 jeffm@suse.de
- Update to 3.14-rc7.
- Eliminated 1 patch.
- commit 56ad46a
* Mon Mar 17 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  This makes it much easier to validate that the debug config file only
  diverges from default by debug and testing options.
- commit 37f104e
* Mon Mar 17 2014 jdelvare@suse.de
- config.conf: ia64 is history
- Delete config/ia64/debug.
- Delete config/ia64/default.
- Delete config/ia64/trace.
- Delete config/ia64/vanilla.
- commit 9e606b5
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit 0509ce5
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit 3659420
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 config files: Disable AMD Elan SC520 drivers
  The AMD Elan SC520 is a 32-bit x86 processor, related drivers are
  useless on other architectures.
- commit e5b4397
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 and ia64 config files: Disable SC1200 drivers
  The SC1200 is a SoC based on the Geode GX1 32-bit x86 processor, so
  its drivers are useless on other architectures.
- commit 1058f71
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Restore CONFIG_THERMAL_HWMON
  Setting CONFIG_THERMAL=y in commit e60ddcfe had the side effect of
  disabling CONFIG_THERMAL_HWMON in many configs that didn't have
  CONFIG_HWMON=y. So revert that change in all affected config files.
  Sorry for overlooking that originally.
- commit b197f4a
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Drop all Geode-related drivers
  The Geode was a 32-bit x86 CPU, so all drivers for its companion
  chips (CS55xx) are useless on other architectures. Same for OT200
  drivers, as the Bachmann OT200 device was based on a Geode CPU.
- commit 0bdb147
* Fri Mar 14 2014 jdelvare@suse.de
- Update arm and ppc config files: Drop OLPC-related driver
  OLPC drivers are only useful on i386.
- commit c98f904
* Thu Mar 13 2014 jdelvare@suse.de
- Update debug config files: mac80211 debug options
  Enable all mac80211 debug options in all debug kernel flavors.
- commit 855178e
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- config: Fix version string for armv7hl/lpae
- commit d1a7ba5
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- ARM: Re-enable and update configs
- commit d73f266
* Tue Mar 11 2014 jbeulich@suse.com
- Update Xen patches to 3.14-rc6.
- commit cc55130
* Mon Mar 10 2014 jeffm@suse.com
- Update to 3.14-rc6.
- commit e9d20d4
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Generate a per-architecture per-package _constraints file
- commit 65a07f7
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Remove dead code
- commit 3fc95f5
* Fri Mar  7 2014 jslaby@suse.cz
- Linux 3.13.6.
- commit 4727218
* Thu Mar  6 2014 jdelvare@suse.de
- Update config files: CONFIG_THERMAL=y
  The generic thermal module is used by several ACPI components
  (processor, fan, thermal and video) and a few other drivers. So
  in practice it will end up being loaded on almost all systems
  which support ACPI. It is small so build it into the kernel to
  improve boot speed on all ACPI-enabled architectures (i386,
  x86_64 and ia64.)
- commit e60ddcf
* Wed Mar  5 2014 jeffm@suse.com
- Update to 3.14-rc5.
- commit 4126853
* Tue Mar  4 2014 jdelvare@suse.de
- Update ppc64le config files: disable STE_MODEM_RPROC
  Disable config option STE_MODEM_RPROC on all ppc64le flavors, because
  it draws dependencies which aren't available on ppc64le:
  warning: (REMOTEPROC && RPMSG) selects VIRTUALIZATION which has unmet direct dependencies (!CPU_LITTLE_ENDIAN)
- commit 712ca17
* Sat Mar  1 2014 jslaby@suse.cz
- rpc_pipe: fix cleanup of dummy gssd directory when notification
  fails (bnc#866437).
- sunrpc: add an "info" file for the dummy gssd pipe (bnc#866437).
- rpc_pipe: remove the clntXX dir if creating the pipe fails
  (bnc#866437).
- nfs: check if gssd is running before attempting to use krb5i
  auth in SETCLIENTID call (bnc#866437).
- sunrpc: replace sunrpc_net->gssd_running flag with a more
  reliable check (bnc#866437).
- sunrpc: create a new dummy pipe for gssd to hold open
  (bnc#866437).
- commit 5bb4797
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/mkspec: Fix whitespace in NoSource lines
- commit 6320617
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not zero modules.dep before using it
  (bnc#866075)
- commit b67b660
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: modularize BLK_DEV_MD, disable MD_AUTODETECT
  Michal Marek says:
  I think that the reason why BLK_DEV_MD is built in is
  config MD_AUTODETECT
    bool "Autodetect RAID arrays during kernel boot"
    depends on BLK_DEV_MD=y
  but since we compile the raid presonalities as modules, this cannot
  work. Also, we use the initrd even in the trivial cases, so why bother
  about root-on-md.
- commit db76347
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files.
  Modularize the following helper drivers:
  INET_LRO, NET_CLS_CGROUP, DNS_RESOLVER
  They had to be built-in before due to dependencies, but this is no
  longer the case, so we can modularize them again.
- commit a970646
* Fri Feb 28 2014 jdelvare@suse.de
- Update x86 config files: CONFIG_X86_MSR=m
  The msr driver creates /dev/cpu/*/msr through which you can poke
  at all the MSRs if you have CAP_SYS_RAWIO. We prefer to be able
  to remove that module if it is not needed.
- commit 9e6b04a
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Drop useless ExclusiveArch statement
- commit 5cdf1da
* Fri Feb 28 2014 guillaume.gardet@oliseo.fr
- config: Update armv7/exynos
- Add sound support
- Add I2C/SPI support
- commit 93b38ce
* Fri Feb 28 2014 tiwai@suse.de
- ALSA: hda/sigmatel - Allow auto-switching for dock line-in of
  HP laptops (bnc#866100).
- commit 6367fe8
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: CONFIG_ISO9660_FS=m
  There is no good reason why isofs would be built into the kernel.
  Most systems don't need it after installation, and reportedly
  mkinitrd etc. can deal with it as a module just fine.
- commit 3dd8a1a
* Tue Feb 25 2014 jdelvare@suse.de
- Update config files: CONFIG_AUTOFS4_FS=y
  systemd requires autofs, so autofs4.ko will always be loaded on boot.
  For performance reasons, it makes sense to build it into the kernel
  (bnc#863771).
- commit 70247d1
* Tue Feb 25 2014 jbeulich@suse.com
- Update Xen patches to 3.14-rc4 and c/s 1252.
- privcmd: allow preempting long running user-mode originating
  hypercalls (bnc#861093).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- scripts/check-cvs-add: Disable config checking for now.
- commit d5aea30
* Mon Feb 24 2014 jeffm@suse.com
- config: disable PINCTRL_MSM and PINCTRL_MSM8X4
  These options were enable accidentally during the 3.14-rc1 update for
  just the i386/default config.
- commit 2ded0ed
* Mon Feb 24 2014 jeffm@suse.com
- Update to 3.14-rc4.
- Eliminated 1 patch.
- commit 16d4242
* Sun Feb 23 2014 jslaby@suse.cz
- Linux 3.13.5.
- commit 4e9ddcc
* Thu Feb 20 2014 jslaby@suse.cz
- Linux 3.13.4.
- commit 6eda950
* Wed Feb 19 2014 jeffm@suse.com
- dmraid45: removed driver.
  This functionality should be offered by the dmraid driver.
- commit 9a83d77
* Tue Feb 18 2014 mszeredi@suse.cz
- cifs: ensure that uncached writes handle unmapped areas
  correctly (bnc#864025 CVE-2014-00691).
- commit 79c42c5
* Mon Feb 17 2014 jeffm@suse.com
- config: CONFIG_BCM_KONA_USB2_PHY=n on s390
- commit f30c873
* Mon Feb 17 2014 jeffm@suse.com
- acpi: Complete fix for thinkpad RSDT blacklist
- commit 2e62bb9
* Mon Feb 17 2014 jeffm@suse.com
- Update to 3.14-rc3.
- commit 058f759
* Mon Feb 17 2014 jeffm@suse.com
- dmraid45: updated to use new bvec iterators.
- commit 9e25806
* Mon Feb 17 2014 jeffm@suse.com
- acpi: Updated acpi=rsdt dmi blacklist to new variable name.
- commit 4bd9031
* Mon Feb 17 2014 jeffm@suse.com
- Update vanilla config files.
- commit b49cb75
* Fri Feb 14 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Do not mount /sys, the build script does it
- commit f11b02a
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable TS5500-specific drivers
  These drivers are useless without TS5500 board support: mtd-ts5500,
  gpio-ts5500 and max197.
- commit 2a03456
* Fri Feb 14 2014 jslaby@suse.cz
- Linux 3.13.3 (bnc#799216).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-patch-3.12.
- Delete
  patches.drivers/drm-cirrus-Correct-register-values-for-16bpp.
- Update config files.
- commit d6e2c2f
* Thu Feb 13 2014 dvaleev@suse.de
- rpm/kernel-obs-build.spec: Fix for ppc64le
- commit 50c4205
* Wed Feb 12 2014 mq@suse.cz
- Scripts: .nosrc.rpm should contain only the specfile (bnc #639379)
- commit afe62e0
* Wed Feb 12 2014 jdelvare@suse.de
- Drop outdated comment
- commit 65bab82
* Wed Feb 12 2014 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.13 (fix net{back,front} checksum setup).
- commit a23672f
* Wed Feb 12 2014 lpechacek@suse.cz
- doc/README.PATCH-POLICY.SUSE: updated links
- commit ac58062
* Tue Feb 11 2014 mmarek@suse.cz
- Delete unused patches.arch/ppc64le-fix-copytofrom.patch
- commit ce3dbc3
* Tue Feb 11 2014 tiwai@suse.de
- drm/cirrus: Fix cirrus drm driver for fbdev + qemu (bnc#856760).
- commit ee73224
* Tue Feb 11 2014 mq@suse.cz
- Spec: zeroing modules.dep to get identical builds among different machines
- commit a1c5879
* Tue Feb 11 2014 mmarek@suse.cz
- rpm/guards: Report which config file has problem in --check mode
- commit b39543d
* Mon Feb 10 2014 jeffm@suse.com
- Updated patch headers for 3.14-rc2.
- commit d0ea44a
* Mon Feb 10 2014 jeffm@suse.com
- Update to 3.14-rc2.
- Eliminated 1 patch.
- commit a5ab7bf
* Mon Feb 10 2014 jslaby@suse.cz
- rpm/config.sh: switch to building against 13.1
- commit b59b809
* Mon Feb 10 2014 mmarek@suse.cz
- doc/README.SUSE: Update to match the current package layout
- commit f357abb
* Mon Feb 10 2014 mmarek@suse.cz
- Add the README.SUSE file to the packaging branch
- commit 11905ea
* Thu Feb  6 2014 jslaby@suse.cz
- Linux 3.13.2 (bnc#860993 CVE-2014-0038).
- Delete patches.fixes/compat_sys_recvmmsg-x32-fix.patch.
- Refresh patches.xen/xen3-patch-2.6.37.
- Refresh patches.xen/xen3-patch-3.10.
- commit 7e6b5de
* Wed Feb  5 2014 mmarek@suse.cz
- Change also BuildRequires from module-init-tools to modutils
- commit f650166
* Tue Feb  4 2014 jeffm@suse.com
- Updated patch headers for 3.14-rc1.
- commit 967bc40
* Tue Feb  4 2014 jeffm@suse.com
- Update to 3.14-rc1.
- 19 patches eliminated.
- Xen is disabled.
- ARM is disabled.
- commit 691c6b1
* Fri Jan 31 2014 adrian@suse.de
- avoid double /sys mounts for kernel-obs-build, OBS is doing this meanwhile
- commit 3ea39a4
* Thu Jan 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require 'modutils' also in the subpackages
- commit 91f0a2e
* Thu Jan 30 2014 mmarek@suse.cz
- Reformat the spec files to what the buildservice expects
- commit 0b9e9a1
* Wed Jan 29 2014 bp@suse.de
- compat_sys_recvmmsg X32 fix (bnc#860993 CVE-2014-0038).
- commit b4ff60b
* Wed Jan 29 2014 jslaby@suse.cz
- Linux 3.13.1.
- commit 01e2360
* Mon Jan 27 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add README.PATCH-POLICY.SUSE as source file
- commit 9c9ce61
* Mon Jan 27 2014 mmarek@suse.cz
- Drop the _constraints file, we are using the prjconf setting for now
- commit a0aa890
* Fri Jan 24 2014 jbeulich@suse.com
- Refresh Xen patches (fix PV driver build).
- commit d9213ce
* Thu Jan 23 2014 jkosina@suse.cz
- floppy: bail out in open() if drive is not responding to block0
  read (bnc#773058).
- commit 1d92189
* Wed Jan 22 2014 jbeulich@suse.com
- Update Xen patched to 3.13-final and c/s 1248.
- Update EC2 config files (restore CONFIG_DEBUG_INFO).
- commit a770ad7
* Tue Jan 21 2014 jeffm@suse.de
- Update to 3.13.
- commit ff46e6a
* Mon Jan 20 2014 jslaby@suse.cz
- Linux 3.12.8.
- commit 2caf20a
* Fri Jan 17 2014 ohering@suse.de
- xen: pv-on-hvm: skip initialization of emulated devices
  (fate#311487).
- commit f011587
* Fri Jan 17 2014 tiwai@suse.de
- ACPI: Blacklist Win8 OSI for some HP laptop 2013 models
  (bnc#856294).
- commit 0223704
* Fri Jan 17 2014 mmarek@suse.cz
- Revert "rpm/config.sh: Drop the ARM and PPC repositories"
  This was actually wrong, the ports repository is broken.
- commit a983897
* Fri Jan 17 2014 mmarek@suse.cz
- rpm/config.sh: Drop the ARM and PPC repositories
  The architectures are provided by the ports repository
- commit 96b9cec
* Tue Jan 14 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Require kernel-devel%%variant
- commit 810ea41
* Tue Jan 14 2014 mhocko@suse.cz
- Delete patches.fixes/remount-no-shrink-dcache.
  the optimization is no longer needed because dcache_lock is long
  gone and replaced by RCU (see b5c84bf6f6 fs: dcache remove
  dcache_lock and others).
- commit 0092763
* Tue Jan 14 2014 mhocko@suse.cz
- Delete patches.fixes/oom-warning.
  The additional warning message is not worth carrying. Highorder
  or atomic allocations which are expected to fail should use
  __GFP_NOWARN to not pollute logs with allocation failures which are
  acceptable.
- commit c07fd34
* Tue Jan 14 2014 mhocko@suse.cz
- Update config files.
  Disable CONFIG_MEMCG_SWAP_ENABLED because it got enabled by accident.
  The CONFIG_MEMCG_SWAP is enabled but the accounting has to be explicitly
  allowed by swap_account=1 kernel command line parameter
- commit 402a841
* Mon Jan 13 2014 jeffm@suse.com
- Update to 3.13-rc8.
- commit 44ad2a9
* Mon Jan 13 2014 jslaby@suse.cz
- efifb: prevent null-deref when iterating dmi_list (bnc#858404).
- commit 78b11e9
* Sat Jan 11 2014 ohering@suse.de
- hv: set guest os id (bnc#814005).
- commit e3d0b5d
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Fix for older Perl
- commit ecf021e
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Add .changes file for kernel-obs-*.spec as well
- commit bd3c299
* Fri Jan 10 2014 ro@suse.de
- rpm/kernel-obs-build.spec: Fix building in chroot instead of Xen
- commit 57e89b6
* Fri Jan 10 2014 jslaby@suse.cz
- Linux 3.12.7.
- commit 2424219
* Thu Jan  9 2014 jdelvare@suse.de
- Disable CONFIG_MODULE_FORCE_UNLOAD (bnc#857673)
  Forcing module unloading can't lead to anything good. If reference
  counting is wrong then it should be fixed. If the reference count is
  right and a regular (unforced) unloading doesn't work, then a forced
  unloading can only lead to chaos and ultimately a kernel crash.
- commit 3d57f73
* Thu Jan  9 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Enable CONFIG_FB_SIMPLE as that's what U-Boot exposes in DT.
- commit c7b8797
* Wed Jan  8 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Activate CONFIG_ARM_ATAG_DTB_COMPAT for it to receive U-Boot bootargs.
  Enable BCM2835_{I2C,WDT}, MMC_SDHCI_BCM2835, USB_HCD_BCMA as modules.
- commit 57a2f1c
* Wed Jan  8 2014 jbeulich@suse.com
- Update Xen patches to 3.13-rc7 and c/s 1245.
- netback: bump tx queue length (bnc#849404).
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 0e71aa4
* Tue Jan  7 2014 agraf@suse.de
- Delete config/armv7hl/cubox.
- commit 85bdaf6
* Mon Jan  6 2014 jeffm@suse.com
- Update to 3.13-rc7.
- Eliminated 1 patch.
- commit fed42b5
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA in config/x86_64/desktop too
- commit febc20c
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA, no 64-bit system would need it
- commit 95d3d3d
* Fri Jan  3 2014 mmarek@suse.cz
- Switch to linux-*.tar.xz
- commit 27d9f61
* Fri Jan  3 2014 mmarek@suse.cz
- Add support for linux-*.tar.xz to the spec files
- commit d12c880
* Thu Jan  2 2014 agraf@suse.de
- ARM: Reenable and update configs
- commit 0d77ece
* Thu Jan  2 2014 jeffm@suse.de
- Update to 3.13-rc6.
- commit 63236e5
* Thu Dec 26 2013 jeffm@suse.de
- Update to 3.13-rc5.
- Eliminated 3 patches.
- commit 7127d5f
* Mon Dec 23 2013 dvaleev@suse.com
- Run add_vmlinux for ppc64le
- commit ae96e26
* Mon Dec 23 2013 agraf@suse.de
- ibmveth: Fix more little endian issues.
- powerpc: Don't return to BE mode when we are already there.
- powerpc: Add hack to make ppc64le work on hosts without ILE.
- powerpc: Add relocation code for fixups.
- powerpc: Add global exports for all interrupt vectors.
- commit 3d0a348
* Sat Dec 21 2013 jeffm@suse.de
- Update to 3.13-rc4.
- ppc64le/vanilla appears to have not been resynced when copied.
- commit 82b44e7
* Sat Dec 21 2013 jslaby@suse.cz
- Linux 3.12.6.
- Update config files.
- commit 080d0df
* Fri Dec 20 2013 agraf@suse.de
- Update config files: Disable relocation on ppc64le (it's broken)
- commit fbe0eb5
* Thu Dec 19 2013 agraf@suse.de
- Update config files: Disable kvm for ppc64le (not implemented upstream)
- commit 7fa2dfd
* Thu Dec 19 2013 agraf@suse.de
- powerpc: PTRACE_PEEKUSR always returns FPR0.
- commit c9829ea
* Thu Dec 19 2013 agraf@suse.de
- PPC: Build only vmlinux target.
- commit 04c2cde
* Thu Dec 19 2013 agraf@suse.de
- powerpc: Make 64-bit non-VMX __copy_tofrom_user bi-endian.
- commit 0044320
* Thu Dec 19 2013 agraf@suse.de
- Add ppc64le support (configs are a copy of the ppc64 ones with LE enabled)
- commit d86dbed
* Thu Dec 19 2013 agraf@suse.de
- sched: Remove PREEMPT_NEED_RESCHED from generic code.  (fixes ppc)
- commit 605502a
* Thu Dec 19 2013 agraf@suse.de
- Disable 32-on-64 ptrace patch, it breaks for ppc64le
- commit a943cf8
* Thu Dec 19 2013 agraf@suse.de
- Update config files
  - remove epapr bytechan interface, we don't support booke
- commit 68ab0ab
* Wed Dec 18 2013 tiwai@suse.de
- Disable simplefb and x86 sysfb due to breakage (bnc#855821)
- commit 3848a14
* Wed Dec 18 2013 adrian@suse.de
- Add kernel-obs-build to use the distribution kernel within OBS VM builds.
  Add kernel-obs-qa to test that the kernel is booting within OBS VMs. It may run also further tests later on.
- commit e9cfd5c
* Tue Dec 17 2013 mmarek@suse.cz
- Port module signing changes from SLE11-SP3 (fate#314508)
- commit 8a264a3
* Mon Dec 16 2013 ohering@suse.de
- fbmem: really support wildcard video=options for all fbdev
  drivers.
- commit 5b170d7
* Mon Dec 16 2013 ohering@suse.de
- Delete
  patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-util-version-negotiatio.patch.
- commit b3125ee
* Mon Dec 16 2013 jkosina@suse.cz
- doc/README.PATCH-POLICY.SUSE: add patch policy / best practices document
- commit 60893d6
* Fri Dec 13 2013 tiwai@suse.de
- Add missing CONFIG_PINCTRL_SINGLE kconfig setups
- commit 39ea148
* Thu Dec 12 2013 jdelvare@suse.de
- config.conf: s390 is history
- Delete config/s390/s390.
- Delete config/s390/trace.
- Delete config/s390/vanilla.
- commit 2bf5161
* Thu Dec 12 2013 jdelvare@suse.de
- Delete patches.suse/ida-remove-warning-dump-stack.patch.
  Already included since kernel 3.11 (WARN calls dump_stack.)
- commit 8e04564
* Thu Dec 12 2013 jslaby@suse.cz
- Linux 3.12.5.
- commit 48b587a
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Spelling fix
- commit 2e074cb
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Delete dead code
- commit 98077a9
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Typo fix from upstream
- commit ce654f8
* Wed Dec 11 2013 stefan.bruens@rwth-aachen.de
- config: set CONFIG_X86_INTEL_LPSS and CONFIG_I2C_DESIGNWARE_PLATFORM
  Enable INTEL LPSS (Low Power SubSystem) for LynxPoint chipsets (bnc#849125)
  and DesignWare (platform) i2c bus driver (bnc#849338).
  The DesignWare i2c driver depends on the clock subsystem.
- commit 3a6fe23
* Tue Dec 10 2013 jslaby@suse.cz
- Linux 3.12.4.
- Refresh patches.suse/connector-read-mostly.
- Refresh patches.xen/xen3-auto-common.diff.
- commit 87dc4f5
* Mon Dec  9 2013 hare@suse.de
- Delete patches.suse/scsi-error-test-unit-ready-timeout:
  Superseded by commit 0816c9251a7180383bb7811e1a1545f7b78e5374.
- commit 44df1ce
* Mon Dec  9 2013 hare@suse.de
- iscsi_target: race condition on shutdown (bnc#850072).
- commit c4710fd
* Sun Dec  8 2013 jeffm@suse.com
- Update to 3.13-rc3.
- commit 82b4383
* Fri Dec  6 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add the OBS _constraints file as source
- commit 17282e4
* Wed Dec  4 2013 jslaby@suse.cz
- Linux 3.12.3.
- Refresh
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- commit f37dca6
* Wed Dec  4 2013 jeffm@suse.de
- config: enable CONFIG_EXPERT
  3.10 introduced Kconfig rules that automatically builds in
  uncommon HID drivers if EXPERT is not set.
  This commit does not introduce any other config changes.
- commit 30a8773
* Wed Dec  4 2013 jeffm@suse.com
- README: Update to document typical patch naming
- commit d2a2470
* Wed Dec  4 2013 tiwai@suse.de
- config: CONFIG_CHECKPOINT_RESTORE=y and CONFIG_MEM_SOFT_DIRTY=y on x86_64
- commit d99342f
* Mon Dec  2 2013 jeffm@suse.com
- Revert "init: define console_initcall when built as a module."
  This reverts commit 9eb723d9911b941e71381831812b7c7bd17d24f3.
- commit c172b07
* Mon Dec  2 2013 jeffm@suse.com
- init: define console_initcall when built as a module.
- commit 9eb723d
* Mon Dec  2 2013 jeffm@suse.com
- overlayfs: update for 3.13 delegated_inode API changes.
- commit 3d88c7f
* Mon Dec  2 2013 jeffm@suse.com
- Update to 3.13-rc2.
  - Eliminated 1 patch.
- commit 75ac3c3
* Fri Nov 29 2013 jslaby@suse.cz
- Linux 3.12.2.
- Refresh patches.xen/xen3-patch-2.6.29.
- Delete
  patches.suse/btrfs-relocate-csums-properly-with-prealloc-extents.patch.
- commit 3b81e61
* Fri Nov 29 2013 tiwai@suse.de
- Build mei and mei_me as modules (bnc#852656)
- commit 1a570dd
* Thu Nov 28 2013 jdelvare@suse.de
- supported.conf: dd drivers/hwmon/smsc47b397
  That one is very simple and reliable and found in a number of
  enterprise-grade workstations. I believe it would make sense to support
  it.
- commit 3a2ac9d
* Wed Nov 27 2013 duwe@suse.de
- pstore: automatically dump and clean dmesg entries
  (fate#315232).
- Update config files.
- commit 9525160
* Tue Nov 26 2013 agraf@suse.de
- omapdrm: fix compile with dma_addr_t > u32.
- commit 611f4eb
* Sat Nov 23 2013 jeffm@suse.com
- Update to 3.13-rc1.
- Eliminated 7 patches.
- Xen is disabled.
- ARM needs config updates.
- commit 2dfdca4
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Add USB PHY support (needed to get USB and Ethernet working on beagle and panda boards) Add CONFIG_PINCTRL_SINGLE=y to be able to use Device tree (at least for beagle and panda boards) Add ARM SoC sound support Add SPI bus support Add user-space access to I2C and SPI
- commit b3c966e
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Set CONFIG_GPIO_TWL4030 as built-in (instead of module) as a requirement to boot on SD card on beagleboard xM
- commit 5b7fb61
* Thu Nov 21 2013 jslaby@suse.cz
- Linux 3.12.1.
- commit 1e06fbe
* Wed Nov 20 2013 jslaby@suse.cz
- Update config files (fate#315172).
- commit a0984ed
* Wed Nov 20 2013 jslaby@suse.cz
- x86/dumpstack: Fix printk_address for direct addresses
  (bnc#845621).
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen-x86_64-dump-user-pgt.
- commit ce55b22
* Tue Nov 19 2013 jbohac@suse.cz
- supported.conf: marked net/netfilter/xt_set as supported (bnc#851066)
  xt_set should have been enabled together with the ip_set modules in
  fate#313309
- commit c2e046e
* Sat Nov 16 2013 jeffm@suse.com
- config: build uncommon HID drivers as modules
- commit 92db3f1
* Sat Nov 16 2013 jeffm@suse.com
- config: sync HID=y on x86_64/debug config
- commit 2437d0f
* Tue Nov 12 2013 jdelvare@suse.de
- armv6hl, armv7hl: Update config files.
  Set CONFIG_BATMAN_ADV_BLA=y as all other kernel configuration files
  have.
- commit e7c00d8
* Fri Nov  8 2013 jdelvare@suse.de
- Update config files:
  * CONFIG_BATMAN_ADV_NC=y, because other BATMAN_ADV options are all
  enabled so why not this one.
  * CONFIG_GPIO_SCH=m, CONFIG_GPIO_PCH=m, because we support all other
  features of these pieces of hardware.
  * CONFIG_INTEL_POWERCLAMP=m, because this small driver might be
  useful in specific cases, and there's no obvious reason not to
  include it.
- commit 79e7a03
* Thu Nov  7 2013 jbeulich@suse.com
- Update Xen patches to 3.12-final.
- commit ec28986
* Wed Nov  6 2013 duwe@suse.de
- fate#316581: CONFIG_IBM_BSR y -> m
- commit f5eba64
* Mon Nov  4 2013 jslaby@suse.cz
- Delete patches.kernel.org/patch-3.11.1.
- commit ec24572
* Mon Nov  4 2013 jeffm@suse.com
- Update config files.
- commit f7c27a2
* Mon Nov  4 2013 jeffm@suse.com
- Update to 3.12-final.
- commit bd2bcf1
* Mon Nov  4 2013 jeffm@suse.com
- Refresh
  patches.suse/btrfs-add-ability-to-query-change-feature-bits-online-ioctl.
- commit a58c8c5
* Mon Nov  4 2013 jeffm@suse.com
- Refresh patches.suse/btrfs-add-tracing-for-failed-reservations.
- Refresh patches.suse/btrfs-publish-allocation-data-in-sysfs.
  - No code change: missing 'quilt add' caused a chunk to be
    in the wrong patch.
- commit 0346b5c
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add extra chmap for 2.1 outputs on ASUS laptops
  (bnc#846531).
- commit 5fe5110
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add a fixup for ASUS N76VZ (bnc#846529).
- commit c8ca4fb
* Tue Oct 29 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc7 and c/s 1240.
- commit 49141ff
* Mon Oct 28 2013 jeffm@suse.de
- Update to 3.12-rc7.
- commit c59f68d
* Tue Oct 22 2013 jeffm@suse.com
- nouveau: Fix race with fence signaling (bnc#844177).
- commit db1113e
* Tue Oct 22 2013 jeffm@suse.com
- btrfs: add ioctl to export size of global metadata reservation.
- btrfs: add tracing for failed reservations.
- btrfs: publish allocation data in sysfs.
- btrfs: publish device membership in sysfs.
- btrfs: publish fs label in sysfs.
- btrfs: publish per-super attributes in sysfs.
- btrfs: publish per-super features in sysfs.
- btrfs: publish supported featured in sysfs.
- btrfs: publish unknown feature bits in sysfs.
- kobject: export kobj_sysfs_ops.
- Refresh
  patches.suse/btrfs-add-ability-to-change-features-via-sysfs.
- Refresh
  patches.suse/btrfs-use-feature-attributes-to-print-names-in-errors.
- Delete
  patches.suse/btrfs-add-per-super-attribute-publishing-to-sysfs.
- Delete
  patches.suse/btrfs-add-publishing-of-unknown-features-in-sysfs.
- Delete patches.suse/btrfs-export-supported-featured-to-sysfs.
- Delete patches.suse/btrfs-publish-per-super-features-to-sysfs.
- Delete patches.suse/introduce-kobj_completion.
- commit 28f62b4
* Mon Oct 21 2013 jeffm@suse.com
- Update to 3.12-rc6.
- commit 7244867
* Fri Oct 18 2013 jslaby@suse.cz
- Linux 3.11.6 (bnc#841645).
- Delete patches.drivers/ALSA-hda-Add-fixup-for-ASUS-N56VZ.
- commit 9ca6827
* Wed Oct 16 2013 jbeulich@suse.com
- Update x86 Xen config files (RTC_DRV_EFI=y).
- commit ac42dba
* Wed Oct 16 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- Delete patches.xen/xen3-010-acpi_initrd_override_tables.patch.
- commit 8673f3f
* Tue Oct 15 2013 oneukum@suse.de
- sha256_ssse3: also test for BMI2 (bnc#842459).
- commit 243990f
* Mon Oct 14 2013 jeffm@suse.com
- config: enable HAVE_BOOTMEM_INFO_NODE on ppc64 to match 3.11.5 (vanilla)
- commit 53efb9c
* Mon Oct 14 2013 jeffm@suse.com
- config: enable HAVE_BOOTMEM_INFO_NODE on ppc64 to match 3.11.5
- commit 22f9877
* Mon Oct 14 2013 jeffm@suse.com
- btrfs: Fix creation of per-super sysfs directories when using multiple
  subvolumes (bnc#845774)
- commit adcee6c
* Mon Oct 14 2013 jeffm@suse.com
- btrfs: Fix creation of per-super sysfs directories when using multiple
  subvolumes (bnc#845774).
- commit 0801062
* Mon Oct 14 2013 jeffm@suse.com
- Update to 3.12-rc5.
- commit 6c5465f
* Mon Oct 14 2013 oneukum@suse.de
- sha256_ssse3: also test for BMI2 (bnc#842459).
- commit 626459d
* Mon Oct 14 2013 jslaby@suse.cz
- Linux 3.11.5.
- Delete
  patches.suse/btrfs-0005-reset-ret-in-record_one_backref.patch.
- Delete
  patches.suse/btrfs-0010-change-how-we-queue-blocks-for-backref-checkin.patch.
- Delete
  patches.suse/btrfs-0022-skip-subvol-entries-when-checking-if-we-ve-cre.patch.
- Delete
  patches.suse/btrfs-0033-remove-ourselves-from-the-cluster-list-under-l.patch.
- commit c00734a
* Fri Oct 11 2013 jeffm@suse.com
- Update to 3.12-rc4.
- commit 8fdbb19
* Fri Oct 11 2013 tiwai@suse.de
- drm/i915: Undo the PIPEA quirk for i845 (bnc#845503).
- commit e401a74
* Tue Oct  8 2013 tiwai@suse.de
- ALSA: hda - Add fixup for ASUS N56VZ (bnc#841645).
- commit 9f1b1d6
* Mon Oct  7 2013 jack@suse.cz
- supported.conf: Update support info
- commit fe619b0
* Sat Oct  5 2013 jslaby@suse.cz
- Linux 3.11.4.
- commit 40d7ca3
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Remove IOMMU v2
  This is only needed for HSA.
- commit 1d0217b
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Add a bunch of AMD-specific drivers to the list
  + sb_edac which people wanted since SLE11-SP2.
- commit 942c03a
* Fri Oct  4 2013 bpoirier@suse.de
- supported.conf: update for network related modules
  based on FATE#313655
  +		drivers/net/ethernet/intel/i40e/i40e
  vhost_net depends on vhost
  +		drivers/vhost/vhost
  nf_nat is now nf_nat_ipv4, _ipv6 was introduced in v3.7
  - net/ipv4/netfilter/nf_nat
  +		net/ipv4/netfilter/nf_nat_ipv4
  +		net/ipv6/netfilter/nf_nat_ipv6
  based on the rationale that we already package `ss` and support inet_diag:
  +		net/ipv4/udp_diag
  +		net/netlink/netlink_diag
  +		net/packet/af_packet_diag
  +		net/unix/unix_diag
- commit 07a54e6
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Add newly requested drivers
- commit 199c169
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: More updates from SLE11-SP3
- commit 45bc81a
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Check module support only if the -extra package is requested
- commit add86bf
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Remove unused options
- commit 3736315
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix creating the kernel-*-extra package
  CONFIG_ENTERPRISE_SUPPORT has been renamed to CONFIG_SUSE_KERNEL_SUPPORTED
- commit 9e5b6fe
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Copy some missing changes from SLE11-SP3
- commit fdeb1a7
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Remove the kernel/ prefix from module paths.
- commit 9649d9f
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Allow wildcards in the Module.supported file.
- commit a464383
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Fix matching of dashes and underscores in Module.supported (bnc#719090).
- commit cab1abc
* Thu Oct  3 2013 mmarek@suse.cz
- Enable CONFIG_DRM_QXL and mark qxl.ko as supported (fate#316469)
- commit acad9db
* Wed Oct  2 2013 jslaby@suse.cz
- Linux 3.11.3.
- Refresh patches.xen/xen3-patch-3.4.
- commit 485f0d1
* Tue Oct  1 2013 jeffm@suse.com
- Update to 3.12-rc3.
- commit e5ef0d0
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_TMIO (Sharp Zaurus) on non-arm configs.
- commit 977b235
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_GEODE, as the individual GEODE options are already disabled
- commit d10fe5f
* Mon Sep 30 2013 mmarek@suse.cz
- Always include the git commit in KOTD builds
  This allows us not to set it explicitly in builds submitted to the
  official distribution (bnc#821612, bnc#824171).
- commit a80e5ef
* Mon Sep 30 2013 mmarek@suse.cz
- Do not build udlfb, to avoid conflict with udl (fate#316407)
- commit 678681d
* Mon Sep 30 2013 mmarek@suse.cz
- Disable fb drivers that have been blacklisted for a long time
  via /etc/modprobe.d/50-blacklist.conf.
- commit b34e737
* Mon Sep 30 2013 dsterba@suse.cz
- Btrfs: relocate csums properly with prealloc extents.
- commit 6cf855e
* Mon Sep 30 2013 dsterba@suse.cz
- Btrfs: relocate csums properly with prealloc extents.
- commit cb5d5b5
* Sat Sep 28 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
  actually assign the divide result to hv_lapic_frequency
- commit 420e19b
* Sat Sep 28 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
  actually assign the divide result to hv_lapic_frequency
- commit 9e0a852
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add obsolete KMPs from sle11-sp1
- commit 221133c
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make sure that all KMP obsoletes are
  versioned (bnc#821465).
- commit d802bf2
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide obsoleted KMPs (bnc#753353)
- commit f5449e6
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unversioned provides/obsoletes
  for packages that were only seen in openSUSE releases up to 11.0.
  (bnc#821465).
- commit 7e1f4b6
* Fri Sep 27 2013 jeffm@suse.com
- config: disable FB_UDL in favor of DRM_UDL (bnc#836782).
- commit 68c5865
* Fri Sep 27 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
- commit 83e7e53
* Fri Sep 27 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
- commit ff1e29f
* Fri Sep 27 2013 ohering@suse.de
- X86: Hyper-V: Get the local APIC timer frequency from the
  hypervisor.
- commit 4f400e1
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit 7affb28
* Fri Sep 27 2013 ohering@suse.de
- X86: Hyper-V: Get the local APIC timer frequency from the
  hypervisor.
- commit ca351ea
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit 0b0a3fa
* Fri Sep 27 2013 jeffm@suse.com
- config: disable DGAP on s390
  It requires ioremap, which isn't available on s390. It's a staging
  driver anyway.
- commit cf0bc41
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors, rpm/mkspec: Add version information to obsolete
  flavors (bnc#821465).
- rpm/kernel-binary.spec.in: Move the xenpae obsolete to the
  old-flavors file.
- commit 25c1b0d
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors: Convert the old-packages.conf file to a flat
  list.
- rpm/mkspec: Adjust.
- rpm/old-packages.conf: Delete.
- commit 4037e16
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-packages.conf: Drop bogus obsoletes for "smp" (bnc#821465)
- commit 50c4c23
* Fri Sep 27 2013 jslaby@suse.cz
- README.BRANCH: fix typo
- commit 4c1fc5a
* Fri Sep 27 2013 jslaby@suse.cz
- Linux 3.11.2.
- Refresh patches.xen/pci-guestdev.
- Refresh patches.xen/xen3-patch-2.6.27.
- Delete
  patches.rpmify/powerpc-add-missing-include-to-book3s_xics-c.
- commit d1e8a21
* Fri Sep 27 2013 jdelvare@suse.de
- config/*/debug: Enable FSCACHE_DEBUG and CACHEFILES_DEBUG.
- commit 5068fbc
* Thu Sep 26 2013 rgoldwyn@suse.com
- rpm/kernel-binary.spec.in: Remove Obsoletes ocfs2-kmp
  This is done to enable install of ocfs2-kmp-* alongwith the
  kernel until the patches are reviewed.
- commit 9d2b4ca
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit 954d4c1
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit adb564f
* Thu Sep 26 2013 jeffm@suse.com
- patches.rpmify/documentation-fix-bad-merge-with-tmpfile-documentation:
  Updated Patch-mainline
- commit a1513a8
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit 68bb010
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit fc372c0
* Thu Sep 26 2013 mmarek@suse.cz
- Update README.BRANCH
- commit 4d432eb
* Wed Sep 25 2013 dsterba@suse.cz
- Disable patches.suse/btrfs-0034-optimize-key-searches-in-btrfs_search_slot.patch
- commit e74b2a8
* Wed Sep 25 2013 agraf@suse.de
- ARM: Update config files: Use lpae for multiarch, exynos for LPAE exynos5
- commit 957e65c
* Wed Sep 25 2013 agraf@suse.de
- Clean up ARM patches:
- Refresh patches.arch/arm-arndale-dma.patch.
- Delete patches.arch/arm-exynos-nosparse.patch.
- Delete
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Delete
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
- Delete
  patches.arch/arm-xen-0006-xen-arm-disable-cpuidle-when-linux-is-running-as-dom.patch.
- Delete
  patches.arch/arm-xen-0007-arm-choose-debug-uncompress.h-include-when-uncompres.patch.
- Delete
  patches.arch/arm-xen-0008-xen-arm-enable-PV-control-for-ARM.patch.
- commit 1cdc83d
* Wed Sep 25 2013 agraf@suse.de
- config.conf:
- Update config files for ARM on 3.12.
- commit 2503bec
* Tue Sep 24 2013 trenn@suse.de
- Delete patches.arch/010-acpi_initrd_override_tables.patch.
  This old one alone broke acpi initrd override -> delete it.
- commit a75f081
* Tue Sep 24 2013 jeffm@suse.com
- lustre/lloop: don't change the logical size for the queue.
- commit 4a2006a
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc2.
- Eliminated 3 patches.
- commit d7d9943
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc1.
- Eliminated 42 patches.
- Xen is disabled.
- ARM is disabled.
- commit c58d853
* Mon Sep 23 2013 jeffm@suse.com
- patches.suse/btrfs-add-per-super-attribute-publishing-to-sysfs: Fix issue where
  the error case would still attempt to create sysfs dir.
- commit 129c02b
* Fri Sep 20 2013 jslaby@suse.cz
- power_supply: Prevent suspend until power supply events are
  processed (bnc#841596).
- commit 11b28da
* Wed Sep 18 2013 duwe@suse.de
- Increase NR_CPUS on ppc64 to 2048 (fate#315438)
- commit 8a38aef
* Tue Sep 17 2013 jslaby@suse.cz
- Update config files.
  Fix ZSWAP on vanillas.
- commit da42424
* Tue Sep 17 2013 jeffm@suse.com
- scripts/sequence-patch.sh: Fix for Xen detection with --vanilla
  When we hit the limit code to handle $SKIP_XEN and there aren't
  any Xen patches to apply anyway, we'll fail because LIMIT is unset.
- commit 1d7b879
* Tue Sep 17 2013 jeffm@suse.com
- scripts/tar-up.sh: Disable Xen patches when Xen configs are disabled
  Similar to the change for scripts/sequence-patch.sh, this change
  disables the Xen patches with +noxen in series.conf when creating
  the kernel-source package.
- commit 3104a04
* Tue Sep 17 2013 jeffm@suse.com
- scripts/sequence-patch.sh: Skip Xen patches when Xen configs are disabled.
  When updating the base kernel version, the Xen patches must be updated
  separately. This allows us to skip the Xen patches until they're resynced
  just by disabling the configs.
- commit d9673e9
* Tue Sep 17 2013 jeffm@suse.com
- btrfs: use feature attribute names to print better error
  messages.
- btrfs: add ability to change features via sysfs.
- btrfs: add publishing of unknown features in sysfs.
- btrfs: publish per-super features to sysfs.
- btrfs: add per-super attributes to sysfs.
- btrfs: export supported featured to sysfs.
- kobject: introduce kobj_completion.
- btrfs: add ioctls to query/change feature bits online.
- btrfs: use btrfs_commit_transaction when setting fslabel.
- commit 7e40f1e
* Tue Sep 17 2013 jeffm@suse.com
- config: Update missing ZSWAP configs.
- commit 85bd223
* Mon Sep 16 2013 dsterba@suse.cz
- Btrfs: optimize key searches in btrfs_search_slot.
- Btrfs: remove ourselves from the cluster list under lock.
- Btrfs: do not clear our orphan item runtime flag on eexist.
- Btrfs: fix printing of non NULL terminated string.
- Btrfs: fix memory leak of orphan block rsv.
- Btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP.
- Btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler.
- Btrfs: move btrfs_free_qgroup_config() out of spin_lock and
  fix comments.
- Btrfs: fix oops when writing dirty qgroups to disk.
- Btrfs: fix heavy delalloc related deadlock.
- Btrfs: fix the error handling wrt orphan items.
- Btrfs: don't allow a subvol to be deleted if it is the default
  subovl.
- Btrfs: skip subvol entries when checking if we've created a
  dir already.
- Btrfs: fix possible memory leak in find_parent_nodes().
- Btrfs: return ENOSPC when target space is full.
- Btrfs: don't ignore errors from btrfs_run_delayed_items.
- Btrfs: fix inode leak on kmalloc failure in tree-log.c.
- Btrfs: stop using GFP_ATOMIC when allocating rewind ebs.
- Btrfs: deal with enomem in the rewind path.
- Btrfs: check our parent dir when doing a compare send.
- Btrfs: handle errors when doing slow caching.
- Btrfs: add missing error handling to read_tree_block.
- Btrfs: add missing error check to find_parent_nodes.
- Btrfs: don't bug_on when we fail when cleaning up transactions.
- Btrfs: change how we queue blocks for backref checking.
- Btrfs: add missing mounting options in btrfs_show_options().
- Btrfs: use u64 for subvolid when parsing mount options.
- Btrfs: don't bother autodefragging if our root is going away.
- Btrfs: cleanup reloc roots properly on error.
- Btrfs: reset ret in record_one_backref.
- btrfs: fix get set label blocking against balance.
- Btrfs: set qgroup_ulist to be null after calling ulist_free().
- Btrfs: add missing error checks to add_data_references.
- Btrfs: Release uuid_mutex for shrink during device delete.
- commit ded2bc7
* Sat Sep 14 2013 jslaby@suse.cz
- Linux 3.11.1.
- commit 1383321
* Thu Sep 12 2013 jeffm@suse.com
- config: Enable CONFIG_ZSWAP (bnc#839064).
  It's built-in but a no-op without zswap.enabled=1 on the kernel
  command line.
- commit 1441e59
* Thu Sep 12 2013 jeffm@suse.com
- Update
  patches.fixes/reiserfs-locking-handle-nested-locks-properly.
- Update
  patches.fixes/reiserfs-locking-push-write-lock-out-of-xattr-code.
- Update
  patches.fixes/reiserfs-locking-release-lock-around-quota-operations.
- commit fd0a178
* Fri Sep  6 2013 rgoldwyn@suse.de
- Update config files to enable GFS DLM locking.
- commit 712cff0
* Thu Sep  5 2013 ohering@suse.de
- Drivers: hv: util: Fix a bug in util version negotiation code
  (bnc#838346).
- commit 938aca5
* Wed Sep  4 2013 jbeulich@suse.com
- Update Xen patches to final 3.11.
- commit e71a103
* Tue Sep  3 2013 jeffm@suse.com
- Update to 3.11-final.
- commit 7561c6f
* Thu Aug 29 2013 jslaby@suse.cz
- Linux 3.10.10.
- commit 8038aea
* Tue Aug 27 2013 jeffm@suse.com
- rpm/kernel-docs.spec.in: Fix missing whitespace error in description
- commit 280c88e
* Tue Aug 27 2013 jeffm@suse.com
- Update to 3.11-rc7.
- commit 99e1318
* Wed Aug 21 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc6.
- commit 7ee85be
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.10.9.
- commit a0841e3
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.10.8.
- commit e77e7a7
* Mon Aug 19 2013 jeffm@suse.com
- Update to 3.11-rc6.
- commit b474038
* Thu Aug 15 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc5.
- config.conf: Re-enable Xen configs
- Delete patches.xen/xen-sections.
- commit adcd98b
* Thu Aug 15 2013 jslaby@suse.cz
- Linux 3.10.7.
- commit 771dec3
* Tue Aug 13 2013 guillaume.gardet@oliseo.fr
- config: update armv6 default config to multi-arch armv6
- commit 25b5917
* Mon Aug 12 2013 jeffm@suse.com
- Update to 3.11-rc5.
- commit c33c981
* Mon Aug 12 2013 jslaby@suse.cz
- Linux 3.10.6.
- commit bd99dce
* Sun Aug 11 2013 jslaby@suse.cz
- Update config files.
  Enable acpi pci hotplug again.
- commit f2022c3
* Thu Aug  8 2013 guillaume.gardet@oliseo.fr
- arm: update default config for 3.11.0-rc4
- Add sound modules
- Add TI wifi modules
- commit 448a93c
* Thu Aug  8 2013 dmueller@suse.com
- config/arm: update and reenable ARM64 config
- commit 327e5fc
* Thu Aug  8 2013 dmueller@suse.com
- Reenable ARMv6/ARMv7 configs
- commit 461df98
* Wed Aug  7 2013 jeffm@suse.com
- config: disable RCU_USER_QS
  RCU_USER_QS is used for hacking on debugging the full dynticks model,
  which we've disabled.
- commit 910e01d
* Mon Aug  5 2013 jeffm@suse.com
- reiserfs: locking, release lock around quota operations
  (bnc#815320).
- reiserfs: locking, handle nested locks properly (bnc#815320).
- reiserfs: locking, push write lock out of xattr code
  (bnc#815320).
- commit 01695c8
* Mon Aug  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid hardcoded runtime dependency on
  module-init-tools.
- commit 2889cef
* Mon Aug  5 2013 jeffm@suse.com
- Update to 3.11-rc4.
- commit 38e9077
* Sun Aug  4 2013 jslaby@suse.cz
- Linux 3.10.5 (bnc#829539 bnc#830492).
- Delete
  patches.fixes/drm-i915-Fix-write-read-race-with-multiple-rings.patch.
- Delete
  patches.fixes/drm-i915-correctly-restore-fences-with-objects-attac.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-balloon-Do-not-post-pressure-status-if-in.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-balloon-Fix-a-bug-in-the-hot-add-code.patch.
- commit 4e0ffc2
* Tue Jul 30 2013 jslaby@suse.cz
- Delete patches.drivers/elousb.patch.
- Delete patches.kernel.org/patch-3.10.1-2.
  They are both obsolete.
- commit e924b54
* Mon Jul 29 2013 jeffm@suse.com
- Update to 3.11-rc3.
- Eliminated 3 patches.
- commit c0a4742
* Mon Jul 29 2013 jslaby@suse.cz
- Linux 3.10.4.
- Refresh patches.suse/no-frame-pointer-select.
- commit d58862b
* Fri Jul 26 2013 jslaby@suse.cz
- Linux 3.10.3 (bnc#802347 bnc#830492).
- Delete
  patches.fixes/drm-i915-Only-clear-write-domains-after-a-successful.patch.
- Delete
  patches.fixes/drm-nouveau-use-vmalloc-for-pgt-allocation.patch.
- Delete
  patches.kernel.org/revert-cpufreq-Fix-cpufreq-regression-after-suspend-.patch.
- commit ec6c1d9
* Thu Jul 25 2013 jeffm@suse.com
- btrfs: check index in extent_buffer_page.
- commit 15eacb9
* Thu Jul 25 2013 jdelvare@suse.de
- Hu, OK, RapidIO can't be fully modularized on PPC (yet.)
- commit 4c2611f
* Thu Jul 25 2013 jdelvare@suse.de
- Update config files: build RapidIO support as modules
- commit 1c6c425
* Thu Jul 25 2013 jeffm@suse.com
- rpm/kernel-binary.spec.in: Obsolete microcode_ctl
  The kernel can request CPU microcode itself now and microcode_ctl is
  no longer required.
- commit 43e5ff5
* Thu Jul 25 2013 jeffm@suse.com
- config: enable early CPU microcode loading.
- commit 0911270
* Wed Jul 24 2013 jeffm@suse.com
- btrfs: fall back to global reservation when removing subvolumes.
- commit 026dc43
* Wed Jul 24 2013 jslaby@suse.cz
- drm/i915: correctly restore fences with objects attached
  (bnc#830492).
- commit 49a8c47
* Tue Jul 23 2013 jeffm@suse.com
- config: disable USB_CHIPIDEA
- commit 00cdcf9
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/dmraid45-api-updates.
- commit 8e1fa8b
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 27c899f
* Tue Jul 23 2013 jeffm@suse.com
- Update to 3.11-rc2.
- Eliminated 1 patch.
- commit f6f5941
* Mon Jul 22 2013 jslaby@suse.cz
- Refresh
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Refresh
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
  Update usptream status.
- commit 17cddd7
* Mon Jul 22 2013 jslaby@suse.cz
- Linux 3.10.2.
- Delete
  patches.arch/arm-xen-0003-ARM-let-the-ASID-allocator-handle-suspended-animatio.patch.
- Delete
  patches.arch/arm-xen-0004-ARM-prevent-risks-of-out-of-bound-access-in-ASID-all.patch.
- Delete
  patches.arch/arm-xen-0005-ARM-Cortex-A15-fix-erratum-798181-implementation.patch.
- commit 16a6c33
* Mon Jul 22 2013 jslaby@suse.cz
- drm/i915: Only clear write-domains after a successful wait-seqno
  (bnc#830492).
- drm/i915: Fix write-read race with multiple rings (bnc#830492).
- commit d76b800
* Fri Jul 19 2013 ohering@suse.de
- Drivers: hv: balloon: Do not post pressure status if interrupted
  (bnc#829539).
- Drivers: hv: balloon: Fix a bug in the hot-add code
  (bnc#829539).
- Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- commit 0cd5432
* Thu Jul 18 2013 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7 (bnc#804198).
- commit 123639e
* Tue Jul 16 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit abd0978
* Tue Jul 16 2013 jslaby@suse.cz
- drm/nouveau: use vmalloc for pgt allocation (bnc#802347).
- commit 114f846
* Tue Jul 16 2013 jeffm@suse.com
- Updated patch-mainline headers.
- commit ba04848
* Tue Jul 16 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 13 patches.
- Xen needs updating and is disabled.
- commit 8ffe6ba
* Tue Jul 16 2013 jeffm@suse.com
- config: revert NO_HZ_FULL=y to NO_HZ_IDLE=y (bnc#826946)
  NO_HZ_FULL mode was introduced in v3.10 but still has some
  problems to be worked out. Most notably are issues with
  CPU accounting and how it interacts with power states.
  We'll re-enable it when it's been proven to be stable.
- commit 80c46a2
* Mon Jul 15 2013 jbeulich@suse.com
- Refresh Xen patches (bnc#814211, bnc#826374).
- commit 56bb9c2
* Mon Jul 15 2013 jslaby@suse.cz
- Revert "cpufreq: Fix cpufreq regression after suspend/resume".
- commit 3bcd588
* Sun Jul 14 2013 jslaby@suse.cz
- Linux 3.10.1.
- commit 062e800
* Mon Jul  8 2013 mmarek@suse.cz
- Require 14GB of free space in the buildservice
- commit e7a8371
* Mon Jul  8 2013 jdelvare@suse.de
- patches.suse/ida-remove-warning-dump-stack.patch: Add upstream commit ID
- commit 4fa2dc2
* Sat Jul  6 2013 agraf@suse.de
- ARM: Enable xen for lpae target
- arm: introduce psci_smp_ops.
- ARM: Enable selection of SMP operations at boot time.
- ARM: let the ASID allocator handle suspended animation.
- ARM: prevent risks of out-of-bound access in ASID allocator.
- ARM: Cortex-A15: fix erratum 798181 implementation.
- xen/arm: disable cpuidle when linux is running as dom0.
- arm: choose debug/uncompress.h include when uncompress debug
  is disabled.
- xen/arm: enable PV control for ARM.
- Update config files.
- Refresh patches.xen/xen3-fixup-xen.
- commit 5c7a1e8
* Fri Jul  5 2013 agraf@suse.de
- MMC: Exynos: Add module alias for dw mmc.
- commit 182d5ca
* Wed Jul  3 2013 agraf@suse.de
- ARM: Enable Arndale board with LPAE config
- ARM: EXYNOS: Set 64-bit DMA mask for EXYNOS5250.
- usb: phy: Fix phy-samsung-usb when built as module.
- USB: ehci-s5p: Fix phy reset.
- ARM: Update config files: Make LPAE Exynos only until Multiarch comes
- commit c521db7
* Tue Jul  2 2013 jbeulich@suse.com
- Update Xen patches to 3.10-final.
- commit c5ad3f9
* Mon Jul  1 2013 jeffm@suse.com
- Update to 3.10-final.
- commit f080c74
* Sat Jun 29 2013 dmueller@suse.com
- arm: cubox, use timer initialization directly in the machine descriptor
  Now that the only field in struct sys_timer is .init, delete the struct,
  and replace the machine descriptor .timer field with the
  initialization function itself.
- commit d522780
* Sat Jun 29 2013 dmueller@suse.com
- arm: add and reenable armv6hl
  We've recently decided to remove the softfp
  targets from the openSUSE ARM portfolio. Add
  a armv6hl default kernel flavor and remove
  traces of armv5tel.
- commit 51c5edf
* Fri Jun 28 2013 jslaby@suse.cz
- Linux 3.9.8.
- commit f3348a8
* Thu Jun 27 2013 mszeredi@suse.cz
- Refresh patches.suse/ovl02-vfs-export-do_splice_direct-to-modules.patch.
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 0e47df9
* Thu Jun 27 2013 mszeredi@suse.cz
- Revert "overlayfs: api: do_splice_direct has changed."
  This reverts commit 6cbfbd0e38cefde22aef0daf8be435a26aa840f7.
  This does not work as new_file->f_pos will not get updated so the file position
  will never advance.
- commit 93bc660
* Thu Jun 27 2013 jeffm@suse.com
- overlayfs: api: do_splice_direct has changed.
- commit 6cbfbd0
* Thu Jun 27 2013 guillaume.gardet@oliseo.fr
- arm: build lpae kernel as zImage
- commit d8f6242
* Wed Jun 26 2013 jeffm@suse.com
- Update to 3.10-rc7.
- Eliminated 1 patch.
- commit 888aa58
* Wed Jun 26 2013 dmueller@suse.com
- arm: fix cubox build by reverting removal of mach-types
- commit ff0165e
* Fri Jun 21 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc6 and c/s 1235.
- commit 20cc894
* Thu Jun 20 2013 jslaby@suse.cz
- Linux 3.9.7.
- Update config files.
- commit fccf19c
* Mon Jun 17 2013 jeffm@suse.com
- config: update vanilla configs for -rc6.
- commit ca41cec
* Mon Jun 17 2013 jeffm@suse.com
- Update to 3.10-rc6.
- commit dbed8c7
* Thu Jun 13 2013 jslaby@suse.cz
- Linux 3.9.6.
- Refresh patches.xen/xen3-patch-3.8.
- commit 8ead728
* Tue Jun 11 2013 dmueller@suse.com
- arm: topology: export cpu_topology
- commit e3dca27
* Mon Jun 10 2013 dmueller@suse.com
- Update and reenable armv7hl configs
- commit 2d22236
* Mon Jun 10 2013 jeffm@suse.com
- Update to 3.10-rc5.
- commit 1ce1338
* Mon Jun 10 2013 schwab@suse.de
- Update arm64/default and reenable it
- commit 4d0acbd
* Sun Jun  9 2013 jslaby@suse.cz
- Linux 3.9.5.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.39.
- Delete
  patches.fixes/reiserfs-fix-deadlock-with-nfs-racing-on-create-lookup.
- commit 08531e3
* Wed Jun  5 2013 jeffm@suse.com
- powerpc: add missing include to book3s_xics.c.
- commit fc06ef7
* Wed Jun  5 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc4.
- use vCPU time info registration to support vread_pvclock().
- Delete patches.xen/xen-netback-nr-irqs.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4967b19
* Wed Jun  5 2013 jbeulich@suse.com
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- commit 8f640b2
* Wed Jun  5 2013 mszeredi@suse.cz
- Refreshed overlayfs patches
- commit 0c856a9
* Mon Jun  3 2013 jeffm@suse.com
- Update to 3.10-rc4.
- Eliminated 4 patches.
- commit b3d0118
* Mon Jun  3 2013 jeffm@suse.com
- vtime: Use consistent clocks among nohz accounting.
- commit 731983f
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix spurious multiple-fill in reiserfs_readdir_dentry
  (bnc#822722).
- commit 244eade
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix problems with chowning setuid file w/ xattrs
  (bnc#790920).
- commit 951bebc
* Fri May 31 2013 jeffm@suse.com
- iscsi-target: fix heap buffer overflow on error (CVE-2013-2850,
  bnc#821560).
- commit 0799911
* Wed May 29 2013 jdelvare@suse.de
- Update config files: Modularize HID drivers
  Modularize all HID drivers which can easily be. Some couldn't due to
  weird Kconfig dependencies.
- commit 02ccd70
* Wed May 29 2013 jdelvare@suse.de
- Update config files: disable RADIO_SI476X
  RADIO_SI476X selects SND_SOC_SI476X, which depends on SND_SOC which we do
  not have.
- commit e75c4a8
* Tue May 28 2013 jeffm@suse.com
- Update to 3.10-rc3.
- 2 patches eliminated.
- commit b74ef38
* Fri May 24 2013 jslaby@suse.cz
- Linux 3.9.4.
- Delete
  patches.kernel.org/x86-Fix-bit-corruption-at-CPU-resume-time.patch.
- commit 51bf0ff
* Wed May 22 2013 jslaby@suse.cz
- Refresh
  patches.fixes/misdn-add-support-for-group-membership-check.
  Let's use the new UID/GID API.
- commit 17413bd
* Wed May 22 2013 jeffm@suse.com
- Remove unused 3.9-stable patches.
- commit d28ac96
* Wed May 22 2013 jslaby@suse.cz
- x86: Fix bit corruption at CPU resume time.
- commit 06ad9d8
* Wed May 22 2013 jeffm@suse.com
- config: remove sparc64 configs
  The sparc64 configs have been completely unmaintained for two years.
  If someone wants to resurrect support, we'll accept patches.
- commit 17364b5
* Wed May 22 2013 jeffm@suse.com
- sparc64: revert accidental changes during the 3.9-rc2 update
- commit b120c5a
* Wed May 22 2013 schwab@suse.de
- Update group-source-files.pl to handle symlink to directory
  Also add arch/[^/]+/boot/dts/include/dt-bindings to the list of devel
  files and avoid listing README.SUSE twice.
- commit af248e4
* Tue May 21 2013 jeffm@suse.com
- Update to 3.10-rc2.
- commit e454a38
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.9.3.
- Update config files.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.36.
- commit 00c4cdd
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid duplicates in the certifiate list.
- commit 9d687ad
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do an exit 0 at the end of each scriptlet
  (bnc#809617).
- commit 7d1a48f
* Thu May 16 2013 mmarek@suse.cz
- rpm/config.sh: Use openSUSE:Factory:{ARM,PowerPC}
  The openSUSE:Factory/ports repository does not work.
- commit 756ee56
* Thu May 16 2013 jdelvare@suse.de
- Update config files: CONFIG_ZSMALLOC=y
  Zsmalloc support can no longer be built as a module, so change
  CONFIG_ZSMALLOC=m to =y in all configuration files to fix the build.
- commit 861551b
* Tue May 14 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 10 patches.
- Xen is disabled.
- ARM configs are disabled pending updates.
- In-kernel Bootsplash has been removed.
- EXT4 rich acls are re-enabled after having the index officially reserved.
- commit 0ead2af
* Tue May 14 2013 jdelvare@suse.de
- Change CONFIG_OF_MDIO from y to m as needed
  Fix build after my previous commit, OF_MDIO depends on PHYLIB so when
  turning the latter into a module I should have done so with the former
  as well.
- commit 7e7365d
* Tue May 14 2013 jdelvare@suse.de
- Update config files : build PHYLIB as a module.
  All but armv7hl/cubox: make PHYLIB modular. Most systems don't
  need it, and it registers a mdio_bus driver. As a side effect,
  we have to disable PHY emulation support, as it is only availble
  when PHYLIB is built-in. This driver is rather weird anyway and
  hopefully no system we want to support needs it, so it should be
  OK.
  - CONFIG_PHYLIB=m
  - CONFIG_FIXED_PHY=n
- commit 49e25f5
* Sun May 12 2013 jslaby@suse.cz
- Linux 3.9.2.
- commit 7bb3aa9
* Fri May 10 2013 jbeulich@suse.com
- Update Xen patches to 3.9.1 and c/s 1231.
- commit 0eb4d0d
* Wed May  8 2013 jslaby@suse.cz
- Linux 3.9.1.
- Delete patches.arch/arm-highbank-sata.patch.
- commit 733bf04
* Wed May  8 2013 jslaby@suse.cz
- Refresh patches.rpmify/ptp-pch-depends-on-x86.
  Update upstream status -- it was rejected.
- commit 4173967
* Wed May  8 2013 neilb@suse.de
- Delete
  patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch.
  Patchset went upstream around about
  commit f16b6e8d838b2e2bb4561201311c66ac02ad67df
  in a form that didn't need this patch.
- commit 226d6be
* Wed May  8 2013 neilb@suse.de
- Delete patches.fixes/nfs-connect-timeout.
  Problem fixed upstream by
  commit 3ed5e2a2c394df4e03a680842c2d07a8680f133b
  Author: Trond Myklebust <Trond.Myklebust@netapp.com>
  Date:   Mon Mar 4 17:29:33 2013 -0500
    SUNRPC: Report network/connection errors correctly for SOFTCONN rpc tasks
- commit afa0a59
* Tue May  7 2013 dmueller@suse.com
- Fix -devel package for armv7hl
  armv7hl kernel flavors in the non-multiplatform configuration
  (which is the default for our openSUSE 12.3 release), needs
  more header files from the machine specific directories to
  be included in kernel-devel.
- commit 882120e
* Tue May  7 2013 jslaby@suse.cz
- Delete patches.fixes/nfs-adaptive-readdir-plus.
  Superseded by d69ee9b85541a69a1092f5da675bd23256dc62af.
- commit f35dac6
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/fs-partitions-efi-c-corrupted-guid-partition-tables-can-cause-kernel-oops.
  Superseded by 3eb8e74ec72736b9b9d728bad30484ec89c91dde.
- commit 7838036
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch.
  Superseded by 0773a6cf673316440999752e23f8c3d4f85e48b9.
- commit 36f8ff4
* Mon May  6 2013 jeffm@suse.com
- config.conf: disable s390 support for openSUSE kernels
  There is no community project to build openSUSE on s390 so we don't need
  to waste resources building the kernel for it.
- commit 5e6ccae
* Mon May  6 2013 jdelvare@suse.de
- S390: Disable CONFIG_PHYLIB on 32-bit kernels
  libphy depends on irq code which is only available on 64-bit S390,
  so disable it on 32-bit kernels.
- commit dd79db9
* Sun May  5 2013 jdelvare@suse.de
- idr: Print a stack dump after ida_remove warning
  (http://lists.opensuse.org/opensuse-kernel/2013-04/msg00102.html).
- commit 4c487a5
* Sun May  5 2013 jdelvare@suse.de
- Update config files: enable CC_STACKPROTECTOR
  All other major Linux distributions are building their kernel
  with -fstack-protector, so do the same. See the discussion at:
  http://lists.opensuse.org/opensuse-kernel/2012-06/msg00088.html
  http://lists.opensuse.org/opensuse-kernel/2012-07/msg00000.html
  http://lists.opensuse.org/opensuse-kernel/2013-05/msg00013.html
  - CONFIG_CC_STACKPROTECTOR=y
- commit fc6f988
* Sat May  4 2013 mmarek@suse.cz
- rpm/config.sh: Drop the ARM repository in Kernel:HEAD
  Use the "ports" repository of openSUSE:Factory instead.
- commit 6fc0bd5
* Fri May  3 2013 mmarek@suse.cz
- rpm/mkspec: Stop generating the get_release_number.sh file
  It was only needed for the old KOTD.
- commit ee71b69
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Properly handle KOTD release numbers with
  .g<commit> suffix
- commit ccb20c3
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Drop the %%release_num macro
  We no longer put the -rcX tag into the release string.
- commit b88e78f
* Tue Apr 30 2013 jeffm@suse.de
- Update to 3.9-final.
- commit b4b0bc4
* Mon Apr 29 2013 agraf@suse.de
- Fix highbank sata proc_name.
- commit 1c2686d
* Mon Apr 29 2013 jslaby@suse.cz
- TTY: fix atime/mtime regression (bnc#815745).
- commit 5e42670
* Fri Apr 26 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc8 and c/s 1229.
- commit dd1fbd8
* Fri Apr 26 2013 jslaby@suse.cz
- efi: Export efi_query_variable_store() for efivars.ko
  (bnc#815170).
- commit 02dfd8e
* Fri Apr 26 2013 jslaby@suse.cz
- Update config files.
- commit 25b8212
* Fri Apr 26 2013 jslaby@suse.cz
- x86/Kconfig: Make EFI select UCS2_STRING (bnc#815170).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- commit ae13122
* Fri Apr 26 2013 jslaby@suse.cz
- Linux 3.8.9.
- commit 3f8cfc6
* Wed Apr 24 2013 jeffm@suse.com
- config: disable SCSI_UFSHCD on s390/x
  It depends on PCI and can be re-enabled when PCI is enabled
  on s390/x. I expect eventually another module will be added to use
  a different bus technology so adding a depends PCI on SCSI_UFSHCD
  won't really help.
- commit 754e58e
* Wed Apr 24 2013 jeffm@suse.com
- patches.arch/ppc-prom-nodisplay.patch: Fix build failure.
  Commit 3bf3dbf8 (Update to 3.9-rc2) missed removing an
  instance of the now-gone RELOC macro, causing build failures.
- commit 674c7b1
* Wed Apr 24 2013 jeffm@suse.com
- Update to 3.9-rc8.
  Eliminated 2 patches.
- commit a86daba
* Wed Apr 24 2013 mmarek@suse.cz
- rpm/macros.kernel-source: Fix the -c option if -n is not given
- commit d704806
* Wed Apr 24 2013 jslaby@suse.cz
- x86,efi: Implement efi_no_storage_paranoia parameter
  (bnc#815170).
- efi: Distinguish between "remaining space" and actually used
  space (bnc#815170).
- x86,efi: Check max_size only if it is non-zero (bnc#815170).
- efi: Pass boot services variable info to runtime code
  (bnc#815170).
- Move utf16 functions to kernel core and rename (bnc#815170).
- x86, efivars: firmware bug workarounds should be in platform
  code (bnc#815170).
- commit e166324
* Thu Apr 18 2013 mmarek@suse.cz
- Remove set -x and set +e statements in KMP scripts
- commit 5575c3c
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.8.8.
- commit 193f348
* Fri Apr 12 2013 agraf@suse.de
- cpuidle: calxeda: disable power gating by default.
- commit 1f54900
* Fri Apr 12 2013 jslaby@suse.cz
- Linux 3.8.7.
- Refresh patches.xen/pci-guestdev.
- Delete patches.arch/arm-fix-build-ux500-module.diff.
- commit 9785c05
* Thu Apr 11 2013 sleep_walker@suse.cz
- Enable FRAMEBUFFER_CONSOLE_ROTATION in our kernels
  More and more monitors have insane aspect ratio and can be better used when
  rotated. This may help when X.org is not running and for boot.
- commit f592a19
* Tue Apr  9 2013 jeffm@suse.com
- Refresh patches.xen/xen3-patch-3.9-rc5.
  Previous commit removed a move of a variable declaration to an ifdef section.
- commit 372aad5
* Tue Apr  9 2013 jeffm@suse.com
- Update to 3.9-rc6.
  Eliminated 1 patch.
- commit 68d380d
* Tue Apr  9 2013 agraf@suse.de
- Refresh patches.arch/arm-fec.patch.
- commit 41b3194
* Tue Apr  9 2013 agraf@suse.de
- ARM: cache-l2x0: fix masking of RTL revision numbering and
  set_debug init.
- commit bd5dc17
* Mon Apr  8 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix bootsplash breakage due to stable fix (bnc#813963)
- commit 5d7fc50
* Mon Apr  8 2013 agraf@suse.de
- ARM: Exynos: Update config files: Use DRM instead of FB
- commit 7e7c136
* Sun Apr  7 2013 agraf@suse.de
- ARM: DMA: PL330: Add check if device tree compatible.
- commit 73c94ff
* Sun Apr  7 2013 agraf@suse.de
- ARM: exynos: only use device tree when it exists.
- commit afed1f3
* Sun Apr  7 2013 agraf@suse.de
- rpm/package-descriptions: add lpae config for ARM
- ARM: Update config files (fix default, split out lpae).
- ARM: xen: Add missing define.
- config.conf: add lpae config for ARM
- rpm/package-descriptions: add lpae config for ARM
- commit 958fe54
* Fri Apr  5 2013 jslaby@suse.cz
- Linux 3.8.6.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-3.1.
- Refresh patches.xen/xen3-patch-3.7.
- commit 713918b
* Fri Apr  5 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 0100be6
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: enable ViperBoard drivers
  All kernels which include core (MFD) support for the ViperBoard
  should also include the actual drivers for its functions:
  - CONFIG_I2C_VIPERBOARD=m
  - CONFIG_GPIO_VIPERBOARD=m
- commit 688764f
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: disable UCB1400 on all but ARM
  Currently UCB1400 is only used on ARM OMAP systems, and part of the
  code is dead code that can't even be modularized.
  - CONFIG_UCB1400_CORE=n
  - CONFIG_TOUCHSCREEN_UCB1400=n
  - CONFIG_GPIO_UCB1400=n
- commit c81a0de
* Thu Apr  4 2013 jslaby@suse.cz
- drm/nouveau: Fix typo in init_idx_addr_latched() (bnc#800686).
- commit 6c8af4a
* Wed Apr  3 2013 jeffm@suse.com
- Update to 3.9-rc5.
  EFI_VARS_PSTORE is disabled. It is potentially useful but can brick
  certain models of notebooks. Until it's been confirmed as safe, we
  should keep this disabled.
- commit 7fd0ea3
* Sat Mar 30 2013 jdelvare@suse.de
- Update config files: Build DSA drivers as modules
  DSA drivers can be built as modules since kernel v3.3, so do that:
  - CONFIG_NET_DSA=m
  - CONFIG_NET_DSA_MV88E6XXX=m
  - CONFIG_NET_DSA_MV88E6060=m
  - CONFIG_NET_DSA_MV88E6131=m
  - CONFIG_NET_DSA_MV88E6123_61_65=m
- commit ab03c84
* Fri Mar 29 2013 jdelvare@suse.de
- Update config file config/sparc64/default: drop X86-only GPIO drivers
- commit 931180e
* Fri Mar 29 2013 jeffm@suse.com
- config: enable GPIO_[PS]CH, disable INTEL_MID_DMAC
- commit 46bdeb9
* Fri Mar 29 2013 jdelvare@suse.de
- Update config files: CONFIG_I2C_COMPAT
  Disable compatibility with lm-sensors <= 3.1.1, version 3.1.2 was
  released 3 years ago.
- commit c1b3c2d
* Thu Mar 28 2013 jslaby@suse.cz
- Linux 3.8.5 (bnc#808829,CVE-2013-0913).
- Delete
  patches.drivers/drm-i915-bounds-check-execbuffer-relocation-count.
- Update config files.
- commit acb103a
* Wed Mar 27 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Fix description and summary.
- commit a4cd5e1
* Tue Mar 26 2013 agraf@suse.de
- Delete config/armv7hl/u8500.
- commit b9fe3d9
* Mon Mar 25 2013 jeffm@suse.com
- Updated to 3.9-rc4.
  Eliminated 2 patches.
- commit 894fec7
* Sat Mar 23 2013 jslaby@suse.cz
- rpm/config.sh: build against 12.3
- commit 20fc41c
* Sat Mar 23 2013 jslaby@suse.cz
- Linux 3.8.4.
- commit a14294f
* Thu Mar 21 2013 agraf@suse.de
- SMDKV310: Fix compilation.
- commit cf345eb
* Thu Mar 21 2013 agraf@suse.de
- ARM: FEC: Fix module compilation.
- ARM: kvm: fix IOMMU dependency check.
- omap3isp: fix miscompile.
- VT8500: fix miscompile in clk driver.
- config.conf: Remove imx51 and omap2plus, reenable arm
- Update config files.
- Delete config/armv7hl/imx51.
- Delete config/armv7hl/omap2plus.
- commit 7d60e2d
* Mon Mar 18 2013 jeffm@suse.com
- Update to 3.9-rc3.
- 2 patches were eliminated
  CONFIG_EXPERIMENTAL was eliminated, so I've updated the Xen patches for
  that. DMRAID45 and Rich ACLs also needed updating.
- commit 228c5dd
* Mon Mar 18 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix sed command with multiple certificates
- commit 59405a2
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install the used certificates below
  /etc/uefi/certs (fate#314507).
- commit 19b4300
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Make the template work with multiple
  certificates.
- commit 3bf5898
* Fri Mar 15 2013 jslaby@suse.cz
- Linux 3.8.3 (bnc#804367 bnc#806966).
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-2.6.34.
- Delete
  patches.fixes/e1000e-fix-pci-device-enable-counter-balance.patch.
- Delete
  patches.fixes/revert-USB-EHCI-remove-ASS-PSS-polling-timeout.patch.
- Delete
  patches.suse/suse-hv-Drivers-scsi-storvsc-Initialize-the-sglist.patch.
- commit 1ca6928
* Thu Mar 14 2013 jeffm@suse.com
- Updated to 3.9-rc2.
- Eliminated 52 patches.
- Xen is disabled.
- ARM configs need updating and are disabled.
- commit 3bf3dbf
* Thu Mar 14 2013 jeffm@suse.com
- Updated Patch-mainline headers for HyperV patches.
- commit 2e0d7a5
* Thu Mar 14 2013 jeffm@suse.com
- supported-flag: clean up patches and merge into one
  The config option is renamed to CONFIG_SUSE_KERNEL_SUPPORTED and
  the text has been updated to reflect that SUSE is no longer a
  unit of Novell.
- commit 7761647
* Thu Mar 14 2013 tiwai@suse.de
- drm/i915: bounds check execbuffer relocation count
  (bnc#808829,CVE-2013-0913).
- commit 72202f0
* Wed Mar 13 2013 jeffm@suse.com
- config: disabled CONFIG_SPI and CONFIG_IIO on non-ARM architectures
  These devices are found almost entirely on embedded platforms and
  end up adding hundreds of drivers for hardware that most users won't
  have. On systems using them, they are more likely to be embedded
  systems that should probably have a specialized kernel anyway.
- commit 33d736f
* Wed Mar 13 2013 jeffm@suse.com
- Updated patch-mainline for patches.rpmify/apm-honor-config_apm_cpu_idle-n
- commit 1008856
* Tue Mar 12 2013 ohering@suse.de
- Drivers: hv: balloon: Do not request completion notification
  (fate#314663).
- commit 6b249cb
* Tue Mar 12 2013 jslaby@suse.cz
- e1000e: fix runtime power management transitions (bnc#806966).
- e1000e: fix pci-device enable-counter balance (bnc#806966).
- e1000e: fix accessing to suspended device (bnc#806966).
- commit 48a333b
* Mon Mar 11 2013 rw@suse.de
- supported.conf: add drivers/s390/block/scm_block
  (fate#314095, bnc#807237)
- commit 09836cb
* Sun Mar 10 2013 mmarek@suse.cz
- KMP: Add -c <cert> option to the %%kernel_module_package macro
  This produces an -ueficert subpackage that imports the certificate into
  the MokList when installed (fate#314511)
- commit d8f177c
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: Add the -kmp suffix inside the subpackage definition
- commit 7c6395d
* Tue Mar  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require new mkinitrd in kernel-vanilla
- commit 26431d8
* Tue Mar  5 2013 jbeulich@suse.com
- Update Xen patches to 3.8.2 and c/s 1226.
- commit eee1405
* Tue Mar  5 2013 jdelvare@suse.de
- gpio-ich: Fix ichx_gpio_check_available() return what callers expect.
  Conflicts:
  series.conf
- commit 051149b
* Mon Mar  4 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash-mgadrmfb-workaround.
  Add the same w/a for ast and cirrus KMS, too (bnc#806990).
- commit 0422575
* Mon Mar  4 2013 jslaby@suse.cz
- Linux 3.8.2 (bnc#802153).
- Delete patches.arch/009-acpi_initrd_override_tables.patch.
- Delete
  patches.fixes/quota-autoload-the-quota_v2-module-for-qfmt_vfs_v1-quota-format.
- commit 3611cf6
* Fri Mar  1 2013 tiwai@suse.de
- Fix broken VT1 output with mgadrmfb (bnc#806990).
- commit 0934989
* Fri Mar  1 2013 jslaby@suse.cz
- PCI/PM: Clear state_saved during suspend (bnc#806966).
- commit cdd289b
* Thu Feb 28 2013 agraf@suse.de
- Add AArch64 support
- commit 09220ef
* Thu Feb 28 2013 jslaby@suse.cz
- Update config files.
- commit 9ad7236
* Thu Feb 28 2013 jslaby@suse.cz
- Linux 3.8.1.
- Refresh patches.xen/xen3-patch-2.6.31.
- Delete
  patches.suse/suse-hv-register-clocksource-only-if-its-adverti.patch.
- commit 0c01cac
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy kernel signing changes from 12.3 to the
  packaging branch
- commit 59d2acf
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: 'bc' is required since v3.9-rc1
- commit 4a9a926
* Thu Feb 28 2013 mmarek@suse.cz
- Copy packaging changes from master to the packaging branch
- commit dd227e2
* Wed Feb 27 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit 4687d79
* Tue Feb 26 2013 agraf@suse.de
- ARM: Update config files: Drop mmap min addr to at most 32k
- commit db497a6
* Tue Feb 26 2013 agraf@suse.de
- ARM: default: Update config file: Compile RTC drivers =y
- commit dfccf37
* Tue Feb 26 2013 aj@suse.de
- Mention Linux 3.x as well
- commit 3d86a6c
* Mon Feb 25 2013 jslaby@suse.cz
- TTY: do not update atime/mtime on read/write (bnc#797175
  CVE-2013-0160).
- commit 821f03c
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: balloon: Execute hot-add code in a separate context
  (fate#314663).
- Drivers: hv: balloon: Execute balloon inflation in a separate
  context (fate#314663).
- commit 2c746be
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: vmbus: Handle channel rescind message correctly
  (fate#314665).
- commit bd98cf4
* Thu Feb 21 2013 jbeulich@suse.com
- update Xen patches to 3.8 final and c/s 1224
- add symbols to hypercall stubs
- commit 88b4228
* Wed Feb 20 2013 jslaby@suse.cz
- Delete patches.drivers/x86_acpi_cpufreq_autoload.patch.
  Substituted by efa17194581bdfca0986dabc178908bd7c21ba00 upstream.
- commit a060c45
* Wed Feb 20 2013 trenn@suse.de
- Disable efi pstore by default (bnc#804482).
- commit 5986b31
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_BGRT on ia64
  bgrt_image is only defined on x86.
- commit e252f7f
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_INITRD_TABLE_OVERRIDE on ia64
  It requires max_low_pfn_mapped, which is x86 only.
- commit 9901a64
* Wed Feb 20 2013 jeffm@suse.com
- Update to 3.8-final.
- commit c9c649c
* Tue Feb 19 2013 jslaby@suse.cz
- Revert "USB: EHCI: remove ASS/PSS polling timeout" (bnc#804367).
- commit 83cb8d1
* Tue Feb 19 2013 jslaby@suse.cz
- drm/nouveau/vm: fix memory corruption when pgt allocation fails
  (bnc#802347).
- commit e224175
* Sun Feb 17 2013 jslaby@suse.cz
- Linux 3.7.9.
- commit c6b8d60
* Sun Feb 17 2013 ohering@suse.de
- video: Add Hyper-V Synthetic Video Frame Buffer Driver
- Update config files.
- commit f3ee42f
* Thu Feb 14 2013 jslaby@suse.cz
- Linux 3.7.8.
- Delete
  patches.fixes/revert-iwlwifi-fix-the-reclaimed-packet-tracking-upon-flush-queue.
- commit 59f2b98
* Wed Feb 13 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Only sign the x86_64 kernels
- commit d55bd47
* Tue Feb 12 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add needssslcertforbuild, so that the project
  certificate is available when signing the kernel.
- commit f4f3306
* Tue Feb 12 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Sign vmlinuz in the buildservice
- commit b13c7b4
* Mon Feb 11 2013 jslaby@suse.cz
- Linux 3.7.7.
- commit 67ebb60
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- commit 77e8d63
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 31ecddc
* Mon Feb 11 2013 jeffm@suse.de
- Update to 3.8-rc7.
  Eliminated 1 patch.
- commit 82fec2f
* Wed Feb  6 2013 jbeulich@suse.com
- Refresh.
- commit 1001e0b
* Wed Feb  6 2013 jbeulich@suse.com
- xen-pciback: rate limit error messages from
  xen_pcibk_enable_msi{,x}() (CVE-2013-0231 XSA-43 bnc#801178).
- Update Xen patches to 3.8-rc6 and c/s 1222.
- commit e6b44d3
* Wed Feb  6 2013 ohering@suse.de
- Drivers: hv: Bind all vmbus interrupts to the boot CPU
  (fate#314665).
- Drivers: hv: vmbus: Use the new infrastructure for delivering
  VMBUS interrupts (fate#314665).
- Delete patches.suse/suse-hv-fate314665-force-win2008.patch.
- commit 444d3d1
* Tue Feb  5 2013 ohering@suse.de
- X86: Handle Hyper-V vmbus interrupts as special hypervisor
  interrupts (fate#314665).
- hv: deliver vmbus interrupts to all vcpus
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-2.6.27.
- commit 3a682f8
* Tue Feb  5 2013 ohering@suse.de
- X86: Add a check to catch Xen emulation of Hyper-V
  (fate#314665).
- commit 3f41db6
* Tue Feb  5 2013 jeffm@suse.com
- quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit bdeb401
* Tue Feb  5 2013 jeffm@suse.com
- quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit ecd48c7
* Tue Feb  5 2013 jbeulich@suse.com
- Update Xen patches to 3.7.6 and c/s 1222.
- xen-pciback: rate limit error messages from
  xen_pcibk_enable_msi{,x}() (CVE-2013-0231 XSA-43 bnc#801178).
- commit ffecceb
* Mon Feb  4 2013 jeffm@suse.com
- Revert "iwlwifi: fix the reclaimed packet tracking upon
  flush queue".
- commit 8f91af5
* Mon Feb  4 2013 jslaby@suse.cz
- Linux 3.7.6 (bnc#800701).
- Update config files.
- Delete patches.drivers/alsa-hda-001-Fix-non-snoop-page-handling.
- commit bcd9d42
* Sun Feb  3 2013 jeffm@suse.com
- Update to 3.8-rc6.
- commit afa3941
* Thu Jan 31 2013 tiwai@suse.de
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
  Conflicts:
  series.conf
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
- commit 86d0404
* Wed Jan 30 2013 ohering@suse.de
- scsi: storvsc: avoid usage of WRITE_SAME.
- Drivers: scsi: storvsc: Initialize the sglist.
- Drivers: hv: Execute shutdown in a thread context.
- commit 133b379
* Wed Jan 30 2013 jeffm@suse.com
- ptp: PTP_1588_CLOCK_PCH depends on x86.
- commit 99fbe25
* Wed Jan 30 2013 ohering@suse.de
- scsi: storvsc: avoid usage of WRITE_SAME.
- Drivers: scsi: storvsc: Initialize the sglist.
- Drivers: hv: Execute shutdown in a thread context.
- commit 1b6d4ef
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on s390/x
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else. Not sure why s390 got skipped in the previous commit.
- commit f0b494a
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on non-ARM arches
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else.
- commit 2bf6fb1
* Wed Jan 30 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc5 and c/s 1218.
- commit 36b617a
* Wed Jan 30 2013 tiwai@suse.de
- ALSA: hda - Fix non-snoop page handling (bnc#800701).
- commit 9969bb3
* Wed Jan 30 2013 jbeulich@suse.com
- Comment out patches.drivers/x86_acpi_cpufreq_autoload.patch as
  conflicting with 3.8.-rc5. Refresh patches.xen/xen3-auto-common.diff.
- commit 737e677
* Wed Jan 30 2013 jeffm@suse.com
- Update to 3.8-rc5.
  Eliminated 4 patches.
- commit e8b3b53
* Tue Jan 29 2013 jeffm@suse.com
- sysctl: Fixed vm.dirty_ratio sysctl name for desktop flavors
- commit 3d41dfd
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/config.sh: Update buildservice projects.
- commit d9a9e6d
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/config.sh: Update $IBS_PROJECT_ARM
- commit 3e873c5
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 2ae0171
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 3c7bac7
* Mon Jan 28 2013 jslaby@suse.cz
- Linux 3.7.5 (bnc#756085).
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete patches.drivers/x86_acpi_cpufreq_autoload.patch.
- commit 236d8d7
* Thu Jan 24 2013 jeffm@suse.com
- Updated to 3.8-rc2.
  Eliminated 1 patch.
- commit e466109
* Tue Jan 22 2013 jslaby@suse.cz
- Linux 3.7.4.
- commit 7f4460e
* Mon Jan 21 2013 agraf@suse.de
- ARM: fix imx usb driver build issue.
- commit 4f2d1a3
* Sun Jan 20 2013 agraf@suse.de
- Delete config/armv7hl/highbank (included in default now)
- commit c0e90d8
* Sun Jan 20 2013 agraf@suse.de
- ARM: Default: Update config file (enable multiarch)
- commit 8a5d039
* Sat Jan 19 2013 agraf@suse.de
- Delete config/armv7hl/tegra
- commit b63dfab
* Sat Jan 19 2013 agraf@suse.de
- ARM: IMX51: Update config file (enable drm)
- commit 8e98c0c
* Sat Jan 19 2013 agraf@suse.de
- ARM: IX51: Update config file (enable drm)
- commit e2d2446
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file
- commit e83ffaa
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file (set drm+video =y)
- commit 7904ca2
* Sat Jan 19 2013 agraf@suse.de
- staging/omapdrm: garbage collect OMAP_DSS_DISPLAY_SUSPENDED.
- OMAP: Fix missing usb.h include.
- OMAP: Fix missing cm3xxx.h include.
- commit c3f4aa6
* Sat Jan 19 2013 agraf@suse.de
- ARM: use zImage for "default" flavor
- commit 0d71552
* Thu Jan 17 2013 jslaby@suse.cz
- Linux 3.7.3.
- Refresh
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch.
- commit 9f86828
* Tue Jan 15 2013 dmueller@suse.com
- Fix build of omap2plus kernel
- commit 48790e9
* Tue Jan 15 2013 dmueller@suse.com
- reenable armv7hl configs
- commit a996303
* Tue Jan 15 2013 ohering@suse.de
- hyperv: force vmbus interrupts to cpu 0. (instead of forcing ws2008 during vmbus negotiation.)
- hyperv: force vmbus interrupts to cpu 0.
  (instead of forcing ws2008 during vmbus negotiation.)
- commit a5459d4
* Tue Jan 15 2013 ohering@suse.de
- x86: Hyper-V: register clocksource only if its advertised (bnc#792500).
- x86: Hyper-V: register clocksource only if its advertised
  (bnc#792500).
- commit 2c26304
* Tue Jan 15 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc3.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4de2e49
* Fri Jan 11 2013 jslaby@suse.cz
- Linux 3.7.2.
- commit d62551b
* Thu Jan 10 2013 jeffm@suse.com
- Update to 3.8-rc3.
- commit 7ce28dd
* Thu Jan 10 2013 dmueller@suse.com
- config: update armv5tel config for 3.8-rc2
- commit df5a66e
* Mon Jan  7 2013 ohering@suse.de
- hyperv: force ws2008 during vmbus negotiation.
- force ws2008 during vmbus negotiation.
- commit b93e5a2
* Fri Jan  4 2013 jeffm@suse.com
- staging/sb105x: remove asm/segment.h dependency.
- commit 473afce
* Thu Jan  3 2013 jeffm@suse.com
- config: Update vanilla configs.
- commit 0d2a457
* Thu Jan  3 2013 jeffm@suse.com
- Updated to 3.8-rc2.
- commit 79d206a
* Thu Dec 27 2012 jslaby@suse.cz
- drm/i915: TLB invalidation with MI_FLUSH_DW requires a post-sync
  op v3 (bnc#795963).
- commit db55aa9
* Tue Dec 25 2012 jeffm@suse.com
- Updated to 3.8-rc1.
- Eliminated 13 patches.
- Xen is disabled.
- ARM configs need updating.
- ext4 richacls are disabled until the upstream index can be reserved.
- commit a952042
* Tue Dec 18 2012 jbeulich@suse.com
- Update Xen patches to 3.7.1 and c/s 1213.
- commit 756a7d4
* Mon Dec 17 2012 jslaby@suse.cz
- Linux 3.7.1.
- Delete patches.rpmify/ezusb-add-dependency-to-usb.
- commit 7c5f8a6
* Wed Dec 12 2012 jeffm@suse.com
- ezusb: add dependency to USB.
  This prevents build failures by making it depend on the value of CONFIG_USB.
  Commit 36e0f0bd did this for architectures other than ARM manually.
- commit b89db5d
* Tue Dec 11 2012 ohering@suse.de
- Drivers: hv: balloon: Fix a memory leak.
- commit 26cdad5
* Tue Dec 11 2012 jeffm@suse.com
- Update to 3.7-final.
- commit 1771a73
* Tue Dec 11 2012 ohering@suse.de
- Update patch headers for fate314663 and fate314665 changes
- commit 44044f1
* Tue Dec 11 2012 jack@suse.cz
- Disable ext3 driver in all kernels and use ext4 driver instead. Eventually
  ext3 will be removed upstream so let's do the transition.
- commit dadc8ea
* Mon Dec 10 2012 jslaby@suse.cz
- Linux 3.6.10.
- Refresh patches.xen/xen3-patch-3.4.
- commit cfa7c19
* Fri Dec  7 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (armv7) config: Enable TWL* USB drivers
- commit 28c09f5
* Fri Dec  7 2012 jbeulich@suse.com
- rpm/kernel-binary.spec.in: Conditionalize the use of vmlinuz instead
  of bzImage for Xen flavors.
- commit 713a73c
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen config files (enable XEN_BZIMAGE and EFI_STUB).
- commit d1ec1be
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen patches to 3.7-rc7 and c/s 1211.
- allow non-pv-ops kernel to be built as bzImage.
- commit 2a7feb8
* Thu Dec  6 2012 ohering@suse.de
- fate#314663 hyper-v memory ballooning support
- mm: Export a function to get vm committed memory.
- Drivers: hv: Add Hyper-V balloon driver.
- Drivers: hv: balloon: Fix a bug in the definition of struct
  dm_info_msg.
- Update config files.
  fate#314665 hyper-v: Update the Vmbus protocol
- Drivers: hv: Implement routines for read side signaling
  optimization.
- Drivers: hv: Add state to manage batched reading.
- Drivers: hv: Turn off batched reading for util drivers.
- Drivers: hv: Optimize signaling in the read path.
- Drivers: hv: Optimize the signaling on the write path.
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask().
- Drivers: hv: Support handling multiple VMBUS versions.
- Drivers: hv: Update the ring buffer structure to match win8
  functionality.
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for
  win7 and beyond.
- Drivers: hv: Save and export negotiated vmbus version.
- Drivers: hv: Change the signature for hv_signal_event().
- Drivers: hv: Change the signature of vmbus_set_event().
- Drivers: hv: Move vmbus version definitions to hyperv.h.
- Drivers: hv: Manage signaling state on a per-connection basis.
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and
  beyond.
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID.
- Drivers: hv: Add state to manage incoming channel interrupt
  load.
- Drivers: hv: Modify the interrupt handling code to support
  win8 and beyond.
- Drivers: hv: Add code to distribute channel interrupt load.
- Drivers: hv: Get rid of the unused global signaling state.
- Drivers: hv: Get rid of unnecessary request for offers.
- Drivers: hv: Manage event tasklets on per-cpu basis.
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus.
- Drivers: hv: Add a check to deal with spurious interrupts.
- Drivers: hv: Enable protocol negotiation with win8 hosts.
- Drivers: hv: Implement flow management on the send side.
- Drivers: hv: Capture the host build information.
- Drivers: hv: Cleanup and consolidate reporting of build/version
  info.
- commit 4fccd03
* Wed Dec  5 2012 jeffm@suse.com
- Update to 3.7-rc8.
- Delete patches.rpmify/net-fix-build-failure-in-xilinx.
- commit 76b3d92
* Tue Dec  4 2012 ohering@suse.de
- add splash=black option to bootsplash code,
  to keep a black background, useful for remote access to VMs
  (bnc#773487)
- commit c060ae1
* Tue Dec  4 2012 jslaby@suse.cz
- Linux 3.6.9.
- commit 9966a2e
* Tue Nov 27 2012 jslaby@suse.cz
- Linux 3.6.8.
- commit 6fb821e
* Fri Nov 23 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not remove fillup from the buildsystem
  (bnc#781327)
- commit 841d864
* Tue Nov 20 2012 jeffm@suse.com
- net: fix build failure in xilinx.
- commit 28be621
* Tue Nov 20 2012 sjayaraman@suse.com
- Update config files. Enable CONFIG_SMB2 to 'y'.
- commit 25bdfaf
* Mon Nov 19 2012 jeffm@suse.com
- Update to 3.7-rc6.
- commit daac70a
* Sun Nov 18 2012 jslaby@suse.cz
- rpm/config.sh: build against 12.2
  It should fix the firmware build problem.
- commit d760411
* Sun Nov 18 2012 jslaby@suse.cz
- Linux 3.6.7.
- commit 2bc3b09
* Fri Nov 16 2012 mmarek@suse.cz
- rpm/config.sh: Set projects for ARM
- commit 55bac79
* Thu Nov 15 2012 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (fix FPU handling related
  crash in context switch code).
- commit bb1d12d
* Wed Nov 14 2012 jbeulich@novell.com
- Update to 3.7-rc5.
- Update Xen patches additionally to c/s 1204:
- commit d5de9cf
* Tue Nov  6 2012 jeffm@suse.com
- config: sync x86_64 configs for NR_UARTS
  This commit sets both CONFIG_SERIAL_8250_RUNTIME_UARTS and
  CONFIG_SERIAL_8250_NR_UARTS to 32.
- commit ddf88e6
* Tue Nov  6 2012 jeffm@suse.com
- Delete patches.arch/s390-remove-kvm-para.patch.
- commit f759e1e
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64 configs for LIB80211, NET_SDA_MV*
  This commit changes the following options to be modular:
  LIB80211
  NET_DSA_MV88E6XXX
  NET_DSA_MV88E6060
- commit caa5a52
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64/debug with ppc64/default
  The debug config should be identical to default with the exception of
  the debug options. This patch brings ppc64/debug in line with ppc64/default
  with the exception of a few things that are modular in debug that should
  also be modular in default.
- commit b981fcd
* Tue Nov  6 2012 jeffm@suse.com
- config: sync kvm options between ppc64 flavors.
- commit 8a389d5
* Tue Nov  6 2012 jeffm@suse.com
- config: disable HW_RANDOM_AMD on ppc64
  This chip is only on AMD hardware and an old ppc64 eval board. We can skip
  it on ppc64.
- commit 03001a4
* Tue Nov  6 2012 jeffm@suse.com
- config: Eliminate unused ppc/ppc64 configs.
  The history of the ppc/ppc64 configs is a convoluted one that started
  before the kernel source could support multiple machine types with a
  single image and before there was a usable 64-bit userspace.
  In the subsequent years, the powerpc code has been unified and we've
  released a 64-bit powerpc userspace. The "default" and "ppc64" configs
  on ppc64 are essentially identical and just waste space. The "ppc64"
  config on 32-bit ppc address a long since unnecessary corner case. Users
  who still want a 32-bit userspace with a 64-bit kernel can install and
  update it themselves using the 64-bit repository like i386/x86_64 users
  can do.
  This commit can be summarized thusly:
  rm config/ppc/ppc64
  rm config/ppc/ps3 (already unused)
  mv config/ppc64/ppc64 config/ppc64/default
- commit a9cc3d5
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Add kernel-versatile description
- commit 5424cf2
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Enable armv5 in arch-symbols
- commit 401de81
* Tue Nov  6 2012 jslaby@suse.cz
- Linux 3.6.6.
- commit 9d1e567
* Mon Nov  5 2012 jeffm@suse.com
- config: sync vanilla flavor with default flavor for each platform
  The vanilla configs have drifted away from the default configuration
  for each platform. This patch brings them back in sync.
- commit 8d4661f
* Mon Nov  5 2012 jeffm@suse.com
- config: -ec2 still had CONFIG_ENTERPRISE_SUPPORT enabled.
- commit 9907c37
* Mon Nov  5 2012 jeffm@suse.com
- Updated to 3.7-rc4.
  Eliminated 1 patch.
- commit 5168053
* Mon Nov  5 2012 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (make "unmodified drivers" build again).
- commit 5feff7e
* Fri Nov  2 2012 jbeulich@novell.com
- Update Xen patches to 3.7-rc3 and c/s 1202.
- extend base interfaces to support multi-page rings for
  frontend/backend communication.
- blkback: allow using multiple page frontend communication ring.
- blkfront: allow using multiple page backend communication ring.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Fix build when disabled.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- Delete patches.xen/xen3-acpi_override_2_2.patch.
- commit f042386
* Fri Nov  2 2012 jbeulich@novell.com
- Refresh patches.xen/xen-x86-EFI (fix build after update to 3.4.17).
- commit 483130a
* Wed Oct 31 2012 jslaby@suse.cz
- Linux 3.6.5.
- commit cefb3b0
* Wed Oct 31 2012 guillaume.gardet@oliseo.fr
- Add support to armv5 versatile kernel
- commit 99d34f3
* Wed Oct 31 2012 jeffm@suse.com
- Update to 3.7-rc3.
- commit 48e5027
* Tue Oct 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require coreutils in kernel-*-devel (bnc#783615)
- commit 2520563
* Tue Oct 30 2012 agraf@suse.de
- ARM: Update config files: Fix vexpress (default) config
- commit be072b4
* Sun Oct 28 2012 jslaby@suse.cz
- Linux 3.6.4.
- commit 0a37c3b
* Thu Oct 25 2012 hare@suse.de
- Fixup kvm for s390.
- commit 503388b
* Tue Oct 23 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable 8bit sd mode to support wifi
- commit 336ead7
* Mon Oct 22 2012 agraf@suse.de
- Revert "disable non-compiling irrelevant I2C module"
- commit d5a21c5
* Mon Oct 22 2012 agraf@suse.de
- thermal: exynos: Fix wrong name of MODULE_DEVICE_TABLE.
- commit 8e108ab
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 565b450
* Mon Oct 22 2012 agraf@suse.de
- Refresh patches.arch/arm-exynos-nosparse.patch.
- commit 55fbf60
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 118f2f9
* Mon Oct 22 2012 agraf@suse.de
- ARM: Exynos: Fix MMC driver
- ARM: Exynos: Update configs
- commit 37a1704
* Mon Oct 22 2012 jeffm@suse.com
- config: change CONFIG_USB_EZUSB_FX2 to module
- commit 36e0f0b
* Mon Oct 22 2012 jeffm@suse.com
- Actually use kthread_run in crasher.ko.
  The previous commit was incomplete.
- commit b8b35ae
* Mon Oct 22 2012 jeffm@suse.com
- crasher: use kthread_run() instead of kernel_thread().
  Linux 3.7-rc2 no longer exports kernel_thread on all architectures.
- commit f17d925
* Mon Oct 22 2012 jeffm@suse.com
- Updated to 3.7-rc2.
- commit e00a663
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable gfx and highmem
- commit e8b3bd9
* Sun Oct 21 2012 jslaby@suse.cz
- Linux 3.6.3.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-3.2.
- Refresh patches.xen/xen3-patch-3.6.
- Delete patches.fixes/hv-storvsc-reset-wait.patch.
- Delete
  patches.rpmify/x86-kbuild-archscripts-depends-on-scripts_basic.
- commit cfee26b
* Thu Oct 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use a macro instead of /etc/IGNORE-KABI-BADNESS
- commit 19e7e54
* Thu Oct 18 2012 agraf@suse.de
- ARM: Update config files: Fix exynos uart
- commit 1b4b5c5
* Thu Oct 18 2012 trenn@suse.de
- Cleanup ACPI table override patches with latest x86-tip commits
  and proper git-xy: meta tags:
- lib: Add early cpio decoder.
- x86, acpi: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Implement physical address table override.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Fix build when disabled.
- X86 ACPI: Use #ifdef not #if for CONFIG_X86 check.
- ACPI: Overriding ACPI tables via initrd only works with
  an initrd.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- Delete patches.arch/acpi_fix_custom_method_acc.patch.
- Delete patches.arch/acpi_override_2_2.patch.
- Delete patches.arch/acpi_override_documentation.
- Delete patches.arch/acpi_override_introduce_taint_func.patch.
- Delete patches.arch/acpi_physical_override.patch.
- Delete patches.arch/lib_earlycpio.patch.
- Delete patches.arch/x86_introduce_reserve_mem_area.patch.
- commit c45da8f
* Wed Oct 17 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Also check for /etc/IGNORE-KABI-BADNESS file
  This allows to control the kabi checker from outside of the package.
- commit 0a0900c
* Wed Oct 17 2012 jeffm@suse.com
- Update to 3.7-rc1.
- Eliminated 38 patches.
- Xen is disabled.
- ARM configs need updating.
- Module signing is disabled until the build infrastructure can support it.
- commit fce087a
* Sat Oct 13 2012 jslaby@suse.cz
- x86/kbuild: archscripts depends on scripts_basic.
- commit 007718d
* Sat Oct 13 2012 jslaby@suse.cz
- Linux 3.6.2.
- commit 798d597
* Thu Oct 11 2012 guillaume.gardet@oliseo.fr
- ARM (omap2plus) : re-enable OMAP DRM module
- commit 379798d
* Wed Oct 10 2012 jslaby@suse.cz
- Delete
  patches.suse/msft-hv-0394-tools-hv-Fix-file-handle-leak.patch.
- Delete
  patches.suse/msft-hv-0395-tools-hv-Fix-exit-error-code.patch.
- Delete
  patches.suse/msft-hv-0396-tools-hv-Check-for-read-write-errors.patch.
  These are in 3.6.1.
- commit 2a321c4
* Mon Oct  8 2012 dmueller@suse.com
- Remove noncompiling modules
- commit b7cdd5a
* Mon Oct  8 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable serial console
- commit a8d41ec
* Sun Oct  7 2012 jslaby@suse.cz
- Linux 3.6.1.
- commit 1f7626a
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: enable Conflicts for
  apparmor, udev and lvm2 also for vanilla kernel
- commit a24206f
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: add Conflicht: hyper-v < 4
  to make sure the daemon is in sync with the kernel
  (bnc#770763 , fate#314441)
- commit 86f9ba3
* Thu Oct  4 2012 jbeulich@novell.com
- Update Xen patches to 3.6-final and c/s 1197.
- Update Xen config files.
- commit 338be2c
* Thu Oct  4 2012 ohering@suse.de
- Hyper-V KVP IP injection (fate#31441)
- hyperv: Add comments for the extended buffer after RNDIS message.
- Drivers: hv: Cleanup the guest ID computation.
- Drivers: hv: vmbus: Use the standard format string to format
  GUIDs.
- Drivers: hv: Add KVP definitions for IP address injection.
- Drivers: hv: kvp: Cleanup error handling in KVP.
- Drivers: hv: Explicitly size elements of protocol structures.
- Drivers: hv: kvp: Support the new IP injection messages.
- Tools: hv: Prepare to expand kvp_get_ip_address() functionality.
- Tools: hv: Further refactor kvp_get_ip_address().
- Tools: hv: Gather address family information.
- Tools: hv: Gather subnet information.
- Tools: hv: Represent the ipv6 mask using CIDR notation.
- Tools: hv: Gather ipv[4,6] gateway information.
- hv: fail the probing immediately when we are not in hyperv
  platform.
- hv: vmbus_drv: detect hyperv through x86_hyper.
- Tools: hv: Get rid of some unused variables.
- Tools: hv: Correctly type string variables.
- Tools: hv: Add an example script to retrieve DNS entries.
- Tools: hv: Gather DNS information.
- Drivers: hv: kvp: Copy the address family information.
- Tools: hv: Add an example script to retrieve dhcp state.
- Tools: hv: Gather DHCP information.
- Tools: hv: Add an example script to configure an interface.
- Tools: hv: Implement the KVP verb - KVP_OP_SET_IP_INFO.
- Tools: hv: Rename the function kvp_get_ip_address().
- Tools: hv: Implement the KVP verb - KVP_OP_GET_IP_INFO.
- tools/hv: Fix file handle leak.
- tools/hv: Fix exit() error code.
- tools/hv: Check for read/write errors.
- tools/hv: Parse /etc/os-release.
- hyperv: Fix the max_xfer_size in RNDIS initialization.
- hyperv: Fix the missing return value in
  rndis_filter_set_packet_filter().
- hyperv: Fix page buffer handling in rndis_filter_send_request().
- hyperv: Remove extra allocated space for recv_pkt_list elements.
- hyperv: Report actual status in receive completion packet.
- hyperv: Add buffer for extended info after the RNDIS response
  message.
- Delete
  patches.suse/suse-hv-Cleanup-the-guest-ID-computation.patch.
- commit 08d283b
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable broken config options
- commit 8d7f8ab
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: disable VFIO
- commit 80abd68
* Mon Oct  1 2012 jeffm@suse.com
- Update to 3.6-final.
- commit 6066894
* Sat Sep 29 2012 dmueller@suse.com
- ARM/u5800: Fix build of ux500 driver
- commit 0ea37a0
* Sat Sep 29 2012 dmueller@suse.com
- disable non-compiling irrelevant I2C module
- commit 0ba9bac
* Sat Sep 29 2012 dmueller@suse.com
- ARM/tegra: Remove optional parts to fix build
- commit d729a16
* Sat Sep 29 2012 dmueller@suse.com
- ARM: enable zcache support
- commit 17b147b
* Sat Sep 29 2012 dmueller@suse.com
- ARM/cubox: set cachefilesd to module
- commit c1fb243
* Fri Sep 28 2012 trenn@suse.de
- Remove old patchset to override ACPI tables via initrd.
  Also remove a stale xen patch related to that.
- Delete
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- Delete
  patches.arch/acpica_fix_wrongly_mapped_acpi_table_header_when_overriding_via_initrd.patch.
- Delete
  patches.arch/acpica_introduce_acpi_os_phys_table_override_function.patch.
- Delete
  patches.xen/xen3-acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- commit dd8f1b0
* Fri Sep 28 2012 trenn@suse.de
- Refresh patches.arch/acpi_override_2_2.patch.
- commit 80dcdb8
* Fri Sep 28 2012 mszeredi@suse.cz
- Update config files to enable building overlayfs as a module.
- commit 42f70e6
* Fri Sep 28 2012 trenn@suse.de
- Update config files.
  Enable ACPI table override capability via initrd for
  all i386/x86_64 flavors:
  +CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
- commit 08721cc
* Fri Sep 28 2012 trenn@suse.de
- ACPI: Only allow users with CAP_SYS_RAWIO rights to overwrite
  ACPI funcs at runtime.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Implement physical address table override.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- X86 ACPI: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- lib: Add early cpio decoder.
- commit dfdfcd3
* Fri Sep 28 2012 mszeredi@suse.cz
- overlayfs: copy up i_uid/i_gid from the underlying inode.
- ovl: switch to __inode_permission().
- vfs: export __inode_permission() to modules.
- overlayfs: create new inode in ovl_link.
- overlayfs: fix possible leak in ovl_new_inode.
- fs: limit filesystem stacking depth.
- overlay: overlay filesystem documentation.
- overlayfs: implement show_options.
- overlayfs: add statfs support.
- overlay filesystem.
- vfs: introduce clone_private_mount().
- vfs: export do_splice_direct() to modules.
- vfs: add i_op->dentry_open().
- commit f3e02da
* Thu Sep 27 2012 agraf@suse.de
- Update config files: Disable JTAG HVC, when enabled the kernel hangs on access
- commit cdf0705
* Tue Sep 25 2012 jeffm@suse.com
- Update to 3.6-rc7.
  Eliminated one patch.
- commit 91c0ddc
* Tue Sep 25 2012 mmarek@suse.cz
- Delete scripts/config.sh, rpm/config.sh has all the needed information
- commit 06c7ff0
* Mon Sep 24 2012 bpoirier@suse.de
- net: do not disable sg for packets requiring no checksum
  (bnc#774859).
- commit f1a1fe2
* Fri Sep 21 2012 bpoirier@suse.de
- af_netlink: force credentials passing [CVE-2012-3520]
  (bnc#776925 CVE-2012-3520).
  Conflicts:
  series.conf
- commit 644e37d
* Fri Sep 21 2012 jslaby@suse.cz
- cgroup: mark subsystems with broken hierarchy support and
  whine if cgroups are nested for them (bnc#781134).
- commit dbeda53
* Fri Sep 21 2012 bpoirier@suse.de
- tcp: Apply device TSO segment limit earlier (bnc#774523
  CVE-2012-3412).
- sfc: Fix maximum number of TSO segments and minimum TX queue
  size (bnc#774523 CVE-2012-3412).
- net: Allow driver to limit number of GSO segments per skb
  (bnc#774523 CVE-2012-3412).
- commit 1908f74
* Thu Sep 20 2012 jeffm@suse.com
- x86/kbuild: archscripts depends on scripts_basic.
  patches.rpmify/makefile-fix-scripts_basic-archscripts-build-order is
  now obsolete.
- commit 33eb1e6
* Wed Sep 19 2012 jeffm@suse.com
- Makefile: Fix scripts_basic / archscripts build order.
- commit 65590b3
* Wed Sep 19 2012 agraf@suse.de
- Delete patches.arch/arm-phys-offset.patch.
- commit 50837bd
* Mon Sep 17 2012 jeffm@suse.com
- Update to 3.6-rc6.
- Eliminated 1 patch.
  patches.arch/arm-phys-offset.patch needs review.
- commit d6432fe
* Sat Sep 15 2012 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid fixdep compilation error
  Let's see if it helps.
- commit c618b7c
* Sat Sep 15 2012 jslaby@suse.cz
- Linux 3.5.4.
- Refresh patches.suse/scsi-error-test-unit-ready-timeout.
- Delete
  patches.fixes/i2c-busses-fix-build-error-if-config_i2c_designware_platform-y-config_i2c_design.
- Update config files.
- commit a925c74
* Tue Sep 11 2012 dmueller@suse.com
- (ARM/tegra) remove non-building module from config
- commit 4cdd491
* Tue Sep 11 2012 jeffm@suse.com
- config: disabled MFD drivers that aren't buildable as modules
  This allows MFD_CORE to be modular on all arch/flavors except for
  ARM and the non-PAE flavors on i386, since it's used with the OLPC XO-1.
- commit ff91de4
* Mon Sep 10 2012 jeffm@suse.com
- Update to 3.6-rc5.
- commit 11b8e7e
* Mon Sep 10 2012 jbeulich@novell.com
- patches.arch/s390-message-catalog.diff: Properly handle pr_cont() and fold
  in the below two trivial fixes.
- Delete patches.arch/s390-message-catalog-fix.diff.
- Delete patches.arch/s390-message-catalog-perl-fix.diff.
- Refresh patches.arch/kmsg-fix-parameter-limitations.
- commit 71b4cc3
* Fri Sep  7 2012 dmueller@suse.com
- fix build of imx51 flavor by removing irrelevant drivers
- commit 7ea6615
* Fri Sep  7 2012 dmueller@suse.com
- remove drivers that do not exist and do not build on ARM (default)
- commit 2319db4
* Thu Sep  6 2012 ohering@suse.de
- Refresh
  patches.suse/suse-hv-identify-virtual-pc-in-ata_piix.patch.
- commit fb4b7f9
* Thu Sep  6 2012 ohering@suse.de
- identify Virtual PC guests in ata_piix (bnc#737532).
- commit 13500ed
* Thu Sep  6 2012 mmarek@suse.cz
- rpm/package-descriptions: Fix typo
- commit c08c34b
* Thu Sep  6 2012 jbeulich@novell.com
- Update Xen patches to 3.6-rc4 and c/s 1188.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 4cdebd8
* Tue Sep  4 2012 jeffm@suse.com
- Update to 3.6-rc4.
- Eliminated one patch.
- commit 9fe3afb
* Tue Sep  4 2012 mmarek@suse.cz
- Disable CONFIG_KMSG_IDS on s390x, because it is currently broken
- commit c1db24a
* Mon Sep  3 2012 jslaby@suse.cz
- Update config files. (vanilla ones)
- commit ca19bfb
* Fri Aug 31 2012 dmueller@suse.com
- ARM(omap2plus): Remove optional parts that don't compile
- commit 77105c2
* Fri Aug 31 2012 jslaby@suse.cz
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- Delete
  patches.fixes/i2c-busses-fix-build-error-if-config_i2c_designware_platform-y-config_i2c_design.
  Move it to rpmify, so that vanilla builds fine too.
- commit 0217ad5
* Thu Aug 30 2012 agraf@suse.de
- Update config files: Add highbank (forgot in last patch)
- commit e86b000
* Thu Aug 30 2012 agraf@suse.de
- config.conf: Enable ARM
- Update ARM config files.
- Add highbank definition
- commit 835e93d
* Thu Aug 30 2012 mmarek@suse.cz
- rpm/kernel-module-subpackage: Provide name-kmp = %%version in KMPs
  This allows userspace packages to require a specific version of a KMP,
  wothout worrying about the _k<kernel version> suffix.
- commit caaaa9a
* Tue Aug 28 2012 jeffm@suse.com
- config: Update -vanilla for ChipIdea fix
- commit c45f0ac
* Tue Aug 28 2012 jeffm@suse.com
- chipidea: Allow user to select PCI/IMX options.
  This allows us to disable the ChipIdea IMX code on powerpc,
  where it was causing build problems.
- commit 278cad2
* Tue Aug 28 2012 jeffm@suse.com
- config: Disable EXYNOS_VIDEO and HW_RANDOM_EXYNOS on all configs except exynos
  This hardware is only found on the Samsung EXYNOS boards.
- commit 429a008
* Mon Aug 27 2012 jeffm@suse.com
- Revert "clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK)."
  This reverts commit 54e1c0025e4757174d8d648e8224bf74009b3c2b.
  The issue is either an incomplete clk API on powerpc or clk_devm needs
  to be made generic. Discussion continues upstream.
- commit 8c9a4e9
* Mon Aug 27 2012 jeffm@suse.com
- clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK).
  This fixes the clk_devm_get build failures on ppc.
- commit 54e1c00
* Mon Aug 27 2012 jeffm@suse.com
- Update to 3.6-rc3.
- commit 0a688a0
* Mon Aug 27 2012 jslaby@suse.cz
- Linux 3.5.3.
- commit ffb9fbd
* Tue Aug 21 2012 jeffm@suse.com
- config: update vanilla configs for 3.6-rc2.
- commit e0fa472
* Fri Aug 17 2012 jeffm@suse.com
- Update to 3.6-rc2.
  - Eliminated 1 patch.
- commit 71963b0
* Wed Aug 15 2012 jslaby@suse.cz
- Fuck, this time maybe
- commit 4904750
* Wed Aug 15 2012 jslaby@suse.cz
- Linux 3.5.2.
- commit 2af8a27
* Fri Aug 10 2012 jeffm@suse.com
- printk: Fix calculation of length used to discard records.
- commit cd6596b
* Fri Aug 10 2012 mmarek@suse.cz
- Revert "rpm/config.sh: really build against openSUSE:12.1 also in the ibs"
  This reverts commit daed3d92. SUSE:openSUSE:12.1:Update:Test does not
  exist, which broke automatic builds. scripts/osc_wrapper is now updated
  to fall back to openSUSE.org:$OBS_PROJECT if IBS_PROJECT is not set.
- commit 370c9f4
* Thu Aug  9 2012 jslaby@suse.cz
- rpm/config.sh: really build against openSUSE:12.1 also in the ibs
- commit daed3d9
* Thu Aug  9 2012 jslaby@suse.cz
- ubifs: remove __DATE__ and __TIME__.
- commit 6702208
* Thu Aug  9 2012 jslaby@suse.cz
- Refresh
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-setup-for-HP-Mini-210.
  Update git-commit tag.
- commit f3a1eba
* Thu Aug  9 2012 jslaby@suse.cz
- Linux 3.5.1.
- Delete
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-initialization-for-IDT-co.
- Delete
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-setup-for-HP-Mini-210.
- Delete
  patches.drivers/ALSA-hda-Fix-polarity-of-mute-LED-on-HP-Mini-210.
- commit d21661b
* Thu Aug  9 2012 jeffm@suse.com
- Update to 3.6-rc2. - Eliminated 2 patches.
- commit b073c66
* Thu Aug  9 2012 jeffm@suse.com
- reiserfs: fix deadlock with nfs racing on create/lookup
  (bnc#762693).
- commit 5b2dce3
* Thu Aug  9 2012 mmarek@suse.cz
- Delete patches.suse/s390-Kerntypes.diff until we get an updated version.
- commit 78f2edc
* Thu Aug  9 2012 mmarek@suse.cz
- Disable CONFIG_DRM_NOUVEAU on ia64 due to build errors
- commit 38e08ef
* Wed Aug  8 2012 mmarek@suse.cz
- Update config files to fix build.
- commit 9c9630c
* Wed Aug  8 2012 dmueller@suse.com
- config: enable various ARM errata workarounds to improve stability
- commit 4e28647
* Tue Aug  7 2012 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:12.1 also in the ibs
- commit 954867f
* Mon Aug  6 2012 tiwai@suse.de
- ASoC: omap: Add missing modules aliases to get sound working
  on omap devices.
- commit cbda3c2
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled DMRAID45.
- commit 6b8bedd
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled richacl support.
- commit 001594d
* Fri Aug  3 2012 jeffm@suse.com
- Update to 3.6-rc1.
  - Eliminated 11 patches.
  - Rich ACLs are disabled.
  - Xen is disabled.
  - ARM is disabled.
  - DMRAID45 is disabled.
- commit 5807d6b
* Fri Aug  3 2012 jeffm@suse.com
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- commit 3bec42b
* Fri Aug  3 2012 jeffm@suse.com
- reiserfs: fix deadlocks with quotas.
- commit 77ba55a
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh Xen patches (fixing a major bug in the most recent Xen commit).
- commit 5df2b91
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh patches.suse/stack-unwind (to work with older tool chains).
- commit 30e4ab0
* Tue Jul 31 2012 jeffm@suse.com
- rpm/kernel-binary.spec.in: Add dependency on mkinitrd >= 2.7.1 (bnc#773559).
- commit 2f75710
* Tue Jul 31 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO initialization for IDT codecs
  (bnc#772923).
- ALSA: hda - Fix polarity of mute LED on HP Mini 210
  (bnc#772923).
- commit f3c90ee
* Mon Jul 30 2012 jeffm@suse.com
- Update config files: HID_GENERIC=y where USBHID=y (bnc#773559).
  On flavors where USBHID is built-in statically, we want HID_GENERIC to
  be built statically as well. This, notably, includes i386/x86_64's desktop
  flavors.
- commit 6d995bc
* Mon Jul 30 2012 jeffm@suse.com
- Synced configs after commit 940e57e2 (Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.)
- commit 104f550
* Mon Jul 30 2012 dmueller@suse.com
- Enable RTL8150 for omap2plus
  Generic USB Network device that also works fine on ARM, so enable it
- commit 400dcb7
* Mon Jul 30 2012 ohering@suse.de
- Drivers: hv: Cleanup the guest ID computation.
- hyperv: Add a check for ring_size value.
- hyperv: Add error handling to rndis_filter_device_add().
- Drivers: hv: Change the hex constant to a decimal constant.
- hyperv: Add support for setting MAC from within guests.
- commit 73d4430
* Fri Jul 27 2012 trenn@suse.de
- ACPI: Only count valid srat memory structures (bnc#757888).
- ACPI: Untangle a return statement for better readability
  (bnc#757888).
- commit 876d6b9
* Fri Jul 27 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix wrong vfree() (bnc#773406)
- commit a637a16
* Thu Jul 26 2012 tiwai@suse.de
- Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.
  This feature was dropped from 12.2/FACTORY packages due to instability
  (bnc#768506,bnc#765524)
- commit 940e57e
* Thu Jul 26 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO setup for HP Mini 210
  (bnc#772923).
- commit 0ac6c27
* Thu Jul 26 2012 jeffm@suse.com
- Enabled patches.fixes/brcmsmac-firmware.
- commit 4ed5cb4
* Thu Jul 26 2012 jeffm@suse.com
- brcmsmac: document firmware dependencies (bnc#733148).
- commit f489263
* Wed Jul 25 2012 jbeulich@novell.com
- Update Xen patches to 3.5-final and c/s 1184.
- Delete patches.xen/xen3-apei_allow_drivers_access_nvs_ram.patch.
- commit 341366d
* Tue Jul 24 2012 jeffm@suse.com
- Update to 3.5-final.
  patches.suse/dm-raid45-26-Nov-2009.patch needs updating to new kmsg
  interface but, since powerpc isn't officially supported by opensuse, the
  update can happen later.
- commit fb9c50b
* Mon Jul 23 2012 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Update mainline tag.
- commit 4e207cd
* Fri Jul 20 2012 jslaby@suse.cz
- Linux 3.4.6.
- patches.xen/xen3-patch-3.3:
- Delete
  patches.fixes/acpica_fix_null_pointer_in_repair_code.patch.
- commit 3689ec0
* Fri Jul 20 2012 dsterba@suse.cz
- btrfs: do not update atime for RO snapshots (FATE#306586).
- commit 2073e27
* Wed Jul 18 2012 ohering@suse.de
- Delete patches.suse/led_classdev.sysfs-name.patch.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
- commit 13b12c9
* Wed Jul 18 2012 ohering@suse.de
- Delete patches.suse/led_classdev.sysfs-name.patch.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
- commit a2f36dc
* Tue Jul 17 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix a typo in the capability bit check (bnc#768506).
- commit 66cae25
* Tue Jul 17 2012 jslaby@suse.cz
- Linux 3.4.5.
- Refresh patches.fixes/bridge-module-get-put.patch.
- Delete patches.fixes/acpi_quirk_cover_all_timer_overrides.patch.
- Delete
  patches.fixes/fujitsu_amilo_v2030_timeroverride_quirk.patch.
- Delete
  patches.fixes/mm-correctly-synchronize-rss-counters-at-exit-exec.patch.
- Delete
  patches.fixes/nfs-force-the-legacy-idmapper-to-be-single-threaded.
- Delete
  patches.fixes/udf-Avoid-run-away-loop-when-partition-table-length-.patch.
- Delete patches.fixes/udf-Fortify-loading-of-sparing-table.patch.
- Delete
  patches.fixes/udf-Use-ret-instead-of-abusing-i-in-udf_load_logical.patch.
- commit 5bbda10
* Mon Jul 16 2012 jeffm@suse.com
- Updated to 3.5-rc7.
- Eliminated 1 patch.
- commit 58a8fc5
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Updates vanilla config files to include NFS_DEBUG implied by SUNRPC_DEBUG
- commit f36b6ed
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Update 'vanilla' configs for SUNRPC_DEBUG
- commit 7749430
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add new option SUNRPC_DEBUG.  This functionality was previously
  always on, and is needed by "rpcdebug" to enable tracing.
  We often ask customers to enable this to analyse NFS issues.
- commit a0aa02e
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add SUNRPC_DEBUG - a new option for functionality that was
  previously always present.
  Without this, "rpcdebug" doesn't work.
  We often request customers enable this to analyse problems.
- commit b4fa24f
* Thu Jul 12 2012 mmarek@suse.cz
- Update vanilla config files.
- commit a0c6b82
* Thu Jul 12 2012 agraf@suse.de
- ARM: Add PM support for OMAP4460 (fixes instability issues)
- commit 9149272
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 8442da0
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 0998ae0
* Tue Jul 10 2012 agraf@suse.de
- Refresh patches.arch/arm-omap-drm-fix-global-buffer.patch: typo
- commit 65dce23
* Tue Jul 10 2012 agraf@suse.de
- Refresh patches.arch/arm-omap-drm-fix-global-buffer.patch: Fix OMAP3
- commit 6df2baf
* Tue Jul 10 2012 agraf@suse.de
- ARM: OMAP: Update config files: Enable status LED
- commit afc95c8
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc6.
- Eliminated 1 patch.
- commit 93575a7
* Mon Jul  9 2012 jeffm@suse.com
- coretemp-xen: Fix usage of X86_FEATURE_DTS -> X86_FEATURE_DTHERM
  Upstream commit 4ad33411308596f2f918603509729922a1ec4411 renamed _DTS to
  _DTHERM, so fix its usage in the Xen driver.
- commit 1732d37
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=y.
- commit 72cd989
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=m.
- commit cdced94
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc5.
- Eliminated 2 patches.
- commit ec675c6
* Sat Jul  7 2012 agraf@suse.de
- ARM: OMAP: dss: GLOBAL_BUFFER hack.
- commit d70ee95
* Thu Jul  5 2012 agraf@suse.de
- Update config files: use PR KVM on ppc/ppc64
- commit c902ea5
* Wed Jul  4 2012 hare@suse.de
- mach-dove: define TIMER_PHYS_BASE.
- Update config files.
- commit 0ea0e05
* Wed Jul  4 2012 agraf@suse.de
- Update config files.
- commit 97411e1
* Wed Jul  4 2012 agraf@suse.de
- Remove non-ARM and Samsung specific CMA patches, we only need the framework for OMAP
- commit a9a5b39
* Wed Jul  4 2012 trenn@suse.de
- Fix NULL pointer derference in acpi_ns_check_object_type()
  (kernel bug 44171).
- commit 10f1915
* Wed Jul  4 2012 trenn@suse.de
- Fix NULL pointer derference in acpi_ns_check_object_type()
  (kernel bug 44171).
- commit 36cf667
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/dell_latitude_e6xxx_e5xxx__fix_reboot.patch.
- Delete patches.drivers/apei_allow_drivers_access_nvs_ram.patch.
- commit c6e9e42
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/acpi_fix_fadt_32_bit_zero_length.patch.
- Delete patches.suse/acpi_osi_sle11_ident.patch.
- commit d8799fb
* Tue Jul  3 2012 agraf@suse.de
- Update config files for CMA
- commit 2b3ec9b
* Tue Jul  3 2012 agraf@suse.de
- ARM: backport CMA framework (required for omapdrm)
- commit d0c4392
* Tue Jul  3 2012 jack@suse.cz
- udf: Fortify loading of sparing table (bnc#769784).
- udf: Avoid run away loop when partition table length is
  corrupted (bnc#769784).
- udf: Use 'ret' instead of abusing 'i' in udf_load_logicalvol()
  (bnc#769784).
- commit 48e23e1
* Tue Jul  3 2012 agraf@suse.de
- omap2+: add drm device for the new Xorg driver.
- omap2+: Revert "mmc: omap_hsmmc: Enable Auto CMD12".
- omap2+: Revert "Fix OMAP EHCI suspend/resume failure (i693)".
- omap2+: add drm device for the new Xorg driver.
- commit babe620
* Mon Jul  2 2012 trenn@suse.de
- ACPI: Make acpi_skip_timer_override cover all source_irq==0
  cases (bnc#676068).
- ACPI: Add a quirk for "AMILO PRO V2030" to ignore the timer
  overriding (bnc#676068).
- Refresh patches.xen/xen3-patch-2.6.27.
- commit ce6a9c8
* Mon Jul  2 2012 dsterba@suse.cz
- btrfs: allow cross-subvolume file clone (bnc#698540).
- btrfs: use correct device for maps (bnc#672923 bnc#769545).
- btrfs: allow cross-subvolume file clone (bnc#698540).
- btrfs: use correct device for maps (bnc#672923 bnc#769545).
- commit 25d8571
* Wed Jun 27 2012 jbeulich@novell.com
- Update Xen patches to c/s 1182.
- Update Xen and EC2 config files.
- commit 1f9dec5
* Tue Jun 26 2012 vojtech@suse.com
- Update post.sh to make the RT kernel default in the bootloader
  after installation.
- commit 3c10ce7
* Tue Jun 26 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (ARM) config
- commit 466b846
* Mon Jun 25 2012 jeffm@suse.com
- Updated Patch-mainline for patches.fixes/mm-correctly-synchronize-rss-counters-at-exit-exec.patch.
- commit d022daf
* Mon Jun 25 2012 jeffm@suse.com
- Updated to 3.5-rc4.
- Eliminated 1 patch.
- commit 65cee14
* Mon Jun 25 2012 jeffm@suse.com
- NFS: Force the legacy idmapper to be single threaded
  (bnc#766514).
- commit b73cb98
* Mon Jun 25 2012 jslaby@suse.cz
- Linux 3.4.4.
- Refresh patches.xen/xen3-patch-2.6.35.
- commit 25f83ba
* Sun Jun 24 2012 awafaa@opensuse.org
- Add support for Samsung Exynos SoC
- commit 81fc687
* Sun Jun 24 2012 awafaa@opensuse.org
- Update configs for cubox/default/imx51/tegra/u8500
- commit 65b18f1
* Tue Jun 19 2012 jbeulich@novell.com
- Update Xen patches to 3.5-rc3 and c/s 1182.
- Update x86 config files.
- Delete patches.xen/add-console-use-vt.
- commit d11f278
* Mon Jun 18 2012 jeffm@suse.com
- Fixed up post-3.5-merge conflicts.
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch.
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch.
- commit 7a3a50c
* Mon Jun 18 2012 jeffm@suse.com
- Updated to 3.5-rc3.
- commit 3ee859e
* Mon Jun 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Revert "Add provides and make most obsoletes
  versioned." (commit e3023c7). This change is wrong, the packages have
  their own versioning schemes.
- commit 29957f5
* Mon Jun 18 2012 jbeulich@novell.com
- Delete patches.xen/frontswap-config.
- Delete patches.xen/frontswap-core.
- Delete patches.xen/frontswap-header.
- Delete patches.xen/frontswap-hooks.
- commit cb6120e
* Mon Jun 18 2012 jbeulich@novell.com
- Refresh an re-enable patches.arch/x86_64-unwind-annotations.
- commit 9ed2387
* Sun Jun 17 2012 jslaby@suse.cz
- Linux 3.4.3.
- Delete patches.suse/suse-hv-pata_piix-ignore-disks.patch.
- commit 76639c2
* Fri Jun 15 2012 mhocko@suse.cz
- mm: correctly synchronize rss-counters at exit/exec (bnc#767152).
- commit d161b60
* Thu Jun 14 2012 jeffm@suse.com
- CONFIG_RTC_DRV_CMOS=y on all x86/x86_64 flavors (bnc#755525).
  When rtc_cmos is module, hctosys fails to set the clock on boot, issuing
  ominious error messages to the console.
- commit cddcbe7
* Thu Jun 14 2012 jbeulich@novell.com
- Update x86 config files (ATA_PIIX=m, bnc#766284).
- commit 8677f43
* Thu Jun 14 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Add product ID 0x84 that may have the LED support (bnc#764339)
- commit 6e5a834
* Wed Jun 13 2012 hare@suse.de
- Rediff patch
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch:
  Rediff after backport from upstream.
- commit fa58c5e
* Wed Jun 13 2012 hare@suse.de
- Fixup patch to apply
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch
  backported from upstream.
- commit 2507393
* Wed Jun 13 2012 hare@suse.de
- Add SolidRun Cubox configuration
- Update config files.
- Add separate cubox configuration.
- mach-dove: Fixup ge00 initialisation.
- spi-orion: convert to new infrastructure.
- config.conf: Add cubox configuration
- rpm/package-descriptions: Add cubox description
- commit bfddec4
* Mon Jun 11 2012 jeffm@suse.com
- Update to 3.5-rc2.
  - Xen needs update.
  - ARM needs update.
  - Eliminated 13 patches.
- commit 3f461b1
* Sat Jun  9 2012 jslaby@suse.cz
- Linux 3.4.2.
- commit 16fc260
* Fri Jun  8 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Use depends instead of reverse selection for avoiding the inconsitent
  Kconfig state.
- commit 316d77d
* Wed Jun  6 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix the detection of LED on the recent HP laptops (bnc#765524)
- commit 27c3276
* Tue Jun  5 2012 ohering@suse.de
- usb/net: rndis: merge command codes.
  only net/hyperv part
- usb/net: rndis: remove ambigous status codes.
  only net/hyperv part
- usb/net: rndis: break out <linux/rndis.h> defines.
  only net/hyperv part
- net/hyperv: Add flow control based on hi/low watermark.
- hv: fix return type of hv_post_message().
- Drivers: hv: util: Properly handle version negotiations.
- Drivers: hv: Get rid of an unnecessary check in vmbus_prep_negotiate_resp().
- HID: hyperv: Set the hid drvdata correctly.
- HID: hid-hyperv: Do not use hid_parse_report() directly.
- commit cfebefe
* Mon Jun  4 2012 jslaby@suse.cz
- Linux 3.4.1.
- commit 4415495
* Mon Jun  4 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago.
- commit 695549b
* Mon Jun  4 2012 ohering@suse.de
- [SCSI] storvsc: Properly handle errors from the host
  (bnc#747404).
- Delete patches.suse/suse-hv-storvsc-ignore-ata_16.patch.
- commit ad28e23
* Fri Jun  1 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago...
- commit 86629f1
* Fri Jun  1 2012 guillaume.gardet@oliseo.fr
- Update ARM configs
- commit 550ef37
* Thu May 31 2012 ohering@suse.de
- replace our version of this patch with upstream variant:
  ata_piix: defer disks to the Hyper-V drivers by default
  libata: add a host flag to ignore detected ATA devices.
- commit bf70e35
* Wed May 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the right -kdump initrd (bnc#764500)
- commit 5c85db8
* Tue May 29 2012 mhocko@suse.cz
- Refresh
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control.
  Fix a compile error due to anonymous union initialization not supported
  by earlier gcc versions (<4.6.x).
- commit 790f341
* Tue May 29 2012 jbeulich@novell.com
- Update Xen config files (XEN_SPINLOCK_ACQUIRE_NESTING=1).
- commit d03820c
* Fri May 25 2012 jeffm@suse.com
- Renamed armv7l to armv7hl, following %%_cpu_target convention.
- commit 64b97cd
* Wed May 23 2012 jbeulich@novell.com
- Update Xen patches to 3.4-final and c/s 1177.
- commit a3c5f2c
* Tue May 22 2012 trenn@suse.de
- X86 acpi_cpufreq: Do not use request_module for autoloading
  (bnc#756085).
- Refresh patches.xen/xen3-auto-common.diff.
- patches.xen/xen3-patch-3.3:
- commit caf270e
* Mon May 21 2012 jslaby@suse.cz
- Let's build against 12.1
  Otherwise we are getting build errors.
- commit 6966f52
* Mon May 21 2012 jeffm@suse.com
- Update to 3.4-final.
- commit 91b2c6e
* Tue May 15 2012 agraf@suse.de
- Update config files: ppc64: use PR instead of HV KVM which is usable by more people
- commit 5e7640a
* Tue May 15 2012 jeffm@suse.com
- Make CRYPTO_CRC32C modular (bnc#762344)
  It was pulled in =y via CEPH_LIB=y, so we change the
  following options to =m:
- CONFIG_CEPH_LIB
- CONFIG_CRYPTO_CRC32C
- CONFIG_LIBCRC32C
  Making it modular allows the Intel-optimized crc32c implementation
  to be loaded, improving performance of things like btrfs.
- commit d569763
* Mon May 14 2012 jeffm@suse.com
- Disabled more Intel embedded drivers.
  Disabled:
- CONFIG_GPIO_LANGWELL
- CONFIG_GPIO_PCH
- CONFIG_GPIO_SCH
- commit f554d8b
* Mon May 14 2012 jeffm@suse.com
- USB storage on -desktop should be modular.
- commit 9331d48
* Mon May 14 2012 jeffm@suse.com
- Disabled more testing options.
  Disables:
  - CONFIG_TEST_POWER
  - CONFIG_VIDEO_MEM2MEM_TESTDEV
- commit ef1f4ca
* Mon May 14 2012 jeffm@suse.com
- Update to 3.4-rc7.
  - Eliminated 1 patch.
- commit 4cd9e9b
* Sun May 13 2012 jslaby@suse.cz
- Linux 3.3.6.
- commit a4363bf
* Wed May  9 2012 jeffm@suse.com
- geodefb: Depend on X86_32.
  Disables:
- CONFIG_FB_GEODE_GX1
- CONFIG_FB_GEODE_GX
- CONFIG_FB_GEODE_LX
- CONFIG_FB_GEODE
- commit 1f260fb
* Wed May  9 2012 jeffm@suse.com
- Disabled testing config options on !debug
- CONFIG_CRYPTO_TEST
- CONFIG_DMATEST
- CONFIG_RTC_DRV_TEST
- commit d7c9a65
* Wed May  9 2012 guillaume.gardet@opensuse.org
- Update ARM configs
- commit aac8787
* Tue May  8 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc6.
- commit 8ed7ef0
* Mon May  7 2012 jslaby@suse.cz
- Linux 3.3.5.
- commit a8d8330
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support. (Xen version)
- commit 1c19c30
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support.
- commit ad06d7d
* Mon May  7 2012 jeffm@suse.com
- Update to 3.4-rc6.
  - Eliminated 2 patches.
- commit 749ea8f
* Sat May  5 2012 jeffm@suse.com
- Disabled MMC_TEST (bnc#760077).
- commit c36bb06
* Fri May  4 2012 jeffm@suse.com
- sysctl/defaults: kernel.hung_task_timeout -> kernel.hung_task_timeout_secs (bnc#700174)
- commit 94b5c35
* Thu May  3 2012 guillaume.gardet@opensuse.org
- Update config/armv7l/omap2plus
- commit db627f7
* Wed May  2 2012 jeffm@suse.com
- patches.drivers/ehea-modinfo.patch: Updated patch-mainline for submission.
- commit e0eb735
* Wed May  2 2012 jeffm@suse.com
- omap-usb-host: include <plat/cpu.h>.
- commit 4d1394a
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require distribution-release
  during build.
- commit 3cd703f
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Depend on distribution-release, so that
  the grub entry has correct title (bnc#757565).
- commit 30145a4
* Mon Apr 30 2012 jeffm@suse.com
- Updated and re-enabled armv7l.
  Thanks to Guillaume GARDET <guillaume.gardet@opensuse.org>
- commit d5a693e
* Mon Apr 30 2012 neilb@suse.de
- Update config files.
  Add CONFIG options for NFSv4v1 support.
  bnc#730444
- commit bd05821
* Mon Apr 30 2012 jeffm@suse.com
- Update to 3.4-rc5.
- commit e4e6b33
* Fri Apr 27 2012 jslaby@suse.cz
- Linux 3.3.4.
- commit d42fe44
* Fri Apr 27 2012 jeffm@suse.com
- Disabled more Moorestown/Medfield drivers.
  Specific options disabled:
  I2C_INTEL_MID
  CONFIG_SFI
  MTD_NAND_DENALI
  SERIAL_MRST_MAX3110
  DRM_GMA600
  SPI_DW_MID_DMA
  APDS9802ALS
- commit 9a9ecdf
* Thu Apr 26 2012 jeffm@suse.com
- Disabled DECNet and ARCNet.
  Specific config options disabled:
  CONFIG_ARCNET
  CONFIG_ARCNET_1051
  CONFIG_ARCNET_1201
  CONFIG_ARCNET_CAP
  CONFIG_ARCNET_COM20020_CS
  CONFIG_ARCNET_COM20020
  CONFIG_ARCNET_COM20020_PCI
  CONFIG_ARCNET_COM90xxIO
  CONFIG_ARCNET_COM90xx
  CONFIG_ARCNET_RAW
  CONFIG_ARCNET_RIM_I
  CONFIG_DECNET
  CONFIG_DECNET_NF_GRABULATOR
- commit 272dd14
* Thu Apr 26 2012 jeffm@suse.com
- Disabled embedded hardware on all architectures except armv7l.
  Regulator drivers, except those needed by Via vx885/875 and OLPC
  are disabled.  IIO drivers are disabled.  SPI drivers are disabled.
  Drivers used only with Intel Medfield or Moorestown have been disabled.
  Specific options disabled:
  CONFIG_AD2S1200, CONFIG_AD2S1210, CONFIG_AD2S90, CONFIG_AD5064,
  CONFIG_AD5360, CONFIG_AD5380, CONFIG_AD5421, CONFIG_AD5446, CONFIG_AD5504,
  CONFIG_AD5624R_SPI, CONFIG_AD5686, CONFIG_AD5764, CONFIG_AD5791,
  CONFIG_AD5930, CONFIG_AD5933, CONFIG_AD7150, CONFIG_AD7152, CONFIG_AD7192,
  CONFIG_AD7280, CONFIG_AD7291, CONFIG_AD7298, CONFIG_AD7476,
  CONFIG_AD7606_IFACE_PARALLEL, CONFIG_AD7606_IFACE_SPI, CONFIG_AD7606,
  CONFIG_AD7746, CONFIG_AD7780, CONFIG_AD7793, CONFIG_AD7816, CONFIG_AD7887,
  CONFIG_AD799X, CONFIG_AD799X_RING_BUFFER, CONFIG_AD9832, CONFIG_AD9834,
  CONFIG_AD9850, CONFIG_AD9852, CONFIG_AD9910, CONFIG_AD9951,
  CONFIG_ADE7753, CONFIG_ADE7754, CONFIG_ADE7758, CONFIG_ADE7759,
  CONFIG_ADE7854_I2C, CONFIG_ADE7854, CONFIG_ADE7854_SPI, CONFIG_ADIS16060,
  CONFIG_ADIS16080, CONFIG_ADIS16130, CONFIG_ADIS16201, CONFIG_ADIS16203,
  CONFIG_ADIS16204, CONFIG_ADIS16209, CONFIG_ADIS16220, CONFIG_ADIS16240,
  CONFIG_ADIS16260, CONFIG_ADIS16400, CONFIG_ADT7310, CONFIG_ADT7316_I2C,
  CONFIG_ADT7316, CONFIG_ADT7316_SPI, CONFIG_ADT7410, CONFIG_ADXRS450,
  CONFIG_BACKLIGHT_WM831X, CONFIG_CAN_JANZ_ICAN3, CONFIG_FB_SM501,
  CONFIG_GPIO_JANZ_TTL, CONFIG_GPIO_RDC321X, CONFIG_GPIO_STMPE,
  CONFIG_GPIO_TIMBERDALE, CONFIG_GPIO_WM831X, CONFIG_IIO_BUFFER,
  CONFIG_IIO_CONSUMERS_PER_TRIGGER=2, CONFIG_IIO_GPIO_TRIGGER,
  CONFIG_IIO_KFIFO_BUF, CONFIG_IIO, CONFIG_IIO_PERIODIC_RTC_TRIGGER,
  CONFIG_IIO_SIMPLE_DUMMY, CONFIG_IIO_ST_HWMON, CONFIG_IIO_SW_RING,
  CONFIG_IIO_SYSFS_TRIGGER, CONFIG_IIO_TRIGGER,
  CONFIG_INPUT_MC13783_PWRBUTTON, CONFIG_INPUT_WM831X_ON,
  CONFIG_KEYBOARD_STMPE, CONFIG_KXSD9, CONFIG_LEDS_MC13783,
  CONFIG_LEDS_REGULATOR, CONFIG_LEDS_WM831X_STATUS,
  CONFIG_LIS3L02DQ_BUF_KFIFO, CONFIG_LIS3L02DQ, CONFIG_MAX1363,
  CONFIG_MAX1363_RING_BUFFER, CONFIG_MAX517, CONFIG_MFD_CORE,
  CONFIG_MFD_JANZ_CMODIO, CONFIG_MFD_MC13783, CONFIG_MFD_MC13XXX,
  CONFIG_MFD_RDC321X, CONFIG_MFD_SM501_GPIO, CONFIG_MFD_SM501,
  CONFIG_MFD_STMPE, CONFIG_MFD_TIMBERDALE, CONFIG_MFD_TPS65217,
  CONFIG_MFD_WM831X_SPI, CONFIG_MFD_WM831X, CONFIG_MFD_WM8400,
  CONFIG_RADIO_TIMBERDALE, CONFIG_REGMAP_I2C, CONFIG_REGMAP_SPI,
  CONFIG_REGMAP, CONFIG_REGULATOR_AD5398, CONFIG_REGULATOR_DA903X,
  CONFIG_REGULATOR_DEBUG, CONFIG_REGULATOR_DUMMY,
  CONFIG_REGULATOR_FIXED_VOLTAGE, CONFIG_REGULATOR_GPIO,
  CONFIG_REGULATOR_ISL6271A, CONFIG_REGULATOR_LP3971,
  CONFIG_REGULATOR_LP3972, CONFIG_REGULATOR_MAX1586,
  CONFIG_REGULATOR_MAX8649, CONFIG_REGULATOR_MAX8660,
  CONFIG_REGULATOR_MAX8952, CONFIG_REGULATOR_MC13783,
  CONFIG_REGULATOR_MC13892, CONFIG_REGULATOR_MC13XXX_CORE,
  CONFIG_REGULATOR_PCAP, CONFIG_REGULATOR_TPS6105X,
  CONFIG_REGULATOR_TPS62360, CONFIG_REGULATOR_TPS65023,
  CONFIG_REGULATOR_TPS6507X, CONFIG_REGULATOR_TPS65217,
  CONFIG_REGULATOR_TPS6524X, CONFIG_REGULATOR_USERSPACE_CONSUMER,
  CONFIG_REGULATOR_VIRTUAL_CONSUMER, CONFIG_REGULATOR_WM831X,
  CONFIG_REGULATOR_WM8400, CONFIG_REGULATOR, CONFIG_RFKILL_REGULATOR,
  CONFIG_RTC_DRV_MC13XXX, CONFIG_RTC_DRV_WM831X, CONFIG_SCA3000,
  CONFIG_SENSORS_AK8975, CONFIG_SENSORS_HMC5843, CONFIG_SENSORS_ISL29018,
  CONFIG_SENSORS_MC13783_ADC, CONFIG_SENSORS_TSL2563, CONFIG_SENSORS_WM831X,
  CONFIG_SERIAL_MFD_HSU, CONFIG_SERIAL_UARTLITE, CONFIG_STMPE_I2C,
  CONFIG_STMPE_SPI, CONFIG_TOUCHSCREEN_MC13783, CONFIG_TOUCHSCREEN_STMPE,
  CONFIG_TOUCHSCREEN_WM831X, CONFIG_TPS6105X, CONFIG_TSL2583,
  CONFIG_WM831X_BACKUP, CONFIG_WM831X_POWER, CONFIG_WM831X_WATCHDOG
- commit 0f27f25
* Thu Apr 26 2012 jeffm@suse.com
- Disabled CONFIG_COPS and CONFIG_LTPC: Ancient ISA LocalTalk hardware.
- commit 43b6598
* Wed Apr 25 2012 jeffm@suse.com
- dl2k: Tighten ioctl permissions (bnc#758813).
- commit 8d00242
* Wed Apr 25 2012 jeffm@suse.com
- Update to 3.4-rc4.
- commit 37113a8
* Mon Apr 23 2012 jslaby@suse.cz
- Linux 3.3.3.
- Delete
  patches.suse/btrfs-REVERT-increase-the-global-block-reserve-estim.patch.
- commit 739b98b
* Sun Apr 22 2012 jeffm@suse.com
- Update config files: Merged omap2plus changes.
- commit f0e2149
* Fri Apr 20 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc3 and c/s 1172.
- config.conf: Re-enabled Xen configs.
- Update config files.
- commit 9f943f6
* Tue Apr 17 2012 jeffm@suse.com
- Update to 3.4-rc3.
  - Eliminated 1 patch.
- commit 2fde7e0
* Fri Apr 13 2012 jslaby@suse.cz
- Linux 3.3.2.
- Delete
  patches.fixes/revert-ath9k-fix-going-to-full-sleep-on-PS-idle.patch.
- commit addbdfa
* Fri Apr 13 2012 jbeulich@novell.com
- Drivers: scsi: storvsc: Account for in-transit packets in the
  RESET path.
- commit 4c1e258
* Mon Apr  9 2012 jeffm@suse.com
- Update to 3.4-rc2.
- commit 976094f
* Sat Apr  7 2012 jslaby@suse.cz
- Revert "ath9k: fix going to full-sleep on PS idle" (bnc#756013).
- commit c31d1b5
* Fri Apr  6 2012 jeffm@suse.com
- Update AppArmor for 3.4.
  - apparmor: Add "profiles" list to sysfs.
- commit 59517ac
* Thu Apr  5 2012 jeffm@suse.com
- Update richacl patchset for 3.4.
- commit f13764e
* Thu Apr  5 2012 jeffm@suse.com
- Updated to 3.4-rc1.
  - Eliminated 121 patches.
  - Xen is unavailable.
  - ACPI overrides are unavailable.
  - AppArmor network feature are unavailable.
- commit 3ac7e79
* Thu Apr  5 2012 jeffm@suse.de
- Updated patch headers
- commit 09c9338
* Tue Apr  3 2012 ohering@suse.de
- Drivers: scsi: storvsc: Properly handle errors from the host
  (bnc#747404).
- commit 2f7920e
* Tue Apr  3 2012 jslaby@suse.cz
- Linux 3.3.1.
- Delete
  patches.drivers/drm-i915-suspend-fbdev-device-around-suspend-hiberna.
- Delete
  patches.fixes/net-fix-a-potential-rcu_read_lock-imbalance-in-rt6_fill_node.
- commit efec235
* Mon Apr  2 2012 jeffm@suse.de
- armv7l: Disable CONFIG_TOUCHSCREEN_EGALAX on default and u8500 due to missing infrastructure.
- commit b614c98
* Mon Apr  2 2012 jslaby@suse.cz
- samsung-laptop: make the dmi check less strict (bnc#746695).
- commit 170a6a2
* Fri Mar 30 2012 tiwai@suse.de
- drm/i915: suspend fbdev device around suspend/hibernate
  (bnc#732908).
- commit 028c29f
* Wed Mar 28 2012 jeffm@suse.com
- net: fix a potential rcu_read_lock() imbalance in
  rt6_fill_node() (bnc#754186).
- commit 8d5a9e4
* Mon Mar 26 2012 ohering@suse.de
- net/hyperv: Fix the code handling tx busy.
- Tools: hv: Support enumeration from all the pools.
- Tools: hv: Fully support the new KVP verbs in the user level
  daemon.
- Drivers: hv: Support the newly introduced KVP messages in
  the driver.
- Drivers: hv: Add new message types to enhance KVP.
- net/hyperv: Add support for vlan trunking from guests.
- net/hyperv: Fix data corruption in rndis_filter_receive().
- drivers: hv: Increase the number of VCPUs supported in the
  guest.
- drivers: hv: kvp: Cleanup the kernel/user protocol.
- tools: hv: Use hyperv.h to get the KVP definitions.
- drivers: hv: Cleanup the kvp related state in hyperv.h.
- net/hyperv: Remove the unnecessary memset in
  rndis_filter_send().
- net/hyperv: Correct the assignment in netvsc_recv_callback().
- net/hyperv: Convert camel cased variables in rndis_filter.c
  to lower cases.
- drivers: hv: kvp: Move the contents of hv_kvp.h to hyperv.h.
- drivers: hv: kvp: Add/cleanup connector defines.
- drivers: hv: Get rid of some unnecessary code.
- commit 78acc3b
* Sat Mar 24 2012 dsterba@suse.cz
- Revert "Btrfs: increase the global block reserve estimates"
- commit 7e9dd21
* Sat Mar 24 2012 dsterba@suse.cz
- Refresh patches.suse/btrfs-handle-EIO.
- Refresh
  patches.suse/btrfs-volumes-schedule_bio-should-return-void.
- commit d97ade6
* Fri Mar 23 2012 jbeulich@novell.com
- Update Xen patches to 3.3 final and c/s 1165.
- commit 6c5f5ef
* Thu Mar 22 2012 jeffm@suse.com
- Update config files: Disable CONFIG_INTEL_IOMMU_DEFAULT_ON (bnc#740102 and others)
- commit b244b17
* Thu Mar 22 2012 jeffm@suse.de
- Update config files: Disabled CONFIG_COMPAT_BRK and CONFIG_COMPAT_VDSO (FATE#313171)
- commit 990b059
* Wed Mar 21 2012 meissner@suse.de
- rpm: include crtsavres.o on ppc
- commit 854a031
* Mon Mar 19 2012 jeffm@suse.com
- Update vanilla config files.
- commit bd476d4
* Mon Mar 19 2012 jslaby@suse.cz
- Update (vanilla) config files.
- commit 55a0a56
* Mon Mar 19 2012 jslaby@suse.cz
- Delete
  patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch.
- Delete patches.arch/dell_optiplex_990_fix_reboot.patch.
- Delete
  patches.drivers/alsa-hda-0004-Add-missing-static-ADC-tables-for-ALC269-qu.
- Delete patches.drivers/libata-unlock-hpa-by-default.
- Delete patches.fixes/scsi-add-tgps-setting.
- Delete patches.fixes/scsi-dh-rdac-add-stk.
- Delete patches.suse/dm-mpath-evaluate-request-result-and-sense.
- Delete patches.suse/richacl-fix.
  Remove unused patches.
- commit 2cbabfe
* Mon Mar 19 2012 jeffm@suse.com
- Update to 3.3-final.
- commit a9ab64a
* Fri Mar 16 2012 ohering@suse.de
- Update bugnumber patches.suse/sd_init.mark_majors_busy.patch (bnc#744658).
- commit e60f2c3
* Tue Mar 13 2012 jslaby@suse.cz
- Linux 3.2.10.
- Delete
  patches.fixes/media-staging-lirc_serial-Do-not-assume-error-codes-.patch.
- Delete
  patches.fixes/media-staging-lirc_serial-Free-resources-on-failure-.patch.
- commit 614ed04
* Mon Mar 12 2012 jslaby@suse.cz
- staging: lirc_serial: Free resources on failure paths of
  lirc_serial_probe() (bnc#750106).
- staging: lirc_serial: Do not assume error codes returned by
  request_irq() (bnc#750106).
- commit 4bff877
* Mon Mar 12 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc7 and c/s 1163.
- commit 0054c83
* Mon Mar 12 2012 ohering@suse.de
- Staging: hv: storvsc: Cleanup some comments.
- Staging: hv: storvsc: Cleanup storvsc_probe().
- Staging: hv: storvsc: Cleanup storvsc_queuecommand().
- Staging: hv: storvsc: Introduce defines for srb status codes.
- Staging: hv: storvsc: Cleanup storvsc_host_reset_handler().
- Staging: hv: storvsc: Move and cleanup storvsc_remove().
- Staging: hv: storvsc: Add a comment to explain life-cycle
  management.
- Staging: hv: storvsc: Get rid of the on_io_completion in
  hv_storvsc_request.
- Staging: hv: storvsc: Rename the context field in
  hv_storvsc_request.
- Staging: hv: storvsc: Miscellaneous cleanup of storvsc driver.
- Staging: hv: storvsc: Cleanup the code for generating protocol
  version.
- Staging: hv: storvsc: Cleanup some protocol related constants.
- Staging: hv: storvsc: Get rid of some unused defines.
- Staging: hv: storvsc: Consolidate the request structure.
- Staging: hv: storvsc: Consolidate all the wire protocol
  definitions.
- Staging: hv: storvsc: Move the storage driver out of the
  staging area.
- Rename patches.suse/staging-hv-pata_piix-ignore-disks.patch to
  patches.suse/suse-hv-pata_piix-ignore-disks.patch
- commit 7487199
* Mon Mar 12 2012 jeffm@suse.com
- Update to 3.3-rc7.
- commit 81a18ea
* Sun Mar 11 2012 jeffm@suse.com
- btrfs: Handle EIO.
- btrfs: add varargs to btrfs_error.
- btrfs: Remove BUG_ON from __finish_chunk_alloc().
- btrfs: Remove BUG_ON from __btrfs_alloc_chunk().
- btrfs: Don't BUG_ON insert errors in btrfs_alloc_dev_extent().
- btrfs: Go readonly on tree errors in balance_level.
- btrfs: Don't BUG_ON errors from update_ref_for_cow().
- btrfs: Go readonly on bad extent refs in update_ref_for_cow().
- btrfs: Don't BUG_ON errors in __finish_chunk_alloc().
- btrfs: Don't BUG_ON kzalloc error in btrfs_lookup_csums_range().
- btrfs: Don't BUG_ON() errors in update_ref_for_cow().
- btrfs: Don't BUG_ON errors from btrfs_create_subvol_root().
- btrfs: btrfs_drop_snapshot should return int.
- brfs: split extent_state ops.
- btrfs: drop gfp_t from lock_extent.
- btrfs: scrub functions should return void.
- btrfs: btrfs_set_item_key_safe should BUG on error and return
  void.
- btrfs: Add extent_state alloc/free tracing.
- btrfs: btrfs_destroy_pending_snapshots should return void.
- btrfs: btrfs_destroy_ordered_extents should return void.
- btrfs: btrfs_destroy_ordered_operations should return void.
- btrfs: del_fs_roots should return void.
- btrfs: btrfs_free_fs_root should return void.
- btrfs: btrfs_add_ordered_sum should return void.
- btrfs: btrfs_add_ordered_operation should return void.
- btrfs: btrfs_run_ordered_operations should return void.
- btrfs: btrfs_wait_ordered_range should return void.
- btrfs: btrfs_wait_ordered_extents should return void.
- btrfs: __btrfs_remove_ordered_extent should return void.
- btrfs: btrfs_put_ordered_extent should return void.
- btrfs: update_inline_extent_backref should return void.
- btrfs: copy_for_split should return void.
- btrfs: end_compressed_writeback should return void.
- btrfs: btrfs_extend_item should return void.
- btrfs: btrfs_truncate_item should return void.
- btrfs: add_delayed_data_ref should return void.
- btrfs: add_delayed_tree_ref should return void.
- btrfs: add_delayed_ref_head should return void.
- btrfs: insert_ptr should return void.
- btrfs: del_ptr should return void.
- btrfs: setup_items_for_insert should return void.
- btrfs: fixup_low_keys should return void.
- btrfs: __add_reloc_root error push-up.
- btrfs: ->submit_bio_hook error push-up.
- btrfs: Factor out tree->ops->merge_bio_hook call.
- btrfs: Simplify btrfs_submit_bio_hook.
- btrfs: Fix kfree of member instead of structure.
- btrfs: setup_inline_extent_backref should return void.
- btrfs: btrfs_set_block_group_rw should return void.
- btrfs: btrfs_prepare_extent_commit should return void.
- btrfs: btrfs_destroy_delalloc_inodes should return void.
- btrfs: __setup_root should return void.
- btrfs: btrfs_invalidate_inodes should return void.
- btrfs: btrfs_init_compress should return void.
- btrfs: wait_for_writer should return void.
- btrfs: btrfs_end_log_trans should return void.
- btrfs: btrfs_requeue_work should return void.
- btrfs: btrfs_stop_workers should return void.
- btrfs: run_ordered_completions should return void.
- btrfs: fill_device_from_item should return void.
- btrfs: schedule_bio should return void.
- btrfs: btrfs_close_extra_devices should return void.
- btrfs: run_scheduled_bios should return void.
- btrfs: btrfs_cleanup_fs_uuids should return void.
- btrfs: clear_extent_buffer_dirty should return void.
- btrfs: check_page_writeback should return void.
- btrfs: check_page_locked should return void.
- btrfs: check_page_uptodate should return void.
- btrfs: __unlock_for_delalloc should return void.
- btrfs: wait_extent_bit should return void.
- btrfs: wait_on_state should return void.
- btrfs: btrfs_update_root error push-up.
- btrfs: find_and_setup_root error push-up.
- btrfs: Remove set bits return from clear_extent_bit.
- btrfs: avoid NULL deref in btrfs_reserve_extent with
  DEBUG_ENOSPC.
- btrfs: clean_tree_block should panic on observed memory
  corruption and return void.
- btrfs: btrfs_tree_{,un}lock should return void.
- btrfs: Simplify btrfs_insert_root.
- btrfs: Panic on bad rbtree operations.
- btrfs: Catch locking failures in {set,clear,convert}_extent_bit.
- btrfs: Add btrfs_panic().
- commit fd31baf
* Fri Mar  9 2012 ohering@suse.de
- mark busy sd majors as allocated (bug#744658).
- commit b2a640b
* Thu Mar  8 2012 mmarek@suse.cz
- Fix vanilla config files.
- commit b343c8a
* Thu Mar  8 2012 mmarek@suse.cz
- Delete patches.rpmify/nvme-broken, nvme builds again on 32bit.
- commit d60272f
* Thu Mar  8 2012 jbeulich@novell.com
- patches.suse/crasher-26.diff: Eliminate build warnings.
- commit 67c3c8d
* Thu Mar  8 2012 agraf@suse.de
- armv7l: config: omap: disable HDMI output (breaks build)
- commit 6a871bd
* Tue Mar  6 2012 agraf@suse.de
- armv7l: omap2plus: Enable TIDSPBRIDGE and SND codecs
- commit 0d8ec4d
* Mon Mar  5 2012 jeffm@suse.com
- Refresh patches.xen/xen3-fixup-arch-x86.
- commit f4b95ae
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6. Previous commit was configs.
- commit 639167f
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6.
- commit ebec13a
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit 2c205b4
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit adb37b7
* Thu Mar  1 2012 jslaby@suse.cz
- xen3-patch-3.2.7-8
  Make xen build again.
- commit ba1cb50
* Thu Mar  1 2012 jslaby@suse.cz
- Linux 3.2.9.
- Refresh patches.xen/xen3-fixup-arch-x86.
- commit 82a8603
* Wed Feb 29 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc5 and c/s 1157.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit f225622
* Tue Feb 28 2012 jslaby@suse.cz
- Linux 3.2.8.
  XEN is broken. The XEN-generated backport patch does not apply
  cleanly. So leaving XEN as is, until this is fixed in master. Then the
  same fix will be ported here.
- commit 2bcad53
* Mon Feb 27 2012 jeffm@suse.com
- Updated to 3.3-rc5.
- commit 0b7f048
* Sun Feb 26 2012 jslaby@suse.cz
- Revert "Disable 3.2.5"
  This reverts commit 6d12c9d00ec52d1d6745a08935b3f10870cbc58d.
  It works now.
- commit 91fa3bc
* Wed Feb 22 2012 jslaby@suse.cz
- Disable 3.2.5
  I lost my ps/2 keyboard and touchpad.
- commit 6d12c9d
* Tue Feb 21 2012 jslaby@suse.cz
- Linux 3.2.5.
- Refresh patches.kernel.org/patch-3.2.5-6.
- commit 9d01b21
* Tue Feb 21 2012 jslaby@suse.cz
- Linux 3.2.7.
- commit 3d38d11
* Sun Feb 19 2012 jeffm@suse.com
- Updated to 3.3-rc4.
- commit 8831dca
* Mon Feb 13 2012 jslaby@suse.cz
- Linux 3.2.6.
- Delete
  patches.fixes/PM-Hibernate-Fix-s2disk-regression-related-to-freezi.patch.
- commit 264e0d4
* Mon Feb 13 2012 trenn@suse.de
- cpufreq/gx: Fix the compile error.
- commit 4ba1d8b
* Mon Feb 13 2012 jslaby@suse.cz
- Update config files.
  Enable brcm80211 wireless driver.
- commit 70a4760
* Mon Feb 13 2012 mmarek@suse.cz
- nvme: Mark as broken on x86_32.
- commit 28ad576
* Sun Feb 12 2012 trenn@suse.de
- Add driver auto probing for x86 features v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Fix overrun check in arch_print_cpu_modalias()
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- crypto: Add support for x86 cpuid
  auto loading for x86 crypto drivers
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Clean up modalias feature matching
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel-idle: convert to x86_cpu_id auto probing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Fix ID for Nehalem-EX Xeon in device ID table
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert via-cputemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k7: Fix CPU family number
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: Load acpi-cpufreq from processor driver automatically
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Revert change of auto_demotion_flags for Nehalem
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert coretemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k6: Really enable auto-loading
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- X86: Introduce HW-Pstate scattered cpuid feature
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- cpufreq: Add support for x86 cpuinfo auto loading v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86: autoload microcode driver on Intel and AMD systems v2
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- CPU: Introduce ARCH_HAS_CPU_AUTOPROBE and X86 parts
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: remove duplicated lines of merging
  problems with acpi_processor_start
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- Update config files.
- commit 6efe9b5
* Fri Feb 10 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build x86 packages as i686, except for
  - default (bnc#745632). KMPs are still built as i586.
- commit 88a632b
* Thu Feb  9 2012 jeffm@suse.com
- Update to 3.3-rc3.
- commit 07ec27c
* Thu Feb  9 2012 agraf@suse.de
- armv7l: Update config files.
- commit d223353
* Thu Feb  9 2012 agraf@suse.de
- armv7l: config: integrate bmwiedemann's updates to make it usable
- commit 76d12ed
* Tue Feb  7 2012 jeffm@suse.com
- Update vanilla config files.
- commit fd3673f
* Tue Feb  7 2012 jeffm@suse.com
- Update to 3.3-rc2.
  - Eliminated 5 patches.
  - Xen is disabled.
- commit d017ea1
* Sat Feb  4 2012 jslaby@suse.cz
- Linux 3.2.4.
- commit 484affb
* Sat Feb  4 2012 jslaby@suse.cz
- Linux 3.2.3.
- commit 9c66f44
* Thu Feb  2 2012 jslaby@suse.cz
- Refresh
  patches.fixes/PM-Hibernate-Fix-s2disk-regression-related-to-freezi.patch.
- commit 763a147
* Mon Jan 30 2012 jslaby@suse.cz
- Do not build with the patch yet. It needs more work.
- commit 1101381
* Mon Jan 30 2012 jslaby@suse.cz
- PM / Hibernate: Fix s2disk regression related to freezing
  workqueues (bnc#743952).
- commit 6f37dda
* Sun Jan 29 2012 jslaby@suse.cz
- Delete patches.fixes/proc-mem-security-fix.
  Fix build error caused by merge of master branch.
- commit 62fc2fa
* Thu Jan 26 2012 jslaby@suse.cz
- Linux 3.2.2.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.28.
- patches.xen/xen3-patch-2.6.39:
- Delete patches.arch/acpi_srat-pxm-rev-ia64.patch.
- Delete patches.arch/acpi_srat-pxm-rev-store.patch.
- Delete patches.arch/acpi_srat-pxm-rev-x86-64.patch.
- Delete
  patches.fixes/intel_idle_fix_mwait_leave_zero_kvm_issue.patch.
- commit 387c074
* Wed Jan 25 2012 dkukawka@suse.de
- fix NULL pointer dereference in DSS2 VENC sysfs debug attr on OMAP4.
- commit 2206a5c
* Wed Jan 25 2012 mmarek@suse.cz
- proc: clean up and fix /proc/<pid>/mem handling (bnc#742279,
  CVE-2012-0056).
- commit 4fb112d
* Tue Jan 17 2012 trenn@suse.de
- Delete patches.fixes/intel_idle_add_flush_tlb_param.patch.
- Delete patches.fixes/intel_idle_lapic_param.patch.
- commit e18e852
* Tue Jan 17 2012 agraf@suse.de
- KVM: PPC: Add HPT preallocator.
- KVM: PPC: Convert RMA allocation into generic code.
- commit a6da6a5
* Fri Jan 13 2012 agraf@suse.de
- ARM: Update config files: Enable highmem everywhere
- commit 4522c1c
* Fri Jan 13 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
- add a proper support for Xen fb (bnc#739020);
- fix the bootsplash-verbose switch race (bnc#734213)
- commit 6f3d77f
* Fri Jan 13 2012 jslaby@suse.cz
- Linux 3.2.1.
- Delete
  patches.fixes/reiserfs-force-inode-evictions-before-umount-to-avoid-crash.
- commit 38ed2a2
* Wed Jan 11 2012 jbeulich@novell.com
- patches.suse/stack-unwind: Fix more 2.6.29 merge problems plus a glue code problem.
- commit 9166360
* Mon Jan  9 2012 mmarek@suse.cz
- Set CONFIG_LOCALVERSION for armv7l/u8500.
- commit dde56d0
* Fri Jan  6 2012 awafaa@opensuse.org
- add support for ST-Ericsson Nova based SoCs
- commit 06d2b6e
* Fri Jan  6 2012 jbeulich@novell.com
- Update Xen patches to 3.2-final and c/s 1140.
- commit 917dd7e
* Thu Jan  5 2012 jeffm@suse.com
- Update to 3.2-final.
- commit 778e265
* Wed Jan  4 2012 jslaby@suse.cz
- Revert "- btrfs: use correct device for maps (bnc#672923)."
  This reverts commit 7e6bd95918d9b297d628b36d4b029da7cc335ca5.
  We mauy break kABI here and use the cleaner version :).
- commit 897def2
* Wed Jan  4 2012 jslaby@suse.cz
- Linux 3.1.7.
- commit 587be3b
* Mon Jan  2 2012 jeffm@suse.com
- Updated to 3.2-rc7.
- commit f458508
* Mon Jan  2 2012 dsterba@suse.cz
- btrfs: use correct device for maps (bnc#672923).
- Delete
  patches.suse/0001-vfs-allow-proc-pid-maps-to-return-a-custom-device.patch.
- Delete
  patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch.
- commit 7e6bd95
* Mon Jan  2 2012 mhocko@suse.cz
- Update
  patches.fixes/oom-thaw-threads-if-oom-killed-thread-is-frozen-befo.patch
  (bnc#718831).
- commit 05b6faf
* Fri Dec 30 2011 bpoirier@suse.de
- net: Add a flow_cache_flush_deferred function (bnc#737624).
- commit 69bd36b
* Mon Dec 26 2011 jslaby@suse.cz
- sound: ratelimit sound debug prints.
- commit 441798f
* Mon Dec 26 2011 jslaby@suse.cz
- Linux 3.1.6.
- Revert "clocksource: Avoid selecting mult values that might
  overflow when adjusted".
- Revert "inet: add a redirect generation id in inetpeer".
- Delete
  patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch.
- Delete
  patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch.
- Linux 3.1.6.
- Delete
  patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch.
- Delete
  patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch.
- commit 2f8a8c2
* Thu Dec 22 2011 jeffm@suse.com
- Update config files.
- CONFIG_X86_INTEL_MID -> CONFIG_X86_WANT_INTEL_MID
- commit c4246bf
* Wed Dec 21 2011 jbeulich@novell.com
- Update Xen patches to 3.2-rc6 and c/s 1133.
- kexec: properly handle pCPU hotplug.
- x86: pCPU handling.
- commit cbe54a1
* Tue Dec 20 2011 dsterba@suse.cz
- Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- btrfs: keep orphans for subvolume deletion (FATE#306586).
- Btrfs: fix ctime update of on-disk inode (FATE#306586).
- Btrfs: add a cond_resched() into the worker loop (FATE#306586).
- BTRFS: Establish i_ops before calling d_instantiate
  (FATE#306586).
- Btrfs: deal with NULL srv_rsv in the delalloc inode reservation
  code (FATE#306586).
- Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- Btrfs: fix leaked space in truncate (FATE#306586).
- Btrfs: don't panic if orphan item already exists (FATE#306586).
- Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- Btrfs: unplug every once and a while (FATE#306586).
- btrfs: lock and disable irq during space alloc (FATE#306586
  bnc#730103).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Delete
  patches.suse/btrfs-0901-fix-num_workers_starting-bug-and-other-bugs-in.patch.
- Delete
  patches.suse/btrfs-0902-deal-with-enospc-from-dirtying-inodes-properly.patch.
- Delete
  patches.suse/btrfs-0903-fix-how-we-do-delalloc-reservations-and-how-we.patch.
- Delete
  patches.suse/btrfs-0904-fix-leaked-space-in-truncate.patch.
- Delete
  patches.suse/btrfs-0905-only-set-cache_generation-if-we-setup-the-bloc.patch.
- Delete
  patches.suse/btrfs-0906-don-t-panic-if-orphan-item-already-exists.patch.
- Delete
  patches.suse/btrfs-8027-fix-ctime-update-of-on-disk-inode.patch.
- Delete
  patches.suse/btrfs-8028-fix-wrong-disk-space-information-of-the-files.patch.
- Delete
  patches.suse/btrfs-8029-fix-wrong-i_size-when-truncating-a-file-to-a-l.patch.
- Delete
  patches.suse/btrfs-8030-fix-inaccurate-available-space-on-raid0-profil.patch.
- commit e3967f3
* Tue Dec 20 2011 jeffm@suse.com
- Update to 3.2-rc6.
  - Eliminated 1 patch.
- commit d5a489e
* Tue Dec 20 2011 trenn@suse.de
- These should all be mainline in some form:
- Delete
  patches.arch/implement_stop_machine_from_offline_cpu.patch.
- Delete patches.arch/kill-__stop_machine.patch.
- Delete patches.arch/reorganize_stop_cpus.patch.
- Delete patches.arch/use_stop_machine_for_mtrr_rendezvous.patch.
- commit 78eb159
* Sun Dec 18 2011 aj@suse.de
- rpm/kernel-source.rpmlintrc: The hidden files are fine, silence rpmlint.
- commit a7813dd
* Fri Dec 16 2011 aj@suse.de
- rpm/kernel-binary.spec.in: Add provides and make most obsoletes versioned.
  This silences rpmlint warnings.
- commit e3023c7
* Thu Dec 15 2011 dsterba@suse.cz
- Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- Btrfs: fix ctime update of on-disk inode (FATE#306586).
- Btrfs: fix possible deadlock when opening a seed device
  (FATE#306586).
- Btrfs: update global block_rsv when creating a new block group
  (FATE#306586).
- btrfs: workaround for cleaner deadlock (FATE#306586).
- Btrfs: don't panic if orphan item already exists (FATE#306586).
- Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- commit 5341000
* Wed Dec 14 2011 dsterba@suse.cz
- btrfs: Introduce btrfs_get_maps_dev() (bnc#672923).
- vfs: allow /proc/pid/maps to return a custom device
  (bnc#672923).
- Btrfs: make lzo the default compression scheme (FATE#306586).
- btrfs: add new ioctl to determine size of compressed file
  (FATE#306586).
- Sector Size check during Mount (FATE#306586 bnc#724620).
- Btrfs: rewrite btrfs_trim_block_group() (FATE#306586).
- btrfs: allow cross-subvolume file clone (bnc#698540).
- Btrfs: fix leaked space in truncate (FATE#306586).
- Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- Btrfs: add allocator tracepoints (FATE#306586).
- Btrfs: fix btrfs_end_bio to deal with write errors to a single
  mirror (FATE#306586).
- Btrfs: drop spin lock when memory alloc fails (FATE#306586).
- Btrfs: check if the to-be-added device is writable
  (FATE#306586).
- Btrfs: try cluster but don't advance in search list
  (FATE#306586).
- Btrfs: try to allocate from cluster even at LOOP_NO_EMPTY_SIZE
  (FATE#306586).
- Btrfs: fix meta data raid-repair merge problem (FATE#306586).
- Btrfs: skip allocation attempt from empty cluster (FATE#306586).
- Btrfs: skip block groups without enough space for a cluster
  (FATE#306586).
- Btrfs: start search for new cluster at the beginning
  (FATE#306586).
- Btrfs: reset cluster's max_size when creating bitmap
  (FATE#306586).
- Btrfs: initialize new bitmaps' list (FATE#306586).
- Btrfs: fix oops when calling statfs on readonly device
  (FATE#306586).
- Btrfs: Don't error on resizing FS to same size (FATE#306586).
- Btrfs: fix deadlock on metadata reservation when evicting a
  inode (FATE#306586).
- btrfs scrub: handle -ENOMEM from init_ipath() (FATE#306586).
- Btrfs: remove free-space-cache.c WARN during log replay
  (FATE#306586).
- Btrfs: sectorsize align offsets in fiemap (FATE#306586).
- Btrfs: clear pages dirty for io and set them extent mapped
  (FATE#306586).
- Btrfs: wait on caching if we're loading the free space cache
  (FATE#306586).
- Btrfs: prefix resize related printks with btrfs: (FATE#306586).
- btrfs: fix stat blocks accounting (FATE#306586).
- Btrfs: avoid unnecessary bitmap search for cluster setup
  (FATE#306586).
- Btrfs: fix to search one more bitmap for cluster setup
  (FATE#306586).
- btrfs: mirror_num should be int, not u64 (FATE#306586).
- btrfs: Fix up 32/64-bit compatibility for new ioctls
  (FATE#306586).
- Btrfs: fix barrier flushes (FATE#306586).
- Btrfs: fix tree corruption after multi-thread snapshots and
  inode_cache flush (FATE#306586).
- btrfs: rename the option to nospace_cache (FATE#306586).
- Btrfs: handle bio_add_page failure gracefully in scrub
  (FATE#306586).
- Btrfs: fix deadlock caused by the race between relocation
  (FATE#306586).
- Btrfs: only map pages if we know we need them when reading
  the space cache (FATE#306586).
- Btrfs: fix orphan backref nodes (FATE#306586).
- Btrfs: Abstract similar code for btrfs_block_rsv_add{, _noflush}
  (FATE#306586).
- Btrfs: fix unreleased path in btrfs_orphan_cleanup()
  (FATE#306586).
- Btrfs: fix no reserved space for writing out inode cache
  (FATE#306586).
- Btrfs: fix nocow when deleting the item (FATE#306586).
- Btrfs: tweak the delayed inode reservations again (FATE#306586).
- Btrfs: rework error handling in btrfs_mount() (FATE#306586).
- Btrfs: close devices on all error paths in open_ctree()
  (FATE#306586).
- Btrfs: avoid null dereference and leaks when bailing from
  open_ctree() (FATE#306586).
- Btrfs: fix subvol_name leak on error in btrfs_mount()
  (FATE#306586).
- Btrfs: fix memory leak in btrfs_parse_early_options()
  (FATE#306586).
- Btrfs: fix our reservations for updating an inode when
  completing io (FATE#306586).
- Btrfs: fix oops on NULL trans handle in btrfs_truncate
  (FATE#306586).
- btrfs: fix double-free 'tree_root' in 'btrfs_mount()'
  (FATE#306586).
- Btrfs: check for a null fs root when writing to the backup
  root log (FATE#306586).
- Btrfs: fix race during transaction joins (FATE#306586).
- Btrfs: fix a potential btrfs_bio leak on scrub fixups
  (FATE#306586).
- Btrfs: stop leaking btrfs_bios on readahead (FATE#306586).
- Btrfs: stop the readahead threads on failed mount (FATE#306586).
- Btrfs: fix extent_buffer leak in the metadata IO error handling
  (FATE#306586).
- Btrfs: fix the new inspection ioctls for 32 bit compat
  (FATE#306586).
- btrfs: integrating raid-repair and scrub-fixup-nodatasum
  (FATE#306586).
- btrfs: Moved repair code from inode.c to extent_io.c
  (FATE#306586).
- btrfs: Put mirror_num in bi_bdev (FATE#306586).
- btrfs: Do not use bio->bi_bdev after submission (FATE#306586).
- btrfs: btrfs_multi_bio replaced with btrfs_bio (FATE#306586).
- btrfs: new ioctls to do logical->inode and inode->path resolving
  (FATE#306586).
- btrfs scrub: add fixup code for errors on nodatasum files
  (FATE#306586).
- btrfs scrub: use int for mirror_num, not u64 (FATE#306586).
- btrfs: add mirror_num to extent_read_full_page (FATE#306586).
- btrfs scrub: bugfix: mirror_num off by one (FATE#306586).
- btrfs scrub: print paths of corrupted files (FATE#306586).
- btrfs scrub: added unverified_errors (FATE#306586).
- btrfs: added helper functions to iterate backrefs (FATE#306586).
- btrfs: use readahead API for scrub (FATE#306586).
- btrfs: hooks for readahead (FATE#306586).
- btrfs: initial readahead code and prototypes (FATE#306586).
- btrfs: state information for readahead (FATE#306586).
- btrfs: add READAHEAD extent buffer flag (FATE#306586).
- btrfs: add an extra wait mode to read_extent_buffer_pages
  (FATE#306586).
- Btrfs: fix delayed insertion reservation (FATE#306586).
- Btrfs: ClearPageError during writepage and clean_tree_block
  (FATE#306586).
- Btrfs: be smarter about committing the transaction in
  reserve_metadata_bytes (FATE#306586).
- Btrfs: make a delayed_block_rsv for the delayed item insertion
  (FATE#306586).
- Btrfs: add a log of past tree roots (FATE#306586).
- btrfs: separate superblock items out of fs_info (FATE#306586).
- Btrfs: use the global reserve when truncating the free space
  cache inode (FATE#306586).
- Btrfs: release metadata from global reserve if we have to
  fallback for unlink (FATE#306586).
- Btrfs: make sure to flush queued bios if write_cache_pages waits
  (FATE#306586).
- Btrfs: fix extent pinning bugs in the tree log (FATE#306586).
- Btrfs: make sure btrfs_remove_free_space doesn't leak EAGAIN
  (FATE#306586).
- Btrfs: don't wait as long for more batches during SSD log commit
  (FATE#306586).
- btrfs: ratelimit WARN_ON in use_block_rsv (FATE#306586).
- btrfs: do not allow mounting non-subvolumes via subvol option
  (FATE#306586).
- Btrfs: close all bdevs on mount failure (FATE#306586).
- Btrfs: fix a bug when opening seed devices (FATE#306586).
- btrfs: fix oops on failure path (FATE#306586).
- Btrfs: fix race between multi-task space allocation and caching
  space (FATE#306586).
- Btrfs: fix return value of btrfs_get_acl() (FATE#306586).
- Btrfs: pass the correct root to lookup_free_space_inode()
  (FATE#306586).
- Btrfs: do not set EXTENT_DIRTY along with EXTENT_DELALLOC
  (FATE#306586).
- Btrfs: fix direct-io vs nodatacow (FATE#306586).
- Btrfs: remove BUG_ON() in compress_file_range() (FATE#306586).
- Btrfs: fix array bound checking (FATE#306586).
- btrfs: return EINVAL if start > total_bytes in fitrim ioctl
  (FATE#306586).
- Btrfs: honor extent thresh during defragmentation (FATE#306586).
- btrfs: trivial fix, a potential memory leak in
  btrfs_parse_early_options() (FATE#306586).
- Btrfs: fix wrong max_to_defrag in btrfs_defrag_file()
  (FATE#306586).
- Btrfs: use i_size_read() in btrfs_defrag_file() (FATE#306586).
- Btrfs: fix defragmentation regression (FATE#306586).
- btrfs: fix memory leak in btrfs_defrag_file (FATE#306586).
- btrfs: check file extent backref offset underflow (FATE#306586).
- Btrfs: don't flush the cache inode before writing it
  (FATE#306586).
- Btrfs: if we have a lot of pinned space, commit the transaction
  (FATE#306586).
- Btrfs: seperate out btrfs_block_rsv_check out into 2 different
  functions (FATE#306586).
- Btrfs: reserve some space for an orphan item when unlinking
  (FATE#306586).
- Btrfs: release trans metadata bytes before flushing delayed refs
  (FATE#306586).
- Btrfs: allow shrink_delalloc flush the needed reclaimed pages
  (FATE#306586).
- Btrfs: wait for ordered extents if we're in trouble when
  shrinking delalloc (FATE#306586).
- Btrfs: don't check bytes_pinned to determine if we should
  commit the transaction (FATE#306586).
- Btrfs: fix regression in re-setting a large xattr (FATE#306586).
- Btrfs: fix the amount of space reserved for unlink
  (FATE#306586).
- Btrfs: wait for ordered extents if we didn't reclaim enough
  (FATE#306586).
- Btrfs: inline checksums into the disk free space cache
  (FATE#306586).
- Btrfs: take overflow into account in reserving space
  (FATE#306586).
- Btrfs: check the return value of filemap_write_and_wait in
  the space cache (FATE#306586).
- Btrfs: add a io_ctl struct and helpers for dealing with the
  space cache (FATE#306586).
- Btrfs: don't skip writing out a empty block groups cache
  (FATE#306586).
- Btrfs: introduce mount option no_space_cache (FATE#306586).
- Btrfs: only inherit btrfs specific flags when creating files
  (FATE#306586).
- Btrfs: allow us to overcommit our enospc reservations
  (FATE#306586).
- Btrfs: break out of orphan cleanup if we can't make progress
  (FATE#306586).
- Btrfs: use the global reserve as a backup for deleting inodes
  (FATE#306586).
- Btrfs: stop using write_one_page (FATE#306586).
- Btrfs: introduce convert_extent_bit (FATE#306586).
- Btrfs: check unused against how much space we actually want
  (FATE#306586).
- Btrfs: fix orphan cleanup regression (FATE#306586).
- Btrfs: use the inode's mapping mask for allocating pages
  (FATE#306586).
- Btrfs: delay iput when deleting a block group (FATE#306586).
- Btrfs: make sure to unset trans->block_rsv before running
  delayed refs (FATE#306586).
- Btrfs: stop passing a trans handle all around the reservation
  code (FATE#306586).
- Btrfs: don't get the block_rsv in btrfs_free_tree_block
  (FATE#306586).
- Btrfs: use the transactions block_rsv for the csum root
  (FATE#306586).
- Btrfs: handle enospc accounting for free space inodes
  (FATE#306586).
- Btrfs: put the block group cache after we commit the super
  (FATE#306586).
- Btrfs: set truncate block rsv's size (FATE#306586).
- Btrfs: don't increase the block_rsv's size when emergency
  allocating space (FATE#306586).
- Btrfs: fix space leak when we fail to make an allocation
  (FATE#306586).
- Btrfs: fix call to btrfs_search_slot in free space cache
  (FATE#306586).
- Btrfs: allow callers to specify if flushing can occur for
  btrfs_block_rsv_check (FATE#306586).
- Btrfs: reduce the amount of space needed for truncates
  (FATE#306586).
- Btrfs: only reserve space in fallocate if we have to do a
  preallocate (FATE#306586).
- Btrfs: kill btrfs_truncate_reserve_metadata (FATE#306586).
- Btrfs: optimize how we account for space in truncate
  (FATE#306586).
- Btrfs: don't try to commit in btrfs_block_rsv_check
  (FATE#306586).
- Btrfs: kill unused parts of block_rsv (FATE#306586).
- Btrfs: ratelimit the generation printk for the free space cache
  (FATE#306586).
- Btrfs: fix how we reserve space for deleting inodes
  (FATE#306586).
- Btrfs: kill the durable block rsv stuff (FATE#306586).
- Btrfs: kill the orphan space calculation for snapshots
  (FATE#306586).
- Btrfs: calculate checksum space correctly (FATE#306586).
- Btrfs: skip looking for delalloc if we don't have
  - >fill_delalloc (FATE#306586).
- Btrfs: use bytes_may_use for all ENOSPC reservations
  (FATE#306586).
- Btrfs: fix how we mount subvol=<whatever> (FATE#306586).
- Btrfs: use d_obtain_alias when mounting subvol/subvolid
  (FATE#306586).
- Btrfs: kill reserved_bytes in inode (FATE#306586).
- Btrfs: move stuff around in btrfs_inode to get better packing
  (FATE#306586).
- commit ba3fdbf
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix tarball URL for -rcX and
  do not generate any URL for linux-next and vanilla snapshots.
- commit 1548daf
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix linux tarball URL
- commit 5453f99
* Tue Dec 13 2011 bpoirier@suse.de
- batman-adv: Only write requested number of byte to user buffer
  (bnc#736149 CVE-2011-4604).
- batman-adv: bat_socket_read missing checks (bnc#736149
  CVE-2011-4604).
- commit 94c2b73
* Tue Dec 13 2011 agraf@suse.de
- doc/config-options.changes: add CONFIG_DEBUG_STACKOVERFLOW change
- commit 42de6ff
* Tue Dec 13 2011 agraf@suse.de
- PPC: Update config files: disable CONFIG_DEBUG_STACKOVERFLOW
- commit 4d462dd
* Mon Dec 12 2011 aj@suse.de
- Silence missing defattr warning.
- commit e7e3743
* Mon Dec 12 2011 aj@suse.de
- Silence warning about dangling symlink and vdsos
- commit 701c5c7
* Mon Dec 12 2011 mmarek@suse.cz
- Revert "USB: fix ehci alignment error".
- kabi/severities: Check drivers/usb again
- commit 6f443ef
* Mon Dec 12 2011 trenn@suse.de
- x86, x2apic: Enable the bios request for x2apic optout.
- commit c1c0cfd
* Sat Dec 10 2011 jslaby@suse.cz
- Revert "Import 12.1 GA kabi files."
  This reverts commit b888bde97978ecb527b6ab1c68edf71b63039c2b.
  We don't need them in stable.
- commit d70fd6b
* Sat Dec 10 2011 jslaby@suse.cz
- Linux 3.1.5.
- Delete
  patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch.
- commit fe92352
* Sat Dec 10 2011 jslaby@suse.cz
- media/staging: fix allyesconfig build error.
- Refresh
  patches.drivers/0014-media-staging-as102-Enable-compilation.patch.
- commit 28aa839
* Fri Dec  9 2011 aj@suse.de
- No self-obsoletions.
- commit 1d2e747
* Fri Dec  9 2011 aj@suse.de
- Do not show rpmlint warnings.
- commit bb45b41
* Fri Dec  9 2011 aj@suse.de
- Use versioned provides/obsoletes.
- commit cf4f296
* Fri Dec  9 2011 aj@suse.de
- Adjust kernel-source.rpmlintrc for Linux 3.x
- commit bc1534e
* Thu Dec  8 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not package the vmlinux image in the devel
  package.
- commit 02bb976
* Wed Dec  7 2011 aj@suse.de
- Use GPL-2.0 as license tag (from http://spdx.org/licenses/)
  Only have one licenses line per file, the rest was just duplicated.
- commit f7c443c
* Wed Dec  7 2011 aj@suse.de
- Fix typo: Base package should not conflict with itself but with main package.
- commit e961ef0
* Tue Dec  6 2011 jeffm@suse.com
- Update to 3.2-rc4.
  - Eliminated 1 patch.
- commit a7d546d
* Mon Dec  5 2011 agraf@suse.de
- ARM: Update config files: omap: enable power management
- commit b97f846
* Sat Dec  3 2011 mmarek@suse.cz
- kabi: fix jiffies_to_clock_t breakage.
- commit c361d8d
* Fri Dec  2 2011 mmarek@suse.cz
- kabi/severities: Ignore changes to usb, nfs and some drivers for now.
- commit c267225
* Fri Dec  2 2011 mmarek@suse.cz
- Import 12.1 GA kabi files.
- commit b888bde
* Thu Dec  1 2011 mhocko@suse.cz
- mm: Ensure that pfn_valid is called once per pageblock when
  reserving pageblocks (bnc#731261, bnc#730731).
- commit 2d4e916
* Tue Nov 29 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make the -base package conflict with the main
  one.
- commit 45ada0d
* Tue Nov 29 2011 jslaby@suse.cz
- Linux 3.1.4.
- commit f68e526
* Mon Nov 28 2011 jeffm@suse.com
- Fix kernel-source spec to give ownership of the /usr/src/linux link
  to kernel-devel. kernel-source depends on kernel-devel, so this is correct.
- commit 7160a9c
* Mon Nov 28 2011 jbeulich@novell.com
- Refresh patches.xen/xen-pcpu-hotplug.
- Refresh patches.xen/xen3-patch-3.2-rc3.
- commit 7956240
* Mon Nov 28 2011 jbeulich@novell.com
- Update Xen patches to 3,2-rc3 and c/s 1127.
- Update frontswap patches to v10.
- config.conf: Re-enable Xen.
- Update config files.
- commit b08ea4f
* Mon Nov 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Ignore staging failures only in vanilla only
  branches.
- commit eeaaaf1
* Mon Nov 28 2011 mmarek@suse.cz
- Build the kotd against 12.1, not Factory.
- commit 2787ebe
* Mon Nov 28 2011 trenn@suse.de
- intel_idle: Fix kvm -cpu host Null pointer enter function issue
  (bnc#726296).
- commit 84d23cb
* Sun Nov 27 2011 jslaby@suse.cz
- Linux 3.1.3.
- commit e70a1d9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: set omap_fb=y
- commit c1efd33
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: disable OMAP2 to fix reboots
- commit 2d07cf1
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable DVI
- commit 40ecc5c
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable ehci
- commit 96a74f9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard usb
- commit bab20e3
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard LAN
- commit db7157b
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: Align with non-arm configs
- commit 9a9b9ee
* Fri Nov 25 2011 agraf@suse.de
- new script common_config.sh: find identical config options
- commit 1562f91
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: enable devtmpfs on all targets
- commit 5c31b37
* Fri Nov 25 2011 jeffm@suse.com
- Update config files for vanilla.
- commit 4c5b0b9
* Fri Nov 25 2011 jeffm@suse.com
- Update to 3.2-rc3.
  - stack unwind: cfi_ignore takes more arguments.
  - iio: Fix build error in industrialio-core.c.
- commit 48ef020
* Thu Nov 24 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- commit d0bebdb
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/try-disable-staging-driver: Script to disable failing staging
  driver and restart make.
- commit 819d1fa
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not have a separate make invocation for
  s390 and the rest.
- commit d72f6c1
* Thu Nov 24 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch: Add missing git-commit.
- commit 3556d24
* Thu Nov 24 2011 agraf@suse.de
- ARM: Update config file file i.MX51 (disable i.MX53)
- commit 6557e92
* Wed Nov 23 2011 agraf@suse.de
- ARM: Refresh patches.arch/arm-phys-offset.patch. (fix warnings)
- commit 519c94a
* Wed Nov 23 2011 agraf@suse.de
- ARM: create uImage, not zImage, so we can boot with u-boot
- commit 63a7b2c
* Wed Nov 23 2011 jdelvare@suse.de
- drm/radeon/kms: fix up gpio i2c mask bits for r4xx (bnc#691052).
- commit 6c3bb8d
* Wed Nov 23 2011 agraf@suse.de
- ARM: Fix compile breakage for generic kernel.
- commit 9d31b12
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: fix several issues in 3.2
- commit 3488f8d
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: disable broken eth driver
- commit 3729fdf
* Tue Nov 22 2011 jslaby@suse.cz
- Linux 3.1.2.
- commit 51ae099
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: run_oldconfig.sh
- commit ae90ef9
* Tue Nov 22 2011 agraf@suse.de
- ARM: fix run_oldconfig.sh
- commit 0362ed5
* Tue Nov 22 2011 agraf@suse.de
- ARM: Use zImage, not vmlinux
  On ARM we use the arch/arm/boot/zImage file similar to x86 to boot systems.
  Put that into the rpm as vmlinuz instead of the vmlinux ELF binary.
- commit 4c08eb0
* Tue Nov 22 2011 agraf@suse.de
- ARM: Dont generalize the target
  On ARM we can not build generic kernels that work through different generations,
  such as armv5 and armv7. So we better list them explicitly and not export an rpm
  that wouldn't even work on the respective architecture :).
- commit 854928d
* Thu Nov 17 2011 bpoirier@suse.de
- dm-raid45: split region hash and log, used by mirror and raid45.
- Update config files.
- commit a85f754
* Wed Nov 16 2011 jslaby@suse.cz
- add as102 dvb-t driver to staging
- staging: as102: Initial import from Abilis.
- staging: as102: Fix CodingStyle errors in file as102_drv.c.
- staging: as102: Fix CodingStyle errors in file as102_fw.c.
- staging: as102: Fix CodingStyle errors in file as10x_cmd.c.
- staging: as102: Fix CodingStyle errors in file
  as10x_cmd_stream.c.
- staging: as102: Fix CodingStyle errors in file as102_fe.c.
- staging: as102: Fix CodingStyle errors in file as102_usb_drv.c.
- staging: as102: Fix CodingStyle errors in file as10x_cmd_cfg.c.
- staging: as102: Add Elgato EyeTV DTT Deluxe.
- staging: as102: Properly handle multiple product names.
- staging: as102: Fix licensing oversight.
- staging: as102: Remove non-linux headers inclusion.
- staging: as102: Convert the comments to kernel-doc style.
- staging: as102: Enable compilation.
- staging: as102: Add nBox Tuner Dongle support.
- staging: as102: Unconditionally compile code dependent on
  DVB_CORE.
- staging: as102: Remove conditional compilation based on
  kernel version.
- Update config files.
- commit f08cab1
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc2.
  - Eliminated 1 patch.
- commit 85c9930
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc1.
  - Eliminate 212 patches.
- commit 6318d5b
* Tue Nov 15 2011 jeffm@suse.com
- Update Patch-mainline headers.
- commit e170ca1
* Mon Nov 14 2011 awafaa@opensuse.org
- Add package descriptions for ARM kernels
- Add ARM support for iMX51, OMAP2plus & Tegra SoC
- commit 51ebb2d
* Mon Nov 14 2011 jeffm@suse.com
- Updated incorrect Patch-mainline header.
- commit ef7dc61
* Sat Nov 12 2011 adrian@suse.de
- initial armv7l default kernel config, everything enable except the non compiling modules
- commit 7a5cd10
* Sat Nov 12 2011 gregkh@suse.de
- Linux 3.1.1.
- Update config files.
- Refresh patches.fixes/scsi-dh-queuedata-accessors.
- Refresh
  patches.suse/staging-hv-staging-next-20110829-0327-Staging-hv-storvsc-Add-the-contents-of-hyperv_sto.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Delete
  patches.drivers/alsa-hda-0002-Keep-EAPD-turned-on-for-old-Conexant-chips.
- Delete
  patches.drivers/alsa-hda-0003-Fix-ADC-input-amp-handling-for-Cx20549.
- Delete
  patches.drivers/alsa-hda-0004-Add-missing-static-ADC-tables-for-ALC269-qu.
- Delete
  patches.drivers/alsa-hda-0005-realtek-Skip-invalid-digital-out-pins.
- Delete patches.fixes/drm-radeon-kms-fix-i2c-masks.patch.
- Delete
  patches.suse/staging-hv-staging-next-20111001-0058-staging-hv-fix-a-kernel-warning-in-netvsc_linkstat.patch.
- Delete
  patches.suse/staging-hv-staging-next-20111001-0129-Staging-hv-Add-support-for-2-TB-LUN-in-storage-dr.patch.
- commit ce7f6bd
* Mon Nov  7 2011 neilb@suse.de
- sunrpc: wake up SOFTCONN tasks when a connection error happens
  (bnc#679059).
- commit f97b834
* Sat Nov  5 2011 trenn@suse.de
- X86: Solve Dell Latitudes do not reboot on x86_64 more
  generally.
- commit b3cc84a
* Thu Nov  3 2011 mszeredi@suse.cz
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
  hfs: fix hfs_find_init() sb->ext_tree NULL ptr oops
  (CVE-2011-2203 bnc#699709).
- commit 7923119
* Thu Nov  3 2011 tiwai@suse.de
- ALSA: hda/realtek - Skip invalid digital out pins (bnc#727348).
- ALSA: hda - Add missing static ADC tables for ALC269 quirks.
- commit 102bac3
* Thu Nov  3 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Add git commit ID.
- commit ee8439f
* Thu Nov  3 2011 mhocko@suse.cz
- oom: thaw threads if oom killed thread is frozen before
  deferring (bnc#723999).
- commit 74af598
* Thu Nov  3 2011 jeffm@suse.com
- Re-disabled patches.xen/xencons-tty_mutex.patch
- commit 187dde0
* Thu Nov  3 2011 jeffm@suse.com
- Re-added patches accidentally dropped with commit 28551a0c.
- commit 3795fde
* Thu Nov  3 2011 jbeulich@novell.com
- Update Xen patches to 3.1-final and c/s 1123.
- commit 35973e8
* Wed Nov  2 2011 jeffm@suse.com
- Add Elantech touchpad v3/v4 support (bnc#716852):
  - Input: elantech - add v3 hardware support.
  - Input: elantech - add v4 hardware support.
  - Input: elantech - better support all those v2 variants.
  - Input: elantech - clean up elantech_init.
  - Input: elantech - correct x, y value range for v2 hardware.
  - Input: elantech - get rid of ETP_2FT_* in elantech.h.
  - Input: elantech - packet checking for v2 hardware.
  - Input: elantech - remove ETP_EDGE_FUZZ_V2.
  - Input: elantech - remove module parameter force_elantech.
  - Input: elantech - use firmware provided x, y ranges.
- commit 28551a0
* Sun Oct 30 2011 mmarek@suse.cz
- rpm/{arch-symbols,mkspec}: Add support for ARM
  The various ARM families need similar handling like i?86.
- commit 0c6be6b
* Thu Oct 27 2011 tiwai@suse.de
- ALSA: hda - Fix ADC input-amp handling for Cx20549 codec.
- ALSA: hda - Keep EAPD turned on for old Conexant chips.
- ALSA: hda/realtek - Fix missing volume controls with ALC260
  (bnc#726812).
- commit 08229b0
* Tue Oct 25 2011 ohering@suse.de
- tty deadlock in kernel-xen, xenconsole (bnc#726333).
- commit 68289aa
* Tue Oct 25 2011 eich@suse.de
-  patches.suse/SUSE-bootsplash: remove DEBUG macro which was
  left in the code by accident.
- commit a56ba15
* Mon Oct 24 2011 jeffm@suse.com
- Update to 3.1-final.
- commit ec0449c
* Mon Oct 24 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  Update comments in code and reduce patch size
- commit 8913d07
* Thu Oct 20 2011 eich@suse.de
- bootsplash: fix logo location when a splash image with an off-center
  logo is rescaled (bnc #722471).
- commit f6d77d4
* Tue Oct 18 2011 jeffm@suse.com
- -Update to 3.1-rc10.
- commit 239957e
* Mon Oct 17 2011 jslaby@suse.cz
- Linux 3.0.7.
- commit b7d5dba
* Fri Oct 14 2011 trenn@suse.de
- x86: Fix reboot issue for Dell Optiplex 990.
- commit 00ea2b5
* Fri Oct 14 2011 mmarek@suse.cz
- rpm/*.spec.in, rpm/mkspec: Generate specfiles according to Factory
  requirements.
- commit aebe2d9
* Thu Oct 13 2011 ohering@suse.de
- series.conf: really apply all hv_mouse patches
- commit 11f65b5
* Wed Oct 12 2011 ohering@suse.de
- Various updates for hv drivers, which fix also the hv_mouse driver
- staging: hv: storvsc: ignore SET_WINDOWN scsi command
  (bnc#722646).
- staging/hv: advertise hv_storvsc instead of storvsc as sysfs
  driver name (bnc#716708).
- staging/hv: fill scsi/proc_name for the sake of mkinitrd
  (bnc#716708).
- Staging: hv: util: Invoke cn_netlink_send() in a work context.
- Refresh patches.suse/staging-hv-pata_piix-ignore-disks.patch.
- Refresh patches.xen/xen3-patch-2.6.32.
- Delete patches.suse/staging-hv-vmbus-modalias-show.patch.
- commit c836841
* Wed Oct 12 2011 eich@suse.de
- SUSE-bootsplash: Don't crash when splash is turned off.
  Fix crash when splash is off (ie. (struct fb_info *)->splash_data == NULL)
  but someone tries to manipulate the splash image thru the /proc interface.
  All other functions in render.c seem to be save - ie. upper level code
  already protects them from being called if the splash_data member is NULL
  (bnc #718666).
- commit 2fc2aaf
* Tue Oct 11 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit d4a7ce4
* Fri Oct  7 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc9 and c/s 1116.
- commit 8f986a2
* Thu Oct  6 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit f1106c1
* Wed Oct  5 2011 jbeulich@novell.com
- patches.suse/supported-flag: Also look for Module.supported in the
  source tree.
- Refresh patches.suse/supported-flag-enterprise.
- commit 9c8680a
* Wed Oct  5 2011 jeffm@suse.com
- Update to 3.1-rc9.
- commit a477439
* Tue Oct  4 2011 jslaby@suse.cz
- vmscan: clear ZONE_CONGESTED for zone with good watermark
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm: vmscan: drop nr_force_scan[] from get_scan_count (MM fixes
  3.0 to 3.1-rc4 not in -stable).
- mm: vmscan: fix force-scanning small targets without swap
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm/memory.c: remove ZAP_BLOCK_SIZE (MM fixes 3.0 to 3.1-rc4
  not in -stable).
- mm/huge_memory.c: minor lock simplification in __khugepaged_exit
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm: swap-token: makes global variables to function local
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- commit 34e40aa
* Tue Oct  4 2011 jslaby@suse.cz
- Linux 3.0.6.
- Refresh patches.fixes/bridge-module-get-put.patch.
- Delete patches.fixes/pty-fix-pty-counting.patch.
- Delete patches.fixes/tg3-Fix-io-failures-after-chip-reset.patch.
- commit 8eedfe8
* Mon Oct  3 2011 jeffm@suse.com
- Update to 3.1-rc8.
- commit 6c33ac4
* Wed Sep 28 2011 jbeulich@novell.com
- Update Xen config files.
- commit 50fb02f
* Tue Sep 27 2011 eich@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix crash when updating boxes: Don't reallocate
  picture.
- commit ba0cfdc
* Mon Sep 26 2011 mmarek@suse.cz
- rpm/host-memcpy-hack.h: Hack to use older version of the memcpy symbol
  in userspace programs, so that they keep working on older systems.
- rpm/kernel-binary.spec.in: Pass -include
  %%_sourcedir/host-memcpy-hack.h to the compiler when compiling
  userspace programs.
- commit e3c78cf
* Mon Sep 26 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc7 and c/s 1105.
- pass PCI segment information to Xen.
- ACPI: Implement overriding of arbitrary ACPI tables via initrd.
- x86: allow NVS can be accessed by driver.
- commit 7de39e8
* Mon Sep 26 2011 jeffm@suse.com
- Update to 3.1-rc7.
- commit ee8cc90
* Thu Sep 22 2011 mmarek@suse.cz
- rpm/split-modules: Print the full path for modules missing in supported.conf
- commit e55e4c6
* Thu Sep 22 2011 mmarek@suse.cz
- supported.conf: Fix stray line making net/atm/atm suddenly unsupported.
- commit 58dbd06
* Wed Sep 21 2011 mmarek@suse.cz
- Add support for wildcards in supported.conf
- rpm/kernel-binary.spec.in: Generate Module.supported with all
  lines from supported conf, unsupported modules are marked as "no"
- rpm/split-modules: Use the supported flag in modules, instead of
  parsing the Module.supported file and report modules that have no
  supported marking.
- rpm/check-supported-list: Delete, this is done by split-modules
  now.
- commit edfdc2a
* Wed Sep 21 2011 trenn@suse.de
- Refresh
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
  - > Fix build on ia64, by moving asm/e820.h into ifdef config protected region.
- commit 0ac4276
* Wed Sep 21 2011 mhocko@suse.cz
- Provide memory controller swap extension.
  Keep the feature disabled by default. Use swapaccount=1 kernel
  boot parameter for enabling it.
- commit 000742c
* Wed Sep 21 2011 mhocko@suse.cz
- Update config files.
  Clean run_oldconfig.sh run to get configs into sync
- commit c985824
* Tue Sep 20 2011 trenn@suse.de
- ACPI: Implement overriding of arbitrary ACPI tables via initrd
  (none).
- ACPICA: Fix wrongly mapped acpi table header when overriding
  via initrd (none).
- ACPICA: Introduce acpi_os_phys_table_override function (none).
- x86: allow NVS can be accessed by driver (none).
- Update config files:
  CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
  on i386 and x86_64 flavors
- commit 34bb195
* Thu Sep 15 2011 jeffm@suse.de
- Update to 3.1-rc6.
- commit 8f0eaba
* Thu Sep 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix unwinding through
  interrupt frames, requiring ...
- patches.suse/stack-unwind: ... support for DW_CFA_def_cfa_expression.
- commit 4d917a5
* Wed Sep 14 2011 agraf@suse.de
- KVM: PPC: Fix incorrect CBE KVM hooks.
  There is another issue with KVM_HV and CBE that I only saw building
  this tree, so the patch is on its way to the kvm tree now.
- KVM: PPC: Assemble book3s{,_hv}_rmhandlers.S separately
  When building KVM HV mode with plenty other options enabled, the build
  fails. That's fixed upstream, but 3.1-rc5 doesn't have the patch yet.
  So I pulled it in from the kvm tree.
- commit 2be41bd
* Mon Sep 12 2011 jbeulich@novell.com
- Re-enabled patches.arch/x86_64-unwind-annotations.
- commit bfd10a0
* Mon Sep 12 2011 jbeulich@novell.com
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh patches.suse/supported-flag.
- commit aa89174
* Mon Sep 12 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc5 and c/s 1104.
- mm: frontswap: config and doc files.
- mm: frontswap: core code.
- mm: frontswap: add swap hooks and extend try_to_unuse.
- mm: frontswap: swap data structure changes.
- In HVM guests do not take over the CDROM device (bnc#645893).
- x86: report ACPI-reserved state of PCI MMCONFIG region to
  hypervisor.
- config.conf: Re-enable Xen flavors.
- Update config files.
- commit 3692f47
* Sun Sep 11 2011 agraf@suse.de
- Update config files (disable EHCA on PPC - gcc bug)
- commit 03a0c8c
* Sun Sep 11 2011 agraf@suse.de
- Update config files (enable KVM on PPC64 for OBS)
- commit 00b922d
* Mon Sep  5 2011 mmarek@suse.cz
- Update to 3.1-rc5 from https://github.com/torvalds/linux.git.
- commit 8a211c9
* Fri Sep  2 2011 ohering@suse.de
- Staging: hv: vmbus: Show the modalias in /sys/bus/vmbus/devices/*/
  (fate#311487).
- commit 94054c9
* Thu Sep  1 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- Staging: hv: vmbus: Don't wait indefinitely for IRQ resouces.
- Staging: hv: tools: Fix a checkpatch warning in hv_kvp_daemon.c.
- Staging: hv: vmbus: Fix checkpatch warnings.
- Staging: hv: util: kvp: Fix the reported OSVersion string.
- Staging: hv: util: kvp: Cleanup kvp_get_domain_name().
- Staging: hv: Fix macros, tab errors and warning in
  drivers/staging/hv/hv_mouse.c.
- Staging: hv: vmbus: VMBUS is an ACPI enumerated device, get
  rid of the PCI signature.
- Staging: hv: Replace struct hv_guid with the uuid type already
  defined in Linux.
- Staging: hv: vmbus: Introduce vmbus ID space in struct
  hv_driver.
- Staging: hv: blkvsc: Use the newly introduced vmbus ID in the
  blockvsc driver.
- Staging: hv: storvsc: Use the newly introduced vmbus ID in
  storvsc driver.
- Staging: hv: netvsc: Use the newly introduced vmbus ID in
  netvsc driver.
- Staging: hv: mousevsc: Use the newly introduced vmbus ID in
  mouse driver.
- Staging: hv: util: Make hv_utils a vmbus device driver.
- Staging: hv: create VMBUS_DEVICE macro and use it.
- Staging: hv: vmbus: Cleanup vmbus_match().
- Staging: hv: vmbus: Cleanup vmbus_uevent() code.
- Staging: hv: vmbus: Support the notion of id tables in
  vmbus_match().
- Staging: hv: vmbus: Get rid of an unnecessary include line
  in vmbus_drv.c.
- Staging: hv: storvsc: Get rid of the DMI signature.
- Staging: hv: netvsc: Get rid of the PCI signature.
- Staging: hv: netvsc: Get rid of the DMI signature in
  netvsc_drv.c.
- Staging: hv: util: Get rid of the DMI signature in hv_util.c.
- Staging: hv: util: Get rid of the PCI signature in hv_util.c.
- Staging: hv: fix up driver registering mess.
- Staging: hv: vmbus: Get rid of some unnecessary comments.
- Staging: hv: vmbus: Cleanup unnecessary comments in hv.c.
- Staging: hv: vmbus: Cleanup error handling in hv_init().
- Staging: hv: vmbus: Get rid of unnecessay comments in
  connection.c.
- Staging: hv: vmbus: Get rid of the function dump_gpadl_body().
- Staging: hv: vmbus: Get rid of the function dump_gpadl_header().
- Staging: hv: vmbus: Rename openMsg to open_msg in channel.c.
- Staging: hv: vmbus: Get rid of unnecessary comments in
  channel.c.
- Staging: hv: vmbus: Change the variable name openInfo to
  open_info in channel.c.
- Staging: hv: vmbus: Cleanup error values in ringbuffer.c.
- Staging: hv: vmbus: Cleanup the error return value in
  vmbus_recvpacket_raw().
- Staging: hv: netvsc: Get rid of an unnecessary print statement
  in netvsc_probe().
- Staging: hv: vmbus: Retry vmbus_post_msg() before giving up.
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_dev_add().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_channel_init().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_connect_to_vsp().
- Staging: hv: storvsc: Cleanup error handling in storvsc_do_io().
- Storage: hv: storvsc: Get rid of some unnecessary DPRINTs
  from storvsc.c.
- Staging: hv: storvsc: Fix/cleanup some dated comments in
  storvsc.c.
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_host_reset().
- Staging: hv: storvsc: Cleanup error code returned in
  storvsc_probe().
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_drv_init().
- Staging: hv: netvsc: Cleanup the returned error code in
  netvsc_probe().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_destroy_recv_buf().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_init_recv_buf().
- Staging: hv: netvsc: Cleanup error returns in
  netvsc_connect_vsp().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_send().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_device_add().
- Staging: hv: netvsc: Cleanup error codes in
  rndis_filter_receive().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_query_device().
- Staging: hv: netvsc: Cleanup error return values in
  rndis_filter_set_packet_filter().
- Staging: hv: netvsc: Cleanup error returns in
  rndis_filter_init_device().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_device_add().
- Staging: hv: mouse: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Exit to exit.
- Staging: hv: mouse: Get rid of the unused PCI signature.
- Staging: hv: hv_mouse: remove deviceinfo_callback function.
- Staging: hv: hv_mouse: remove inputreport_callback function.
- Staging: hv: hv_mouse: remove a forward declaration.
- Staging: hv: hv_mouse: fix up remove() function.
- Staging: hv: Add struct hv_vmbus_device_id to mod_devicetable.h.
- Staging: hv: add driver_data to hv_vmbus_device_id.
- Staging: hv: Add code to parse struct hv_vmbus_device_id table.
- Staging: hv: file2alias: fix up alias creation logic for
  hv_vmbus_device_id.
- Staging: hv: storvsc: Inline free_stor_device().
- Staging: hv: storvsc: Do not aquire an unnecessary reference
  on stor_device.
- Staging: hv: storvsc: Rename must_get_stor_device().
- Staging: hv: storvsc: Rename get_stor_device().
- Staging: hv: storvsc: Cleanup alloc_stor_device().
- Staging: hv: storvsc: Introduce state to manage the lifecycle
  of stor device.
- Staging: hv: storvsc: Prevent outgoing traffic when stor dev
  is being destroyed.
- Staging: hv: storvsc: Get rid of release_stor_device() by
  inlining the code.
- Staging: hv: storvsc: Get rid of final_release_stor_device()
  by inlining code.
- Staging: hv: storvsc: Get rid of the reference counting in
  struct storvsc_device.
- Staging: hv: netvsc: Inline the code for free_net_device().
- Staging: hv: netvsc: Cleanup alloc_net_device().
- Staging: hv: netvsc: Introduce state to manage the lifecycle
  of net device.
- Staging: hv: netvsc: Prevent outgoing traffic when netvsc dev
  is destroyed.
- Staging: hv: netvsc: Get rid of release_outbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of release_inbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of the refcnt field in struct
  netvsc_device.
- Staging: hv: storvsc: Add code to handle IDE devices using
  the storvsc driver.
- Staging: hv: storvsc: Handle IDE devices using the storvsc
  driver.
- Staging: hv: blkvsc: Get rid of blkvsc_drv.c as this code is
  not used.
- Staging: hv: storvsc: Optimize bounce buffer handling for the
  "write" case.
- Staging: hv: storvsc: Optimize the bounce buffer handling in
  the "read" case.
- Staging: hv: storvsc: Include storvsc.c in storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of storvsc.c.
- Staging: hv: storvsc: Add the contents of hyperv_storage.h
  to storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of hyperv_storage.h.
- Staging: hv: storvsc: Fixup srb and scsi status for INQUIRY
  and MODE_SENSE.
- Staging: hv: storvsc: Fix a typo.
- Staging: hv: storvsc: In case of scsi errors offline the device.
- Staging: hv: storvsc: No need to copy from bounce buffer in
  case of a failure.
- Staging: hv: util: Forcefully shutdown when shutdown is
  requested.
- Staging: hv: util: Adjust guest time in a process context.
- Staging: hv: vmbus: Check before invoking the channel callback.
- Staging: hv: vmbus: Properly deal with de-registering channel
  callback.
- Staging: hv: Fix a bug in vmbus_match().
- Staging: hv: vmbus: Get rid of vmbus_on_isr() by inlining
  the code.
- Staging: hv: vmbus: Do not enable auto eoi.
- Staging: hv: vmbus: Fixup indentation in vmbus_acpi_add().
- Staging: hv: vmbus: Get rid of some dated/redundant comments.
- Staging: hv: vmbus: Get rid of an unnecessary check in
  vmbus_connect().
- Staging: hv: vmbus: Fix a checkpatch warning in ring_buffer.c.
- Staging: hv: vmbus: Fix checkpatch warnings in connection.c.
- Staging: hv: mousevsc: Fix checkpatch errors and warnings.
- Staging: hv: netvsc: return negative error codes.
- Delete patches.suse/staging-hv-vmbus-init-on-dmi-match.patch.
- commit d77df1b
* Wed Aug 31 2011 jslaby@suse.cz
- TTY: pty, fix pty counting (bnc#711203).
- commit a432f18
* Tue Aug 30 2011 jdelvare@suse.de
- Delete patches.fixes/net-tulip-debug-off-by-default.patch.
  Obsoleted by upstream commit 0b8f6273eb6fd0611849d6fb432151f04e042434.
- commit bd9ecd2
* Tue Aug 30 2011 jslaby@suse.cz
- Linux 3.0.4.
- Refresh patches.arch/reorganize_stop_cpus.patch.
- x86, mtrr: use stop_machine APIs for doing MTRR rendezvous
  (bnc#697859).
- Delete patches.arch/mtrr_stop_machine_quick_fix.patch.
- stop_machine: implement stop_machine_from_inactive_cpu().
- Delete
  patches.arch/implement_stop_machine_from_offline_cpu.patch.
- Delete patches.arch/kill-__stop_machine.patch.
- commit 1fb7ef5
* Tue Aug 30 2011 gregkh@suse.de
- supported.conf: xhci-hcd not xhci. Also move it to +base so you can boot
  off of USB3 devices.
- commit 66f95ad
* Tue Aug 30 2011 gregkh@suse.de
- supported.conf: xhci-hcd not xhci. Also move it to base so you can boot
  off of a USB3 device (bnc#712752)
- commit f6522ba
* Mon Aug 29 2011 jeffm@suse.com
- Re-Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit 626749c
* Mon Aug 29 2011 jeffm@suse.com
- Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit e82bcac
* Mon Aug 29 2011 jeffm@suse.com
- Disabled patches.rpmify/pti-depends-on-x86-pci
- commit 0baba30
* Mon Aug 29 2011 jeffm@suse.com
- Update to 3.1-rc4.
- commit 68e08b1
* Wed Aug 24 2011 jeffm@suse.com
- PTI: depends on X86 && PCI.
- commit e975e4b
* Wed Aug 24 2011 jeffm@suse.com
- scsi_dh_alua: always update TPGS status on activate.
- scsi_dh: Check for sdev state in store_dh_state() (bnc#616080).
- scsi_dh_alua: Evaluate TPGS setting from inquiry data.
- scsi_dh: Implement match callback function.
- Delete patches.fixes/scsi-dh-alua-retry-UA.
- Delete patches.fixes/scsi-dh-alua-send-stpg.
- commit 026eef6
* Wed Aug 24 2011 jeffm@suse.com
- Refresh and re-enable patches.arch/x86_64-hpet-64bit-timer.patch.
- commit bd2f299
* Wed Aug 24 2011 jeffm@suse.com
- Refreshed and re-enabled dm-path patches:
  - patches.suse/dm-mpath-accept-failed-paths.
  - patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit d374e62
* Wed Aug 24 2011 jeffm@suse.com
- Update to 3.1-rc3.
  - Eliminated 8 patches.
  - Xen is disabled.
- commit eccefcc
* Thu Aug 18 2011 eich@suse.de
- * Refresh patches.suse/SUSE-bootsplash.
  * Fix bootsplash code for 15bpp framebuffers.
  These framebuffers are rare these days, the legendary and still
  popular server chipset Radeon ES1000 supports it, though.
- commit 637eb19
* Wed Aug 17 2011 jslaby@suse.cz
- Linux 3.0.3.
- commit e4182fa
* Tue Aug 16 2011 jslaby@suse.cz
- Linux 3.0.2.
- Revert "xen: allow enable use of VGA console on dom0".
- commit 9caf7b1
* Sun Aug 14 2011 trenn@suse.de
- Properly destroy pmsr devices:
  Refresh patches.xen/xen-x86-msr-on-pcpu.
- commit 934d81a
* Sat Aug 13 2011 gregkh@suse.de
- Update config files, enabling CONFIG_RT2800PCI as requested.
- commit b2f65f0
* Tue Aug  9 2011 trenn@suse.de
- Update config files:
  bnc#674988, change:
  - CONFIG_ACPI_CUSTOM_METHOD=m
  +# CONFIG_ACPI_CUSTOM_METHOD is not set
  for all flavors
- commit f1af972
* Fri Aug  5 2011 jslaby@suse.cz
- Linux 3.0.1.
- Refresh
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Refresh patches.xen/kexec-move-segment-code-i386.patch.
- Refresh patches.xen/kexec-move-segment-code-x86_64.patch.
- Refresh patches.xen/xen3-patch-2.6.36.
- Delete patches.fixes/SCSI-fix-crash-in-scsi_dispatch_cmd.patch.
- commit 191d3db
* Mon Aug  1 2011 mmarek@suse.cz
- rpm/modversions: Support for new genksyms format with E# tags for enum
  constants.
- commit ee6da8c
* Fri Jul 29 2011 jslaby@suse.cz
- tg3: Fix io failures after chip reset (bnc#705962).
- commit c8d864c
* Mon Jul 25 2011 mmarek@suse.cz
- Fix format of patches to apply with series2git:
  patches.arch/s390-message-catalog.diff
  patches.drivers/input-Add-LED-support-to-Synaptics-device
  patches.fixes/kvm-macos.patch
  patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch
  patches.fixes/nfs-slot-table-alloc
  patches.fixes/oom-warning
  patches.fixes/scsi-dh-alua-send-stpg
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch
  patches.suse/0015-ext4-Use-IS_POSIXACL-to-check-for-POSIX-ACL-support.patch
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch
  patches.suse/dm-mpath-no-activate-for-offlined-paths
  patches.suse/dm-mpath-no-partitions-feature
  patches.suse/no-frame-pointer-select
  patches.suse/no-partition-scan
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops
  patches.suse/setuid-dumpable-wrongdir
  patches.suse/stack-unwind
  patches.suse/supported-flag-enterprise
- commit b5f5212
* Mon Jul 25 2011 meissner@suse.de
- Powerpc config adjustments
  This makes CONFIG_POWER_SUPPLY=y like in the other architectures,
  it also disables the EHCA driver as gcc 4.6 currently fails to compile
  it correctly.
- commit aa27d23
* Sun Jul 24 2011 jslaby@suse.cz
- fix crash in scsi_dispatch_cmd() (bnc#707853).
- commit dfe0dcf
* Fri Jul 22 2011 mmarek@suse.cz
- Update to 3.0.
- commit 50c05d7
* Thu Jul 21 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc7 and c/s 1098.
- Update Xen config files.
- commit f4eb207
* Mon Jul 18 2011 jdelvare@suse.de
- tulip: Disable debugging messages by default
- commit 141a54f
* Fri Jul 15 2011 ohering@suse.de
- hv: only load the driver in a hyper-v guest (bnc#704957).
- commit f2f7449
* Thu Jul 14 2011 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.  Fix for nouveau.
- commit 27de298
* Thu Jul 14 2011 tiwai@suse.de
- ALSA: hda - Add Kconfig for the default buffer size
  (bnc#682725).
- Update config files.
- Delete, replaced with the new upstream patch
  patches.drivers/alsa-hda-0019-Increase-default-buffer-size.
- commit 40c7644
* Wed Jul 13 2011 jeffm@suse.com
- Update to 3.0-rc7.
- commit 0de37e1
* Sat Jul  9 2011 jslaby@suse.cz
- Delete patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Delete patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
  They were superseded by other patches in
  aa3d6e2b140aac24a432f830d30047b1842aed0b.
- commit 84b09a0
* Sat Jul  9 2011 jslaby@suse.cz
- Linux 2.6.39.3.
- Delete
  patches.fixes/bridge-provide-a-cow_metrics-method-for-fake_ops.patch.
- Delete
  patches.fixes/tty-ldisc-do-not-close-until-there-are-readers.patch.
- commit 8f499df
* Thu Jul  7 2011 jeffm@suse.com
- Update to 3.0-rc6.
  - Eliminated 1 patch.
- commit 56e99da
* Tue Jul  5 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc5 and c/s 1095.
- xen: prepare tmem shim to handle frontswap.
- support booting Xen from EFI (fate#311376, fate#311529,
  bnc#578927, bnc#628554).
- config.conf: Re-enabled Xen flavors.
- Update x86 config files.
- Delete patches.xen/xen-blkback-bimodal-suse.
- commit 4c2a76f
* Mon Jul  4 2011 tiwai@suse.de
- Fix invalid colormap override in SUSE-bootsplash patch (bnc#584493)
- commit b4495f4
* Wed Jun 29 2011 jeffm@suse.com
- Update to 3.0-rc5.
- commit 9eb1a0f
* Wed Jun 29 2011 jslaby@suse.cz
- TTY: ldisc, do not close until there are readers (bnc#698247
  bnc#693374).
- commit 0615f1a
* Sun Jun 26 2011 jslaby@suse.cz
- Update header: Revert "HID: magicmouse: ignore 'ivalid report id'
  while switching modes"
- commit aff1267
* Sun Jun 26 2011 jslaby@suse.cz
- bridge: provide a cow_metrics method for fake_ops.
- commit 5bff18d
* Fri Jun 24 2011 jeffm@suse.com
- Enable TOMOYO (FATE#310292, bnc#668381).
- commit 997e757
* Fri Jun 24 2011 jslaby@suse.cz
- Linux 2.6.39.2.
- Delete
  patches.fixes/asus-wmi-Remove-__init-from-asus_wmi_platform_init.patch.
- Delete
  patches.kernel.org/0001-Revert-x86-efi-Retain-boot-service-code-until-after-.patch.
- commit a1dc102
* Tue Jun 21 2011 mmarek@suse.cz
- Update vanilla configs.
- commit 1738011
* Tue Jun 21 2011 mmarek@suse.cz
- Update to 3.0-rc4
- commit 1b6bf5d
* Fri Jun 17 2011 mmarek@suse.cz
- rpm/post.sh: Touch /boot/do_purge_kernels on package install
  (fate#312018).
- rpm/postun.sh: Remove it again if it still exists on package
  uninstall.
- commit 82f4a5d
* Fri Jun 17 2011 trenn@suse.de
- stop_machine: implement stop_machine_from_offline_cpu()
  (bnc#697859).
- stop_machine: kill __stop_machine() (bnc#697859).
- x86, mtrr: lock stop machine during MTRR rendezvous sequence
  (bnc#697859).
- stop_machine: reorganize stop_cpus() implementation
  (bnc#697859).
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#697859).
- commit 303cc0e
* Thu Jun 16 2011 mmarek@suse.cz
- Remove the novfs patches, it should be packaged as a KMP, or
  ideally, reimplemented as a fuse filesystem (which is the reason why
  the current implementation it is never going to be accepted upstream).
- Delete patches.fixes/novfs-copy_user-fixes.diff.
- Delete patches.fixes/novfs-minsize-fixes.
- Delete patches.fixes/novfs-nwcapi.patch.
- Delete patches.suse/novfs-client-module.
- Delete patches.suse/novfs-remove-bkl.
- commit bc3a79d
* Thu Jun 16 2011 tiwai@suse.de
- ALSA: fix hda AZX_DCAPS_NO_TCSEL quirk check in driver_caps
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Reorganize controller quriks with bit flags
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Enable snoop bit for AMD controllers
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Enable sync_write workaround for AMD generically
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - ALSA HD Audio patch for Intel Panther Point DeviceIDs
  (bnc#700250,bnc#700251,bnc#700253).
- commit e9fb121
* Thu Jun 16 2011 ohering@suse.de
- Update vanilla config files.
- commit a642909
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  jobs is not defined for home: projects, use the new _smp_mflags to enable parallel build
- commit 1009eaf
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  Update comment, get the number of cpus from /proc/stat
- commit b4cf18c
* Wed Jun 15 2011 jeffm@suse.com
- Update config files: Disable BRCMSMAC on ppc/ppc64.
- commit 20b3d8e
* Wed Jun 15 2011 jack@suse.cz
- "Unable to save Login Script" appears when trying to save a
  user login script (bnc#638985).
- commit fb87098
* Wed Jun 15 2011 jack@suse.cz
- fs: novfs: Limit check for datacopy between user and kernel space.
- commit 2985362
* Wed Jun 15 2011 jeffm@suse.com
- Update to 3.0-rc3.
  - Eliminated 2 patches.
- commit a1fe999
* Tue Jun 14 2011 mmarek@suse.cz
- scripts/config.sh: Remove MIRROR handling, _find_tarball() does it
  itself.
- commit 18ad47f
* Mon Jun 13 2011 jeffm@suse.com
- nouveau: Make vga_switcheroo code depend on VGA_SWITCHEROO.
- commit b3f32a6
* Mon Jun 13 2011 jeffm@suse.com
- apm: Honor CONFIG_APM_CPU_IDLE=n.
- commit 8ad9b51
* Mon Jun 13 2011 jeffm@suse.com
- Update config files.
- commit 2cd7359
* Mon Jun 13 2011 jeffm@suse.com
- Delete patches.rpmify/qla4xx-missing-readq-definition.
- commit b48337d
* Mon Jun 13 2011 mmarek@suse.cz
- Remove copypasted lines from vanilla configs.
- commit b395e52
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Call gzip with -n.
- commit 9a65e48
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/mkspec: Put the -rcX tag into the rpm version instead of the
  trailing zero. Rpm considers "rc" older than "0", so this will sort
  properly.
- commit 8d9b2b9
* Mon Jun 13 2011 mmarek@suse.cz
- x86, build: Do not set the root_dev field in bzImage.
- commit 15e4a82
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/kernel-binary.spec.in: Revert the previous hack.
- commit 95c9977
* Sat Jun 11 2011 jeffm@suse.de
- kbuild: Fix KERNELVERSION for empty SUBLEVEL or PATCHLEVEL.
- kbuild: Fix <linux/version.h> for empty SUBLEVEL or PATCHLEVEL.
- Refresh patches.suse/supported-flag.
- rpm/kernel-binary.spec.in: Hack to work around v3.0 vs v3.0.0
- commit a95ebd8
* Fri Jun 10 2011 jeffm@suse.com
- Delete patches.suse/file-capabilities-disable-by-default.diff.
- commit 2694a88
* Fri Jun 10 2011 jeffm@suse.com
- x86: Remove warning and warning_symbol from struct
  stacktrace_ops.
- Delete
  patches.fixes/asus-wmi-Remove-__init-from-asus_wmi_platform_init.patch.
- commit 608ce9e
* Fri Jun 10 2011 trenn@suse.de
- Update Suresh's patchset to version 3:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 9f2e923
* Wed Jun  8 2011 jeffm@suse.com
- Revert "Revert "- Updated to 3.0-rc1.""
  This reverts commit b2d9e72dc9cd8e62d49e0565babd76332f7c2114.
  Conflicts:
  rpm/config.sh
  series.conf
- commit 408e273
* Wed Jun  8 2011 jeffm@suse.com
- Update to 3.0-rc2.
- commit b97d26c
* Wed Jun  8 2011 trenn@suse.de
- Update Suresh's version 2 of the patchseries:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 4ef8999
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for empty EXTRAVERSION
- commit a0a1386
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for 3.0
- commit dca1465
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/mkspec: Fix perl warning
- commit 395d7d8
* Tue Jun  7 2011 trenn@suse.de
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#672008).
- stop_machine: enable __stop_machine() to be called from the
  cpu online path (bnc#672008).
- commit 684cd78
* Mon Jun  6 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Loosen the mkinitrd requirement, this was
  only a workaround for a 11.3 update problem (cf bnc#615680).
- commit 05ade7d
* Sun Jun  5 2011 jslaby@suse.cz
- Revert "HID: magicmouse: ignore 'ivalid report id' while
  switching modes".
- Revert "x86, efi: Retain boot service code until after switching
  to virtual mode".
- commit 855dd58
* Sun Jun  5 2011 jslaby@suse.cz
- asus-wmi: Remove __init from asus_wmi_platform_init
  (bnc#696212).
- commit 2e6cc6b
* Fri Jun  3 2011 mmarek@suse.cz
- Temporarily set PPC_DISABLE_WERROR=y in power to fix build
- commit 5e9cb3b
* Fri Jun  3 2011 mmarek@suse.cz
- scripts/kmsg-doc: Do not require Switch.pm.
- commit 83a39c7
* Fri Jun  3 2011 mmarek@suse.cz
- rpm/macros.kernel-source: Add -b option to %%kernel_module_package
  to unconditionally call mkinitrd on kmp install (fate#309400).
- rpm/kernel-module-subpackage: Pass KMP_NEEDS_MKINITRD=1 to
  weak-modules2 if the -b option is used.
- commit 83331f5
* Fri Jun  3 2011 jslaby@suse.cz
- Linux 2.6.39.1.
- Refresh patches.suse/no-partition-scan.
- Refresh patches.xen/xen3-patch-2.6.27.
- Delete
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
- commit 577661d
* Thu Jun  2 2011 jslaby@suse.cz
- rpm/config.sh: allow building in IBS
- commit 607aaf6
* Wed Jun  1 2011 jbeulich@novell.com
- Delete patches.xen/sfc-* (as advised by Solarflare).
- commit a144c73
* Tue May 31 2011 jeffm@suse.com
- Revert "- Updated to 3.0-rc1."
  This reverts commit 5710413eb834b0f215f6f4249d6ff7c3f7673eb7.
  Should have been committed to the merge-v3.0 branch.
- commit b2d9e72
* Tue May 31 2011 jeffm@suse.com
- Updated to 3.0-rc1.
  - Eliminated 9 patches.
- commit 5710413
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit d3e465a
* Mon May 30 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
- aic94xx: world-writable sysfs update_bios file.
  Update upstream info.
- commit 8912816
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit 646bfb1
* Fri May 27 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Set KBUILD_BUILD_{USER,HOST} to
  geeko@buildhost, obsoleting the patch to scripts/mkcompile_h.
- commit b4b7255
* Mon May 23 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39 final and c/s 1085.
- xen/sfc_netfront: fix an unused variable error.
- commit 3b6edff
* Fri May 20 2011 jslaby@suse.cz
- PM: Print a warning if firmware is requested when tasks are
  frozen (bnc#695219).
- commit e78f4ce
* Fri May 20 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
  Bah, cherry-picked a wrong version. Fix it.
- commit f9674b8
* Fri May 20 2011 jslaby@suse.cz
- Delete patches.suse/slab-handle-memoryless-nodes-v2a.patch.
  It was part of removed SoN patches.
- commit 1d0599a
* Fri May 20 2011 jeffm@suse.com
- Updated to 2.6.39-final.
- commit 7c72384
* Thu May 19 2011 jbeulich@novell.com
- supported.conf: blktap2 modules are supported.
- commit fa60394
* Tue May 17 2011 jslaby@suse.cz
- Refresh
  patches.kernel.org/libata-fix-oops-when-lpm-is-used-with-pmp.patch.
  Note upstream commit SHA.
- commit 17fc03c
* Mon May 16 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add the commit hash to uname -v, cleanup.
- commit f3bdb4c
* Sun May 15 2011 jslaby@suse.cz
- eeepc-laptop: Use ACPI handle to identify rfkill port
  (bnc#595586).
- commit 3c190ca
* Fri May 13 2011 mhocko@suse.cz
- proc: fix oops on invalid /proc/<pid>/maps access (bnc#693382).
- commit 0422a7e
* Fri May 13 2011 jeffm@suse.com
- Update to 2.6.39-rc7.
  - Eliminated 5 patches.
- commit a8a170f
* Fri May 13 2011 mmarek@suse.cz
- Build the kotd against 11.4
- commit 2ad3395
* Fri May 13 2011 mhocko@suse.cz
- memcg: allocate memory cgroup structures in local nodes
  (bnc#692502, bnc#669889).
- mm: add alloc_pages_exact_nid() (bnc#692502, bnc#669889).
- commit fe168ad
* Thu May 12 2011 jslaby@suse.cz
- Refresh
  patches.kernel.org/libata-fix-oops-when-lpm-is-used-with-pmp.patch.
  Just change the patch-mainline field. It's not upstream yet.
- commit 485c6fe
* Thu May 12 2011 jslaby@suse.cz
- block: add proper state guards to __elv_next_request.
- commit bcb6433
* Thu May 12 2011 gregkh@suse.de
- libata: fix oops when LPM is used with PMP.
- commit 762704b
* Thu May 12 2011 jslaby@suse.cz
- Delete
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  It's fixed differently by commits 43f12d47f and f844a709a7 in .38.5.
- Delete
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  It's fixed differently by commits 43f12d47f and f844a709a7 in .39-rc1
- commit b64bc58
* Thu May 12 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  Note about submission.
- commit 9922e20
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/files-slab-rcu.patch.
- commit 6547edf
* Tue May 10 2011 mhocko@suse.cz
- patches.fixes/aggressive-zone-reclaim.patch: delete because
  the patch is very workload specific and can lead to unexpected
  reclaims in parallel node local workloads.
- commit 56cf10e
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/mm-devzero-optimisation.patch: we do not need
  it anymore as we have zero page back since 2.6.32
- commit 323a093
* Tue May 10 2011 mmarek@suse.cz
- Really delete patches.fixes/aggressive-zone-reclaim.patch.
- commit b21d4b6
* Tue May 10 2011 jslaby@suse.cz
- deal with races in /proc/*/{syscall,stack,personality}
  (bnc#674982 CVE-2011-1020).
- auxv: require the target to be tracable (or yourself)
  (bnc#674982 CVE-2011-1020).
- close race in /proc/*/environ (bnc#674982 CVE-2011-1020).
- report errors in /proc/*/*map* sanely (bnc#674982
  CVE-2011-1020).
- pagemap: close races with suid execve (bnc#674982
  CVE-2011-1020).
- commit 346cb46
* Tue May 10 2011 jslaby@suse.cz
- Linux 2.6.38.6.
- Refresh patches.fixes/scsi-dh-queuedata-accessors.
- commit 5e831f6
* Mon May  9 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc6.
- commit b976a7e
* Mon May  9 2011 jbeulich@novell.com
- patches.suse/kconfig-automate-kernel-desktop: Remove stray blank
  lines (for older versions of "patch" to grok).
- commit 4dfa74d
* Sat May  7 2011 jeffm@suse.com
- Removed network driver entropy patches. haveged is installed by default
  and should be enabled to generate entropy from non-predictable sources.
  - Delete patches.drivers/bnx2-entropy-source.patch.
  - Delete patches.drivers/e1000-entropy-source.patch.
  - Delete patches.drivers/e1000e-entropy-source.patch.
  - Delete patches.drivers/igb-entropy-source.patch.
  - Delete patches.drivers/ixgbe-entropy-source.patch.
  - Delete patches.drivers/tg3-entropy-source.patch.
- commit c88b893
* Fri May  6 2011 jeffm@suse.com
- Update
  patches.fixes/netfilter-implement-rfc-1123-for-ftp-conntrack
  (bnc#466279 bnc#681639).
- commit 72e779f
* Fri May  6 2011 jeffm@suse.com
- Disabled patches.drivers/libata-unlock-hpa-by-default; It may have
  been obsoleted by upstream commit d8d9129e.
- commit 1a21ab3
* Fri May  6 2011 jeffm@suse.com
- sysctl: Increase IPC defaults (bnc#146656)
  - Delete patches.suse/shmall-bigger.
- commit a70e34f
* Fri May  6 2011 jeffm@suse.com
- sysctl/i386/desktop, sysctl/x86_64/desktop: Add vm.dirty_ratio = 20
  for desktop flavors (bnc#552883)
  - Delete patches.suse/mm-tune-dirty-limits.patch.
- commit dbe73e2
* Fri May  6 2011 jeffm@suse.com
- sysctl/defaults: Added kernel.hung_task_timeout=0
  - Delete patches.suse/hung_task_timeout-configurable-default.
- commit 78f9eed
* Fri May  6 2011 mmarek@suse.cz
- rpm/kernel-{binary,source}.spec.in: Install per-kernel /boot/sysctl-*
  files (patch from Jeff Mahoney).
- commit 473f2d1
* Thu May  5 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 97ce5d8
* Thu May  5 2011 jeffm@suse.com
- Updated to 2.6.39-rc6.
  - 2 patches eliminated.
- commit 2643e59
* Tue May  3 2011 tonyj@suse.de
- Delete patches.fixes/oprofile_bios_ctr.patch.
- Delete patches.suse/kdump-dump_after_notifier.patch.
- commit 012455a
* Mon May  2 2011 gregkh@suse.de
- Update config files to handle .5 changes
- commit 0274ea5
* Mon May  2 2011 gregkh@suse.de
- Linux 2.6.38.5.
- Delete
  patches.fixes/flexcop-fix-registering-braindead-stupid-names.
- commit d41164a
* Fri Apr 29 2011 jeffm@suse.com
- rpm/compute-PATCHVERSION.sh: Replace ^+++ with ^\+\+\+ as an
    awk regex. It's technically invalid.
- commit 52dd0f0
* Fri Apr 29 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
- commit c602ee1
* Fri Apr 29 2011 sjayaraman@suse.de
- Delete patches.suse/sched-revert-latency-defaults.
- commit 90be226
* Fri Apr 29 2011 tiwai@suse.de
- Delete patches.arch/ppc-ipic-suspend-without-83xx-fix.
- Delete patches.arch/x86-hpet-pre-read.
- commit 3489146
* Fri Apr 29 2011 gregkh@suse.de
- Delete patches.suse/linux-2.6.29-dont-wait-for-mouse.patch.
- Delete patches.suse/linux-2.6.29-even-faster-kms.patch.
- Delete
  patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch.
- Delete patches.suse/linux-2.6.29-kms-after-sata.patch.
- Delete patches.suse/linux-2.6.29-touchkit.patch.
- commit c13427d
* Fri Apr 29 2011 jbenc@suse.cz
- Delete patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch.
- commit df46fe0
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.xen/xen3-x86-mcp51-no-dac.
  Also remove the series.conf entires for the x86-mcp-no-dac patches.
- commit 574577b
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.arch/x86-mcp51-no-dac.  (This is a blacklist entry that
  has been rejected by the mainline, the problem reporter is gone and
  it's next to impossible to verify it now.)
- commit 195b113
* Thu Apr 28 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
- commit a2662ae
* Thu Apr 28 2011 jslaby@suse.cz
- Delete patches.suse/wireless-no-aes-select.
  Optimized x86 AES implementations select CRYPTO_AES themselves. So we
  don't need the patch anymore -- AES is selected always.
- commit 88f80fa
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch.
- commit 9917206
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch.
- commit 08374b3
* Thu Apr 28 2011 jeffm@suse.com
- Delete patches.suse/audit-export-logging.patch.
- commit de054eb
* Thu Apr 28 2011 jbeulich@novell.com
- Update i386 Xen config files.
- commit 7b776ee
* Thu Apr 28 2011 jack@suse.cz
- Fix checking of login id (bnc#626119).
- commit 0fd91a9
* Thu Apr 28 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc5.
- Delete patches.xen/xen3-seccomp-disable-tsc-option.
- Delete patches.xen/xen3-x86-mark_rodata_rw.patch.
- commit 81fdf67
* Thu Apr 28 2011 mfasheh@suse.com
- btrfs: return EXDEV when linking from different subvolumes
  (bnc#679545).
- commit f9ddc29
* Wed Apr 27 2011 jeffm@suse.com
- Delete
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch.
- commit 399a100
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/x86_agpgart-g33-stoeln-fix-2.patch.
- commit e5c964a
* Wed Apr 27 2011 jeffm@suse.com
- Merged patches.fixes/fix-nf_conntrack_slp into patches.suse/netfilter-ip_conntrack_slp.patch.
- commit 213a0d5
* Wed Apr 27 2011 jeffm@suse.com
- Removed Swap-over-NFS patches.
- commit e061d16
* Wed Apr 27 2011 jeffm@suse.com
- Unified novfs patches into patches.suse/novfs-client-module.
- commit 3f8a199
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/reiserfs-remove-2-tb-file-size-limit.
- commit 2d63b14
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/mm-increase-dirty-limits.patch: Replaced by patches.suse/mm-tune-dirty-limits.patch
- commit 4f8033f
* Wed Apr 27 2011 jeffm@suse.com
- series.conf: Removed commented out patches for cpuidle. The patches themselves are long gone.
- commit 93ce9f3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/acpi-export-hotplug_execute: ACPI_DOCK is now a boolean.
- commit f178332
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch.
- commit 5a2eae2
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-don-t-preempt-until-the-system-is-up.
- Delete
  patches.suse/acpi-generic-initramfs-table-override-support.
- Delete patches.suse/add-initramfs-file_read_write.
- Delete
  patches.suse/init-move-populate_rootfs-back-to-start_kernel.
- commit d4910b3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/nfs-acl-caching.diff.
- Delete patches.suse/nfsacl-client-cache-CHECK.diff.
- commit e1a5c5c
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/osync-error. It was unused and the issue it fixed in
  kernels prior to 2.6.32 doesn't exist anymore.
- commit 52cc654
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/s390-System.map.diff: Proper fix in binutils has
  long since been upstream.
- commit 2847a36
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/x86-mark_rodata_rw.patch: Removed as promised.
- commit f196f98
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/ia64-page-migration.
- Delete patches.arch/ia64-page-migration.fix.
- Delete patches.arch/mm-avoid-bad-page-on-lru.
- commit e469a91
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default: Update patch-mainline.
- commit 4bcc987
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/seccomp-disable-tsc-option: Unused in all configs.
- commit 0833556
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/unmap_vmas-lat: No bug report or signed-off-by.
  - Delete patches.arch/s390-add-FREE_PTE_NR.
- commit 2a392c2
* Wed Apr 27 2011 jeffm@suse.com
- Updated Patch-mainline for  patches.fixes/ia64-sparse-fixes.diff.
- commit d79b32f
* Wed Apr 27 2011 jeffm@suse.com
- Update to 2.6.39-rc5.
  - Eliminated 2 patches.
- commit 5288a05
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/export-release_open_intent.
- Delete patches.suse/export-security_inode_permission.
- commit 5cd669f
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.trace/utrace-core.
- commit a9639aa
* Tue Apr 26 2011 jslaby@suse.cz
- NET: cdc-phonet, fix stop-queue handling (bnc#689583).
- commit 7b4abdd
* Tue Apr 26 2011 jkosina@suse.cz
- HID: add noget quirk barcode scanners from Symbol Technologies
  (bnc#689290).
- commit dcae8fa
* Fri Apr 22 2011 jslaby@suse.cz
- XEN: add fixup_4gb_segment ENDPROC.
- Refresh patches.xen/xen3-patch-2.6.19.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.33.
- Refresh patches.xen/xen3-patch-2.6.37.
  Now, with binutils 2.21.0 we see build errors like:
  arch/x86/kernel/entry_32-xen.S: Assembler messages:
  arch/x86/kernel/entry_32-xen.S:1734: Error: .size expression for spurious_interrupt_bug does not evaluate to a constant
  BS doesn't complain about this yet, only abuild.
- commit b5e9a32
* Fri Apr 22 2011 jslaby@suse.cz
- Update to 2.6.38.4:
  - obsoletes:
  - patches.arch/i386-unwind-annotations.
  - patches.drivers/alsa-hda-0018-Fix-pin-config-of-Gigabyte-mobo.
  - patches.fixes/cdc-phonet-handle-empty-phonet-header.patch.
  - patches.fixes/media-video-sn9c102-world-wirtable-sysfs-files.
  - patches.fixes/ubifs-restrict-world-writable-debugfs-files.
  - patches.rpmify/ia64-mca-fix-cast-from-integer-to-pointer-warning.
  - patches.rpmify/tioca-fix-assignment-from-incompatible-pointer-warnings.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.27.
- Update config files.
- commit 4632d1a
* Fri Apr 22 2011 jeffm@suse.com
- Delete patches.suse/nameif-track-rename.patch: The same info is made available via udev.
- commit e74929e
* Tue Apr 19 2011 jack@suse.cz
- Revert changes to sparc configs to not make life harder for Jan Engelhardt
  maintaining sparc architecture.
- commit cdac873
* Tue Apr 19 2011 jack@suse.cz
- config.conf: Remove sparc as it is maintained separately by Jan Engelhardt
- commit 91307e3
* Tue Apr 19 2011 jack@suse.cz
- Update vanilla config files.
- commit 5e3c232
* Tue Apr 19 2011 jack@suse.cz
- ext4: fix ext4_da_block_invalidatepages() to handle page range
  properly (bnc#679898).
- commit 616d360
* Tue Apr 19 2011 jack@suse.cz
- ext4: mark multi-page IO complete on mapping failure
  (bnc#679898).
- commit c04b19f
* Tue Apr 19 2011 jeffm@suse.com
- Updated to 2.6.39-rc4.
  - Eliminated 1 patch.
- commit 3f654c8
* Tue Apr 19 2011 jeffm@suse.com
- libata: DVR-216D can't do SETXFER DVD-RW DVR-216D (bnc#679143).
- commit b09d00e
* Mon Apr 18 2011 eich@suse.de
- Combined and consolidated bootsplash patch (bnc#669777,
  bnc#570082, bnc#595657, bnc#594209, bnc#544645).
  - Delete patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch.
  - Delete patches.suse/bootsplash.
  - Delete patches.suse/bootsplash-console-fix.
  - Delete patches.suse/bootsplash-keep-multiple-data.
  - Delete patches.suse/bootsplash-scaler.
  - Reformatted code, fixed some minor bugs that became obvious.
  - Fixed race that led to null pointer dereference in splash_read_proc():
    bnc#669777.
- commit 95844c5
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Add a boot param to keep flushing TLBs (bnc#675161).
- commit 02c0d8a
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Make lapic_timer_reliable_states a boot param
  (bnc#675161).
- commit 85b156b
* Sat Apr 16 2011 jack@suse.cz
- Disable ext2, use ext4 instead as a driver
- Update config files.
- commit 2601b15
* Fri Apr 15 2011 jeffm@suse.com
- Enabled CONFIG_GIGASET_CAPI (bnc#686008).
  - This results in automatically disabling CONFIG_GIGASET_I4L.
- commit 697e68b
* Fri Apr 15 2011 jack@suse.cz
- novfs: Set the sticky bit for the novfs mountpoint (bnc#686412).
- commit 860f111
* Fri Apr 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add.
- commit 728e154
* Fri Apr 15 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc3 and c/s 1079.
- blktap2: replace hard-coded limit of tap devices with
  configurable one.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit d3bfd6c
* Fri Apr 15 2011 bphilips@suse.de
- bonding: Incorrect TX queue offset (bnc#687116, CVE-2011-1581).
- commit 6d208f9
* Thu Apr 14 2011 gregkh@suse.de
- Linux 2.6.38.3.
  - lots of security updates and bugfixes
  - obsoletes:
  patches.drivers/alsa-hda-0017-Fix-SPDIF-out-regression-on-ALC889.
  patches.drivers/sound-oss-opl3-validate-voice-and-channel-indexes.
  patches.drivers/sound-oss-remove-offset-from-load_patch-callbacks.
  patches.fixes/drivers-leds-leds-lp5521-c-world-writable-sysfs-engine-files.
  patches.fixes/drivers-leds-leds-lp5523-c-world-writable-engine-sysfs-files.
  patches.fixes/drivers-misc-ep93xx_pwm-c-world-writable-sysfs-files.
  patches.fixes/drivers-rtc-rtc-ds1511-c-world-writable-sysfs-nvram-file.
  patches.fixes/irda-validate-peer-name-and-attribute-lengths.
  patches.fixes/mfd-ab3100-world-writable-debugfs-_priv-files.
  patches.fixes/mfd-ab3500-world-writable-debugfs-register-files.
  patches.fixes/mfd-ab8500-world-writable-debugfs-register-files.
  patches.fixes/prevent-rt_sigqueueinfo-from-spoofing-fix.patch.
  patches.fixes/scsi-scsi_transport_iscsi-make-priv_sess-file-writeable-only-by-root.
  patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch.
- commit a6acdda
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
- commit cc60bed
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
- commit 385b393
* Thu Apr 14 2011 jeffm@suse.com
- scsi: aic94xx: world-writable sysfs update_bios file.
- drivers/leds/leds-lp5523.c: world-writable engine* sysfs files
  (bnc#673934).
- drivers/leds/leds-lp5521.c: world-writable sysfs engine* files
  (bnc#673934).
- mfd: ab8500: world-writable debugfs register-* files
  (bnc#673934).
- scsi_transport_iscsi: make priv_sess file writeable only by root
  (bnc#673934).
- mfd: ab3500: world-writable debugfs register-* files
  (bnc#673934).
- drivers/misc/ep93xx_pwm.c: world-writable sysfs files
  (bnc#673934).
- mfd: ab3100: world-writable debugfs *_priv files (bnc#673934).
- UBIFS: restrict world-writable debugfs files (bnc#673934).
- scsi: aic94xx: world-writable sysfs update_bios file.
- drivers/rtc/rtc-ds1511.c: world-writable sysfs nvram file
  (bnc#673934).
- video: sn9c102: world-wirtable sysfs files (bnc#673934).
- commit 7f827e6
* Wed Apr 13 2011 jeffm@suse.com
- irda: validate peer name and attribute lengths (bnc#681497
  CVE-2011-1180).
- commit 1d6013e
* Wed Apr 13 2011 jeffm@suse.com
- mpc5xxx_can: Fix typo causing build failure (of_dev -> ofdev).
- ft1000: Remove unnecessary EXPORT_SYMBOLs.
- commit 62653bb
* Wed Apr 13 2011 jeffm@suse.de
- fhandle: Add <linux/personality.h> for ia64.
- commit 83cec5a
* Wed Apr 13 2011 jeffm@suse.com
- kvm: Fix off by one in kvm_for_each_vcpu iteration.
- commit 4e5c2b7
* Wed Apr 13 2011 jeffm@suse.com
- rts_pstor: Add <linux/vmalloc.h>.
- rts_pstor: use #ifdef instead of #if.
- commit caa5347
* Tue Apr 12 2011 jeffm@suse.com
- gma500: Depend on X86.
- commit 3aa298c
* Tue Apr 12 2011 jeffm@suse.com
- Updated to 2.6.39-rc3.
  - Eliminated 2 patches.
- commit 200c913
* Tue Apr 12 2011 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: remove <linux/smp_lock.h>
- commit d7c79f2
* Tue Apr 12 2011 jeffm@suse.com
- olpc: Add <linux/delay.h>.
- commit 58ce0db
* Tue Apr 12 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 52fe306
* Tue Apr 12 2011 jeffm@suse.com
- Update to 2.6.39-rc2.
  - Eliminated 18 patches.
  - Added 3 patches.
  - hv_mouse: needs <linux/delay.h>.
  - dm-raid45: Remove blk_unplug calls.
  - novfs: 2.6.39 API update.
  - Xen, Swap-over-NFS, and certain SCSI multipath features are disabled.
  - patches.kernel.org is no longer used to contain upstream patches
    for -rc releases. Users planning on building their own kernel should
    have a copy of the tarball corresponding to the -rc releases.
- commit adf9d16
* Mon Apr 11 2011 neilb@suse.de
- Make selection of 'readdir-plus' adapt to usage patterns
  (bnc#678123).
- commit 78e8a63
* Wed Apr  6 2011 jslaby@suse.cz
- Revert "x86: Cleanup highmap after brk is concluded"
  (bnc#684248).
- Delete
  patches.arch/x86-save-cr4-to-mmu_cr4_features-at-boot.patch.
- commit 2d275f3
* Wed Apr  6 2011 jeffm@suse.de
- reiserfs: Force inode evictions before umount to avoid crash
  (bnc#610598 bnc#680073 bnc#684112).
- Delete patches.fixes/reiserfs-xattr-crash-fix.
- commit bf57d20
* Tue Apr  5 2011 jslaby@suse.cz
- remove obsolete comment from series.conf
- commit 4bad172
* Thu Mar 31 2011 jslaby@suse.cz
- x86: Save cr4 to mmu_cr4_features at boot time (bnc#684248).
- commit 98ac070
* Wed Mar 30 2011 jeffm@suse.com
- Delete patches.suse/twofish-2.6.
  - This was for 2.4 compatibility and has been moved to KMP purgatory.
- commit dcca506
* Wed Mar 30 2011 jslaby@suse.cz
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
  (bnc#681826).
- commit 2e71042
* Mon Mar 28 2011 trenn@suse.de
- Update config files, remove CONFIG_X86_MCE_XEON75XX=m
  - >driver got reverted with previous commit
- Refresh patches.xen/xen3-auto-arch-x86.diff.
- commit b367e7b
* Mon Mar 28 2011 trenn@suse.de
- Remove xeon75xx driver, was intended as a SLE11 SP1 workaround
  to decode physical memory address on Boxboro-EX for MCEs.
  APEI implementation should take care of that in recent kernels.
- Delete patches.arch/x86_mce_intel_decode_physical_address.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch.
- commit 1fe7a22
* Mon Mar 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not install unneeded packages in the
  build chroot.
- commit 7f4c49d
* Mon Mar 28 2011 tiwai@suse.de
- ALSA: hda - Increase the default buffer size (682725).
- ALSA: hda - Fix pin-config of Gigabyte mobo (bnc#677256).
- commit 8088cec
* Mon Mar 28 2011 jslaby@suse.cz
- Update to 2.6.38.2:
  - obsoletes:
  - patches.fixes/prevent-rt_sigqueueinfo-from-spoofing.patch.
- Refresh patches.xen/tmem.
- Refresh patches.xen/xen-dcdbas.
- commit 5b9dd3d
* Fri Mar 25 2011 mhocko@suse.cz
- page_cgroup: reduce allocation overhead for page_cgroup array
  for CONFIG_SPARSEMEM (bnc#669889).
- commit 6a934f2
* Fri Mar 25 2011 jslaby@suse.cz
- Update patches.kernel.org/patch-2.6.38.1 (bnc#558740).
  (Add a bug reference)
- commit 3285b9b
* Thu Mar 24 2011 tiwai@suse.de
- ALSA: hda - Fix SPDIF out regression on ALC889 (bnc#679588).
- commit f9b1d82
* Thu Mar 24 2011 jslaby@suse.cz
- Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing
  the signal code (bnc#681826 CVE-2011-1020).
- commit 2e42fd4
* Thu Mar 24 2011 tiwai@suse.de
- sound/oss/opl3: validate voice and channel indexes (bnc#681999).
- sound/oss: remove offset from load_patch callbacks (bnc#681999).
- ALSA: sound/pci/asihpi: check adapter index in hpi_ioctl
  (bnc#680816).
- commit 09ff6e9
* Thu Mar 24 2011 jslaby@suse.cz
- Update to 2.6.38.1:
  - obsoletes:
  - patches.rpmify/winbond-needs-msleep.
- Refresh
  patches.fixes/hid-add-support-for-Skycable-0x3f07-wireless-present.patch.
- Update config files.
- commit 4836c9f
* Mon Mar 21 2011 jack@suse.cz
- Fix almost-infinite slab cache growing (bnc#554081).
- commit 44e668f
* Mon Mar 21 2011 jkosina@suse.cz
- HID: add support for Skycable 0x3f07 wireless presenter
  (bnc#681297).
- commit c88c4a7
* Mon Mar 21 2011 mmarek@suse.cz
- Delete config/i386/vmi, it was an artifact from SLE11-SP1 development.
- commit 9877488
* Fri Mar 18 2011 jslaby@suse.cz
- NET: cdc-phonet, handle empty phonet header (bnc#673992).
- commit da6e6d1
* Fri Mar 18 2011 jslaby@suse.cz
- SPI: dw_spi, fix PPC build.
- commit 80ca063
* Fri Mar 18 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38 and c/s 1073.
- commit 89cb2b4
* Thu Mar 17 2011 sjayaraman@suse.de
- netvm: Do not mark requests for swapfile writes as dirty or
  kswapd fails to free the page (bnc#678472).
- nfs: Use page_file_offset during page writeback (bnc#677738).
- nfs: Convert nfs_mark_request_dirty() to use page_file_mapping()
  (bnc#677738).
- netvm: Remove duplicated initialization in net/ipv4/route.c
  (bnc#678970).
- collapse: mm: Report the low watermark correctly (bnc#678497).
- commit a798dd1
* Tue Mar 15 2011 jeffm@suse.com
- Update to 2.6.38.
- commit f2ec6ad
* Tue Mar 15 2011 jslaby@suse.cz
- Update to 2.6.37.4:
  - obsoletes:
  - patches.fixes/ath9k-Fix-ath9k-prevents-CPU-to-enter-C3-states.patch.
  - patches.fixes/media-DiB7000M-add-pid-filtering.patch.
- commit b3091d2
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: HDA: Realtek ALC88x: Do not over-initialize speakers
  and hp that are primary outputs (bnc#679016).
- ALSA: HDA: Fixup unnecessary volume control index on Realtek
  ALC88x (bnc#679016).
- ALSA: HDA: Fix volume control naming for surround speakers on
  Realtek auto-parser (bnc#679016).
- ALSA: HDA: Enable surround and subwoofer on Lenovo Ideapad Y530
  (bnc#679016).
- ALSA: hda - Add support for multiple headphone/speaker controls
  for Realtek (bnc#679016).
- ALSA: hda - 4930g add internal lfe slider (bnc#679016).
- ALSA: hda - Fix unable to record issue on ASUS N82JV
  (bnc#679016).
- ALSA: hda - switch lfe with side in mixer for 4930g
  (bnc#679016).
- ALSA: HDA: Fix automute on Thinkpad L412/L512 (bnc#679016).
- ALSA: HDA: Add SKU ignore for another Thinkpad Edge 14
  (bnc#679016).
- ALSA: hda - Apply Sony VAIO hweq fixup only once (bnc#679016).
- ALSA: hda - Fix ALC275 enable hardware EQ for SONY VAIO
  (bnc#679016).
- ALSA: hda - Fix EAPD on Lenovo NB ALC269 to low (bnc#679016).
- commit b5b352b
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: hda - Add a generic fixup callback for Realtek codecs
  (bnc#679016).
- ALSA: hda - Fix missing EAPD for Acer 4930G (bnc#679016).
- commit 35da099
* Mon Mar 14 2011 jeffm@suse.com
- Linux: 2.6.38-rc8.
  - Eliminated 1 patch.
- commit 7da557d
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc7 and c/s 1072
- pv-ops blktap2.
- adjust xen build after addition of pv-ops' blktap2.
- blktap: Fix reference to freed struct request.
- cleanup to blkback and blktap.
- apply xen specific patch to the Chelsio ethernet drivers.
- Update Xen config files.
- commit 289ecca
* Fri Mar 11 2011 jbeulich@novell.com
- fix i386 unwind annotations.
- commit 02bd501
* Fri Mar 11 2011 jslaby@suse.cz
- DiB7000M: add pid filtering (bnc#644807).
- commit ab6796e
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37.3 and c/s 1072.
- apply xen specific patch to the Chelsio ethernet drivers.
- commit 7db4348
* Thu Mar 10 2011 jslaby@suse.cz
- Mantis, hopper: use MODULE_DEVICE_TABLE (bnc#607239).
- commit 33a71b9
* Tue Mar  8 2011 jslaby@suse.cz
- Update to 2.6.37.3:
  - obsoletes:
  - patches.drivers/alsa-usb-audio-fix-oops-due-to-cleanup-race-when-disconnect.
  - patches.drivers/e1000e-82579-PHY-incorrectly-identified-during-init.patch.
  - patches.arch/acpi-debugfs-fix-buffer-overflows-double-free.patch.
  - patches.fixes/loop-over-loop-hang-fix.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-patch-2.6.19.
- commit dca38e6
* Tue Mar  8 2011 jeffm@suse.de
- Update to 2.6.38-rc7.
  - Refresh patches.xen/xen-x86-no-lapic.
  - Refresh patches.xen/xen3-patch-2.6.19.
- commit 7eb9d30
* Mon Mar  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not abort build because of
  supported.conf inconsistency if %%supported_modules_check == 0.
- commit 88d5daa
* Fri Mar  4 2011 jack@suse.cz
- debugfs: Fix filesystem reference counting on debugfs_remove()
  failure (bnc#668101).
- commit 9166129
* Wed Mar  2 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix a fatal oversight in
  yesterday's change.
- commit 098768b
* Wed Mar  2 2011 bphilips@suse.de
- e1000e: 82579 PHY incorrectly identified during init
  (bnc#668437).
- commit 8e49073
* Tue Mar  1 2011 knikanth@suse.de
- block: kill loop_mutex (bnc#669394).
- commit e8a3617
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
- commit a1349cb
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
- commit 87944ac
* Sun Feb 27 2011 jslaby@suse.cz
- iwlwifi: fix ack health for WiFi/BT combo devices (bnc#662733).
- iwlwifi: cleanup iwl_good_ack_health (bnc#662733).
- iwlwifi: fix ack health for WiFi/BT combo devices (bnc#662733).
- iwlwifi: cleanup iwl_good_ack_health (bnc#662733).
- commit 261a9d2
* Fri Feb 25 2011 jslaby@suse.cz
- Update to 2.6.37.2 (bnc#674245):
  - obsoletes:
  - patches.arch/perf_adjust_timechart_to_new_cpuidle_events.patch.
  - patches.drivers/alsa-01-caiaq-Fix-possible-string-buffer-overflow.
  - patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- commit d1287f4
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
- commit 74b3781
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
- commit ed81f8c
* Thu Feb 24 2011 jslaby@suse.cz
- ath9k: Fix ath9k prevents CPU to enter C3 states (bnc#667793).
- Refresh
  patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- Delete
  patches.fixes/0001-Revert-ath9k-use-per-device-struct-for-pm_qos_-opera.patch.
- Delete
  patches.fixes/0002-Revert-ath9k-Remove-pm_qos-request-after-hw-unregist.patch.
- Delete
  patches.fixes/0003-Revert-ath9k-Fix-a-DMA-latency-issue-for-Intel-Pinet.patch.
  These patches went upstream, update.
- commit be3e181
* Thu Feb 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unused code.
- commit dacbc44
* Tue Feb 22 2011 jeffm@suse.com
- Update to 2.6.38-rc6.
  - Eliminated 1 patch.
- commit 6cce7bb
* Tue Feb 22 2011 mszeredi@suse.cz
- xfs: prevent leaking uninitialized stack memory in FSGEOMETRY_V1
  (CVE-2011-0711 bnc#672524).
- commit 547a9f9
* Tue Feb 22 2011 mmarek@suse.cz
- rpm/mkspec: Do not create kernel-syms.spec on vanilla-only branches
- commit eb17bba
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
- commit f6a72cc
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
- commit 5ef002b
* Sun Feb 20 2011 jslaby@suse.cz
- Revert "tpm_tis: Use timeouts returned from TPM" (bnc#673619).
- commit d991856
* Sat Feb 19 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit 41c6654
* Fri Feb 18 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit da9d3a8
* Fri Feb 18 2011 jslaby@suse.cz
- Update to 2.6.37.1:
  - obsoletes:
  - patches.arch/x86-mtrr-avoid-MTRR-reprogramming-on-BP-during-boot-on.patch
  - patches.drivers/alsa-hda-0001-Fix-memory-leaks-in-conexant-jack-arrays
  - patches.drivers/alsa-hda-0002-Fix-missing-CA-initialization-for-HDMI-DP
  - patches.fixes/calibrate-jiffy-overflow
  - patches.fixes/fix-ata-panic-with-ata_id
  - patches.fixes/fix-prlimit64-for-suid-sgid-processes.patch
  - patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch
  - patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash
  - patches.fixes/staging-rt2860-Fix-incorrect-netif_stop_queue-usage.patch
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/SoN-16-netvm-reserve-inet.patch.
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-fixup-common.
- Refresh patches.xen/xen3-patch-2.6.37.
- commit a638bb4
* Fri Feb 18 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate
  an upstream change.
- commit a4e281e
* Thu Feb 17 2011 rjw@suse.de
- PNP / ACPI: Use DEVICE_ACPI_HANDLE() for device ACPI handle access (bnc#434742).
- commit a73834f
* Thu Feb 17 2011 jeffm@suse.de
- Update to 2.6.38-rc5.
- commit 8344657
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  - disable CONFIG_DRM_VMWGFX (bnc#606458)
  - update sparc configs to at least be able to run "make oldconfig"
- commit da75bd9
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_VMWGFX. (bnc#606458)
- commit 409d54e
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
  initial 2.6.37 merge.
- commit 7a5313d
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
  initial 2.6.37 merge.
- commit e493205
* Wed Feb 16 2011 tiwai@suse.de
- ALSA: HDA: Add Lenovo vendor quirk for Conexant 205xx
  (bnc#670946).
- commit b3bc287
* Tue Feb 15 2011 jeffm@suse.com
- tty: add 'active' sysfs attribute to tty0 and console device.
- commit 7ae6e9a
* Tue Feb 15 2011 jslaby@suse.cz
- Revert "ath9k: Fix a DMA latency issue for Intel Pinetrail
  platforms." (bnc#667793).
- Revert "ath9k: Remove pm_qos request after hw
  unregister." (bnc#667793).
- Revert "ath9k: use per-device struct for pm_qos_* operations"
  (bnc#667793).
- commit b2849f6
* Tue Feb 15 2011 jack@suse.cz
- bridge: Replace mp->mglist hlist with a bool (bnc#653547).
- bridge: Fix timer typo that may render snooping less effective
  (bnc#653547).
- bridge: Fix mglist corruption that leads to memory corruption
  (bnc#653547).
- commit a70e5ca
* Mon Feb 14 2011 mmarek@suse.cz
- Move spec file templates and helper scripts to a separate branch, to
  ease synchronizing these files among master, vanilla and linux-next.
- commit 411abb8
* Mon Feb 14 2011 mmarek@suse.cz
- Delete a couple of obsolete kabi and other scripts from misc/:
- Delete misc/checkmod.
- Delete misc/collect_ksyms.
- Delete misc/diff-the-xfs-cvs.
- Delete misc/ksyms.py.
- Delete misc/mangle-ifdef.py.
- Delete misc/obsolete-module-aliases.
- Delete misc/testmodule.
- commit 3dd255b
* Mon Feb 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Delete misc/extract-modaliases, the code
  was merged into rpm's find-supplements script.
- Delete rpm/check-build.sh, not needed anymore.
- commit bd6fa48
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
  bnc#661429).
- commit 72bd3d0
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
  bnc#661429).
- commit 2e98bfc
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
  (bnc#661682).
- commit 1eb5eaa
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
  (bnc#661682).
- commit c6d0dc9
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Set timestamp of sources to the commit
  timestamp, so that they are always older than generated files in
  /usr/src/linux-obj (bnc#669669).
- commit 31e675a
* Wed Feb  9 2011 tiwai@suse.de
- ALSA: hda - Fix missing CA initialization for HDMI/DP
  (bnc#670577).
- commit 474305e
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not run fdupes in /usr/src/linux-obj, to
  keep timestamps intact.
- commit e211a69
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove .gitignore files after applying patches
  (fix last change).
- commit d6a7494
* Tue Feb  8 2011 jeffm@suse.com
- Updated to 2.6.38-rc4.
  - Eliminated 1 patch.
- commit c327e0a
* Tue Feb  8 2011 jslaby@suse.cz
- orinoco: allow IW_AUTH_MFP to pass through (bnc#661624).
- commit 442a3d7
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit f82619b
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit 027481c
* Tue Feb  8 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc4 and c/s 1066.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 72cea6e
* Tue Feb  8 2011 jbeulich@novell.com
- Update config files.
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- Refresh and re-enable patches.suse/stack-unwind.
- commit 1fabeda
* Tue Feb  8 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate an
  upstream change.
- commit ae5bb3f
* Mon Feb  7 2011 jslaby@suse.cz
- staging: rt2860: Fix incorrect netif_stop_queue usage warning
  (bnc#661657).
- commit 39b4c1e
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/{kernel-source.spec.in,mkspec}: Sync with vanilla and linux-next
- commit fecf998
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove dead code.
- commit b97b6f2
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-spec-macros: Fix the definition
  of %%release_major and rename it to %%release_num to better describe
  what it does. Add some comments to explain how the versioning works.
- commit 3de2a1a
* Fri Feb  4 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix sed regexp
- commit d889fe7
* Fri Feb  4 2011 jeffm@suse.com
- hfs: avoid crash in hfs_bnode_create (bnc#552250).
- commit d84296a
* Fri Feb  4 2011 jeffm@suse.com
- Updated to 2.6.38-rc3.
  - Eliminated 2 patches.
- commit b6b51ca
* Thu Feb  3 2011 rjw@suse.de
- x86, mtrr: avoid MTRR reprogramming on BP during boot on (bnc#623393).
- commit 0664ad4
* Thu Feb  3 2011 jbeulich@novell.com
- Update Xen patches to c/s 1066.
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- commit e88242f
* Thu Feb  3 2011 jbeulich@novell.com
- Fix jiffy calculations in calibrate_delay_direct to handle
  overflow.
- commit 4a69163
* Wed Feb  2 2011 jeffm@suse.com
- patches.fixes/reiserfs-xattr-crash-fix: fix crash
  during failed mount (bnc#668878)
- commit de24d15
* Wed Feb  2 2011 tiwai@suse.de
- ALSA: hda - Fix memory leaks in conexant jack arrays
  (bnc#668929).
- commit 7dbcb59
* Tue Feb  1 2011 jslaby@suse.cz
- Refresh patches.rpmify/cloneconfig.diff.
  scripts/kconfig/conf accepts long parameters only for some time already
- commit 939410c
* Mon Jan 31 2011 jslaby@suse.cz
- block: loop queue_lock null pointer derefence in blk_throtl_exit
  v3 (bnc#666598).
- commit cd38efd
* Mon Jan 31 2011 jslaby@suse.cz
- Fix prlimit64 for suid/sgid processes (bnc#668262).
- commit dae8217
* Mon Jan 24 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 3e2a2b2
* Mon Jan 24 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 4bf0e68
* Sun Jan 23 2011 jeffm@suse.de
- winbond: needs <linux/delay.h> for msleep and friends.
- commit e394a2e
* Sun Jan 23 2011 jeffm@suse.de
- Refresh patches.arch/ia64-page-migration: Update for migrate_pages() API change.
- commit 40d2921
* Sun Jan 23 2011 jeffm@suse.de
- supported.conf: Added rc_core as a dependency.
- commit 8b2c1b9
* Sun Jan 23 2011 jeffm@suse.com
- Update config files.
  - CONFIG_EXPERT=n on all but ps3
  - Vanilla configs updated.
- commit b25e639
* Sun Jan 23 2011 jeffm@suse.com
- Revert "- Update config files: CONFIG_EXPERT=n except ps3"
  This reverts commit 3f2c93d6a0593b2cc0c40f5ffee426eef27cc400.
  This was a bad commit. I have no idea where all the changes came from.
- commit 459f3f1
* Sun Jan 23 2011 jeffm@suse.com
- Update config files: CONFIG_EXPERT=n except ps3
- commit 3f2c93d
* Sun Jan 23 2011 jeffm@suse.com
- Updated to 2.6.38-rc2.
  - Eliminated 1 patch.
- commit 90baa82
* Sat Jan 22 2011 jeffm@suse.com
- ata: Fix panics with ata_id (bnc#660464).
- commit fa7af15
* Sat Jan 22 2011 jeffm@suse.de
- Updated some Patch-mainline headers.
- commit 9122bf0
* Sat Jan 22 2011 jeffm@suse.de
- Update to 2.6.38-rc1.
  - Removed 12 patches.
  - Xen is disabled.
  - Quite a few patches need updating.
- commit 9163bb7
* Fri Jan 21 2011 trenn@suse.de
- perf: Do not export power_frequency, but power_start event
  (bnc#665153).
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- cpuidle: Rename X86 specific idle poll state from C0 to POLL
  (bnc#665153).
- perf timechart: Adjust perf timechart to the new power events
  (bnc#665153).
- Fix display of idle boxes (none).
- Fix huge and wronge C-state drawings due to uninitialized
  start/end timestamps (none).
- Update config files.
- doc/config-options.changes:
  CONFIG_EVENT_POWER_TRACING_DEPRECATED=y
- commit b308eff
* Wed Jan 19 2011 jbohac@suse.cz
-    revert: ipv6: don't flush routes when setting loopback down.
- commit de347ac
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Initialize the global lock spinlock as
  appropriate (bnc#637377).
- commit c4b8238
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Fix global lock acquisition (bnc#637377).
- commit 15cd726
* Mon Jan 17 2011 jeffm@suse.com
- mISDN: Add support for group membership check (bnc#564423).
- commit 3f46938
* Fri Jan 14 2011 mmarek@suse.cz
- Revert %%kernelrelease changes originally made on the vanilla branch,
  they break on master and must be done differently.
- commit b610327
* Thu Jan 13 2011 jkosina@suse.cz
- Input: introduce 'notimeout' blacklist for Dell Vostro V13
  (bnc#641105).
- commit cb76856
* Wed Jan 12 2011 jeffm@suse.com
- In-kernel dependencies for reiser4
  - Delete patches.suse/reiser4-exports.
  - Delete patches.suse/reiser4-set_page_dirty_notag.
- commit 1b97130
* Tue Jan 11 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29: Fix a regression.
- commit 6acb967
* Mon Jan 10 2011 jack@suse.cz
- novfs: NCP Fragments can be upto 64k in size (bnc#625965).
- commit afd7489
* Mon Jan 10 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37-final and c/s 1062.
- commit ef70146
* Mon Jan 10 2011 jeffm@suse.com
- Enabled AGP modules as parts of the static kernel on i386 (bnc#609607)
- commit 9446eb0
* Sat Jan  8 2011 jengelh@medozas.de
- config: run oldconfig on sparc64/default
- commit aa3e940
* Sat Jan  8 2011 jengelh@medozas.de
- config: update sparc64/net and throw out unworthy options
- commit 1aca53d
* Sat Jan  8 2011 gregkh@suse.de
- Comment out broken rt2x00 driver patch, don't know how to fix it right
  now.
- commit 70ec9f3
* Sat Jan  8 2011 gregkh@suse.de
- updated to Linux 2.6.36.3.
  - security fixes
  - bug fixes
  - obsoleted:
  - patches.fixes/rt2x00-Fix-max-TX-power-settings.patch.
  - patches.fixes/tehuti-firmware-name.
- commit d4997c9
* Fri Jan  7 2011 mmarek@suse.cz
- Delete patches.suse/gfs2-ro-mounts-only.patch (obsolete and unused)
- commit 38ff246
* Fri Jan  7 2011 trenn@suse.de
- Some are mainline, some are/will be implemented differently:
- Delete patches.drivers/dynamic_debug_1.patch.
- Delete patches.drivers/dynamic_debug_2.patch.
- Delete patches.drivers/dynamic_debug_3.patch.
- Delete patches.drivers/dynamic_debug_4.patch.
- Delete patches.drivers/dynamic_debug_5.patch.
- Delete patches.drivers/dynamic_debug_6.patch.
- Delete patches.drivers/dynamic_debug_7.patch.
- commit 68dc5c8
* Fri Jan  7 2011 neilb@suse.de
- Remove old patch
- commit 7fc009b
* Thu Jan  6 2011 jeffm@suse.com
- reiserfs: Fix crash during umount (bnc#610598).
- commit 88f26ac
* Thu Jan  6 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Move the source tree if %%kernelrelease is
  different from the tarball version.
- commit 6be9ffe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.suse/export-sync_page_range (unused).
- commit d19ee6d
* Thu Jan  6 2011 jeffm@suse.com
- Delete patches.suse/supported-flag-sysfs: Merged with patches.suse/supported-flag
- commit 0f2e67b
* Thu Jan  6 2011 jeffm@suse.com
- Removed unused kdb patches.
  - Delete patches.suse/kdb-build-fixes.
  - Delete patches.suse/kdb-common.
  - Delete
    patches.suse/kdb-fix-assignment-from-incompatible-pointer-warnings.
  - Delete
    patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro.
  - Delete patches.suse/kdb-handle-nonexistance-keyboard-controller.
  - Delete patches.suse/kdb-ia64.
  - Delete patches.suse/kdb-usb-rework.
  - Delete patches.suse/kdb-vm-api-changes-for-2-6-34.
  - Delete patches.suse/kdb-x86.
  - Delete patches.suse/kdb-x86-build-fixes.
  - Delete patches.suse/kdb_dont_touch_i8042_early.patch.
  - Delete patches.suse/kdb_fix_ia64_build.patch.
  - Delete patches.xen/xen3-kdb-x86.
- commit c9e725d
* Thu Jan  6 2011 jeffm@suse.com
- rpm/kernel-source.spec.in: Remove the relocation of the source tree.
  It's expanded in-place.
- commit 8cde941
* Thu Jan  6 2011 jack@suse.cz
- Delete patches.suse/ext2-fsync-err as it is obsolete and unused.
- commit c8f4ebe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.fixes/kbuild-fix-generating-of-.symtypes-files.
  Fixed upstream in commit e26d6b8.
- commit 1b628e1
* Thu Jan  6 2011 mgalbraith@suse.de
- Replaced autogroup patch with what will appear in 2.6.38
- Replaced cgroup use after free fix wtih what will appear in 2.6.38
- Refresh
  patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Delete patches.fixes/sched-fix-autogroup-proc-interface-race.
- commit 81f018b
* Thu Jan  6 2011 jeffm@suse.com
- Update to 2.6.37-final.
- commit f4cd126
* Thu Dec 30 2010 jeffm@suse.com
- taskstats: Use better ifdef for alignment (bko#24272).
- commit 2948ffa
* Wed Dec 29 2010 jeffm@suse.com
- Update to 2.6.37-rc8.
  - Eliminated 1 patch.
- commit 42518e6
* Tue Dec 28 2010 mgalbraith@suse.de
- sched: fix autogroup /proc interface race.
- commit fd7019c
* Tue Dec 28 2010 jeffm@suse.com
- scripts/wd-functions.sh: Re-added support for finding tarball in $MIRROR.
- commit c8014fb
* Tue Dec 28 2010 jeffm@suse.com
- sched, cgroup: Use exit hook to avoid use-after-free crash.
- commit 59c0581
* Tue Dec 28 2010 jeffm@suse.com
- Update to 2.6.37-rc7.
  - Eliminated 9 patches.
- commit d38591c
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
  Backport to XEN.
- commit 92c0965
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "PCI: fix pci_bus_alloc_resource() hang, prefer positive
  decode" (bnc#655048).
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
- Revert "x86/PCI: allocate space from the end of a region,
  not the beginning" (bnc#655048).
- Revert "PCI: allocate bus resources from the top down"
  (bnc#655048).
- Revert "resources: support allocating space within a region
  from the top down" (bnc#655048).
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid low BIOS area when allocating address space
  (bnc#655048).
- x86: avoid E820 regions when allocating address space
  (bnc#655048).
- x86: avoid high BIOS area when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7bbbf27
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "- resources: add arch hook for preventing allocation in reserved"
  This reverts commit 7e253537787f4fb057e12a166356169c5adb9665. It was unintended to be pushed as the patches are obsoleted.
- commit 6f3bdf8
* Mon Dec 20 2010 jslaby@suse.cz
- Delete
  patches.fixes/res-0010-PCI-fix-pci_bus_alloc_resource-hang-prefer-positive-.patch.
  It's unreferenced and wrong.
- commit 9e6fc50
* Fri Dec 17 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Define %%kernelrelease
- commit 1d67b13
* Thu Dec 16 2010 jeffm@suse.com
- Linux: 2.6.37-rc6.
- Update config files.
- Refresh patches.suse/SoN-23-mm-swapfile.patch.
- Refresh patches.suse/SoN-26-nfs-swapper.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit 5650f90
* Mon Dec 13 2010 jbeulich@novell.com
- Update Xen config files (XEN_NETDEV_LOOPBACK=n).
- supported.conf: Update.
- commit d385dff
* Mon Dec 13 2010 tiwai@suse.de
- Refresh patches.suse/bootsplash-scaler: Fix crash when bootsplash animation is used (bnc#646908)
- commit c5eced1
* Fri Dec 10 2010 jslaby@suse.cz
- Update to Linux 2.6.36.2
- Obsoletes:
  patches.drivers/alsa-hda-01-Fix-wrong-SPDIF-NID-assignment-for-CA0110
  patches.drivers/alsa-hda-02-Add-some-workarounds-for-Creative-IBG
  patches.drivers/alsa-hda-03-Add-workarounds-for-CT-IBG-controllers
  patches.fixes/hpet-unmap-unused-I-O-space.patch
  patches.fixes/net-Limit-socket-I-O-iovec-total-length.patch
  patches.fixes/tty-restore-tty_ldisc_wait_idle.patch
- Refresh patches.suse/SoN-22-netvm.patch
- commit 8c48718
* Fri Dec 10 2010 jslaby@suse.cz
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid BIOS area when allocating address space (bnc#655048).
- x86: avoid PNP resources when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7e25353
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen config files (CONFIG_XEN_COMPAT=0x040000).
- commit 5343e5f
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc5.
- commit bef1a0d
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- commit dbec62c
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:Factory
- commit bf19860
* Wed Dec  8 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Allow to build against any version of
  kernel-source
- commit da8598f
* Tue Dec  7 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Remove stringification
  (needed only with very old assemblers).
- commit 987c244
* Tue Dec  7 2010 jeffm@suse.com
- scripts/sequence-patch.sh: Added -vanilla suffix to the directory name when expanding vanilla tree.
- commit 77ad87b
* Tue Dec  7 2010 jeffm@suse.com
- Update vanilla config files.
- commit f55f81b
* Tue Dec  7 2010 jeffm@suse.com
- Update to 2.6.37-rc5.
- commit ca102d9
* Tue Dec  7 2010 jbeulich@novell.com
- patches.suse/novfs-fix-ioctl-usage: Fix compiler warnings.
- commit faf2142
* Mon Dec  6 2010 mgalbraith@suse.de
- Replace buggy per tty autogroup patch with final per session patch as
  integrated into tip.
- sched: Add 'autogroup' scheduling feature: automated per session task groups (bnc#657613).
- Delete patches.suse/sched-automated-per-tty-task-groups.
- commit 0db6b6b
* Mon Dec  6 2010 jbeulich@novell.com
- patches.rpmify/rpm-kernel-config, patches.rpmify/split-package,
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch,
  patches.suse/SoN-15-netvm-reserve.patch,
  patches.suse/SoN-27-nfs-swap_ops.patch,
  patches.suse/kconfig-automate-kernel-desktop,
  patches.suse/mm-tune-dirty-limits.patch,
  patches.suse/supported-flag-enterprise: Clean up Kconfig portions.
- commit 713650c
* Mon Dec  6 2010 jeffm@suse.com
- Fixed corrupted -rc4 patch.
- commit 9802d4e
* Mon Dec  6 2010 jeffm@suse.de
- Update to 2.6.37-rc4.
- commit d102b44
* Wed Dec  1 2010 jslaby@suse.cz
- Update README.BRANCH
  To reflect what the stable branch really is.
- commit 59a125e
* Mon Nov 29 2010 jeffm@suse.com
- Merge 2.6.37-rc3-git6 with Xen.
- commit 7089cd5
* Mon Nov 29 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git6.
- commit 1294ef9
* Mon Nov 29 2010 jslaby@suse.cz
- Update to Linux 2.6.36.1
- commit 11bcaf3
* Fri Nov 26 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc3-git1 and c/s 1055.
- xen/acpi: Add memory hotadd to pvops dom0 (bnc#651066).
- xen/acpi: Export host physical CPU information to dom0
  (bnc#651066).
- Xen: para-virtual watchdog driver.
- introduce {rd,wr}msr_safe_on_pcpu() and add/enable users.
- eliminate scalability issues from initrd handling.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit cf6d991
* Fri Nov 26 2010 trenn@suse.de
- PERF: Fix perf timechart C-state regression (none).
- commit ba2671d
* Wed Nov 24 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git1.
- commit 4ad245f
* Mon Nov 22 2010 jeffm@suse.com
- Update to 2.6.37-rc3.
  - Eliminated 1 patch.
- commit 12ac0ac
* Mon Nov 22 2010 jslaby@suse.cz
- Delete patches.fixes/make-note_interrupt-fast.diff.
- Delete patches.fixes/twl6030-fix-note_interrupt-call.
  __do_IRQ from ia64 lapic code is no longer called, because they use
  genirqs properly. So these patches don't make sense anymore. If we
  need something to do, then it's adding action_ret == IRQ_NONE test
  into handle_percpu_irq before jumping into note_interrupt.
- commit facd623
* Sun Nov 21 2010 jslaby@suse.cz
- PCI: fix offset check for sysfs mmapped files (bnc#655157).
- commit 2938f56
* Wed Nov 17 2010 jeffm@suse.com
- sched: automated per tty task groups.
  - Enabled in -desktop flavors for better interactivity.
- commit 2d5d397
* Tue Nov 16 2010 jeffm@suse.de
- doc/config-options.changes: Updated changes for 2.6.37-rc1 and -rc2.
- commit 0aca8b8
* Tue Nov 16 2010 jeffm@suse.com
- Update to 2.6.37-rc2.
- commit 1453a04
* Tue Nov 16 2010 jslaby@suse.cz
- PCI: fix pci_bus_alloc_resource() hang, prefer positive decode
  (bnc#651256).
- commit b4888f0
* Mon Nov 15 2010 jeffm@suse.com
- Update vanilla config files.
- commit 60b4a47
* Mon Nov 15 2010 jeffm@suse.com
- Update to 2.6.37-rc1-git11.
  - Eliminated 2 patches.
- commit 5959a67
* Mon Nov 15 2010 jeffm@suse.com
- supported.conf: Added missing dependencies.
- commit 0537c35
* Sat Nov 13 2010 jslaby@suse.cz
- TTY: restore tty_ldisc_wait_idle (bnc#642043).
- commit 84d87bf
* Fri Nov 12 2010 jeffm@suse.de
- Update to 2.6.37-rc1.
  - Eliminated 26 patches.
  - Xen is disabled.
- commit b9044e3
* Thu Nov 11 2010 gregkh@suse.de
- Update config files. (bnc#652954) increase the number of possible and
  default uarts for users with multi-port serial cards for the i386 and
  x86-64 default configs.
- commit 85c87e3
* Thu Nov 11 2010 jslaby@suse.cz
- rt2x00: Fix max TX power settings (bnc#584028).
- rt2x00: Fix channel configuration for RF3052 (bnc#584028).
- commit 60c0452
* Thu Nov 11 2010 jslaby@suse.cz
- resources: add a default alignf to simplify find_resource()
  (bnc#651256).
- resources: factor out resource_clip() to simplify
  find_resource() (bnc#651256).
- resources: ensure callback doesn't allocate outside available
  space (bnc#651256).
- resources: handle overflow when aligning start of available area
  (bnc#651256).
- resources: support allocating space within a region from the
  top down (bnc#651256).
- PCI: allocate bus resources from the top down (bnc#651256).
- x86/PCI: allocate space from the end of a region, not the
  beginning (bnc#651256).
- x86: update iomem_resource end based on CPU physical address
  capabilities (bnc#651256).
- x86: allocate space within a region top-down (bnc#651256).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 8c68ad1
* Tue Nov  9 2010 jack@suse.cz
- novfs: Fix for the issue of kernel dumps core on restart
  (bnc#641811).
- commit 76ba833
* Fri Oct 29 2010 jslaby@suse.cz
- net: Limit socket I/O iovec total length to INT_MAX
  (bnc#650128).
- commit 2ba74bb
* Fri Oct 29 2010 trenn@suse.de
- Update config files.
  Forgot to enable ACPI_EC_DEBUGFS on i386/pae
- commit 66b605b
* Wed Oct 27 2010 jslaby@suse.cz
- aha152x: enable PCMCIA on 64bit (bnc#630652).
- Update config files.
- commit a91d17c
* Wed Oct 27 2010 jslaby@suse.cz
- hpet: unmap unused I/O space (bnc#629908 bnc#629901).
- commit dad22c3
* Tue Oct 26 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_ACPI_EC_DEBUGFS=m on supported archs.
- commit 9035254
* Tue Oct 26 2010 jbeulich@novell.com
- Update Xen config files (restore options accidentally deleted
  by 1b1584fccbfdc42e6e8b35c3c207ca65feb0c7d5).
- commit f8e5000
* Mon Oct 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36 and c/s 1043.
- xen: netback: take net_schedule_list_lock when removing entry
  from net_schedule_list.
- Update Xen config files.
- commit b772cd8
* Mon Oct 25 2010 tiwai@suse.de
- ALSA: hda - Add workarounds for CT-IBG controllers (bnc#564324).
- ALSA: hda - Add some workarounds for Creative IBG (bnc#564324).
- ALSA: hda - Fix wrong SPDIF NID assignment for CA0110
  (bnc#564324).
- commit 2256eda
* Fri Oct 22 2010 jeffm@suse.de
- Update to 2.6.36-final.
- commit 1b1584f
* Fri Oct 22 2010 jbeulich@novell.com
- patches.arch/i386-unwind-annotations,
  patches.arch/x86_64-unwind-annotations: Update Patch-mainline tags.
- commit 6ee5ccb
* Thu Oct 21 2010 sjayaraman@suse.de
- SoN: fix null pointer dereference in swap_entry_free.
- SoN: fix mess up on swap with multi files from same nfs server.
- Refresh patches.xen/tmem.
- commit d068f12
* Mon Oct 18 2010 trenn@suse.de
- ACPI: Make Embedded Controller command timeout delay
  configurable (bnc#639261).
- commit 9ea38cf
* Fri Oct 15 2010 jslaby@suse.cz
- Update to 2.6.36-rc8.
- commit 0c0e67c
* Fri Oct 15 2010 jslaby@suse.cz
- Refresh patches.suse/SoN-22-netvm.patch.
  Fix lock imbalance in net core (caused errors with bridges). (bnc#637235)
- commit f7ca98f
* Tue Oct 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc7 and c/s 1042.
- Update tmem interface to v1.
- commit 03c1043
* Mon Oct 11 2010 mmarek@suse.cz
- Generate per-symbol provides again (fate#305945).
  11.4 will do incremental downloads of repository metadata
  (fate#309561), so there should be no problem with the update
  repository anymore.
- commit 4258cf2
* Mon Oct 11 2010 jbeulich@novell.com
- patches.apparmor/apparmor-compatibility-patch-for-v5-network-control:
  Remove .rej file from this patch.
- commit 8828ce5
* Fri Oct  8 2010 jeffm@suse.de
- Update to 2.6.36-rc7.
- commit 82673e4
* Tue Oct  5 2010 jbeulich@novell.com
- patches.drivers/dynamic_debug_4.patch: Fix build issues with
  !DYNAMIC_DEBUG and build warning.
- commit b08d2aa
* Tue Oct  5 2010 jeffm@suse.de
- Enable SECURITY_APPARMOR_COMPAT_24
- commit f9b83fc
* Tue Oct  5 2010 jeffm@suse.de
- AppArmor: Allow dfa backward compatibility with broken
  userspace.
- AppArmor: compatibility patch for v5 interface.
- AppArmor: compatibility patch for v5 network control.
- commit cb27981
* Mon Oct  4 2010 jeffm@suse.de
- Update to 2.6.36-rc6.
  - Eliminated 2 patches.
- commit 57ae577
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 one more time.
- commit d527087
* Fri Sep 24 2010 trenn@suse.de
- acpi: ec_sys: access user space with get_user()/put_user()
  (none).
- commit d028761
* Fri Sep 24 2010 trenn@suse.de
- kernel/module.c: Fix compiler warnings if debug is compiled in
  (none).
- PNP: Use dev_dbg instead of dev_printk(KERN_DEBUG.. if
  DYNAMIC_DEBUG is compiled in (none).
- PNP: Compile all pnp built-in stuff in one module namespace
  (none).
- Dynamic Debug: Introduce global fake module param module.ddebug
  - V4 (none).
- Dynamic Debug: Initialize dynamic debug earlier via
  arch_initcall (none).
- Dynamic Debug: Introduce ddebug_query= boot parameter (none).
- Dynamic Debug: Split out query string parsing/setup from
  proc_write (none).
- commit dcd5c68
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 again.
- commit 2fbc89f
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28.
- commit cba31c7
* Fri Sep 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc5 and c/s 1038.
- commit 7b86243
* Thu Sep 23 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kernel release strings like
  2.6.36-rc5-73-g57aebd7-vanilla.
- rpm/kernel-spec-macros: Cleanup.
- commit 0926a18
* Thu Sep 23 2010 jeffm@suse.de
- rose: Fix signedness issues wrt. digi count (CVE-2010-3310
  bnc#640721).
- commit bcdc88b
* Tue Sep 21 2010 jeffm@suse.de
- qla4xxx: add workaround for missing readq/writeq.
- commit 643f9cf
* Tue Sep 21 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: BuildRequire proper version of kernel-source
- commit beb33d1
* Tue Sep 21 2010 jeffm@suse.de
- Linux: 2.6.36-rc5.
  - Eliminated 6 patches (all security backports).
- commit d4603b4
* Mon Sep 20 2010 jeffm@suse.de
- Revert "- make SCSI and ATA drivers modules again. (bnc#564357)."
  This reverts commit 75e8e5eae2c1e8dd279370f2c7650835ee821deb.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
  This change only applies to enterprise releases and should have been
  reverted prior to the release of openSUSE 11.3.
- commit 7fc084f
* Mon Sep 20 2010 sjayaraman@suse.de
- Update patches.suse/SoN-05-reserve-slub.patch to accomodate an upstream
  change that uses kmem_cache flags instead of PageSlubDebug flag.
- commit 4ea582b
* Mon Sep 20 2010 jeffm@suse.de
- Set LSM_MMAP_MIN_ADDR=0 to allow tools like DOSemu to work properly. The
  default is still set to 64k.
- commit 0581892
* Sun Sep 19 2010 jeffm@suse.com
- Delete patches.suse/cgroup-disable-memory.patch: It is no longer needed. The performance hit that it caused has been eliminated.
- commit 1ec7da8
* Fri Sep 17 2010 jeffm@suse.de
- wext: fix potential private ioctl memory content leak
  (CVE-2010-2955 bnc#635413).
- commit 6df45c9
* Thu Sep 16 2010 jeffm@suse.de
- x86-64, compat: Test %%rax for the syscall number, not %%eax
  (CVE-2010-3301 bnc#639708).
- x86-64, compat: Retruncate rax after ia32 syscall entry tracing
  (CVE-2010-3301 bnc#639708).
- commit fb77404
* Thu Sep 16 2010 jeffm@suse.de
- compat: Make compat_alloc_user_space() incorporate the
  access_ok() (CVE-2010-3081 bnc#639709).
- commit 664a0ac
* Wed Sep 15 2010 jeffm@suse.com
- Remove reference to unused patch.
- commit a3abfe2
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/usb/hso.c: prevent reading uninitialized memory
  (CVE-2010-3298 bnc#639483).
- commit 35e70c8
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/cxgb3/cxgb3_main.c: prevent reading uninitialized
  stack memory (CVE-2010-3296 bnc#639481).
- commit a0634a9
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/eql.c: prevent reading uninitialized stack memory
  (CVE-2010-3297 bnc#639482).
- commit 2a7b160
* Wed Sep 15 2010 tiwai@suse.de
- Revert "patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171"
  This reverts commit c6a176c1df9ab4c69dd54ff3076bc92806eac8fd.
  It should have been applied to SLE11-SP1 branch.
- commit 05f07f3
* Tue Sep 14 2010 jslaby@suse.cz
- Update to Linux 2.6.36-rc4.
  - Obsoletes:
  - patches.fixes/bonding-jiffies2.patch.
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure.
  - patches.fixes/net-sched-fix-kernel-leak-in-act_police.
  - patches.rpmify/spectra-depends-on-moorestown.
- fix build on s390 as of 2.6.36-rc4.
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/reiser4-set_page_dirty_notag.
- Refresh patches.xen/pci-guestdev.
- Update config files.
- commit 6915057
* Mon Sep 13 2010 oneukum@suse.de
- patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171
- commit c6a176c
* Mon Sep 13 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Update patch-mainline.
- commit a1a8fdd
* Fri Sep  3 2010 jeffm@suse.de
- Always build in AGP on x86/x86_64 so KMS works on LiveCDs (bnc#609607).
- commit d9bfa1e
* Fri Sep  3 2010 jeffm@suse.com
- irda: Correctly clean up self->ias_obj on irda_bind() failure
  (CVE-2010-2954 bnc#636112).
- commit f04e61f
* Wed Sep  1 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc3 and c/s 1029.
- fix unwind annotations.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 6836619
* Wed Sep  1 2010 jbeulich@novell.com
- fix unwind annotations.
- commit 5aa6daf
* Wed Sep  1 2010 jeffm@suse.com
- net sched: fix kernel leak in act_police (CVE-2010-2942
  bnc#632309).
- commit 66e1d72
* Tue Aug 31 2010 jdelvare@suse.de
- fix jiffies overflow problems in bonding (bnc#613273).
- commit 28bd2e8
* Mon Aug 30 2010 jeffm@suse.de
- Refresh vanilla configs.
- commit 26a681e
* Mon Aug 30 2010 jeffm@suse.de
- Update to Linux: 2.6.36-rc3.
  - Eliminated 7 patches.
- commit d298d2d
* Sat Aug 28 2010 jslaby@suse.cz
- Delete
  patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch.
- Delete
  patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch.
- Delete
  patches.suse/rlim-0022-FS-proc-make-limits-writable.patch.
  This was just a workaround crap. In 2.6.36 we have a nice syscall
  instead. Sorry for commiting this to the merge-36 branch first. I
  didn't notice it was already merged here.
- commit 5449fcb
* Fri Aug 27 2010 jeffm@suse.com
- Disabled ACPI table override patches again. fsnotify was introduced into
  the truncate path and causes crashes.
- commit e18fc2c
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/supported-flag-enterprise: Fixed recovery on load failure.
- commit 8a06643
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/stack-unwind: Fixed recovery on load failure.
- commit 7f15b29
* Tue Aug 24 2010 jeffm@suse.com
- patches.arch/s390-message-catalog.diff: dev_info -> _dev_info
- commit ba20988
* Tue Aug 24 2010 jeffm@suse.de
- patches.suse/stack-unwind: Fix build on !SMP
- commit abd5493
* Tue Aug 24 2010 jeffm@suse.de
- s390: Fix prototype for execve.
- commit b448268
* Tue Aug 24 2010 jeffm@suse.de
- spectra: depend on X86_MRST.
- commit 1e3fb89
* Tue Aug 24 2010 jeffm@suse.de
- Delete patches.arch/ppc-vmcoreinfo.diff.
- commit ea39e14
* Tue Aug 24 2010 jeffm@suse.de
- caif: Use asm/unaligned.h.
- commit 92c07c2
* Tue Aug 24 2010 jeffm@suse.de
- Refresh patches.suse/SoN-20-netvm-tcp-deadlock.patch: Added missing
  fixup for sk_rmem_schedule in caif.
- commit a9ff761
* Tue Aug 24 2010 mmarek@suse.cz
- makefile: not need to regenerate kernel.release file when
  make kernelrelease.
- commit 81237a8
* Tue Aug 24 2010 jeffm@suse.com
- rpm/kernel-source.spec.in, scripts/tar-up.sh: Renamed config-options.changes
  to config-options.changes.txt in the exported package to avoid triggering
  a build service rule error.
- commit ff4889e
* Tue Aug 24 2010 jeffm@suse.com
- Revert "- Renamed doc/config-options.changes to doc/config-options.changes.txt to"
  This reverts commit 124ac26de4839f8181a5badedb231eedf5770a3e.
- commit 2932c62
* Tue Aug 24 2010 jeffm@suse.com
- Renamed doc/config-options.changes to doc/config-options.changes.txt to
  avoid triggering a build service rule error.
- commit 124ac26
* Mon Aug 23 2010 jeffm@suse.de
- supported.conf: Add iscsi_boot_sysfs
- commit 80e2ea9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Fixed typo with last fix.
- commit 22210d9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disable CONFIG_DEBUG_INFO. It's enabled
  dynamically in the spec file and now has follow-on options.
- commit d270759
* Mon Aug 23 2010 jeffm@suse.de
- patches.rpmify/spectra-drop-locked_ioctl-support: add <linux/smp_lock.h>
  to grab the BKL
- commit 1df02ec
* Mon Aug 23 2010 jeffm@suse.de
- Update config files: Disabled DEBUG_INFO_REDUCED.
- commit 393680a
* Mon Aug 23 2010 jeffm@suse.de
- Updated to 2.6.36-rc2.
  - Eliminated 2 patches.
- commit 52d47a0
* Wed Aug 18 2010 jeffm@suse.de
- Update to 2.6.36-rc1.
  - Eliminated 71 patches.
  - spectra: Drop ->locked_ioctl support.
  - spectra: Drop ->prepare_flush_fn support.
  - spectra: Remove duplicate GLOB_VERSION.
  - novfs: Fix ioctl usage.
  - novfs: use evict_inode.
  - Xen is disabled.
- commit 63642f6
* Mon Aug 16 2010 tiwai@suse.de
- ALSA: hda - Add quirk for Dell Vostro 1220 (bnc#631066).
- commit df12c34
* Fri Aug 13 2010 jeffm@suse.com
- README.BRANCH: Updated to reflect the permenent in-progress status.
- commit a2c882e
* Thu Aug 12 2010 gregkh@suse.de
- Update to 2.6.35.1
  - security fixes
  - bug fixes
  - obsoletes:
    patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch.
- commit a009fb4
* Thu Aug 12 2010 gregkh@suse.de
- Delete patches.kernel.org/patch-2.6.35-rc1.
- Delete patches.kernel.org/patch-2.6.35-rc1-rc2.
- Delete patches.kernel.org/patch-2.6.35-rc2-rc3.
- Delete patches.kernel.org/patch-2.6.35-rc3-rc4.
- Delete patches.kernel.org/patch-2.6.35-rc4-rc5.
- Delete patches.kernel.org/patch-2.6.35-rc5-rc6.
- commit 2e67843
* Thu Aug 12 2010 gregkh@suse.de
- Refresh patches.fixes/novfs-lindent.
  Someone needs to remember to actually test out their patches before
  adding them to the repo...
- commit 6569c56
* Thu Aug 12 2010 jeffm@suse.com
- doc/README.SUSE: Updated to describe the process used to add custom patches
- commit e5f4670
* Thu Aug 12 2010 jslaby@suse.cz
- patches.fixes/vmscan-fix-stalls.patch: vmscan: raise the bar
  to PAGEOUT_IO_SYNC stalls (bnc#625339).
- commit 1efea94
* Wed Aug 11 2010 jack@suse.cz
- novfs: Lindent novfs sources.
- commit 361594a
* Wed Aug 11 2010 neilb@suse.de
- Refresh
  patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch.
- Refresh patches.fixes/sunrpc-monotonic-expiry.
- Delete patches.fixes/nfs-write.c-bug-removal.patch.
  Update some patches for 2.6.35
- commit 15d7a62
* Wed Aug 11 2010 neilb@suse.de
- NFS: allow close-to-open cache semantics to apply to root of
  NFS filesystem (bnc#584720).
- commit deea101
* Tue Aug 10 2010 tiwai@suse.de
- ALSA: hda - patch_nvhdmi.c: Add missing codec IDs, unify names
  (bnc#627212).
- ALSA: hda - Add pin-fix for HP dc5750 (bnc#624118).
- commit 4844a71
* Mon Aug  9 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35 final and c/s 1025.
- create devices in /dev/xen when they are expected to be
  used there.
- xen/netback: Allow setting of large MTU before rings have
  connected.
- xen/netback: Always pull through PKT_PROT_LEN bytes into the
  linear part of an skb.
- pass trigger mode and polarity information to Xen for all
  interrupts.
- Update Xen config files.
- supported.conf: Add pci-iomul.ko.
- commit c642c1b
* Fri Aug  6 2010 jeffm@suse.de
- patches.xen/xen3-auto-xen-arch.diff: Update struct acpi_power_register
  usage from upstream commit 718be4aa.
- commit 4ce0b48
* Fri Aug  6 2010 jeffm@suse.de
- Update to 2.6.35-final and refresh patch set.
- commit a40327f
* Mon Aug  2 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Package log.sh in the source rpm
- commit 53246ff
* Fri Jul 23 2010 jack@suse.cz
- novfs: Fix error codes for getxattr for novfs (bnc#529535).
- commit 06b3243
* Fri Jul 23 2010 jeffm@suse.de
- Update to 2.6.35-rc6.
- commit 643df99
* Fri Jul 23 2010 jack@suse.cz
- novfs: code cleanup for one case of novfs return value
  (bnc#624606).
- commit 4875860
* Wed Jul 21 2010 jack@suse.cz
- Fixed patch headers of patches.fixes/novfs-xattr-memleak
- commit 65ab01f
* Wed Jul 21 2010 jack@suse.cz
- novfs: Fix a memory leak that causes an OOM condition
  (bnc#610828).
- commit 519d8a0
* Tue Jul 20 2010 jack@suse.cz
- novfs: backing device info initialization (bnc#623472).
- commit b576dae
* Tue Jul 20 2010 mmarek@suse.cz
- scripts/tar-up.sh: Generate the rpm changelog using gitlog2changes.
- Move kernel-source.changes.old to rpm/ (not included in the pachage
  though).
- commit 8ed2389
* Tue Jul 20 2010 jblunck@suse.de
- rpm/package-descriptions: Change summary/description for trace flavor (bnc#488692).
- commit da8e17e
* Mon Jul 19 2010 mmarek@suse.cz
- Move rpm changelog to kernel-source.changes.old
- commit 93036bd
* Thu Jul 15 2010 bphilips@suse.de
- X86_MRST: Disable moorsetown since it deselects SERIO_I8042
  - See 0b28bac5aef7bd1ab213723df031e61db9ff151a, fixed in -tip but we
    still don't want X86_MRST
* Wed Jul 14 2010 trenn@suse.de
- patches.arch/acpi_fix_fadt_32_bit_zero_length.patch: Only use
  32 bit addresses if they have a valid length (bug#581644).
* Wed Jul 14 2010 bphilips@suse.de
- Update -desktop config files to enable CGROUPS for systemd
* Wed Jul 14 2010 jeffm@suse.de
- Update to 2.6.35-rc5.
  - Eliminated 5 patches.
* Tue Jul 13 2010 jack@suse.de
- patches.fixes/novfs-overflow-fixes: novfs: security: Add buffer
  overflow, integer wraparound fixes (bnc#594362).
* Wed Jul  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc4.
* Wed Jul  7 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-2.6.35-api-changes: Updated for -debug flavor.
* Wed Jul  7 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Jul  7 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install config-option.changes
  This file documents the changes in the kernel configs.
* Wed Jul  7 2010 mmarek@suse.cz
- patches.rpmify/kbuild-setlocalversion-fix: kbuild: Fix path
  to scripts/setlocalversion.
* Wed Jul  7 2010 jeffm@suse.de
- Update to 2.6.35-rc4.
  - Eliminated 4 patches.
* Fri Jul  2 2010 jeffm@suse.de
- patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices:
  iwlwifi: fix TX power configuration on 3945 and 4965 devices
  (bnc#619440 bnc#610421).
* Fri Jul  2 2010 jbeulich@novell.com
- patches.suse/stack-unwind: Fix after upstream commit
  9e565292270a2d55524be38835104c564ac8f795.
* Fri Jul  2 2010 trenn@suse.de
- patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch:
  For some reason the macro used by dynamic debug breaks things
  (bnc#619416).
* Fri Jul  2 2010 trenn@suse.de
  Mainline goes another way (bug #476509).
  Also there is a problem with this patch, breaking dynamic debugging
  (bnc#619416) -> just remove it, there will show up something else
  mainline.
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Delete.
* Thu Jul  1 2010 jeffm@suse.de
- patches.suse/dm-raid45-api-update-remove-dm_put-after-dm_table_get_md:
  dm-raid45: API update: Remove dm_put after dm_table_get_md
  (bnc#615656).
* Thu Jul  1 2010 jdelvare@suse.de
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  Update references (bnc#610362).
* Thu Jul  1 2010 bphilips@suse.de
- patches.drivers/ixgbe-disable-tx-engine-before-disabling-tx-laser.patch:
  ixgbe: disable tx engine before disabling tx laser.
- patches.drivers/ixgbe-fix-panic-when-shutting-down-system-with-WoL-e.patch:
  ixgbe: fix panic when shutting down system with WoL enabled.
- patches.drivers/ixgbe-skip-non-IPv4-packets-in-ATR-filter.patch:
  ixgbe: skip non IPv4 packets in ATR filter.
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  e1000e: don't inadvertently re-set INTX_DISABLE.
* Wed Jun 30 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Delete.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Delete.
* Tue Jun 29 2010 nfbrown@suse.de
- patches.fixes/nfs_wb_page_deadlock.fix: NFS: Fix another
  nfs_wb_page() deadlock (bnc#612794).
* Mon Jun 28 2010 mmarek@suse.cz
- rpm/find-provides: Add base symsets to the main subpackage.
* Fri Jun 25 2010 jeffm@suse.de
- Update config files for sparc64/net to remove unnecessary options.
* Fri Jun 25 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Fri Jun 25 2010 jbeulich@novell.com
- patches.arch/kvm-split-paravirt-ops-by-functionality: Adjust
  Kconfig style to match upstream.
- patches.fixes/seccomp-disable-tsc-option: Adjust Kconfig style
  to match upstream.
- patches.suse/SoN-11-mm-reserve.patch: Fix compiler warning.
* Fri Jun 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc3.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Thu Jun 24 2010 agruen@suse.de
- Replace the nfs4acl patches by their successor patch queue,
  richacls (see http://www.suse.de/~agruen/richacl/).
- Update config files: CONFIG_EXT4_FS_RICHACL=y.
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files:
  ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only
  files (bnc#612457 CVE-2010-2066).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-writing-to-non-page-aligned-gfs2_quota-structures:
  GFS2: Fix writing to non-page aligned gfs2_quota structures
  (bnc#599957 CVE-2010-1436).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl:
  GFS2: Fix permissions checking for setflags ioctl() (bnc#608576
  CVE-2010-1641).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jeffm@suse.de
- btrfs fix rollup from v2.6.35:
- patches.fixes/btrfs-handle-err_ptr-from-posix_acl_from_xattr:
  Btrfs: handle ERR_PTR from posix_acl_from_xattr().
- patches.fixes/btrfs-avoid-bug-when-dropping-root-and-reference-in-same-transaction:
  Btrfs: avoid BUG when dropping root and reference in same
  transaction.
- patches.fixes/btrfs-prohibit-a-operation-of-changing-acl-s-mask-when-noacl-mount-option-used:
  Btrfs: prohibit a operation of changing acl's mask when noacl
  mount option used.
- patches.fixes/btrfs-should-add-a-permission-check-for-setfacl:
  Btrfs: should add a permission check for setfacl.
- patches.fixes/btrfs-btrfs_lookup_dir_item-can-return-err_ptr:
  Btrfs: btrfs_lookup_dir_item() can return ERR_PTR.
- patches.fixes/btrfs-btrfs_read_fs_root_no_name-returns-err_ptrs:
  Btrfs: btrfs_read_fs_root_no_name() returns ERR_PTRs.
- patches.fixes/btrfs-unwind-after-btrfs_start_transaction-errors:
  Btrfs: unwind after btrfs_start_transaction() errors.
- patches.fixes/btrfs-btrfs_iget-returns-err_ptr: Btrfs:
  btrfs_iget() returns ERR_PTR.
- patches.fixes/btrfs-handle-kzalloc-failure-in-open_ctree:
  Btrfs: handle kzalloc() failure in open_ctree().
- patches.fixes/btrfs-handle-error-returns-from-btrfs_lookup_dir_item:
  Btrfs: handle error returns from btrfs_lookup_dir_item().
- patches.fixes/btrfs-fix-bug_on-for-fs-converted-from-extn:
  Btrfs: Fix BUG_ON for fs converted from extN.
- patches.fixes/btrfs-fix-null-dereference-in-relocation-c:
  Btrfs: Fix null dereference in relocation.c.
- patches.fixes/btrfs-fix-remap_file_pages-error: Btrfs: fix
  remap_file_pages error.
- patches.fixes/btrfs-uninitialized-data-is-check_path_shared:
  Btrfs: uninitialized data is check_path_shared().
- patches.fixes/btrfs-fix-fallocate-regression: Btrfs: fix
  fallocate regression.
- patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs: Btrfs:
  fix loop device on top of btrfs.
- patches.fixes/btrfs-add-more-error-checking-to-btrfs_dirty_inode:
  Btrfs: add more error checking to btrfs_dirty_inode.
- patches.fixes/btrfs-allow-unaligned-dio: Btrfs: allow unaligned
  DIO.
- patches.fixes/btrfs-drop-verbose-enospc-printk: Btrfs: drop
  verbose enospc printk.
- patches.fixes/btrfs-fix-block-generation-verification-race:
  Btrfs: Fix block generation verification race.
- patches.fixes/btrfs-fix-preallocation-and-nodatacow-checks-in-o_direct:
  Btrfs: fix preallocation and nodatacow checks in O_DIRECT.
- patches.fixes/btrfs-avoid-enospc-errors-in-btrfs_dirty_inode:
  Btrfs: avoid ENOSPC errors in btrfs_dirty_inode.
- patches.fixes/btrfs-move-o_direct-space-reservation-to-btrfs_direct_io:
  Btrfs: move O_DIRECT space reservation to btrfs_direct_IO.
- patches.fixes/btrfs-rework-o_direct-enospc-handling: Btrfs:
  rework O_DIRECT enospc handling.
- patches.fixes/btrfs-use-async-helpers-for-dio-write-checksumming:
  Btrfs: use async helpers for DIO write checksumming.
- patches.fixes/btrfs-don-t-walk-around-with-task-state-task_running:
  Btrfs: don't walk around with task->state != TASK_RUNNING.
- patches.fixes/btrfs-do-aio_write-instead-of-write: Btrfs:
  do aio_write instead of write.
- patches.fixes/btrfs-add-basic-dio-read-write-support: Btrfs:
  add basic DIO read/write support.
- patches.fixes/direct-io-add-a-hook-for-the-fs-to-provide-its-own-submit_bio-function:
  direct-io: add a hook for the fs to provide its own submit_bio
  function.
- patches.fixes/btrfs-metadata-enospc-handling-for-balance:
  Btrfs: Metadata ENOSPC handling for balance.
- patches.fixes/btrfs-pre-allocate-space-for-data-relocation:
  Btrfs: Pre-allocate space for data relocation.
- patches.fixes/btrfs-metadata-enospc-handling-for-tree-log:
  Btrfs: Metadata ENOSPC handling for tree log.
- patches.fixes/btrfs-metadata-reservation-for-orphan-inodes:
  Btrfs: Metadata reservation for orphan inodes.
- patches.fixes/btrfs-introduce-global-metadata-reservation:
  Btrfs: Introduce global metadata reservation.
- patches.fixes/btrfs-update-metadata-reservation-for-delayed-allocation:
  Btrfs: Update metadata reservation for delayed allocation.
- patches.fixes/btrfs-integrate-metadata-reservation-with-start_transaction:
  Btrfs: Integrate metadata reservation with start_transaction.
- patches.fixes/btrfs-introduce-contexts-for-metadata-reservation:
  Btrfs: Introduce contexts for metadata reservation.
- patches.fixes/btrfs-kill-init_btrfs_i: Btrfs: Kill
  init_btrfs_i().
- patches.fixes/btrfs-shrink-delay-allocated-space-in-a-synchronized:
  Btrfs: Shrink delay allocated space in a synchronized.
- patches.fixes/btrfs-kill-allocate_wait-in-space_info: Btrfs:
  Kill allocate_wait in space_info.
- patches.fixes/btrfs-link-block-groups-of-different-raid-types:
  Btrfs: Link block groups of different raid types.
- patches.fixes/nilfs-fix-breakage-caused-by-barrier-flag-changes:
  nilfs: fix breakage caused by barrier flag changes.
- patches.fixes/blkdev-generalize-flags-for-blkdev_issue_fn-functions:
  blkdev: generalize flags for blkdev_issue_fn functions.
* Wed Jun 23 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Tue Jun 22 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-force_dma: ata_generic:
  implement ATA_GEN_* flags and force enable DMA on MBP 7,1
  (bko#15923).
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Tue Jun 22 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:11.3.
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Mon Jun 21 2010 jeffm@suse.de
- Resync v2.6.35 with master.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/acpi-generic-initramfs-table-override-support:
  Refresh.
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Refresh.
* Mon Jun 21 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require a mkinitrd that supports
  KMS (bnc#615680).
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap calls
  while loading initramfs files.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap of
  pages for initramfs loading.
* Fri Jun 18 2010 jbeulich@novell.com
- patches.xen/xen3-driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
- Refresh other Xen patches.
- Update Xen config files.
* Thu Jun 17 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-mcp89-mbp71:
  ahci,ata_generic: let ata_generic handle new MBP w/ MCP89
  (bko#15923).
* Wed Jun 16 2010 jeffm@suse.de
- Update to 2.6.35-rc3.
  - Eliminated 1 patch.
* Mon Jun 14 2010 jslaby@suse.de
- patches.fixes/pci-hotplug-cpqphp-fix-crash.patch: PCI:
  hotplug/cpqphp, fix NULL dereference (bnc#609338).
* Wed Jun  9 2010 jeffm@suse.de
- patches.rpmify/ceph-atomic_long-init-fix: ceph: fix atomic64_t
  initialization on ia64.
* Tue Jun  8 2010 jeffm@suse.de
- patches.trace/utrace-core: Workaround missing kref_set().
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/ppc64-xmon-dmesg-printing.patch: Refresh.
* Tue Jun  8 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: Refresh.
- patches.rpmify/wlags49-missing-strlen-include: wlags49_h2:
  build fix.
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Refresh.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Refresh.
* Tue Jun  8 2010 jeffm@suse.com
- supported.conf: Updated dependencies for 2.6.35
* Mon Jun  7 2010 jeffm@suse.com
- patches.kernel.org/revert-tty-fix-a-little-bug-in-scrup-vt-c:
  Revert "tty: fix a little bug in scrup, vt.c".
* Mon Jun  7 2010 jeffm@suse.com
- Update to 2.6.35-rc2.
* Thu Jun  3 2010 jeffm@suse.de
- Re-enable DSDT in initramfs code.
- patches.suse/acpi-don-t-preempt-until-the-system-is-up: acpi:
  don't preempt until the system is up.
* Wed Jun  2 2010 bphilips@suse.de
- patches.drivers/e1000e-entropy-source.patch: Reintroduce IRQF_SHARED
  to fix non-MSI case (bnc#610362).
* Wed Jun  2 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: More -rt fixes.
* Tue Jun  1 2010 jeffm@suse.com
- Update to 2.6.35-rc1.
  - Eliminated 13 patches.
  - Xen is disabled.
* Tue Jun  1 2010 bphilips@suse.de
- patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch:
  tg3: 5785 and 57780 asic revs not working (bnc#580780).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-module-subpackage: Change the kmp versioning to prefix
  the kernel version with "k" to avoid false version downgrades
  (bnc#609483).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: pcre-tools is not needed.
* Mon May 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix for -rt.
* Wed May 26 2010 gregkh@suse.de
- patches.drivers/driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
* Tue May 25 2010 jeffm@suse.de
- supported.conf: Added mperf, which powernow and acpi-cpufreq now
  depend on.
* Tue May 25 2010 jeffm@suse.com
- patches.arch/powernow-k8-add-core-performance-boost-support:
  powernow-k8: Add core performance boost support (bnc#602209).
- patches.arch/x86-cpu-add-amd-core-boosting-feature-flag-to-proc-cpuinfo:
  x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo.
- patches.arch/x86-cpufreq-add-aperf-mperf-support-for-amd-processors:
  x86, cpufreq: Add APERF/MPERF support for AMD processors
  (bnc#602209).
* Tue May 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34 final.
- Update Xen config files.
- patches.xen/xen3-acpi_processor_check_maxcpus.patch: Do not
  try to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Mon May 24 2010 jbenc@suse.cz
- patches.suse/b43-missing-firmware-info.patch: b43: Change
  firmware missing message to refer to openSUSE script.
* Sun May 23 2010 teheo@suse.de
- patches.drivers/pci-disable-msi-on-K8M800: pci: disable MSI
  on VIA K8M800 (bnc#599508).
* Sat May 22 2010 trenn@suse.de
- patches.xen/xen3-auto-common.diff: Refresh.
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
- patches.fixes/acpi_wmi_debug.patch: X86 platform wmi: Introduce
  debug param to log all WMI events (bnc#598059).
- patches.fixes/hp_wmi_fix_acpi_version_integer_size.patch:
  x86 platform drivers: hp-wmi fix buffer size depending on ACPI
  version (bnc#598059).
- patches.fixes/wmi_debug_pass_guid: X86 platform wmi: Also log
  GUID string when an event happens and debug is set (bnc#598059).
- patches.fixes/wmi_dump_wdg_data.patch: X86 platfrom wmi: Add
  debug facility to dump WMI data in a readable way (bnc#598059).
* Thu May 20 2010 jeffm@suse.com
- Disabled CONFIG_RT2800PCI (bnc#606243)
  - These devices are handled by the rt2860 staging driver.
* Mon May 17 2010 jeffm@suse.com
- patches.fixes/kvm-ioapic.patch: Refresh.
* Mon May 17 2010 jeffm@suse.com
- Update to 2.6.34-final.
* Wed May 12 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix preserving of old symsets.
* Wed May 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc7 and c/s 1017.
* Tue May 11 2010 jeffm@suse.com
- Update config files for vanilla.
* Tue May 11 2010 jeffm@suse.com
- Updated to 2.6.34-rc7.
  - Eliminated 3 patches.
* Sun May  2 2010 jeffm@suse.com
- Update to 2.6.34-rc6.
  - Eliminated 2 patches.
* Sun May  2 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-due-to-null-nameidata: Allow null nd
  (as nfs server uses) on create (bnc#593940).
* Fri Apr 30 2010 trenn@suse.de
- patches.fixes/acpi_ensure_spec_correct_address_space_length.patch:
  ACPI/x86/PCI: compute Address Space length rather than using
  _LEN (bnc#598641).
* Thu Apr 29 2010 jbeulich@novell.com
- Update -ec2 config files (X86_MSR=m again).
* Thu Apr 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc5-git8 and c/s 1016.
- Update Xen config files.
- patches.xen/xen-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/xen-fix_trace_power.patch: Rename to ...
- patches.xen/xen3-x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  ... this.
* Thu Apr 29 2010 knikanth@suse.de
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Refresh.
  Fix patch to call dm_table_get directly instead of calling
  dm_get_table unnecesarily.
* Thu Apr 29 2010 jeffm@suse.com
- Update to 2.6.34-rc5-git8.
  - Eliminated 1 patch.
* Wed Apr 28 2010 trenn@suse.de
- patches.xen/xen-fix_trace_power.patch: x86 cpufreq: Make
  trace_power_frequency cpufreq driver independent (none).
* Wed Apr 28 2010 mmarek@suse.cz
- Disable CONFIG_FIRMWARE_IN_KERNEL in all configs, we start udev
  early enough in the initrd.
* Wed Apr 28 2010 trenn@suse.de
- patches.fixes/acpi-cpufreq_fix_cpu_any_notification.patch:
  acpi-cpufreq: Fix CPU_ANY CPUFREQ_{PRE,POST}CHANGE notification
  (none).
- patches.trace/x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  x86 cpufreq: Make trace_power_frequency cpufreq driver
  independent (none).
* Wed Apr 28 2010 trenn@suse.de
- Update config files.
  Unify X86_MSR and X86_CPUID configs:
  - CONFIG_X86_CPUID=m
  - CONFIG_X86_MSR=y
  for all i386 and x86_64 flavors.
* Mon Apr 26 2010 jeffm@suse.com
- Disabled CONFIG_TUNE_CELL on ppc64 (bnc#599045)
* Mon Apr 26 2010 jeffm@suse.com
- Enabled CONFIG_FIREWIRE (bnc#586172)
  - CONFIG_IEEE1394 is still enabled but deprecated.
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp_wmi_add_media_key.patch: x86 platform drivers:
  hp-wmi Add media key 0x20e8 (bnc#598059).
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp-wmi_detect_keys.patch: x86 platform drivers:
  hp-wmi Reorder event id processing (bnc#598059).
- patches.fixes/hp_wmi_catch_unkown_event_key_codes.patch: x86
  platform drivers: hp-wmi Catch and log unkown event and key
  codes correctly (bnc#598059).
- patches.fixes/hp_wmi_use_prefix_string.patch: x86 platform
  drivers: hp-wmi Use consistent prefix string for messages
  (bnc#598059).
* Thu Apr 22 2010 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: Fix slab.h vs slab_def.h
  include ordering in kerntypes.c
* Thu Apr 22 2010 mmarek@suse.cz
- rpm/kernel-*.spec.in: Provide %%name = %%version-%%source_rel in
  all spec files (bnc#598453).
* Thu Apr 22 2010 tiwai@suse.de
- Update config files: Fix remaining CONFIG_LEDS_CLASS=m
* Thu Apr 22 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  Refresh.  Fix dependency with LED class.
- Update config files.
* Wed Apr 21 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  input: Add LED support to Synaptics device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/input-Add-support-of-Synaptics-Clickpad-device:
  input: Add support of Synaptics Clickpad device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/synaptics-hp-clickpad: Delete.
* Wed Apr 21 2010 jeffm@suse.com
- Update to  2.6.34-rc5.
  - Eliminated 1 patch.
* Tue Apr 20 2010 jack@suse.de
- patches.fixes/novfs-LFS-initialization: fs: novfs: Initialize
  super-block with standard macros.
- patches.fixes/novfs-return-ENOTEMPTY-when-deleting-nonempty-dir:
  fs: novfs: Return ENOTEMPTY when tyring to delete a non-empty
  folder (bnc#583964).
* Mon Apr 19 2010 jeffm@suse.de
- patches.fixes/x86-apbt-conditionally-register-cpu-hp-notifier-for-apbt:
  x86/apbt: conditionally register cpu hp notifier for apbt
  (bko#15786).
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, rpm/old-packages.conf:
  Obsolete kernel-vmi-base by kernel-pae-base (bnc#594271).
- commit a48fbdf
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/mkspec, rpm/old-packages.conf: Explicitly list ppc64 flavors that
  obsolete kernel-kdump.
- commit 0a4f75b
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/old-packages.conf: s390(x) provides/obsoletes not needed anymore.
- commit 0e039b7
* Thu Apr 15 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc4 and c/s 1011.
- patches.xen/xen-netfront-ethtool: netfront: ethtool -i does
  not return info about xennet driver (bnc#591179).
- patches.xen/xen-no-reboot-vector: eliminate REBOOT_VECTOR.
- patches.xen/xen-x86_64-kern_addr_valid: x86-64:
  kern_addr_valid() must not walk page tables mapping hypervisor
  space (bnc#591371).
- Update Xen config files.
- supported.conf: drivers/xen/evtchn.ko is supported.
* Thu Apr 15 2010 teheo@suse.de
- patches.fixes/block-blk_abort_request-lock-fix: libata/SCSI:
  fix locking around blk_abort_request() (bnc#585927).
* Wed Apr 14 2010 jeffm@suse.de
- Update to 2.6.34-rc4.
  - Eliminated 3 patches.
* Tue Apr 13 2010 mmarek@suse.cz
- Update vanilla config files.
* Tue Apr 13 2010 tiwai@suse.de
- patches.suse/bootsplash-console-fix: Fix rendering on linux
  console with bootsplash (bnc#595657,bnc#594209).
* Tue Apr 13 2010 agraf@suse.de
- Update config files to disable KVM on PPC also for ppc/ppc64.
* Tue Apr 13 2010 teheo@suse.de
- Update config files to disable CONFIG_DEBUG_BLOCK_EXT_DEVT which was
  enabled by 5246824c to ease testing userland handling of ext devt.
* Mon Apr 12 2010 jslaby@suse.de
- patches.fixes/hibernation-fix-s2disk.patch: PM / Hibernate:
  user.c, fix SNAPSHOT_SET_SWAP_AREA handling (bko#15728).
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-dentry-cache-limit.patch: novfs: Remove
  dcache count restricting code (bnc#576026).
* Mon Apr 12 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Refresh (bnc#588458).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: Fix issue on
  32-bit systems.
* Fri Apr  9 2010 knikanth@suse.de
- patches.fixes/loop-update-mtime.patch: loop: Update mtime when
  writing using aops (bnc#590738).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv:
  reiserfs: Fix permissions on .reiserfs_priv (bnc#593906
  CVE-2010-1146).
* Thu Apr  8 2010 agraf@suse.de
- Update PPC config files to disable KVM on PPC. It's not ready yet.
  Please enable it again as soon as we hit 2.6.35.
* Wed Apr  7 2010 jengelh@medozas.de
- Add config/sparc64/net that is light on size. For netbooting,
  both the kernel and initrd must fit into 10MB.
* Wed Mar 31 2010 jeffm@suse.de
- Updated sparc64 config.
* Wed Mar 31 2010 jeffm@suse.de
- Update to 2.6.34-rc3.
* Wed Mar 31 2010 mmarek@suse.cz
- doc/README.SUSE: Update some obsolete information.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix path to kernel source.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/configtool.pl, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Add support for custom config options
  in config.addon.tar.bz2. This tarball is expected to have the
  same layout as config.tar.bz2 and the config options listed there
  take precedence over config.tar.bz2.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generate the chmod +x line automatically.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh:
  Generate the Source: lines from kernel-source.spec.in.
* Tue Mar 30 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: reiserfs:
  Remove 2 TB file size limit (bnc#592100).
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generated the NoSource and %%setup lines automatically from the
  preamble.
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Provide $pkg = %%version-%%source_rel
  in kernel-devel and kernel-source-vanilla.
* Mon Mar 29 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-locking-BUG-during-mount-failure:
  reiserfs: Fix locking BUG during mount failure (bnc#591807).
* Mon Mar 29 2010 jeffm@suse.de
- Disabled MAX63XX_WATCHDOG on s390.
* Mon Mar 29 2010 jeffm@suse.de
- Update to 2.6.34-rc2-git3.
  - Eliminated 1 patch.
  - Fixed ps3 config.
* Mon Mar 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc2 and c/s 1007.
- Update config files.
- config.conf: Re-enable Xen configs.
- patches.xen/xen-floppy: Xen: improve floppy behavior
  (bnc#584216).
- patches.xen/xen-vscsi-module-alias: allow pv scsi hba driver
  to be loaded automatically.
- patches.xen/xen-vusb-module-alias: allow pv usb hcd driver to
  be loaded automatically (bnc#584213).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.fixes/hid-fix-gyration-oops.patch: HID: fix oops in
  gyration_event() (bnc#589329).
* Fri Mar 26 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579).
* Thu Mar 25 2010 jeffm@suse.de
- patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len:
  powerpc: fix handling of strnlen with zero len (bnc#582681).
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/lpfc-add-raywire-id: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/linux-2.6.29-kms-after-sata.patch: Refresh.
* Tue Mar 23 2010 jeffm@suse.de
- patches.fixes/do_anonymous_page-race: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/libata-prefer-over-ide: Delete.
- patches.drivers/libata-ahci-aspire-3810t-noncq: Delete.
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: Delete.
- patches.suse/block-add-mangle-devt-switch: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/apm_setup_UP.diff: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: Delete.
- patches.arch/ppc-efika-mpc52xx-ac97.patch: Delete.
- patches.arch/ppc-efika-psc-console-autodetection.patch: Delete.
- patches.suse/suse-ppc32-mol-BIT: Delete.
- patches.suse/suse-ppc32-mol-get-property: Delete.
- patches.suse/suse-ppc32-mol-handle-mm-fault: Delete.
- patches.suse/suse-ppc32-mol-ioctl: Delete.
- patches.suse/suse-ppc32-mol-kbuild.patch: Delete.
- patches.suse/suse-ppc32-mol-semaphore: Delete.
- patches.suse/suse-ppc32-mol-sheep: Delete.
- patches.suse/suse-ppc32-mol.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/dlm-enable-debug.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/ds1682-build-fix: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/kvm-as-kmp: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-fix-incompatible-pointer-type-warning:
  xfs/dmapi: fix incompatible pointer type warning.
* Mon Mar 22 2010 jeffm@suse.de
- Updated to 2.6.34-rc2.
  - Eliminated 4 patches.
* Fri Mar 19 2010 jbohac@suse.cz
- set CONFIG_IPV6=y for all flavours (bnc#561611)
* Thu Mar 18 2010 jeffm@suse.de
- Refreshed patch series.
* Wed Mar 17 2010 jeffm@suse.de
- Updated to 2.6.34-rc1-git6.
  - Eliminated 8 patches.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove Obsoletes: for 10.3 KMPs.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Move Obsoletes: msi-wmi-kmp to the
  sle11-ga group and make the comment more explanatory.
* Tue Mar 16 2010 trenn@suse.de
- rpm/kernel-binary.spec.in:
  bnc#587578
* Thu Mar 11 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Thu Mar 11 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  Fix unintialized variable. Refresh.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/gpio/max730x, max7301 now
  depends on it.
* Wed Mar 10 2010 jeffm@suse.de
- Enabled CONFIG_DRM_RADEON_KMS; Matching KMS-enabled X.org has
  been committed to Factory.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: powerpc:
  kvm build failure workaround.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/i2c/i2c-smbus, i2c-parport
  now depends on it.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: the dwarfextract package has been
  dropped from Factory.
* Wed Mar 10 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Mar 10 2010 jdelvare@suse.de
- supported.conf: Add hwmon/ams back.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix symsets for non-split kernels.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add symsets.pl to the src.rpm.
* Wed Mar 10 2010 jeffm@suse.de
- Updated to 2.6.34-rc1.
  - Eliminated 36 patches.
  - Xen is disabled
  - Added new doc/config-options.changes to document configuration
    changes.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/old-packages.conf: Obsolete kernel-vmi by kernel-default.
- rpm/kernel-module-subpackage: Also obsolete vmi KMPs.
- commit bf55479
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package symsets in the -devel package.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides: Do not generate ksym(...) provides.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides, rpm/symsets.pl: Generate symsets again
  (bnc#582907).
* Fri Mar  5 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  xfs: Non-blocking inode locking in IO completion (bnc#568319).
* Fri Mar  5 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: split devel files and full source
  into two rpms, of which only the former is really required for
  KMP building
* Fri Mar  5 2010 jengelh@medozas.de
- add configs/sparc64/default
* Wed Mar  3 2010 tonyj@suse.de
- patches.trace/powerpc-rename-irq-tracing: should have been deleted by
  previous commit
* Wed Mar  3 2010 tonyj@suse.de
- remove perfmon2 patches
* Wed Mar  3 2010 tonyj@suse.de
- Remove lttng-instrumentation patches, they have been removed from
  SLE11SP1
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Tue Mar  2 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33 and c/s 1003.
- patches.xen/xen-clockevents: replace Xen's custom time handling
  with such using GENERIC_CLOCKEVENTS infrastructure.
- Update Xen config files.
* Tue Mar  2 2010 nfbrown@suse.de
- patches.fixes/sunrpc-monotonic-expiry: sunrpc: use monotonic
  time in expiry cache (bnc#578668).
* Thu Feb 25 2010 jeffm@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: Obsolete.
* Thu Feb 25 2010 mmarek@suse.cz
- Drop include of generated/autoconf.h in our patches, it's not
  needed since 2.6.15:
- patches.suse/novfs-client-module: Refresh.
- patches.suse/s390-Kerntypes.diff: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
* Thu Feb 25 2010 teheo@suse.de
- scripts/run_oldconfig.sh doesn't update ppc/vanilla for some reason.
  Do it manually.
* Thu Feb 25 2010 teheo@suse.de
- ppc explicitly sets CONFIG_LEDS_TRIGGER_IDE_DISK.  Run
  scripts/run_oldconfig.sh to fix configs up.
* Thu Feb 25 2010 teheo@suse.de
- Drop CONFIG_IDE from all configs.
* Thu Feb 25 2010 jeffm@suse.com
- patches.xen/xen3-patch-2.6.33-rc8-final: Build fix for the
  2.6.33-final update.
* Wed Feb 24 2010 jeffm@suse.de
- Updated to 2.6.33-final.
  - Eliminated 4 patches.
* Wed Feb 24 2010 jeffm@suse.de
- patches.rpmify/ftrace-fix-ftrace_event_call-alignment-for-use-with-gcc-4-5:
  ftrace: fix ftrace_event_call alignment for use with gcc 4.5
  (bnc#582222).
* Wed Feb 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc8 and c/s 997.
- patches.xen/xen-x86-time-per-cpu: fold per-CPU accounting data
  into a structure.
- patches.xen/xen-x86-xtime-lock: reduce contention on xtime_lock
  (bnc#569014, bnc#571041, bnc#571769, bnc#572146).
* Wed Feb 24 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: use macros in a few more places
* Tue Feb 23 2010 jack@suse.de
- patches.fixes/novfs-fix-inode-uid: novfs: Get proper UID when
  looking up inode (bnc#486997).
- patches.fixes/novfs-incorrect-filesize-fix: novfs: novfs
  reports incorrect file size (bnc#426536).
- patches.fixes/novfs-truncate-fix: novfs: Fixes corruption of
  OO documents on NSS Volumes (bnc#508259).
* Sun Feb 21 2010 jengelh@medozas.de
- use standard short options in tar commands
* Wed Feb 17 2010 nfbrown@suse.de
- patches.fixes/nfs-find-crash: Fix potential oops when running
  find on an NFS mount. (bnc#573107).
* Tue Feb 16 2010 jeffm@suse.com
- Set CONFIG_LSM_MMAP_MIN_ADDR=4096 to allow qemu to emulate
  other architectures properly (bnc#574654).
* Tue Feb 16 2010 jeffm@suse.com
- Update to 2.6.33-rc8.
  - Eliminated 1 patch.
* Mon Feb 15 2010 rgoldwyn@suse.de
- patches.fixes/novfs-err_ptr-fix.diff: Oops in novfs:unlink_local
  (bnc#569071).
* Fri Feb 12 2010 trenn@suse.de
- Update config files.
  Enable p4_clockmod for i386 desktop
  While this is broken by design it allows to remove clocking
  limits from the vendor on e.g. eeepc 701
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/taskstats-alignment: delayacct: align to 8 byte
  boundary on 64-bit systems (bnc#578065).
* Fri Feb 12 2010 trenn@suse.de
- patches.fixes/acpi_fix_no_critical_tp.patch: ACPI thermal:
  Don't invalidate thermal zone if critical trip point is bad
  (bnc#531547).
- patches.fixes/acpi_pci_hot_plug_sanity_checks.patch: ACPI:
  acpi_bus_{scan,bus,add}: return -ENODEV if no device was found
  (bnc#531547).
- patches.fixes/acpi_thermal_check_trip_points.patch: ACPI
  thermal: Check for thermal zone requirement (bnc#531547).
* Fri Feb 12 2010 jdelvare@suse.de
- supported.conf: saa7111 and saa7114 are gone.
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  kdb: fix kdb_cmds to include the arch common macro (bnc#578421).
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-handle-nonexistance-keyboard-controller: kdb:
  handle nonexistance keyboard controller (bnc#578051).
* Wed Feb 10 2010 gregkh@suse.de
- patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch: dvb:
  l64781.ko broken with gcc 4.5.
* Tue Feb  9 2010 jeffm@suse.com
- patches.apparmor/apparmor-check-for-network-in-interrupt-and-work-around:
  apparmor: check for network in interrupt and work around
  (bnc#492961, bln#350789).
* Tue Feb  9 2010 jeffm@suse.com
- Update to 2.6.33-rc7.
  - Eliminated 1 patch.
* Tue Feb  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-66-idt-hp-mute-led-fix-polarity:
  ALSA: hda - Fix default polarity of mute-LED GPIO on 92HD83x/88x
  codecs (bnc#578190).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-63-idt-hp-mute-led-detect:
  ALSA: hda - Detect HP mute-LED GPIO setup from GPIO counts
  (bnc#577927).
- patches.drivers/alsa-sp1-hda-64-idt-hp-mute-led-cleanup: ALSA:
  hda - Merge HP mute-LED status callback on both IDT 92HD7x
  and 8x codecs (bnc#577927).
- patches.drivers/alsa-sp1-hda-65-idt-hp-mute-led-cleanup2:
  ALSA: hda - Remove static gpio_led setup via model (bnc#577927).
* Fri Feb  5 2010 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: Delete from repo and series.conf.
  Back to 32bytes lvb length for clvm (bnc#573460).
* Fri Feb  5 2010 duwe@suse.de
- Update config files: Compile IBM_BSR into kernel, not as module.
  (ppc only, bnc#572381)
* Fri Feb  5 2010 duwe@suse.de
- patches.arch/ppc-pseries-ncpus-1: powerpc: Add static fields
  to ibm,client-architecture call (bnc#570909).
- patches.arch/ppc-pseries-ncpus-2: powerpc/pseries: Pass more
  accurate number of supported cores to firmware (bnc#570909).
* Fri Feb  5 2010 coly.li@suse.de
- disable patches.suse/64bytes_lvb_len.diff in series.conf
* Thu Feb  4 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: Remove the previous
  hack and set STRIP_KEEP_SYMTAB='*/vmlinux-*' instead to avoid
  stripping symbols from the ppc vmlinux image (bnc#572148).
* Thu Feb  4 2010 knikanth@suse.de
- patches.fixes/dm-stripe-zero-stripes: dm-stripe: return -EINVAL
  if stripe count is zero (bnc#576312).
* Thu Feb  4 2010 npiggin@suse.de
- Disable patches.suse/files-slab-rcu.patch.
* Thu Feb  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete iwlagn-2-6-27-kmp
  (bnc#559533).
* Thu Feb  4 2010 tiwai@suse.de
- supported.conf: mark snd-wss-lib unsupported
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-61-add-idt92hd88x-support2:
  ALSA: hda - Adding support for another IDT 92HD83XXX codec
  (bnc#569354).
* Wed Feb  3 2010 jbohac@suse.cz
- supported.conf: marked em_cmp supported (bnc#568130)
* Wed Feb  3 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: automatically install a matching
  - devel package if kernel-source is installed.
* Wed Feb  3 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc6 and c/s 989.
- patches.xen/xen-netback-generalize: Netback: Generalize
  static/global variables into 'struct xen_netbk'.
- patches.xen/xen-netback-kernel-threads: Use Kernel thread to
  replace the tasklet.
- patches.xen/xen-netback-multiple-tasklets: Netback:
  Multiple tasklets support.
* Tue Feb  2 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: the message about crashed kernel
  doesn't make sense any more with CONFIG_CRASH_DUMP enabled by
  default (bnc#575884).
* Sat Jan 30 2010 jeffm@suse.com
- Update to 2.6.33-rc6.
  - Eliminated 12 patches.
* Sat Jan 30 2010 jeffm@suse.com
- patches.rpmify/hugetlbfs-fix-section-mismatches: Removed __init
  from hugetlb_sysfs_add_hstate instead of adding it elsewhere.
* Sat Jan 30 2010 jslaby@suse.de
- patches.suse/kdb-common: Fix hid crash (bnc#570591)
* Fri Jan 29 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-60-add-idt92hd88x-support: ALSA:
  hda - Add support for IDT 92HD88 family codecs (bnc#569354).
* Fri Jan 29 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  Update patch-mainline tag.
* Fri Jan 29 2010 jbenc@suse.cz
- Update config files: fixed vanilla configs.
* Thu Jan 28 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-59-idt92hd83xxx-hp-mute-led: ALSA:
  hda - Add mute LED check for HP laptops with IDT 92HD83xxx codec
  (bnc#569354).
* Thu Jan 28 2010 jbeulich@novell.com
- patches.suse/supported-flag: Fix -ec2 build.
- patches.suse/supported-flag-enterprise: Refresh.
- patches.xen/xen3-patch-2.6.33-rc3: Fix ia64 build.
* Thu Jan 28 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc5 and c/s 987.
- config.conf: Re-enable Xen.
- Update config files.
* Thu Jan 28 2010 jbenc@suse.cz
- Update config files: enabled CONFIG_CFG80211_WEXT to keep backward
  user space compatibility and enabled few wireless drivers.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: Add support for an additional series file in
  patches.addon/series, this will be applied after the main series.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: put the patch loops from kernel-binary.spec.in
  and kernel-source.spec.in to one place.
* Wed Jan 27 2010 jeffm@suse.de
- Deleted 28 unused patches.
* Wed Jan 27 2010 jeffm@suse.com
- Update config files.
* Wed Jan 27 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  pci: fix nested spinlock hang in aer_inject (bnc#573578).
* Wed Jan 27 2010 mmarek@suse.cz
- Update config files: disable generic_serial users.
- patches.drivers/reenable-generic_serial: Delete.
- rpm/generic_serial-blacklist: Delete (bnc#569676).
* Wed Jan 27 2010 jengelh@medozas.de
- remove patches.suse/netfilter-ipv4options [bnc#490142]
* Wed Jan 27 2010 jeffm@suse.com
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: Refresh.
* Tue Jan 26 2010 knikanth@suse.de
- supported.conf: Fix misspelt dm-region-hash and mark it supported
  correctly (bnc#565962)
* Mon Jan 25 2010 gregkh@suse.de
- Update to 2.6.32.6
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/8250_pnp-wacom-add
  - patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch
  - patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch
  - patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch
* Mon Jan 25 2010 jeffm@suse.com
- supported.conf: Added sparse_keymap (eeepc_laptop depends on it)
* Mon Jan 25 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: slab -
  handle memoryless nodes V2a (bnc#436025, bnc#570492).
* Mon Jan 25 2010 jeffm@suse.com
- Updated to 2.6.33-rc5.
  - Eliminated 2 patches.
* Mon Jan 25 2010 trenn@suse.de
- Update config files.
- patches.arch/x86_mce_intel_decode_physical_address.patch: x86,
  mce: Xeon75xx specific interface to get corrected memory error
  information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  x86, mce: Xeon75xx specific interface to get corrected memory
  error information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
  (bnc#573380, fate#307738).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Mon Jan 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-57-cx5051-toshiba-quirk:
  ALSA: hda - Add support for Toshiba Satellite M300
  (bnc#492233,bnc#565904).
- patches.drivers/alsa-sp1-hda-58-cx5051-lenovo-mute-fix: ALSA:
  hda - Change headphone pin control with master volume on cx5051
  (bnc#573050).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_enable_tsc_sync_check_again.patch: x86:
  Reenable TSC sync check at boot, even with NONSTOP_TSC
  (bnc#573379).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch:
  x86: Set hotpluggable nodes in nodes_possible_map (bnc#567216).
- patches.arch/x86_node_hotplug_parse_srat_fix.patch: Delete.
* Mon Jan 25 2010 trenn@suse.de
- supported.conf:
  Add mce-inject and hwpoison-inject so that Intel can easier test
  this. As these are debug drivers, they might get reverted from
  support.conf again if kernel-extra package gets fixed for SLES,
  only seem to exist for SLED because "NCC is not yet working for SP1".
  (bnc#572552).
* Sat Jan 23 2010 bphilips@suse.de
- patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch: tg3:
  updates from f4188d to ba5b0bf (bnc#573237).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-irq-check-move_in_progress-before-freeing-the-vector-mapping.patch:
  x86, irq: Check move_in_progress before freeing the vector
  mapping (bnc#558247).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch:
  x86, apic: use logical flat for systems with <= 8 logical cpus
  (bnc#567510).
- patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch:
  x86: Revert "apic: Use logical flat on intel with <= 8 logical
  cpus" (bnc#567510).
* Sat Jan 23 2010 gregkh@suse.de
- Update to 2.6.32.5:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-54-alc861-capture-fix
  - patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard
  - patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
  - patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch
* Fri Jan 22 2010 tonyj@suse.de
- Update config files: drop UTRACE from default s390 configs
  as per communication from Ihno.
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch:
  x86, msr/cpuid: Register enough minors for the MSR and CPUID
  drivers (bnc#572720).
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch:
  SCSI: enclosure: fix oops while iterating enclosure_status array
  (bnc#572818).
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  Delete.
* Fri Jan 22 2010 duwe@suse.de
- Update config files.
- patches.arch/ppc-extended_h_cede-update-to-mainline: Incremental
  patch set to sync H_CEDE with actual mainline (bnc#550447,
  FATE#307059).
* Fri Jan 22 2010 trenn@suse.de
- Update config files.
  Add DMAR to -trace flavor -> get in sync with -default
* Fri Jan 22 2010 hare@suse.de
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Re-save PCI state after EEH recovery (bnc#570233).
* Fri Jan 22 2010 jjolly@suse.de
- patches.arch/s390-06-01-zfcp-introduce-bsg-timeout-callback.patch:
  zfcp: introduce BSG timeout callback (BNC#572659).
- patches.arch/s390-06-02-zfcp-set-hw-timeout-requested-by-bsg.patch:
  zfcp: set HW timeout requested by BSG request (BNC#572659).
* Fri Jan 22 2010 bphilips@suse.de
- patches.drivers/netxen-8f9b3f-to-c651a8.patch: netxen: 8f9b3f
  to c651a8 (bnc#572832).
* Fri Jan 22 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh to
  newest version of patch.
* Thu Jan 21 2010 astarikovskiy@suse.de
- supported.conf: added power_meter driver (FATE #306959).
* Thu Jan 21 2010 tonyj@suse.de
- config.conf: add -trace flavor for s390* at Ihno's request
- Add more tracers to existing ppc64 trace config at IBM request
  Both related to FATE# 307051.
- patches.trace/ftrace-framepointer.diff: Delete.
* Thu Jan 21 2010 hare@suse.de
- patches.fixes/scsi-fc-class-allow-LLD-bsg-timeout:
  scsi_transport_fc: Allow LLD to reset FC BSG timeout
  (bnc#572658).
* Thu Jan 21 2010 jbeulich@novell.com
- patches.xen/xen-privcmd-mmap-batch-clear: privcmd: mmapbatch-v2
  fixes.
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5-update: lpfc update to 8.3.5
  (bnc#572427).
- patches.drivers/lpfc-8.3.5.3-update: lpfc driver update to
  8.3.5.3 (bnc#572427).
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh. More updates and
  clean-up by Egbert (bnc#570082)
* Wed Jan 20 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
* Wed Jan 20 2010 jslaby@suse.de
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
  (change firmwares in makefile)
* Wed Jan 20 2010 jslaby@suse.de
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: Refresh.
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch: Refresh.
* Wed Jan 20 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.4 and c/s 984.
- Update Xen config files.
* Wed Jan 20 2010 bphilips@suse.de
- patches.drivers/bnx2i-backport-from-v2.6.32-to-45ca38e.patch:
  bnx2i: Backport from v2.6.32 to 45ca38e (bnc#564640).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  bnx2x: backports v2.6.32 to af901ca (bnc#564638).
- patches.drivers/cnic-backport-from-v2.6.32-4e9c4f.patch: cnic:
  backport from v2.6.32-4e9c4f (bnc#564640).
* Wed Jan 20 2010 gregkh@suse.de
- Update config files.  2.6.32.4 changed one of them.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fixed the text area
  calculation, and added the upscaling (bnc#570082).
* Tue Jan 19 2010 jeffm@suse.com
- Updated to 2.6.33-rc4-git7.
  - Eliminated 4 patches.
* Tue Jan 19 2010 gregkh@suse.de
- Patch refresh for fuzz due to upstream -stable additions.
* Tue Jan 19 2010 gregkh@suse.de
- Update to 2.6.32.4
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y
  - patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix
  - patches.fixes/audit_untag_chunk.patch
  - patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch
  - patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1
* Tue Jan 19 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix: ALSA: hda -
  Fix parsing pin node 0x21 on ALC259 (bnc#571879).
- patches.drivers/alsa-sp1-hda-56-realtek-eapd-fix: ALSA: hda -
  Turn on EAPD only if available for Realtek codecs (bnc#571879).
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fix the hang-up with
  resolution changes (bnc#570082)
* Tue Jan 19 2010 jkosina@suse.cz
- supported.conf: added aesni-intel (bnc#566618 FATE#304209).
* Tue Jan 19 2010 jkosina@suse.cz
- Update config files: set CONFIG_CRYPTO_HMAC=y to avoid
  regression from SLE11 (bnc#571501).
* Tue Jan 19 2010 jack@suse.de
- patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch:
  reiserfs: truncate blocks not used by a write (bnc#483375).
* Mon Jan 18 2010 jeffm@suse.de
- patches.suse/smtnice-disable: Delete (obsolete).
* Mon Jan 18 2010 jeffm@suse.com
- Disabled custom ACPI table loading from initramfs again.
* Mon Jan 18 2010 jeffm@suse.com
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Mon Jan 18 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix.patch:
  x86/mm/srat_64.c: nodes_parsed should include all nodes detected
  by ACPI (bnc#567140).
* Mon Jan 18 2010 hare@suse.de
- patches.fixes/aic79xx-null-scb-in-nonpkt-busfree: aic79xx: check
  for non-NULL scb in ahd_handle_nonpkt_busfree (bnc#542568).
* Mon Jan 18 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh to fix 60 second delay. (bnc#568271)
* Sat Jan 16 2010 tonyj@suse.de
- patches.fixes/audit_untag_chunk.patch: fix braindamage in
  audit_tree.c untag_chunk() (bnc#556282).
* Sat Jan 16 2010 rjw@suse.de
- patches.xen/xen-x86-rename-display_cacheinfo-to-cpu_detect_cache_sizes.patch:
  x86: Rename display_cacheinfo() to cpu_detect_cache_sizes().
* Fri Jan 15 2010 gregkh@suse.de
- Update config files.
- patches.drivers/vmw_pvscsi-scsi-driver-for-vmware-s-virtual-hba.patch:
  vmw_pvscsi: SCSI driver for VMware's virtual HBA.
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard:
  HID: add device IDs for new model of Apple Wireless Keyboard
  (bnc#568231).
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 trenn@suse.de
- patches.suse/kdb_dont_touch_i8042_early.patch: Avoid early
  hang when i8042 controller is missing (bnc#528811).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/remount-no-shrink-dcache: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/smtnice-disable: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 mfasheh@suse.com
- patches.fixes/Ocfs2-Let-ocfs2-support-fiemap-for-symlink-and-fast-.patch:
  Ocfs2: Let ocfs2 support fiemap for symlink and fast symlink..
- patches.fixes/Ocfs2-Should-ocfs2-support-fiemap-for-S_IFDIR-inode.patch:
  Ocfs2: Should ocfs2 support fiemap for S_IFDIR inode?.
- patches.fixes/ocfs-stop-using-do_sync_mapping_range.patch:
  ocfs: stop using do_sync_mapping_range.
- patches.fixes/ocfs2-Add-reflinked-file-s-inode-to-inode-hash-earil.patch:
  ocfs2: Add reflinked file's inode to inode hash eariler..
- patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch:
  ocfs2: Find proper end cpos for a leaf refcount block..
- patches.fixes/ocfs2-Set-i_nlink-properly-during-reflink.patch:
  ocfs2: Set i_nlink properly during reflink..
- patches.fixes/ocfs2-always-include-acl-support.patch: ocfs2:
  Always include ACL support.
- patches.fixes/ocfs2-cluster-Make-fence-method-configurable-v2.patch:
  ocfs2/cluster: Make fence method configurable - v2.
- patches.fixes/ocfs2-devel-remove-redundant-OCFS2_MOUNT_POSIX_ACL-c.patch:
  ocfs2-devel: remove redundant OCFS2_MOUNT_POSIX_ACL check
  in ocfs2_get_acl_nolock().
- patches.fixes/ocfs2-explicit-declare-uninitialized-var-in-user_clu.patch:
  ocfs2: explicit declare uninitialized var in
  user_cluster_connect().
- patches.fixes/ocfs2-make-acl-use-the-default.patch: ocfs2:
  Make acl use the default.
- patches.fixes/ocfs2-refcounttree.c-cleanup.patch: ocfs2:
  refcounttree.c cleanup..
- patches.fixes/ocfs2-replace-u8-by-__u8-in-ocfs2_fs.h.patch:
  ocfs2: replace u8 by __u8 in ocfs2_fs.h.
- patches.fixes/ocfs2-return-EAGAIN-instead-of-EAGAIN-in-dlm.patch:
  ocfs2: return -EAGAIN instead of EAGAIN in dlm.
- patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch: ocfs2:
  Set MS_POSIXACL on remount.
- patches.fixes/ocfs2-trivial-Use-le16_to_cpu-for-a-disk-value-in-xa.patch:
  ocfs2/trivial: Use le16_to_cpu for a disk value in xattr.c.
- patches.fixes/ocfs2-trivial-Use-proper-mask-for-2-places-in-hearbe.patch:
  ocfs2/trivial: Use proper mask for 2 places in hearbeat.c.
- patches.suse/fiemap-Add-new-extent-flag-FIEMAP_EXTENT_SHARED.patch:
  fiemap: Add new extent flag FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-Use-FIEMAP_EXTENT_SHARED.patch: ocfs2:
  Use FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch:
  x86: Limit number of per cpu TSC sync messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Limit-the-number-of-processor-bootup-messages.patch:
  x86: Limit the number of processor bootup messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-CPU-cache-size-output-for-non-Intel-too.patch:
  x86: Remove CPU cache size output for non-Intel too (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-enabling-x2apic-message-for-every-CPU.patch:
  x86: Remove enabling x2apic message for every CPU (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-the-CPU-cache-size-printks.patch: x86:
  Remove the CPU cache size printk's (bnc#564618, FATE#306952).
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  x86, cpu: mv display_cacheinfo -> cpu_detect_cache_sizes
  (bnc#564618, FATE#306952).
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  x86: ucode-amd: Load ucode-patches once and not separately of
  each CPU (bnc#564618, FATE#306952).
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch:
  sched: Limit the number of scheduler debug messages (bnc#564618,
  FATE#306952).
- patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch:
  timers, init: Limit the number of per cpu calibration bootup
  messages (bnc#564618, FATE#306952).
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/add-initramfs-file_read_write: Build fix.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-enterprise: Refresh.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-sysfs: Properly report proprietary modules
* Thu Jan 14 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: initramfs: add
  initramfs_{read,write} (bnc#568120).
- Re-enabled custom ACPI table loading from initramfs.
* Thu Jan 14 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_CPU_FREQ_DEBUG as requested by HP.
  This one adds conditional printks which can be enabled via:
  cpufreq.debug=7
* Thu Jan 14 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-54-alc861-capture-fix: ALSA: hda -
  Fix missing capture mixer for ALC861/660 codecs (bnc#567340).
* Thu Jan 14 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: really fix ppc
  symbol provides.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/UV-Expose-irq_desc-node-in-proc.patch: Expose the
  irq_desc node as /proc/irq/*/node. (bnc#566745, fate#306952).
* Thu Jan 14 2010 bphilips@suse.de
- patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch:
  dmfe/tulip: Let dmfe handle DM910x except for SPARC on-board
  chips (bnc#537016).
* Thu Jan 14 2010 jkosina@suse.cz
- patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch:
  crypto: testmgr - Fix complain about lack test for internal
  used algorithm (bnc#568278 FATE#306883).
* Wed Jan 13 2010 jeffm@suse.com
- Update to 2.6.33-rc4.
  - Eliminated patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
* Wed Jan 13 2010 mmarek@suse.cz
- patches.suse/bootsplash-keep-multiple-data: Keep multiple
  splash screens for KMS (bnc#570082).
- patches.suse/bootsplash-scaler: Add bootsplash image scaler
  (bnc#570082).
* Wed Jan 13 2010 mmarek@suse.de
- rpm/kernel-binary.spec.in, rpm/find-provides: extract exported
  symbols from /boot/vmlinux before the image is stripped (affects
  ppc).
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/twl6030-fix-note_interrupt-call: Rename to patches.fixes/twl6030-fix-note_interrupt-call
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/autoconf-h-fix-locations: autoconf.h: Fix
  locations.
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: Renamed to patches.rpmify/ppc-crashdump-typefix
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  Delete.
* Tue Jan 12 2010 jeffm@suse.com
- Update config files.
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: rename to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 rjw@suse.de
- needs_update: Remove some patches that we've got through the
  upstream.
* Tue Jan 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix: ALSA:
  hda - Fix ALC861-VD capture source mixer (bnc#568305).
* Tue Jan 12 2010 jeffm@suse.com
- Update to 2.6.33-rc3-git5.
* Tue Jan 12 2010 trenn@suse.de
- patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch:
  nohz: Prevent clocksource wrapping during idle (bnc#569238).
* Tue Jan 12 2010 jack@suse.de
- patches.suse/readahead-request-tunables.patch: Update readahead
  and max_sectors tunables (bnc#548529).
* Tue Jan 12 2010 jkosina@suse.cz
- patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch:
  iTCO_wdt: Add support for Intel Ibex Peak (bnc#557081
  FATE#308591).
* Tue Jan 12 2010 tonyj@suse.de
- needs_update: remove LTT/trace patches (assigned to jbl), all had
  already been taken care of by my fwd port to 2.6.32
* Tue Jan 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Fixup compilation error.
* Tue Jan 12 2010 rjw@suse.de
- patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch:
  PCI: Always set prefetchable base/limit upper32 registers
  (bnc#569003).
* Mon Jan 11 2010 jeffm@suse.com
- Merged patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu into
  patches.arch/kvm-split-paravirt-ops-by-functionality
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/kmsg-fix-parameter-limitations to
  patches.arch/kmsg-fix-parameter-limitations
* Mon Jan 11 2010 jeffm@suse.com
- patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu:
  x86_64/ksyms: Make the native_load_gs_index export depend
  on CONFIG_PARAVIRT_CPU.
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/rt2870-fix-section-mismatches to
  patches.rpmify/rt2860-fix-section-mismatches
* Mon Jan 11 2010 jeffm@suse.de
- Updated to 2.6.33-rc3-git3.
  - Eliminated 392 patches.
  - Xen is disabled.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Update qla4xxx driver for SLES11 SP1 (bnc#556572,FATE#307128).
* Mon Jan 11 2010 jblunck@suse.de
- needs_update: Removed some patches.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-update: Update bfa driver to
  version 2.1.2.1 (bnc#561881).
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/fcoe-libfc-adds-enable-di: adds enable/disable
  for fcoe interface (bnc#562046).
- patches.fixes/fcoe-use-lld-s-wwpn-and-w: Use LLD's WWPN and
  WWNN for lport if LLD supports ndo_fcoe_get_wwn (bnc#562046).
- patches.fixes/libfc-reduce-hold-time-on: reduce hold time on
  SCSI host lock (bnc#562046).
- patches.fixes/libfc-remote-port-gets-st: remote port gets
  stuck in restart state without really restarting (bnc#562046).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: LSI mptsas2 driver
  update to 03.100.03.00 (bnc#566013).
* Mon Jan 11 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-nx-user-mappings: Delete (bnc#568741).
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/qla4xxx-lun-reset-fix: Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-ibm-174x: scsi_dh_rdac: Add
  two new IBM devices (bnc# 556159).
* Sat Jan  9 2010 jslaby@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Refresh.
- patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch:
  resource: move kernel function inside __KERNEL__ (FATE#305733).
- patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits (FATE#305733).
- patches.suse/rlim-0004-IA64-use-helpers-for-rlimits.patch:
  [IA64] use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  infiniband: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  FS: proc, switch limits reading to fops (FATE#305733).
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable (FATE#305733).
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Delete.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Delete.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Delete.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Delete.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Delete.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Delete.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Delete.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Delete.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Delete.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Delete.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Delete.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Delete.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Delete.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Delete.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
  Sync with upstream. Drop limits syscalls altogether.
* Sat Jan  9 2010 jkosina@suse.cz
- patches.apparmor/apparmor.diff: Delete, as it is unused after
  splitup into smaller patches.
* Fri Jan  8 2010 sjayaraman@suse.de
- patches.suse/SoN-23-mm-swapfile.patch: Fix up the enum declaration
  to avoid conflict due to a upstream change.
* Fri Jan  8 2010 jkosina@suse.cz
- patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch:
  quota: fix reserved space management for ordinary fs.
* Fri Jan  8 2010 gregkh@suse.de
- patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch:
  Staging: hv: fix smp problems in the hyperv core code.
* Fri Jan  8 2010 jeffm@suse.de
- Disable set,getprlimit compat syscalls on xen.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled custom ACPI table loading from initramfs until
  the scheduling while atomic issues are worked out.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled set,getprlimit syscalls until the syscall numbers
  have been officially reserved.
* Fri Jan  8 2010 jeffm@suse.com
- patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y:
  module: handle ppc64 relocating kcrctabs when
  CONFIG_RELOCATABLE=y (bnc#566243).
* Thu Jan  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.3 and c/s 974.
- Update EC2 config files.
- patches.xen/xen3-x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.xen/xen3-x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.xen/xen3-x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  Delete.
- patches.xen/xen-scsifront-block-timeout-update: Delete.
- patches.xen/xen3-x86-fix-nodac: Delete.
* Thu Jan  7 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  e1000: enhance frame fragment detection (bnc#567376,
  CVE-2009-4536).
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  e1000e: enhance frame fragment detection (bnc#567376,
  CVE-2009-4538).
* Thu Jan  7 2010 gregkh@suse.de
- Update to 2.6.32.3
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-04-03-dasd-diag-ro.patch
  - patches.drivers/alsa-sp1-hda-50-alc88x-missing-capsrc_nids
  - patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host
  - patches.fixes/scsi-ipr-fix-eeh-recovery
* Wed Jan  6 2010 rjw@suse.de
- patches.arch/x86-Force-irq-complete-move-during-cpu-offline.patch:
  x86: Force irq complete move during cpu offline (bnc#558247).
- patches.arch/x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.arch/x86-Remove-move_cleanup_count-from-irq_cfg.patch:
  x86: Remove move_cleanup_count from irq_cfg (bnc#558247).
- patches.arch/x86-Remove-unnecessary-mdelay-from-cpu_disable_common.patch:
  x86: Remove unnecessary mdelay() from cpu_disable_common()   .
- patches.arch/x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.arch/x86-Use-EOI-register-in-io-apic-on-intel-platforms.patch:
  x86: Use EOI register in io-apic on intel platforms
  (bnc#558247).
- patches.arch/x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.arch/x86-io-apic-Move-the-effort-of-clearing-remoteIRR-explicitly-before-migrating-the-irq.patch:
  x86, io-apic: Move the effort of clearing remoteIRR explicitly
  before migrating the irq (bnc#558247).
- patches.arch/x86-ioapic-Document-another-case-when-level-irq-is-seen-as-an-edge.patch:
  x86, ioapic: Document another case when level irq is seen as
  an edge (bnc#558247).
- patches.arch/x86-ioapic-Fix-the-EOI-register-detection-mechanism.patch:
  x86, ioapic: Fix the EOI register detection mechanism
  (bnc#558247).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch: PCI:
  AER: fix aer inject result in kernel oops (bnc#566619).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch:
  PCIe AER: reject aer inject if hardware mask error reporting
  (bnc#566621).
* Wed Jan  6 2010 gregkh@suse.de
- patches.xen/xen3-patch-2.6.29: Refresh due to conflicts from i915
  changes.  Ick, the xen code sucks rocks, it shouldn't be touching
  stuff here at all.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
- patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch:
  drm/i915: add i915_lp_ring_sync helper (bnc#568447).
- patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch:
  drm/i915: fix get_core_clock_speed for G33 class desktop chips
  (bnc#568447).
- patches.drivers/drm-i915-fully-switch-off-overlay-when-not-in-use.patch:
  drm/i915: fully switch off overlay when not in use (bnc#568447).
- patches.drivers/drm-i915-implement-drmmode-overlay-support-v4.patch:
  drm/i915: implement drmmode overlay support v4 (bnc#568447).
- patches.drivers/drm-i915-implement-fastpath-for-overlay-flip-waiting.patch:
  drm/i915: implement fastpath for overlay flip waiting
  (bnc#568447).
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  drm/i915: Add ACPI OpRegion support for Ironlake (bnc#568436).
* Tue Jan  5 2010 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Update to newer version
* Wed Dec 30 2009 nfbrown@suse.de
- patches.fixes/nfs-fix-NFS4ERR_FILE_OPEN-handling:
  NFS4ERR_FILE_OPEN handling in Linux/NFS (bnc#526819).
* Mon Dec 28 2009 jeffm@suse.com
- patches.fixes/dmar-fix-oops-with-no-dmar-table: dmar: Fix oops
  with no DMAR table (bnc#548108).
* Sun Dec 27 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-52-hdmi-sticky-stream-tag: ALSA:
  hda - HDMI sticky stream tag support (FATE#306783).
* Thu Dec 24 2009 rjw@suse.de
- patches.arch/xpc_first_contact_when_active.patch: X86: UV
  - xpc_make_first_contact hang due to not accepting ACTIVE
  state. (bnc#562288, fate#306952).
- patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch: x86: UV - XPC
  NULL deref when mesq becomes empty. (bnc#562288, fate#306952).
- patches.arch/xpc_introduce_xp_socket.patch: x86: UV - XPC
  needs to provide an abstraction for uv_gpa. (bnc#562288,
  fate #306952).
- patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch:
  UV - pass nasid instead of nid to gru_create_message_queue
  (bnc#562288, fate#306952).
- patches.arch/xpc_recv_msg_slots_wrap.patch: X86: UV - XPC
  receive message reuse triggers invalid BUG_ON(). (bnc#562288,
  fate#306952).
- patches.arch/xpc_uv_bios_changes.patch: x86: UV - Update XPC
  to handle updated BIOS interface. (bnc#562288, fate#306952).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561989_gru_rollup.patch: SGI GRU Updates
  (bnc#561989, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: powerpc: use min_t in
  copy_oldmem_page.
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561946_uv_irq_affinity.patch: x86: SGI UV: Fix
  irq affinity for hub based interrupts (bnc#561946, fate#306952).
- patches.arch/bug-561946_uv_move_ioapic.patch: x86, apic: Move
  SGI UV functionality out of generic IO-APIC code (bnc#561946,
  fate#306952).
- patches.arch/bug-561946_uv_use_rtc.patch: x86: UV RTC: Always
  enable RTC clocksource (bnc#561946, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly:
  fix SBA IOMMU to handle allocation failure properly
  (bnc#545367).
* Tue Dec 22 2009 jeffm@suse.com
- Enabled CONFIG_CRASH_DUMP on ppc/ppc64 (bnc#566243).
* Tue Dec 22 2009 jeffm@suse.com
- patches.fixes/scsi-ipr-fix-eeh-recovery: ipr: fix EEH recovery
  (bnc#566613).
* Sun Dec 20 2009 trenn@suse.de
- Update config files.
- patches.drivers/cpufreq_ondemand_limit_fix.patch: cpufreq:
  Fix ondemand to not request targets outside policy limits
  (fate#306746).
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver.patch:
  x86,cpufreq: Processor Clocking Control (PCC) driver
  (fate#306746).
- supported.conf:
* Sun Dec 20 2009 rjw@suse.de
- patches.arch/bug-561939_uv_bios_call_hwperf_updated.patch:
  x86, uv: Add serial number parameter to uv_bios_get_sn_info()
  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: Delete.
* Sat Dec 19 2009 jeffm@suse.com
- patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly:
  scsi_debug: scale virtual_gb with sector_size properly
  (bnc#535939).
* Sat Dec 19 2009 gregkh@suse.de
- patches.xen/xen3-fixup-xen: Refresh.  Fix up build error from
  .32.2 import
* Sat Dec 19 2009 gregkh@suse.de
- Update to 2.6.32.2
  - lots of security fixes
  - loads of bugfixes
  - other goodness
  - obsoletes:
  - patches.arch/bug-561939_bau_data_config.patch
  - patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch
  - patches.arch/s390-04-01-clear-high-regs.patch
  - patches.arch/s390-kvm-prefix.patch
  - patches.arch/s390-kvm-psw.patch
  - patches.arch/x86-fix-nodac
  - patches.arch/x86_mce_nfs-mig2
  - patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero
  - patches.fixes/uart-txen-race.patch
* Fri Dec 18 2009 jeffm@suse.com
- Update config files: CONFIG_STRICT_DEVMEM=n. It was enabled
  mistakenly in commit 3df90f9e and affects using tools like
  crash with a live system.
* Fri Dec 18 2009 gregkh@suse.de
- Update config files.
  CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT = n (bnc#565607)
* Fri Dec 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-{24..51}-*: 2.6.33-rc1 backport
  fixes for HDMI and new Realtek codecs (FATE#306783)
- Refresh Patch-mainline tags in patches.drivers/alsa-*
* Fri Dec 18 2009 jjolly@suse.de
- patches.arch/s390-05-01-netiucv-tx-bytes.patch: netiucv:
  displayed TX bytes value much too high (BNC#565612).
- patches.arch/s390-05-02-cmm-suspend.patch: cmm: free pages on
  hibernate. (BNC#565612).
- patches.arch/s390-05-03-iucv-suspend.patch: iucv: add work_queue
  cleanup for suspend (BNC#565612).
- patches.arch/s390-05-04-zfcp-work-queue.patch: zfcp: Assign
  scheduled work to driver queue (BNC#565612).
- patches.arch/s390-05-05-zfcp-fail-commands.patch: zfcp: Don't
  fail SCSI commands when transitioning to blocked fc_rport
  (BNC#565612,LTC#58541).
- patches.arch/s390-05-06-zfcp-adisc.patch: zfcp: Improve ELS
  ADISC handling (BNC#565612).
- patches.arch/s390-05-07-zfcp-fsf-errors.patch: zfcp: Update
  FSF error reporting (BNC#565612).
- patches.arch/s390-05-08-zfcp-block.diff: zfcp: Block SCSI EH
  thread for rport state BLOCKED (BNC#565612).
- patches.arch/s390-05-09-ctcm-suspend-wait.diff: ctcm: suspend
  has to wait for outstanding I/O (BNC#565612).
- patches.arch/s390-05-10-rework-tso.diff: qeth: rework TSO
  functions (BNC#565612).
- patches.arch/s390-05-11-atomic-volatile.patch: kernel: improve
  code generated by atomic operations. (BNC#565612).
- patches.arch/s390-05-12-tape-remove-fn.patch: tape: incomplete
  device removal (BNC#565612).
- patches.arch/s390-05-13-qeth-blkt-defaults.patch: qeth:
  set default BLKT settings dependend on OSA hw level
  (BNC#565612,LTC#58654).
- patches.arch/s390-05-14-dasd-dasd-enable-prefix.patch: dasd:
  enable prefix independent of pav support (BNC#565612).
- patches.arch/s390-05-15-dasd-s390dbf-strings.patch: dasd:
  remove strings from s390dbf (BNC#565612).
- patches.arch/s390-05-16-dasd-wait-lcu-setup.patch: dasd:
  let device initialization wait for LCU setup (BNC#565612).
* Fri Dec 18 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix generating /boot/Kerntypes* for
  s390/vanilla.
* Fri Dec 18 2009 nfbrown@suse.de
- patches.fixes/md-start_ro-fix: md: fix small irregularity with
  start_ro module parameter (bnc#565219).
* Fri Dec 18 2009 rjw@suse.de
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  XEN: Fix compilation after renaming of generic_irqs.
* Fri Dec 18 2009 rjw@suse.de
- patches.arch/bug-561946_rename_generic_int.patch: x86: UV RTC:
  Rename generic_interrupt to x86_platform_ipi (bnc#561946,
  fate#306952).
* Fri Dec 18 2009 mmarek@suse.cz
- patches.suse/s390-Kerntypes.diff: S390: Generate Kerntypes file.
- rpm/kernel-binary.spec.in: install /boot/Kerntypes-$version.
* Thu Dec 17 2009 jeffm@suse.com
- patches.fixes/powerpc-fix-cpu-name-in-show-cpuinfo: powerpc:
  fix cpu name in show-cpuinfo (bnc#565267).
* Thu Dec 17 2009 hare@suse.de
- patches.fixes/fc-transport-remove-BUG_ON: scsi_transport_fc:
  remove invalid BUG_ON (bnc#564479).
- patches.fixes/lpfc-ia64-hang: lpfc: fix hang on SGI ia64
  platform (bnc#564479).
- patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host:
  qla2xxx: dpc thread can execute before scsi host has been added
  (bnc#564479).
- patches.suse/fc-transport-allow-dev_loss_tmo-disable: Remove
  capping from dev_loss_tmo (bnc#492469).
* Wed Dec 16 2009 gregkh@suse.de
- Update config files.
  - fix up CONFIG_IPV6 option that was built into the kernel
    incorrectly (bnc#564357)
* Wed Dec 16 2009 jeffm@suse.com
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  acpi: Fix build when CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS is
  not defined.
* Wed Dec 16 2009 jbeulich@novell.com
- Update Xen patches to c/s 960.
- Update Xen EC2 config files.
- patches.xen/xen3-bug-561933_uv_pat_is_gru_range.patch: x86:
  UV SGI: Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.fixes/aggressive-zone-reclaim.patch: be more aggressive
  with zone reclaims (bnc#476525).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.suse/x86-mark_rodata_rw.patch: Refresh.
* Wed Dec 16 2009 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Dec 15 2009 jeffm@suse.com
- patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero:
  firewire: ohci: handle receive packets with a data length of
  zero (bnc#564712 CVE-2009-4138).
* Tue Dec 15 2009 mmarek@suse.cz
- rpm/config.sh: set OBS_PROJECT and IBS_PROJECT variables for
  osc_wrapper.
* Tue Dec 15 2009 knikanth@suse.de
- supported.conf: Mark dm-log-userspace as supported (fate#307380).
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  Fix the build failure due to previous commit.
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  sched: Fix missing sched tunable recalculation on cpu add/remove
  (bnc#560317).
- patches.fixes/sched-make-tunable-scaling-configurable: sched:
  Make tunable scaling style configurable (bnc#560317).
- patches.fixes/sched-sysctl-for-normalized-tunables:  sched:
  Update normalized values on user updates via proc (bnc#560317).
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - fix up USB options that were built into the kernel incorrectly
    (bnc#564357)
* Mon Dec 14 2009 jjolly@suse.de
- patches.arch/s390-04-01-clear-high-regs.patch: kernel:
  clear high-order bits after switching to 64-bit mode
  (BNC#563999,LTC#58088).
- patches.arch/s390-04-02-zcrypt-hrtimer.patch: zcrypt: Do not
  simultaneously schedule hrtimer (BNC#563999,LTC#58222).
- patches.arch/s390-04-03-dasd-diag-ro.patch: dasd: support DIAG
  access for read-only devices (BNC#563999,LTC#57147).
- patches.arch/s390-04-04-mm-fault-fix.patch: kernel: performance
  counter fix and page fault optimization (BNC#563999).
- patches.arch/s390-04-05-sclp-dump-indicator.patch: kernel:
  fix dump indicator (BNC#563999).
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: dasd:
  move diag kmsg to generic dasd kmsg (BNC#563999).
- patches.arch/s390-04-07-cio-fix-double-free.patch: cio: double
  free under memory pressure (BNC#563999).
- patches.arch/s390-04-08-cio-fix-dev-stall.patch: cio: device
  recovery stalls after multiple hardware events (BNC#563999).
- patches.arch/s390-04-09-cio-recover-hw-changes.patch: cio:
  device recovery fails after concurrent hardware changes
  (BNC#563999).
- patches.arch/s390-04-10-cio-fix-onoffline-failure.patch: cio:
  setting a device online or offline fails for unknown reasons
  (BNC#563999).
- patches.arch/s390-04-11-cio-error-reporting.patch: cio:
  incorrect device state after device recognition and recovery
  (BNC#563999).
- patches.arch/s390-04-12-cio-avoid-panic.patch: cio: kernel
  panic after unexpected interrupt (BNC#563999).
- patches.arch/s390-04-13-cio-internal-io.patch: cio:
  initialization of I/O devices fails (BNC#563999).
- patches.arch/s390-04-14-cio-allow-offline.patch: cio: not
  operational devices cannot be deactivated (BNC#563999).
- patches.arch/s390-04-15-cio-split-pgid.patch: cio: erratic
  DASD I/O behavior (BNC#563999).
- patches.arch/s390-04-16-cio-path-verification.patch: cio:
  DASD cannot be set online (BNC#563999).
- patches.arch/s390-04-17-cio-steal-lock.patch: cio: DASD steal
  lock task hangs (BNC#563999).
- patches.arch/s390-04-18-cio-fix-memleak-chk-dev.patch: cio:
  memory leaks when checking unusable devices (BNC#563999).
- patches.arch/s390-04-19-cio-fix-deact-dev-panic.patch: cio:
  deactivated devices can cause use after free panic (BNC#563999).
* Mon Dec 14 2009 rjw@suse.de
- patches.arch/bug-561933_uv_pat_is_gru_range.patch: x86: UV SGI:
  Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.arch/bug-561939_bau_data_config.patch: x86: SGI UV
  BAU initialization (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: x86: UV
  hardware performance counter and topology access  (bnc#561939,
  fate#306952).
- patches.arch/bug-561939_uv_gpa_is_mmr_space.patch: x86: UV -
  Introduce uv_gpa_is_mmr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_gpa_to_soc_phys_ram.patch:
  x86: UV - Introduce a means to translate from gpa ->
  socket_paddr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_ipi_macro.patch: x86: UV: Introduce
  uv_hub_ipi_value (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_mmap_low.patch: x86: SGI UV: Map
  low MMR ranges (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_cleanup.patch: x86: UV RTC:
  Clean up error handling (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_fixes.patch: x86: UV RTC:
  Fix early expiry handling  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_setup_evt.patch: x86: UV RTC:
  Add clocksource only boot option (bnc#561939, fate#306952).
- patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch:
  x86: Fix duplicated UV BAU interrupt vector (bnc#564471).
* Mon Dec 14 2009 gregkh@suse.de
- Refresh patches to be clean of fuzz
* Mon Dec 14 2009 gregkh@suse.de
- Update to 2.6.32.1
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext
  - patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects
* Mon Dec 14 2009 jjolly@suse.de
- patches.drivers/dcb-data-center-bridging-ops-s: dcb: data
  center bridging ops should be r/o (BNC#562046).
- patches.drivers/drivers-net-request_irq-remove: drivers/net:
  request_irq - Remove unnecessary leading & from second arg
  (BNC#562046).
- patches.drivers/ethtool-add-direct-attach-supp: ethtool: Add
  Direct Attach support to connector port reporting (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-al: ixgbe: Add
  support for 82599 alternative WWNN/WWPN prefix (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-ba: ixgbe: add
  support for 82599 based Express Module X520-P2 (BNC#562046).
- patches.drivers/ixgbe-add-support-for-netdev_o: ixgbe: Add
  support for netdev_ops.ndo_fcoe_get_wwn to 82599 (BNC#562046).
- patches.drivers/ixgbe-change-default-ring-size: ixgbe: change
  default ring size (BNC#562046).
- patches.drivers/ixgbe-disable-flow-control-for: ixgbe: Disable
  Flow Control for certain devices (BNC#562046).
- patches.drivers/ixgbe-display-currently-attach: ixgbe: Display
  currently attached PHY through ethtool (BNC#562046).
- patches.drivers/ixgbe-fix-erroneous-display-of: ixgbe: Fix
  erroneous display of stats by ethtool -S (BNC#562046).
- patches.drivers/ixgbe-fix-kr-to-kx-fail-over-f: ixgbe: Fix KR
  to KX fail over for Mezzanine cards (BNC#562046).
- patches.drivers/ixgbe-fix-receive-address-regi: ixgbe:
  Fix Receive Address Register (RAR) cleaning and accounting
  (BNC#562046).
- patches.drivers/ixgbe-flush-the-lsc-mask-chang: ixgbe: Flush
  the LSC mask change to prevent repeated interrupts (BNC#562046).
- patches.drivers/ixgbe-handle-parameters-for-tx: ixgbe: handle
  parameters for tx and rx EITR, no div0 (BNC#562046).
- patches.drivers/ixgbe-links2-is-not-a-valid-re: ixgbe: LINKS2
  is not a valid register for 82598 (BNC#562046).
- patches.drivers/ixgbe-make-queue-pairs-on-sing: ixgbe: Make
  queue pairs on single MSI-X interrupts (BNC#562046).
- patches.drivers/ixgbe-modify-82599-hwrsc-stati: ixgbe: Modify
  82599 HWRSC statistics counters (BNC#562046).
- patches.drivers/ixgbe-only-set-clear-vfe-in-ix: ixgbe: Only
  set/clear VFE in ixgbe_set_rx_mode (BNC#562046).
- patches.drivers/ixgbe-performance-tweaks: ixgbe: performance
  tweaks (BNC#562046).
- patches.drivers/ixgbe-r_idx-not-used-in-ixgbe_: ixgbe: r_idx
  not used in ixgbe_msix_clean_rx() (BNC#562046).
- patches.drivers/ixgbe-select-fcoe-tx-queue-in-: ixgbe: select
  FCoE Tx queue in ndo_select_queue (BNC#562046).
- patches.drivers/ixgbe-use-eiam-to-automask-msi: ixgbe: use
  EIAM to automask MSI-X (BNC#562046).
- patches.drivers/ixgbe-use-known-user-priority-: ixgbe: use
  known user priority for FCoE when DCB is enabled (BNC#562046).
- patches.drivers/ixgbe-use-rx-buffer-length-fro: ixgbe: Use rx
  buffer length from rx ring for configuring rscctl (BNC#562046).
- patches.drivers/ixgbe-use-the-instance-of-net_: ixgbe: Use
  the instance of net_device_stats from net_device. (BNC#562046).
- patches.drivers/net-add-ndo_fcoe_get_wwn-to-ne: net: Add
  ndo_fcoe_get_wwn to net_device_ops (BNC#562046).
- patches.drivers/net-add-netdev_alloc_skb_ip_al: net: Add
  netdev_alloc_skb_ip_align() helper (BNC#562046).
- patches.drivers/net-use-netdev_alloc_skb_ip_al: net: Use
  netdev_alloc_skb_ip_align() (BNC#562046).
- patches.drivers/vlan-add-support-to-netdev_ops: vlan:
  Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device
  (BNC#562046).
- patches.fixes/fcoe-allow-scsi-fcp-to-be: fcoe: allow SCSI-FCP
  to be processed directly in softirq context (BNC#562046).
- patches.fixes/fcoe-libfc-add-get_lesb-t: fcoe, libfc: add
  get_lesb() to allow LLD to fill the link error status block
  (LESB) (BNC#562046).
- patches.fixes/libfc-add-fc-bb-5-lesb-co: libfc: add FC-BB-5
  LESB counters to fcoe_dev_stats (BNC#562046).
- patches.fixes/libfc-add-fcoe_fc_els_les: libfc: add
  fcoe_fc_els_lesb to fc_fcoe.h for FC-BB-5 LESB definitions
  (BNC#562046).
- patches.fixes/libfc-add-support-of-rece: libfc: add support
  of receiving ELS_RLS (BNC#562046).
- patches.fixes/libfc-add-target-reset-fl: libfc: Add target
  reset flag to FCP header file (BNC#562046).
- patches.fixes/libfc-fix-payload-size-pa: libfc: fix payload size
  passed to fc_frame_alloc() in fc_lport_els_request (BNC#562046).
- patches.fixes/libfcoe-add-checking-disa: libfcoe: add checking
  disable flag in FIP_FKA_ADV (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip-: libfcoe: add tracking
  FIP Missing Discovery Advertisement count (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip--0: libfcoe: add tracking
  FIP Virtual Link Failure count (BNC#562046).
* Mon Dec 14 2009 mmarek@suse.cz
- rpm/kabi.pl: Do not print harmless kabi changes by default.
* Mon Dec 14 2009 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Revert sched
  latency defaults and turn FAIR_SLEEPERS off (bnc#557307).
* Mon Dec 14 2009 jkosina@suse.cz
- patches.fixes/uart-txen-race.patch: Serial: Do not read IIR in
  serial8250_start_tx when UART_BUG_TXEN (bnc#479304 bnc#509066).
* Mon Dec 14 2009 rjw@suse.de
- patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch: sched:
  Fix isolcpus boot option (bnc#562290, fate#306952).
* Sat Dec 12 2009 mmarek@suse.cz
- patches.suse/supported-flag: Fix -Wmissing-prototypes warnings
  in modpost.c.
* Sat Dec 12 2009 mmarek@suse.cz
- patches.rpmify/modpost-segfault: modpost: fix segfault with
  short symbol names.
* Fri Dec 11 2009 jeffm@suse.com
- Moved kernel-docs into the git repo. It is now built automatically
  with the matching kernel sources.
* Fri Dec 11 2009 trenn@suse.de
- patches.suse/kdb_fix_ia64_build.patch: Fix ia64 - Export
  kdb_usb_kbds (none).
* Fri Dec 11 2009 trenn@suse.de
  Jeff updated kdb, try without this ugly workaround.
  If it still does not work, I have something better...
- patches.suse/kdb_x86_fix_hang.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Dec 11 2009 trenn@suse.de
  Updated MCE/MCA patches from Andi -> delete the old ones:
- patches.arch/x86_mce_hwpoison-action_result-valid-pfn.patch:
  HWPOISON: return ENXIO on invalid page number (fate#307738).
- patches.arch/x86_mce_hwpoison-is-free-page.patch: HWPOISON:
  detect free buddy pages explicitly (fate#307738).
- patches.arch/x86_mce_hwpoison-no-double-ref.patch: HWPOISON:
  avoid grabbing the page count multiple times during madvise
  injection (fate#307738).
- patches.arch/x86_mce_madvise-locking: HWPOISON: Use
  get_user_page_fast in hwpoison madvise (fate#307738).
- patches.arch/x86_mce_nfs-mig2: NFS: Fix nfs_migrate_page()
  (fate#307738).
- patches.arch/x86_mce_offline-inject: HWPOISON: Add a madvise()
  injector for soft page offlining (fate#307738).
- patches.arch/x86_mce_page-offline: HWPOISON: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_ref-to-flags: HWPOISON: Turn ref argument
  into flags argument (fate#307738).
- patches.arch/x86_mce_shake-page: HWPOISON: Be more aggressive
  at freeing non LRU caches (fate#307738).
- patches.arch/x86_mce_undef-lru: HWPOISON: Undefine short-hand
  macros after use to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_lru_cleanup.patch: Delete.
- patches.arch/x86_mce_page_offlining.patch: Delete.
- patches.arch/x86_mce_page_offlining_test_ability.patch: Delete.
- patches.arch/x86_mce_test_page.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
- needs_update: Merge or delete remaining patches.
- patches.fixes/scsi-dh-emc-mode-select-10-size: DM-MPIO fails
  to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.fixes/scsi-dh-emc-rw-mismatch: Server crashes when
  path failures occur against EMC storage (bnc#474482).
- patches.fixes/scsi-dh-rdac-add-stk: STK arrays missing from
  rdac devicehandler (bnc#503855).
- patches.fixes/scsi-retry-alua-transition-in-progress: I/O
  errors for ALUA state transitions (bnc#491289).
- patches.suse/dm-mpath-no-activate-for-offlined-paths: DM-MPIO
  fails to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.suse/dm-mpath-no-partitions-feature: Disable partitions
  scan for multipathed devices (bnc#402922,bnc#514767).
* Fri Dec 11 2009 tiwai@suse.de
- Update config files: set back to CONFIG_SOUND=m
* Fri Dec 11 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-23-hp-mute-led-gpio-fixes:
  ALSA: hda - Fix LED GPIO setup for HP laptops with IDT codecs
  (bnc#547357,bnc#523487).
* Fri Dec 11 2009 jeffm@suse.de
- patches.suse/kdb-usb-rework: Fix ia64.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files: Enable USB_SERIAL_DEBUG.
* Fri Dec 11 2009 jeffm@suse.com
- patches.suse/kdb-usb-rework: kdb: Cleanup KDB_USB.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files.
  - Disabled USB_TEST and USB_LIBUSUAL.
* Thu Dec 10 2009 jeffm@suse.com
- Update config files. Re-enable missing options:
  - CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
  - CONFIG_VIDEO_GO7007=m (and related options)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  Refresh to fix fuzz
* Thu Dec 10 2009 jeffm@suse.com
- Updated KDB to v4.4-2.6.32-3 and re-enabled USB keyboard support.
* Thu Dec 10 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: Fix vmlinux stripping on power
  (bnc#559547)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0000-Use-the-instance-of-net_device_stats-from-net.patch:
  netxen: Use the instance of net_device_stats from
  net_device. (bnc#560003, fate#307134).
- patches.drivers/netxen-0001-remove-sub-64-bit-mem-accesses.patch:
  netxen: remove sub 64-bit mem accesses (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0002-add-access-to-on-chip-memory-for-tools.patch:
  netxen: add access to on chip memory for tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0003-annotate-register-windowing-code.patch:
  netxen: annotate register windowing code (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0004-separate-register-and-memory-access-lock.patch:
  netxen: separate register and memory access lock (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0005-add-sysfs-entries-for-diag-tools.patch:
  netxen: add sysfs entries for diag tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0006-defines-for-next-revision.patch:
  netxen: defines for next revision (bnc#560003, fate#307134).
- patches.drivers/netxen-0007-128-memory-controller-support.patch:
  netxen: 128 memory controller support (bnc#560003, fate#307134).
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  netxen: reset sequence changes (bnc#560003, fate#307134).
- patches.drivers/netxen-0009-onchip-memory-access-change.patch:
  netxen: onchip memory access change (bnc#560003, fate#307134).
- patches.drivers/netxen-0010-fix-error-codes-in-for-tools-access.patch:
  netxen: fix error codes in for tools access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0011-sysfs-control-for-auto-firmware-recovery.patch:
  netxen: sysfs control for auto firmware recovery (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0012-update-version-to-4.0.62.patch:
  netxen; update version to 4.0.62 (bnc#560003, fate#307134).
- patches.drivers/netxen-0013-fix-builds-for-SYSFS-n-or-MODULES-n.patch:
  netxen: fix builds for SYSFS=n or MODULES=n (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  netxen: support for new firmware file format (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0015-refactor-indirect-register-access.patch:
  netxen: refactor indirect register access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0016-add-PCI-IDs-for-new-chip.patch:
  netxen: add PCI IDs for new chip (bnc#560003, fate#307134).
- patches.drivers/netxen-0017-update-module-info.patch: netxen:
  update module info (bnc#560003, fate#307134).
- patches.drivers/netxen-0018-module-firmware-hints.patch:
  netxen: module firmware hints (bnc#560003, fate#307134).
- patches.drivers/netxen-0019-update-version-to-4.0.65.patch:
  netxen: update version to 4.0.65 (bnc#560003, fate#307134).
- patches.drivers/netxen-0020-remove-PCI-IDs-of-CNA-device.patch:
  netxen: remove PCI IDs of CNA device (bnc#560003, fate#307134).
- patches.drivers/netxen-0021-fix-debug-tools-access-for-NX2031.patch:
  netxen : fix debug tools access for NX2031 (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0022-fix-failure-cases-for-fw-hang-recovery.patch:
  netxen: fix failure cases for fw hang recovery (bnc#560003,
  fate#307134).
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/qlge-0001-Use-the-instance-of-net_device_stats-from-net_.patch:
  qlge: Use the instance of net_device_stats from
  net_device. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch:
  qlge: Remove explicit setting of PCI Dev CTL reg. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  qlge: Set PCIE max read request size. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch:
  qlge: Add handler for DCBX firmware event. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0005-Store-firmware-revision-as-early-as-possible.patch:
  qlge: Store firmware revision as early as possible. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0006-Remove-inline-math-for-small-rx-buf-mapping.patch:
  qlge: Remove inline math for small rx buf mapping. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0007-Get-rid-of-firmware-handler-debug-code.patch:
  qlge: Get rid of firmware handler debug code. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch:
  qlge: Don't fail open when port is not initialized. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0009-Add-CBFC-pause-frame-counters-to-ethtool-stats.patch:
  qlge: Add CBFC pause frame counters to ethtool
  stats. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0010-Size-RX-buffers-based-on-MTU.patch:
  qlge: Size RX buffers based on MTU. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0011-Add-ethtool-get-set-pause-parameter.patch:
  qlge: Add ethtool get/set pause parameter. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0012-Add-ethtool-blink-function.patch:
  qlge: Add ethtool blink function. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0013-Add-ethtool-wake-on-LAN-function.patch:
  qlge: Add ethtool wake on LAN function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0014-Add-ethtool-register-dump-function.patch:
  qlge: Add ethtool register dump function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0015-Add-ethtool-self-test.patch: qlge:
  Add ethtool self-test. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0016-Change-naming-on-vlan-API.patch:
  qlge: Change naming on vlan API. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0017-Fix-indentations.patch: qlge: Fix
  indentations. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0018-Add-firmware-driver-sub-command-support.patch:
  qlge: Add firmware/driver sub-command support. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0019-Clean-up-netdev-stats-usage.patch:
  qlge: Clean up netdev->stats usage. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0020-Do-not-change-frame-routing-during-suspend.patch:
  qlge: Do not change frame routing during suspend. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0021-Add-asic-reset-to-open-call.patch:
  qlge: Add asic reset to open call. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0022-Clean-up-module-parameter-name.patch:
  qlge: Clean up module parameter name. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0023-Change-version-to-v1.00.00.23.00.00-01.patch:
  qlge: Change version to v1.00.00.23.00.00-01. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch: qlge:
  Bonding fix for mode 6. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  qlge: Add performance change for non-split headers. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: qlge:
  Add firmware core dump. (bnc#560420, FATE#307130).
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete more merged fixes.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete merged driver fixes.
- patches.drivers/megaraid-mbox-fix-SG_IO: megaraid_mbox: Oops
  on SG_IO (bnc#475619).
* Thu Dec 10 2009 duwe@suse.de
- Disable PHYP_DUMP for all PPC flavours, per bnc#541302.
* Thu Dec 10 2009 jbenc@suse.cz
- patches.suse/novfs-fix-debug-message.patch: novfs: fix debug
  message.
* Thu Dec 10 2009 hare@suse.de
- patches.fixes/tehuti-firmware-name: Tehuti network driver
  references wrong firmware (bnc#562092).
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: fix section mismatch due to
  previous checkin
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: export audit logging
  symbols.
* Wed Dec  9 2009 jbohac@suse.cz
- Update config files: added CONFIG_IP_NF_MATCH_IPV4OPTIONS
  to ppc64/trace
* Wed Dec  9 2009 jeffm@suse.com
- patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext:
  ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT (bnc#561018
  CVE-2009-4131).
* Wed Dec  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Fix a potentially serious mis-merge
  in swiotlb code.
* Wed Dec  9 2009 jjolly@suse.de
- patches.fixes/nohz-delay-from-tip.diff: nohz: Introduce
  arch_needs_cpu.
- patches.fixes/reuse-ktime-from-tip.diff: nohz: Reuse ktime in
  sub-functions of tick_check_idle..
- series.conf: Moved s390 patchs to proper place
* Wed Dec  9 2009 npiggin@suse.de
- patches.fixes/ipc-ns-fix-memory-leak-idr.patch: ipc: ns fix
  memory leak (bnc#518767).
- patches.fixes/ipc-remove-unreachable-code-in-semc.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-add-a-per-semaphore-pending-list.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-if-semops-fail.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-semop-operations.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-sops-when-semval-is-zero.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-optimise-undo-list-search.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-preempt-improve.patch:  (bnc#518767).
- patches.fixes/ipc-semc-sem-use-list-operations.patch:
  (bnc#518767).
* Wed Dec  9 2009 bphilips@suse.de
- needs_update: patches moved upstream or obsoleted by upstream
* Tue Dec  8 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: Update to what will
  hopefully be in 2.6.33.
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin: Delete.
* Tue Dec  8 2009 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: netfilter ipv4options
  match from patch-o-matic-ng (bnc#131728 - FATE#182).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-devzero-optimisation.patch: mm: /dev/zero
  optimisation (bnc#430738).
* Tue Dec  8 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-22-alc888-exclude-unusable-adcs:
  ALSA: hda - Exclude unusable ADCs for ALC88x (bnc#561235).
* Tue Dec  8 2009 mmarek@suse.cz
- patches.drivers/reenable-generic_serial: Revert "tty: Mark
  generic_serial users as BROKEN".
- Update config files: enable RIO and SX.
- rpm/generic_serial-blacklist: blacklist generic_serial users from
  automatic loading (bnc#551348).
* Tue Dec  8 2009 rgoldwyn@suse.de
- needs_update: patches merged upstream
- novfs patches to be handled by novfs team
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-vmalloc-fail-dump-stack.patch: mm: improve
  vmalloc reporting (bnc#511079).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update: most of mine are merged. apparmor patch sent to Andreas.
* Tue Dec  8 2009 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: use 64byte lvb len.(bnc#515645)
* Tue Dec  8 2009 agraf@suse.de
- patches.arch/s390-kvm-prefix.patch: KVM: s390: Fix prefix
  register checking in arch/s390/kvm/sigp.c (FATE#306513).
- patches.arch/s390-kvm-psw.patch: KVM: s390: Make psw available
  on all exits, not just a subset (FATE#306513).
* Mon Dec  7 2009 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add support of
  clickpad mode to synaptics mouse driver (bnc#547370).
* Mon Dec  7 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32 final and c/s 958.
- patches.xen/xen-dcdbas: force proper address translation
  in DCDBAS.
- patches.xen&xen-vmalloc_32: guarantee 32-bit
  (bus-)addressability of vmalloc_32() output (bnc#548010,
  bnc#552492).
- patches.xen/xen-x86_64-nx-user-mappings: set NX bit in kernel
  version of top level user mode page table entries.
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls (FATE#305733).
- patches.xen/xen3-x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829, bnc#482220).
- patches.xen/xen3-x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829, bnc#482220).
- Update EC2 config files (disable CAN_DEV and UIO).
* Mon Dec  7 2009 jbeulich@novell.com
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch,
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  Fix build warnings.
* Mon Dec  7 2009 hare@suse.de
- patches.drivers/lpfc-add-raywire-id: Add missing PCI-ID to lpfc.
* Sat Dec  5 2009 tonyj@suse.de
- config.conf: add trace flavor for ppc64 (fate# 307051)
- Update config files.
* Fri Dec  4 2009 jeffm@suse.com
- Split apparmor.diff out into separate patches to align more
  closely with the upstream AppArmor 2.4 repo.
- patches.apparmor/apparmor-fix-cap-audit_caching-preemption-disabling:
  AppArmor: Fix cap audit_caching preemption disabling.
- patches.apparmor/apparmor-fix-change_profile-failing-lpn401931:
  AppArmor: Fix change_profile failing lpn401931.
- patches.apparmor/apparmor-fix-change_profile-failure: AppArmor:
  Fix change_profile failure.
- patches.apparmor/apparmor-fix-determination-of-forced-audit-messages:
  AppArmor: Fix determination of forced AUDIT messages..
- patches.apparmor/apparmor-fix-failure-to-audit-change_hat-correctly:
  AppArmor: fix failure to audit change_hat correctly.
- patches.apparmor/apparmor-fix-file-auditing-when-quiet-is-used:
  AppArmor: Fix file auditing when quiet is used.
- patches.apparmor/apparmor-fix-leak-when-profile-transition-table-fails-unpack:
  AppArmor: Fix leak when profile transition table fails unpack.
- patches.apparmor/apparmor-fix-mediation-of-created-paths-that-look-like-deleted-paths:
  AppArmor: Fix mediation of created paths that look like
  "deleted" paths.
- patches.apparmor/apparmor-fix-oops-after-profile-removal:
  AppArmor: Fix oops after profile removal.
- patches.apparmor/apparmor-fix-oops-when-auditing-the-addition-of-profile-namespace:
  AppArmor: Fix oops when auditing the addition of profile
  namespace.
- patches.apparmor/apparmor-fix-oops-when-in-apparmor_bprm_set_creds:
  AppArmor: Fix Oops when in apparmor_bprm_set_creds.
- patches.apparmor/apparmor-fix-profile-namespace-removal:
  AppArmor: Fix profile namespace removal..
- patches.apparmor/apparmor-fix-refcounting-bug-causing-leak-of-creds-and-oops:
  AppArmor: Fix refcounting bug causing leak of creds and oops.
- patches.apparmor/apparmor-fully-close-race-condition-for-deleted-paths:
  AppArmor: Fully close race condition for deleted paths.
- patches.apparmor/apparmor-missing-unlock: AppArmor: Add missing
  unlock to next_profile.
- patches.apparmor/apparmor-policy-load-and-replacement-can-fail-to-alloc-mem:
  AppArmor: Policy load and replacement can fail to alloc mem.
- patches.apparmor/apparmor-fix-security_ops-task_setrlimit-api-use:
  AppArmor: Fix security_ops->task_setrlimit API use.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
- patches.suse/revert-usb-remove-phidget-drivers-from-kernel-tree.patch:
  Revert "USB: remove phidget drivers from kernel tree.".
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-message-catalog.diff: Updated patch
  (bnc#549193,FATE#306999,LTC#57210).
* Fri Dec  4 2009 mmarek@suse.cz
- supported.conf: Update wireless drivers.
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-03-qeth-hs-traffic-analyzer.patch: qeth:
  HiperSockets Network Traffic Analyzer (bnc#560674).
* Fri Dec  4 2009 hare@suse.de
- patches.drivers/qla2xxx-8.03.01-k7-update: qla2xxx driver
  update to 8.03.01-k7 (bnc#560415).
* Fri Dec  4 2009 mmarek@suse.cz
- rpm/package-descriptions: Add description for kernel-vmi.
* Fri Dec  4 2009 trenn@suse.de
- patches.arch/x86_mce_lru_cleanup.patch: HWPOISON: Undefine lru
  define after table to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_page_offlining.patch: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_page_offlining_test_ability.patch:
  HWPOISON: Add a madvise() injector for soft page offlining
  (fate#307738).
- patches.arch/x86_mce_test_page.patch: Expose Test pageflagA
  and set pageflagB primitive (fate#307738).
* Fri Dec  4 2009 mmarek@suse.cz
- Add the vmi flavor again.
* Fri Dec  4 2009 sjayaraman@suse.de
- patches.suse/SoN-18-netvm-skbuff-reserve.patch: add emergeny flag
  inside kmemcheck boundaries.
- patches.xen/xen3-auto-common.diff: Refresh.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 and i386 vanilla (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for i386 (bnc#560402)
* Thu Dec  3 2009 jeffm@suse.com
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch:
  Delete. (bnc#560043)
* Thu Dec  3 2009 jeffm@suse.com
- Cleanup config files.
* Thu Dec  3 2009 bphilips@suse.de
- patches.drivers/tg3_libphy_workaround: Delete. We have all of the 57780
  phylib and tg3 changes due to 2.6.32 bump.
* Thu Dec  3 2009 duwe@suse.de
- back out cpuidle feature that is still unconsistent.
* Thu Dec  3 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  Fix the "fixed" feature patch set from IBM.
* Thu Dec  3 2009 mfasheh@suse.com
- Update config files.
- patches.suse/gfs2-ro-mounts-only.patch: gfs2: allow spectator
  mounts for migration to ocfs2 (FATE#307584).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for 2.6.32 (again).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for cpuidle.
* Thu Dec  3 2009 tiwai@suse.de
- patches.drivers/8250_pnp-wacom-add: serial/8250_pnp.c: add
  new Wacom devices (bnc#544763).
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  one lonely hunk already seems to be in 2.6.32 final
* Thu Dec  3 2009 duwe@suse.de
- bnc#552860 / FATE#307104: kernel idle low power, take 2:
- patches.suse/cpuidle-cleanup: Refresh.
- patches.suse/cpuidle-cleanup-x86: Refresh.
- patches.suse/cpuidle-eliminate-ppcmdpowersave1: Refresh.
* Thu Dec  3 2009 jeffm@suse.com
- Updated to 2.6.32-final.
  - 2 patches eliminated.
* Thu Dec  3 2009 hare@suse.de
- Update config files: Enable Hibernation for zSeries.
* Thu Dec  3 2009 mmarek@suse.cz
- Update config files: Disable CONFIG_MFD_PCF50633, the chip is
  unlikely to be used on architectures we support.
* Thu Dec  3 2009 mmarek@suse.cz
- rpm/split-modules: Print which supported modules need unsupported
  modules.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: support lis3lv02d, hp_accel needs it.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: hp_accel is supported (FATE #306448).
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: remove wm831x drivers, we no longer ship them.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable all new hwmon drivers on ppc
  (default and vanilla) for consistency.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Add wm831x, needed by drivers/input/misc/wm831x-on.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Fix up after commit bfea0bd.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable WM831x and WM8350 support entirely,
  as recommended by the drivers author. These devices are only
  found on embedded devices such as music players or mobile phones.
* Thu Dec  3 2009 hare@suse.de
- supported.conf: Mark pmcraid and igbvf as supported;
  OSD drivers as unsupported.
* Thu Dec  3 2009 jdelvare@suse.de
- Restore link from config/s390/vanilla to config/s390x/vanilla.
* Thu Dec  3 2009 jbeulich@novell.com
- supported.conf: Update Xen drivers.
* Thu Dec  3 2009 tonyj@suse.de
- needs_update: readd
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch
  patches.suse/perfmon2-remove_syscalls.patch
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: woh dluoc I tegrof ot esolc eht fi
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: If this is a Moblin-based box, don't run yast-bootloader
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: stop shipping wm831x-hwmon, wm8350-hwmon,
  i2c-simtec and i2c-designware.
- supported.conf: remove i2c-simtec.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Add all new hwmon and i2c/busses drivers. The
  former unsupported, the latter supported.
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_VOODOO3.
- supported.conf: drop i2c-voodoo3, superseded by tdfxfb.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Drop hwmon and i2c/chips drivers which have been
  obsoleted.
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete perfmon-kmp.
* Wed Dec  2 2009 mmarek@suse.cz
- supported.conf: Add perfmon, hid and input modules.
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: Fix vanilla configs
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: disabled CONFIG_SND_SOC* in ppc configs.
* Wed Dec  2 2009 tiwai@suse.de
- Updated the sound section of supported.conf
* Wed Dec  2 2009 gregkh@suse.de
- Update config files. disable USB OTG drivers that should not
  have been enabled.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: remove some usb drivers that were deleted or renamed.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: update usb driver section
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/check-supported-list: Skip modules in Documentation and
  drivers/staging.
* Wed Dec  2 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-remote-DoS.patch: mac80211: fix
  remote DoS (bnc#558267).
* Tue Dec  1 2009 tiwai@suse.de
- Forward-port 11.2 patches:
  patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix: ALSA: hda -
    Add a position_fix quirk for MSI Wind U115.
  patches.drivers/alsa-sp1-hda-19-cx5047-test-mode-fix: ALSA:
    hda - Fix Cxt5047 test mode (bnc#559062).
  patches.drivers/alsa-sp1-hda-20-fsc-amilo-pi1505-fix: ALSA:
    hda - Add a pin-fix for FSC Amilo Pi1505 (bnc#557403).
  patches.drivers/alsa-sp1-hda-21-hp-dv3-position-fix-quirk:
    ALSA: hda - Add position_fix quirk for HP dv3 (bnc#555935).
* Tue Dec  1 2009 jeffm@suse.com
- patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io:
  megaraid_sas: Fix permissions on poll_mode_io (bnc#557180
  CVE-2009-3939).
* Tue Dec  1 2009 jeffm@suse.com
- patches.arch/x86-64-add-comment-for-rodata-large-page-retainment:
  x86-64: add comment for RODATA large page retainment
  (bnc#558249).
- patches.arch/x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.arch/x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop libata patches which are already included in
  2.6.31 vanilla.
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop patches which are already included in 2.6.31
  vanilla.
* Mon Nov 30 2009 teheo@suse.de
  Forward port two x86 patches from SLE11.
- needs_update:
- patches.arch/x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829).
- patches.arch/x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829).
* Mon Nov 30 2009 agraf@suse.de
- Update config files: Enable KSM (FATE#306513)
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: acpi dock patch was hmacht's, not mine
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: sysfs debugging crash patch is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: jeffm merged novfs patches into the main novfs patch.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: qualcomm modem driver is upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: squashfs is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: via driver bugfixes never went upstream, and people
  are complaining about them, so they were dropped.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove staging driver entries, they are all upstream.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove hv driver entries, those are upstream now.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove xen patches with my name on it.  Just because
  I refreshed the patch, doesn't mean I own it or even like the
  thing :)
* Sat Nov 28 2009 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix build errors in -trace
  and ppc64 flavors.
* Fri Nov 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Abort if supported modules depend on
  unsupported ones.
* Fri Nov 27 2009 mmarek@suse.cz
- supported.conf: mark cnic as supported (needed by bnx2i).
* Fri Nov 27 2009 jbenc@suse.cz
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch: API
  fix: X86: sysctl to allow panic on IOCK NMI error (bnc#427979).
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Nov 27 2009 jbohac@suse.cz
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
* Fri Nov 27 2009 trenn@suse.de
- needs_update:
  One I still have to send upstream, but it's nicer error output
  only, SP1 is fine in respect to removing all these, thanks.
* Fri Nov 27 2009 hare@suse.de
- Update config files: Compile in efivars module for
  x86_64 (FATE#306931).
* Fri Nov 27 2009 sjayaraman@suse.de
- needs_update:	sjayaraman's patches are either upstream already or
  rebased to SP1.
* Fri Nov 27 2009 sjayaraman@suse.de
- Update config files: NFS_SWAP=y.
* Fri Nov 27 2009 sjayaraman@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh and fix
  a build failure with fuzz factor 0.
* Fri Nov 27 2009 sjayaraman@suse.de
- Rebase Swap-over-NFS(SoN) patches:
- patches.xen/tmem: Refresh to accomodate changes due to SoN patches.
- patches.xen/xen3-auto-common.diff: Refresh to accomodate changes
  due to SoN patches.
* Fri Nov 27 2009 knikanth@suse.de
- needs_update: Verify knikanth's patches in SLE11 but not in SP1
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Release
  md->map_lock before set_disk_ro  (bnc#556899 bnc#479784).
* Fri Nov 27 2009 nfbrown@suse.de
- Restore following patches from SLES11 that are still needed for
  SLES11-SP1
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  sunrpc/cache: allow thread to block while waiting for cache
  update. (bnc#498708).
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  sunrpc/cache: retry cache lookups that return -ETIMEDOUT
  (bnc#498708).
- patches.fixes/nfsd-07-nfsd-idmap-drop-special-request-deferal-in-favour-of.patch:
  nfsd/idmap: drop special request deferal in favour of improved
  default. (bnc#498708).
- patches.fixes/nfsd-09-fix-kabi: Fix kabi breakage in previous
  nfsd patch series (bnc#498708).
* Thu Nov 26 2009 coly.li@suse.de
- needs_update: remove patches item of coly.li, lmb and mfasheh.
- patches.fixes/dlm-enable-debug.patch: update the patch from SLES11
  to SLES11 SP1 tree.
* Thu Nov 26 2009 jslaby@suse.cz
- patches.fixes/make-note_interrupt-fast.diff: Fix performance
  regression on large IA64 systems (bnc #469589).
* Thu Nov 26 2009 mmarek@suse.cz
- rpm/old-packages.conf: obsolete kernel-kdump on ppc.
- config.conf: delete kdump configs.
- config/ppc/kdump: Delete.
- config/ppc64/kdump: Delete.
* Thu Nov 26 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-Export_memory_sysdev_class:
  Refresh. Fix "typo", memory_sysdev_class should be exported
  only to GPL'ed modules.
* Thu Nov 26 2009 hare@suse.de
  Fixup patches for series2git:
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 duwe@suse.de
- config.conf: disable build of ppc kdump flavours
  (FATE#304346)
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/libata-missing-_SDD-is-not-an-error:
  libata-acpi: missing _SDD is not an error (bnc#551942).
* Thu Nov 26 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-spurious-delba-handling.patch:
  mac80211: fix spurious delBA handling (bnc#558267,
  CVE-2009-4026, CVE-2009-4027).
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/sky2-add-register-definitions: sky2: add
  register definitions for new chips (bnc#544760).
- patches.drivers/sky2-88E8059-support: sky2: 88E8059 support
  (bnc#544760).
- patches.drivers/sky2-optima-tcp-offload-fix: net: Fix Yukon-2
  Optima TCP offload setup (bnc#544760).
- patches.drivers/sky2-optima-fix-pci-cfg: net: Add missing
  TST_CFG_WRITE bits around sky2_pci_write (bnc#544760).
* Thu Nov 26 2009 nfbrown@suse.de
- Update config files.
  disable CONFIG_MULTICOE_RAID456 as it is not yet stable.
  Enable CONFIG_ASYNC_TX_DMA for FATE#306368
* Thu Nov 26 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Nov 26 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: Delete.
  it never went upstream, so we should drop it as well.
* Thu Nov 26 2009 tonyj@suse.de
- patches.trace/lttng-*: update for 2.6.32
- patches.trace/lttng-instrumentation-timer.patch: Delete.
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: detect oprofile counters
  reserved by bios (FATE#307426).
* Wed Nov 25 2009 jeffm@suse.com
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  netfilter: Remove pointless CONFIG_NF_CT_ACCT warning
  (bnc#552033 (and others)).
* Tue Nov 24 2009 hare@suse.de
- Update config files.
- patches.drivers/mpt-fusion-4.22.00.00-update: Update MPT Fusion
  driver to 4.22.00.00-suse (bnc#556587).
- patches.drivers/mpt-fusion-4.16.00.00-update: Delete.
* Tue Nov 24 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-17-fix-mute-LED-sync-idt92h383xxx:
  ALSA: hda - Fix mute-LED sync on HP laptops with IDT92HD83xxx
  codecs (bnc#547357).
* Tue Nov 24 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-*: Increase power savings
  by allowing the core to sleep.
  (FATE##307059, bnc#550447)
* Tue Nov 24 2009 sjayaraman@suse.de
- patches.suse/kconfig-automate-kernel-desktop: automate a few config
  options for kernel-desktop (FATE#305694).
* Tue Nov 24 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Update
  references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Update references (bnc#556135, FATE#306453).
* Mon Nov 23 2009 jeffm@suse.com
- Enabled:
  patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch: crypto:
  Add ghash algorithm test before provide to users (FATE#306883,
  bnc#554578).
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "ghash - put proper .data section in place" fix
* Mon Nov 23 2009 sjayaraman@suse.de
- Update config files.
  - Add new options KERNEL_DESKTOP and DEFAULT_VM_DIRTY_RATIO.
  - Enable KERNEL_DESKTOP for only desktop flavor.
* Mon Nov 23 2009 sjayaraman@suse.de
- patches.suse/mm-tune-dirty-limits.patch: mm: Make default
  VM dirty ratio configurable to suit different workloads
  (bnc#552883).
* Fri Nov 20 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in, rpm/mkspec: build kernel-syms only for
  supported architectures.
* Fri Nov 20 2009 jeffm@suse.com
- Enabled B43_PHY_LP=y for PHY support on certain b43 chips.
* Fri Nov 20 2009 mmarek@suse.cz
- patches.suse/export-sync_page_range: Revert "vfs: Remove
  generic_osync_inode() and sync_page_range{_nolock}()"
  (bnc#557231).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Fix a bad-pointer warning.
* Fri Nov 20 2009 agruen@suse.de
- rpm/macros.kernel-source: Add kernel_module_package_moddir()
  macro for cross-distro compatibility (FATE 305225).
* Fri Nov 20 2009 jslaby@suse.cz
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Update
  references (FATE#305733).
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Update references (FATE#305733).
* Fri Nov 20 2009 jslaby@suse.cz
- Add writable resource limits support
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  SECURITY: selinux, fix update_rlimit_cpu parameter.
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  IA64: use helpers for rlimits.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  misc: use helpers for rlimits.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  core: rename setrlimit to do_setrlimit.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  core: implement getprlimit and setprlimit syscalls.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  unistd: add __NR_[get|set]prlimit syscall numbers.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  COMPAT: add get/put_compat_rlimit.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 hare@suse.de
- patches.drivers/megaraid-04.12-update: megaraid: Update
  megaraid_sas to version 04.12 (FATE#307125).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/bnx2-entropy-source.patch: bnx2: entropy source
  (FATE#307517).
- patches.drivers/e1000-entropy-source.patch: Enable e1000 as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/e1000e-entropy-source.patch: Enable e1000e as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/igb-entropy-source.patch: Enable igb as entropy
  source (disabled by default) (FATE#307517).
- patches.drivers/ixgbe-entropy-source.patch: Enable ixgbe as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/tg3-entropy-source.patch: tg3: entropy source
  (FATE#307517).
* Fri Nov 20 2009 hare@suse.de
- patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects:
  scsi_lib_dma: fix bug with dma maps on nested scsi objects
  (bnc#556595).
- patches.fixes/scsi-introduce-helper-function-for-blocking-eh:
  scsi_transport_fc: Introduce helper function for blocking
  scsi_eh (bnc#556595).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Delete.
* Fri Nov 20 2009 hare@suse.de
  Whitespace cleanup for series2git:
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/aacraid-24701-update: Refresh.
- patches.suse/crasher-26.diff: Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-ia64: Refresh.
- patches.suse/kdb-x86: Refresh.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch:
  igb: add support for 82576NS SerDes adapter (FATE#306856).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  Fix for !CONFIG_SCSI (in -ec2).
* Fri Nov 20 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: ocfs2:
  allocation reservations (bnc#501563 FATE#307247).
* Fri Nov 20 2009 jjolly@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86-self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
- patches.suse/self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
* Fri Nov 20 2009 jeffm@suse.com
- Update to 2.6.32-rc8.
  - Eliminated 1 patch.
* Fri Nov 20 2009 jeffm@suse.de
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  enclosure: fix oops while iterating enclosure_status array
  (bnc#540997).
* Thu Nov 19 2009 tonyj@suse.de
- Update config files.
- patches.suse/perfmon2.patch: perfmon2 (FATE#303968).
- patches.suse/perfmon2_ioctl.patch: switch to ioctl interface
  for perfmon2.
- patches.suse/perfmon2_noutrace.patch: remove UTRACE code
  from perfmon2.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Nov 19 2009 jjolly@suse.de
- Update config files.
- patches.arch/s390-message-catalog.diff: Kernel message
  catalog. (bnc#549193,LTC#57210,FATE#306999).
- rpm/kernel-binary.spec.in:
* Thu Nov 19 2009 jbohac@suse.cz
- patches.suse/add-queue_depth-ramp-up-code.patch: add queue_depth
  ramp up code (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-a-separate-scsi-transport-template-for-npiv-vports.patch:
  fcoe: add a separate scsi transport template for NPIV vports
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-check-to-fail-gracefully-in-bonding-mode.patch:
  fcoe: add check to fail gracefully in bonding mode (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-call-ndo_fcoe_enable-disable-to-turn-fcoe-feature-on-off-in-lld.patch:
  fcoe: Call ndo_fcoe_enable/disable to turn FCoE feature on/off
  in LLD (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-checking-san-mac-address.patch: fcoe: Fix
  checking san mac address (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch:
  fcoe: Fix getting san mac for VLAN interface (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-fix-setting-lport-s-wwnn-wwpn-to-use-san-mac-address.patch:
  fcoe: Fix setting lport's WWNN/WWPN to use san mac address
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-using-vlan-id-in-creating-lport-s-wwwn-wwpn.patch:
  fcoe: Fix using VLAN ID in creating lport's WWWN/WWPN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-formatting-cleanups-and-commenting.patch:
  fcoe: Formatting cleanups and commenting (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-increase-fcoe_max_lun-to-0xffff-65535.patch:
  fcoe: Increase FCOE_MAX_LUN to 0xFFFF (65535) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch:
  fcoe: initialize return value in fcoe_destroy (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch:
  fcoe, libfc: fix an libfc issue with queue ramp down in libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-use-single-frame-allocation-api.patch:
  fcoe, libfc: use single frame allocation API (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-npiv-vport-create-destroy.patch: fcoe: NPIV
  vport create/destroy (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-remove-extra-function-decalrations.patch:
  fcoe: remove extra function decalrations (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch:
  fcoe: remove redundant checking of netdev->netdev_ops
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-use-netif_f_fcoe_mtu-flag-to-set-up-max-frame-size-lport-mfs.patch:
  fcoe: Use NETIF_F_FCOE_MTU flag to set up max frame size
  (lport->mfs) (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-vport-symbolic-name-support.patch: fcoe: vport
  symbolic name support (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-host-number-to-lport-link-up-down-messages.patch:
  libfc: add host number to lport link up/down
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-libfc-fc_libfc-ch-for-libfc-internal-routines.patch:
  libfc: Add libfc/fc_libfc.[ch] for libfc internal routines
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-queue_depth-ramp-up.patch: libfc:
  add queue_depth ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-routine-to-copy-data-from-a-buffer-to-a-sg-list.patch:
  libfc: Add routine to copy data from a buffer to a SG list
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-set_fid-function-to-libfc-template.patch:
  libfc: add set_fid function to libfc template (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-add-some-generic-npiv-support-routines-to-libfc.patch:
  libfc: add some generic NPIV support routines to libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-can_queue-ramp-up.patch: libfc: adds
  can_queue ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-missing-exch-release-for-accepted-rrq.patch:
  libfc: adds missing exch release for accepted RRQ (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-changes-to-libfc_host_alloc-to-consolidate-initialization-with-allocation.patch:
  libfc: changes to libfc_host_alloc to consolidate initialization
  with allocation (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-request-functions.patch:
  libfc: combine name server registration request functions
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-response-handlers.patch:
  libfc: combine name server registration response handlers
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-convert-to-scsi_track_queue_full.patch:
  libfc: convert to scsi_track_queue_full (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-do-not-use-did_no_connect-for-pkt-alloc-failures.patch:
  libfc: do not use DID_NO_CONNECT for pkt alloc
  failures. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch:
  libfc: don't WARN_ON in lport_timeout for RESET state
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-export-fc-headers.patch: libfc: Export FC
  headers (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-add-fc-passthrough-support.patch: libfc,
  fcoe: Add FC passthrough support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fcoe-don-t-export_symbols-unnecessarily.patch:
  libfc, fcoe: Don't EXPORT_SYMBOLS unnecessarily (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-fixes-for-highmem-skb-linearize-panics.patch:
  libfc, fcoe: fixes for highmem skb linearize panics
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-increase-els-and-ct-timeouts.patch:
  libfc fcoe: increase ELS and CT timeouts (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-an-issue-of-pending-exch-es-after-i-f-destroyed-or-rmmod-fcoe.patch:
  libfc: fix an issue of pending exch/es after i/f destroyed or
  rmmod fcoe (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch: libfc: fix
  ddp in fc_fcp for 0 xid (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-fc_els_resp_type-to-correct-display-of-ct-responses.patch:
  libfc: fix fc_els_resp_type to correct display of CT responses
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch:
  libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in
  fc_fcp_send_data (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch:
  libfc: fix free of fc_rport_priv with timer pending
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch:
  libfc: fix memory corruption caused by double frees and bad
  error handling (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-rnn_id-smashing-skb-payload.patch: libfc:
  fix RNN_ID smashing skb payload (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fix-symbolic-name-registrations-smashing-skb-data.patch:
  libfc: fix symbolic name registrations smashing skb data
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch:
  libfc: fix typo in retry check on received PRLI (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch:
  libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-formatting-cleanups-across-libfc.patch:
  libfc: Formatting cleanups across libfc (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-libfcoe-fdisc-els-for-npiv.patch: libfc,
  libfcoe: FDISC ELS for NPIV (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-lport-fix-minor-documentation-errors.patch:
  libfc: lport: fix minor documentation errors (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-move-libfc_init-and-libfc_exit-to-fc_libfc-c.patch:
  libfc: Move libfc_init and libfc_exit to fc_libfc.c
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-move-non-common-routines-and-prototypes-out-of-libfc-h.patch:
  libfc: Move non-common routines and prototypes out of libfc.h
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-reduce-can_queue-for-all-fcp-frame-allocation-failures.patch:
  libfc: reduce can_queue for all FCP frame allocation failures
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-register-fc4-features-with-the-fc-switch.patch:
  libfc: register FC4 features with the FC switch (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-node-name-rsnn_nn.patch:
  libfc: Register Symbolic Node Name (RSNN_NN) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-port-name-rspn_id.patch:
  libfc: Register Symbolic Port Name (RSPN_ID) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-remove-fc_fcp_complete.patch: libfc: Remove
  fc_fcp_complete (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-remove-unused-fc_lport-pointer-from-fc_fcp_pkt_abort.patch:
  libfc: Remove unused fc_lport pointer from fc_fcp_pkt_abort
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-initializing-fc_cpu_order-and-fc_cpu_mask-per-lport.patch:
  libfc: removes initializing fc_cpu_order and fc_cpu_mask per
  lport (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-unused-disc_work-and-ex_list.patch:
  libfc: removes unused disc_work and ex_list (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-rnn_id-may-be-required-before-rsnn_nn-with-some-switches.patch:
  libfc: RNN_ID may be required before RSNN_NN with some switches
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-rpn_id-is-obsolete-and-unnecessary.patch:
  libfc: RPN_ID is obsolete and unnecessary (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-vport-link-handling-and-fc_vport-state-managment.patch:
  libfc: vport link handling and fc_vport state managment
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-allow-fip-to-be-disabled-by-the-driver.patch:
  libfcoe: Allow FIP to be disabled by the driver (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-do-not-pad-fip-keep-alive-to-full-frame-size.patch:
  libfcoe: Do not pad FIP keep-alive to full frame size
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-don-t-send-els-in-fip-mode-if-no-fcf-selected.patch:
  libfcoe: don't send ELS in FIP mode if no FCF selected
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fcoe-libfcoe-npiv-support.patch:
  libfcoe, fcoe: libfcoe NPIV support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfcoe-fcoe-simplify-receive-flogi-response.patch:
  libfcoe: fcoe: simplify receive FLOGI response (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-allow-fip-receive-to-be-called-from-irq.patch:
  libfcoe: fip: allow FIP receive to be called from
  IRQ. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-should-report-link-to-libfc-whether-selected-or-not.patch:
  libfcoe: FIP should report link to libfc whether selected or
  not (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-use-scsi-host-number-to-identify-debug-messages.patch:
  libfcoe: fip: use SCSI host number to identify debug
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-formatting-and-comment-cleanups.patch:
  libfcoe: formatting and comment cleanups (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  modify change_queue_depth to take in reason why it is being
  called (fate#306857, fate#306859, bnc#551175).
- patches.suse/scsi-error-have-scsi-ml-call-change_queue_depth-to-handle-queue_full.patch:
  scsi error: have scsi-ml call change_queue_depth to handle
  QUEUE_FULL (fate#306857, fate#306859, bnc#551175).
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fixup patch to apply.
* Thu Nov 19 2009 hare@suse.de
  Port patches from SLES11:
- patches.fixes/scsi-dh-queuedata-accessors: Kernel bug triggered
  in multipath (bnc#486001).
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-detach-existing-hardware-handler:
  multipath: detach existing hardware handler if none was
  specified.
- patches.suse/dm-mpath-requeue-for-stopped-queue: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  multipath: Evaluate request result and sense code
  (FATE#303695,bnc#433920,bnc#442001).
* Thu Nov 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Kill support for kernel-$flavor
  symbols, we need a unified kernel-source for all flavors.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/bnx2i-use-common-iscsi-suspend-queue: bnx2i:
  use common iscsi suspend queue (FATE#307215).
- patches.fixes/iscsi-class-modify-handling-of-replacement-time:
  iscsi class: modify handling of replacement timeout
  (FATE#307215).
- patches.fixes/iser-set-tgt-and-lu-reset-timeout: iser: set
  tgt and lu reset timeout (FATE#307215).
- patches.fixes/libiscsi-add-warm-target-reset-tmf-support:
  libiscsi: add warm target reset tmf support (FATE#307215).
- patches.fixes/libiscsi-check-tmf-state-before-sending-pdu:
  libiscsi: Check TMF state before sending PDU (FATE#307215).
- patches.fixes/libiscsi-fix-login-text-checks-in-pdu-inject:
  libiscsi: fix login/text checks in pdu injection code
  (FATE#307215).
- patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl:
  add scsi target reset support to scsi ioctl.
- patches.fixes/scsi-devinfo-update-hitachi-entries: scsi_devinfo:
  update Hitachi entries (v2).
- patches.fixes/scsi-fc-class-failfast-bsg-requests: [SCSI]
  fc class: fail fast bsg requests.
- patches.drivers/cxgb3i: Delete.
- patches.drivers/cxgb3i-fixed-offload-array-size: Delete.
- patches.fixes/disable-lro-per-default: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/scsi_dh-always-attach-sysfs: scsi_dh: create
  sysfs file, dh_state for all SCSI disk devices.
- patches.fixes/scsi_dh-change-activate-interface: scsi_dh: Change
  the scsidh_activate interface to be asynchronous (bnc#556144).
- patches.fixes/scsi_dh-make-alua-handler-asynchronous: scsi_dh:
  Make alua hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-hp_sw-handler-asynchronous: scsi_dh:
  Make hp hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-rdac-handler-asynchronous: scsi_dh:
  Make rdac hardware handler's activate() async (bnc#556144).
* Thu Nov 19 2009 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Delete.
- patches.drivers/qla4xxx-sles11-update: Delete.
* Thu Nov 19 2009 hare@suse.de
- Update config files.
- patches.drivers/hpsa: hpsa: New driver SCSI driver for HP
  Smart Array (FATE#307153,bnc#555855).
- supported.conf: Mark hpsa as supported.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-01-qeth-isolation.patch: qeth: Exploit QDIO
  Data Connection Isolation (bnc#555199,LTC#57826,FATE#307015).
- patches.arch/s390-02-01-cex3-init-msg.patch:
  zcrypt: initialize ap_messages for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-02-cex3-special-command.patch:
  zcrypt: special command support for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-03-cex3-device.patch: zcrypt: add support
  for cex3 device types (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-04-cex3-use-def.patch: zcrypt: use
  definitions for cex3 (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-05-zcrypt-speed-cex2c.patch:
  zcrypt: adjust speed rating between cex2 and pcixcc
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-06-zcrypt-speed-cex3.patch:
  zcrypt: adjust speed rating of cex3 adapters
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch: Delete.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch:
  qeth: Exploit QDIO Data Connection Isolation
  (bnc#555199,LTC#57826,FATE#307015).
* Wed Nov 18 2009 jeffm@suse.com
- scripts/sequence-patch.sh: Add automatic generation of supported
  modules list.
* Wed Nov 18 2009 jeffm@suse.com
- Update config files: Enable CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/acpi-generic-initramfs-table-override-support:
  ACPI: generic initramfs table override support (bnc#533555).
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  init: move populate_rootfs back to start_kernel (bnc#533555).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "crypto: ghash-intel - Hard-code pshufb" fix
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default:
  hung_task_timeout: configurable default (bnc#552820).
  - Default to runtime-disabled on all flavors except debug.
* Wed Nov 18 2009 agraf@suse.de
- patches.fixes/kvm-ioapic.patch: Ignore apic polarity
  (bnc#556564).
- patches.fixes/kvm-macos.patch: Implement some missing intercepts
  so osx doesn't blow up (bnc#556564).
* Wed Nov 18 2009 hare@suse.de
- supported.conf: mark missing 10Gb drivers as supported
  (bnc#555793)
* Wed Nov 18 2009 hare@suse.de
- patches.drivers/aacraid-24701-update: Problems with aacraid
  (bnc#524242,FATE#307437).
* Wed Nov 18 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.apparmor/apparmor.diff: Refresh.
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Refresh.
- patches.suse/bootsplash: Refresh.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- patches.suse/silent-stack-overflow-2.patch: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
* Wed Nov 18 2009 agraf@suse.de
- Update config files to enable pv-ops for KVM clock. (bnc#556135)
* Wed Nov 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler: ALSA:
  hda - select IbexPeak handler for Calpella (FATE#306783).
- patches.drivers/alsa-sp1-hda-02-vectorize-get_empty_pcm_device:
  ALSA: hda - vectorize get_empty_pcm_device() (FATE#306783).
- patches.drivers/alsa-sp1-hda-03-allow-up-to-4-HDMI: ALSA:
  hda - allow up to 4 HDMI devices (FATE#306783).
- patches.drivers/alsa-sp1-hda-04-convert-intelhdmi-global-references:
  ALSA: hda - convert intelhdmi global references to local
  parameters (FATE#306783).
- patches.drivers/alsa-sp1-hda-05-remove-intelhdmi-dependency-on-multiout:
  ALSA: hda - remove intelhdmi dependency on multiout
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-06-use-pcm-prepare-callbacks-for-intelhdmi:
  ALSA: hda - use pcm prepare/cleanup callbacks for intelhdmi
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-07-reorder-intelhemi-prepare-callbacks:
  ALSA: hda - reorder intelhdmi prepare/cleanup callbacks
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-08-vectorize-intelhdmi: ALSA:
  hda - vectorize intelhdmi (FATE#306783).
- patches.drivers/alsa-sp1-hda-09-get-intelhtemi-max-channels:
  ALSA: hda - get intelhdmi max channels from widget caps
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-10-auto-parse-intelhdmi-cvt-pin:
  ALSA: hda - auto parse intelhdmi cvt/pin configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-11-remove-static-intelhdmi-config:
  ALSA: hda - remove static intelhdmi configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-12-reset-pins-idt-codec-free:
  ALSA: hda - Reset pins of IDT/STAC codecs at free (bnc#544779).
- patches.drivers/alsa-sp1-hda-13-add-reboot-notifier: ALSA:
  hda - Add reboot notifier to each codec (bnc#544779).
- patches.drivers/alsa-sp1-hda-14-add-missing-export: ALSA: hda -
  Add missing export for snd_hda_bus_reboot_notify (bnc#544779).
- patches.drivers/alsa-sp1-hda-15-fix-build-warning: ALSA: hda -
  Add a proper ifdef to a debug code (FATE#306783).
- patches.drivers/alsa-sp1-hda-16-stac-dual-headphones-fix:
  ALSA: hda - Fix detection of dual headphones (bnc#556532).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  crypto: ghash - Add PCLMULQDQ accelerated implementation
  (FATE#306883, bnc#554578).
- Update config files: set CRYPTO_GHASH_CLMUL_NI_INTEL=m
- patches.xen/xen3-patch-2.6.28: Refresh to apply cleanly
* Wed Nov 18 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Only export selected pv-ops feature structs (bnc#556135).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Replace kvm io delay pv-ops with linux magic (bnc#556135).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Split
  paravirt ops by functionality (bnc#556135).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Split the KVM pv-ops support by feature (bnc#556135).
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Nov 18 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: Delete.
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Also enable CONFIG_DMAR (fate#306796) for vanilla flavors
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Do the same for i386
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Enabling CONFIG_DMAR (fate#306796), introduces these changes:
    +CONFIG_HAVE_INTEL_TXT=y
  - # CONFIG_DMAR is not set
    +CONFIG_DMAR=y
    +# CONFIG_DMAR_DEFAULT_ON is not set
    +CONFIG_DMAR_FLOPPY_WA=y
    +# CONFIG_INTEL_TXT is not set
  Done for x86_64 for now only.
* Tue Nov 17 2009 jkosina@suse.de
- patches.fixes/hid-fixup-ncr-quirk.patch: HID: fixup quirk for
  NCR devices (bnc#548807).
* Fri Nov 13 2009 mmarek@suse.cz
- rpm/*.spec.in, rpm/kernel-module-subpackage: add
  Provides: multiversion(kernel) to binary kernel packages,
  kernel-source, kernel-syms and all KMPs so that zypp can be
  configured to keep multiple versions of these packages
  (fate#305311).
* Fri Nov 13 2009 npiggin@suse.de
- Disable LGUEST on x86 32. It doesn't build properly without PARAVIRT.
* Wed Nov 11 2009 jack@suse.cz
- patches.fixes/zisofs-large-pagesize-read.patch: zisofs:
  Implement reading of compressed files when PAGE_CACHE_SIZE >
  compress block size (bnc#540349).
* Wed Nov 11 2009 npiggin@suse.de
- Update config files.
* Wed Nov 11 2009 npiggin@suse.de
- Disable PARAVIRT_GUEST on x86 32 and 64.
* Tue Nov 10 2009 teheo@suse.de
- patches.drivers/libata-ahci-aspire-3810t-noncq: ahci: disable
  NCQ on Aspire 3810t (bnc#522790).
* Tue Nov 10 2009 npiggin@suse.de
- Update config files.
* Tue Nov 10 2009 npiggin@suse.de
- Update config files. Disable CONFIG_CC_STACKPROTECTOR on all
  x86 kernels except debug. Overhead is prohibitive.
* Mon Nov  9 2009 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: SLAB_DESTROY_BY_RCU for
  file slab.
* Mon Nov  9 2009 npiggin@suse.de
- Update config files. Vanilla doesn't have unwinder, trace selects
  options which select frame pointers.
* Mon Nov  9 2009 npiggin@suse.de
- Disable FRAME_POINTER on i386 and x86-64, all kernels. Unwind info
  should provide all this functionality.
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-honour-server-preferred-io-size: NFS: Honour
  server-preferred io sizes (bnc#550648).
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-slot-table-alloc: Don't fail allocations
  for the slot table when mounting an NFS filesystem (bnc#519820).
* Fri Nov  6 2009 trenn@suse.de
- patches.arch/x86_amd_fix_erratum_63.patch: x86/amd-iommu:
  Workaround for erratum 63 (bnc#548274).
* Fri Nov  6 2009 jeffm@suse.de
- Disabled PARAVIRT_GUEST on ia64/trace and ia64/vanilla.
* Fri Nov  6 2009 trenn@suse.de
- patches.suse/kdb_x86_fix_hang.patch: X86 KDB: Reduce timeout
  for blinking LEDs (bnc#528811).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix last change.
* Fri Nov  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc6 and c/s 941.
- Update Xen config files.
- supported.conf: Add domctl.
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add the /lib/modules/.../{source,devel}
  symlinks to the -devel package (bnc#548728).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kvm-kmp.
* Thu Nov  5 2009 jeffm@suse.com
- Update to 2.6.32-rc6.
  - 2 patches eliminated
  - NR_CPUS=4096 on ia64/vanilla again
* Thu Nov  5 2009 jeffm@suse.com
- Performance: Disabled CONFIG_PARAVIRT on all flavors.
* Thu Nov  5 2009 mmarek@suse.cz
- Delete unused 2.6.31.y patches.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: add libfcoe and fix typo.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: update so that supported modules don't require
  unsupported ones by adding following modules: async_pq
  async_raid6_recov ath blkback_pagemap crypto_hash drm_kms_helper
  fddi fscache lib80211 libfcoe libipw libiscsi_tcp llc md_mod mdio
  mfd_core nf_defrag_ipv4 p8022 psnap raid6_pq tr ttm ucb1400_core
  v4l2_compat_ioctl32.
* Thu Nov  5 2009 mmarek@suse.cz
- config.conf: remove kernel-ps3-devel (does not exist) and
  kernel-debug-devel (not needed most of the time) from
  kernel-syms.
* Thu Nov  5 2009 hare@suse.de
- Update config files: Set CONFIG_HZ to 100 for zSeries
  (bnc#552564).
* Thu Nov  5 2009 hare@suse.de
- Update config files: Increase MAX_RAW_DEVS to 4096 on
  zSeries (bnc#552565).
* Thu Nov  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete stray text.
* Tue Nov  3 2009 mmarek@suse.cz
- config.conf: remove the ec2 flavor from kernel-syms, most KMPs
  don't make any sense on ec2
  (http://lists.opensuse.org/opensuse-kernel/2009-11/msg00001.html).
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete also brocade-bfa-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: add split-modules to the src.rpm.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete enic-kmp and fnic-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kmps by their full name, not
  just the foo-kmp virtual dependency (bnc#472410).
* Thu Oct 29 2009 tonyj@suse.de
- Update ppc/ps3 config for CONFIG_UTRACE
* Thu Oct 29 2009 tonyj@suse.de
- patches.trace/utrace-core: Update for SP1 (FATE# 304321)
* Wed Oct 28 2009 nfbrown@suse.de
- patches.fixes/nfsd-acl.patch: nfsd: Fix sort_pacl in
  fs/nfsd/nf4acl.c to actually sort groups (bnc#549748).
* Wed Oct 28 2009 jdelvare@suse.de
- Update config files:
  CONFIG_NTFS_FS=n
  We handle NTFS through FUSE these days.
* Tue Oct 27 2009 jbohac@suse.cz
- Update config files:
  CONFIG_NETLABEL=y
  CONFIG_SECURITY_NETWORK_XFRM=y
  (fate#307284)
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix compilation failure for configs with CONFIG_SMP=n and
  CONFIG_FAR_GROUP_SCHED=y
* Tue Oct 27 2009 jbeulich@novell.com
- Update config files (MINIX_FS=m globally, NTFS_FS off for -ec2).
- supported.conf: Add fs/minix.
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/percpu-allow-pcpu_alloc-to-be-called-with-IRQs-off:
  percpu: allow pcpu_alloc() to be called with IRQs off
  (bnc#548119).
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  Update to newer version which is going to be merged upstream.
* Fri Oct 23 2009 jeffm@suse.com
- Update to 2.6.32-rc5-git3.
* Fri Oct 23 2009 mmarek@suse.cz
- Update config files: set NR_CPUS back to 2048 for ia64/vanilla
  until there is a fix in mainline.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix for !CONFIG_SMP.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Cleanup and make boot splash work with KMS (bnc#544645).
* Thu Oct 22 2009 jeffm@suse.com
- Re-enabled NR_CPUS=4096 on ia64.
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  sched: move rq_weight data array out of .percpu (bnc#548119).
* Tue Oct 20 2009 jbeulich@novell.com
- Update x86-64 Xen config file (NR_CPUS=512).
- Refresh a few Xen patches.
- rpm/kernel-binary.spec.in: Handle -ec2 flavor.
- rpm/package-descriptions: Describe -ec2 flavor.
- rpm/post.sh: Handle -ec2 flavor.
* Tue Oct 20 2009 jbeulich@novell.com
- patches.fixes/use-totalram_pages: Delete.
* Tue Oct 20 2009 jbeulich@novell.com
- config.conf: Add -ec2 configs (fate#305273)
- Add ec2 config files.
- patches.xen/xen-unpriv-build: No need to build certain bits
  when building non-privileged kernel.
- supported.conf: Add fs/nls/nls_base.
* Mon Oct 19 2009 jeffm@suse.com
- Temporarily reduce NR_CPUS to 2048 on ia64 to avoid build
  failures (bnc#548119)
* Mon Oct 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: [s390x] ignore errors from
  dwarfextract for now.
* Fri Oct 16 2009 jeffm@suse.com
- Update config files.
* Fri Oct 16 2009 jeffm@suse.com
- Update to 2.6.32-rc5.
* Fri Oct 16 2009 mmarek@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: ia64/sn: fix
  percpu warnings.
* Fri Oct 16 2009 mmarek@suse.de
- Update config files: disable MTD_GPIO_ADDR, VME_CA91CX42 and
  VME_TSI148 on ia64 to fix build.
* Fri Oct 16 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32-rc4: Fix AGP for PowerPC.
* Fri Oct 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc4 and c/s 938.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Tue Oct 13 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: Added missing sites.
* Mon Oct 12 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: staging: Complete
  sched.h removal from interrupt.h.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/ptrace_may_access-fix: apparmor:
  ptrace_may_access -> ptrace_access_check.
* Mon Oct 12 2009 jeffm@suse.de
- Update config files.
* Mon Oct 12 2009 jeffm@suse.de
- Updated to 2.6.32-rc4.
  - Eliminated 4 patches.
  - Refreshed context.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: Refresh and enable.
* Fri Oct  9 2009 jeffm@suse.de
- Cleanup unused patches:
  - patches.fixes/iwl3945-fix-rfkill.patch: Delete.
  - patches.fixes/iwlagn-fix-rfkill.patch: Delete.
  - patches.suse/kdb-serial-8250: Delete.
  - patches.suse/kdb-sysctl-context: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.fixes/scsi-add-tgps-setting: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.suse/kbuild-icecream-workaround: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/mm-avoid-bad-page-on-lru: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- Update vanilla config files.
* Fri Oct  9 2009 jeffm@suse.de
- Update to 2.6.32-rc3.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/tsi148-dependency: vme/tsi148: Depend on VIRT_TO_BUS
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-x86-build-fixes: kdb: Use $srctree not $TOPDIR
  in Makefile.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-prepare_multicast: winbond: implement
  prepare_multicast and fix API usage.
- patches.rpmify/winbond_beacon_timers: winbond: use
  bss_conf->beacon_int instead of conf->beacon_int.
- patches.rpmify/winbond-build-fixes: Delete.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/rtl8192e-build-fixes: rtl8192e: Add #include
  <linux/vmalloc.h>.
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-build-fixes: kdb: Build fixes.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/iio-s390-build-fix: iio: Don't build on s390.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-build-fixes: winbond: API fix.
* Thu Oct  8 2009 jeffm@suse.de
- Update vanilla config files.
* Thu Oct  8 2009 jeffm@suse.de
- Update config files.
* Thu Oct  8 2009 jeffm@suse.de
- Updated to 2.6.32-rc1 (AKA 2.6.32-rc2).
  - Eliminated 28 patches.
  - 14 patches need further review.
  - Xen and AppArmor are currently disabled.
  - USB support in KDB is disabled.
* Thu Oct  8 2009 gregkh@suse.de
- patches.kernel.org/patch-2.6.31.2-3: Linux 2.6.31.3.
  - major tty bugfix
* Wed Oct  7 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc268-automic-fix: ALSA: hda -
  Fix yet another auto-mic bug in ALC268 (bnc#544899).
* Wed Oct  7 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Fix the regression,
  "iostat reports wrong service time and utilization", introduced
  by this patch  (bnc#544926).
* Tue Oct  6 2009 gregkh@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Delete.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
  - both of these were not being used anyway.
* Tue Oct  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.2.
* Tue Oct  6 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc660vd-asus-a7k-fix: ALSA: hda -
  Add a workaround for ASUS A7K (bnc#494309).
* Mon Oct  5 2009 gregkh@suse.de
- refresh patch fuzz due to 2.6.31.2 import.
* Mon Oct  5 2009 gregkh@suse.de
- Update to Linux 2.6.31.2:
  - bugfixes, lots of them.
  - security fixes
* Mon Oct  5 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc861-toshiba-fix: ALSA: hda -
  Fix invalid initializations for ALC861 auto mode (bnc#544161).
* Fri Oct  2 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: Delete.
  The code never got upstream and looks incorrect.
* Fri Oct  2 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi-04-fix-surround-side-mute: ALSA:
  ctxfi: Swapped SURROUND-SIDE mute.
- patches.drivers/alsa-hda-2.6.32-rc1-toshiba-fix: ALSA: hda -
  Added quirk to enable sound on Toshiba NB200.
- patches.drivers/alsa-hda-2.6.32-rc2: ALSA: backport 2.6.32-rc2
  fixes for HD-audio.
* Thu Oct  1 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.1 and c/s 934.
* Thu Oct  1 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete quickcam-kmp (bnc#543361).
* Wed Sep 30 2009 gregkh@suse.de
- Update to 2.6.31.1
  - lots of bugfixes
  - security fixes
* Wed Sep 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete the sle11 ocfs2-kmp.
* Tue Sep 29 2009 trenn@suse.de
- Disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
  with +trenn (bnc#542767)
* Wed Sep 23 2009 teheo@suse.de
- Update config files.  Build pci-stub driver into the kernel so that
  built in pci drivers can be blocked from attaching to devices.
* Tue Sep 22 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: when building against Linus'
  kernels (2.6.x), append a .0 to the kernel version embedded in
  the KMP version, to ensure that such KMP is older than a KMP
  built against a subsequent stable kernel (2.6.x.y, y > 0).
* Mon Sep 21 2009 jeffm@suse.de
- Update config files.
* Mon Sep 21 2009 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Ported to
  2.6.31 (bnc#533555).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: do not remove the bootloader entry if the kernel
  version didn't change (bnc#533766).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: remove dead code.
* Fri Sep 18 2009 jeffm@suse.de
- patches.fixes/reiserfs-replay-honor-ro: reiserfs: Properly
  honor read-only devices (bnc#441062).
* Thu Sep 17 2009 jeffm@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86-64) (bnc#503038).
* Thu Sep 17 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-rc1: ALSA HD-audio backport
  from 2.6.32-rc1.
* Wed Sep 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31 final.
* Tue Sep 15 2009 teheo@suse.de
  Backport attach inhibition for builtin pci drivers from 2.6.32-rc.
- patches.drivers/pci-separate-out-pci_add_dynid: pci: separate
  out pci_add_dynid().
- patches.drivers/pci_stub-add-ids-parameter: pci-stub: add
  pci_stub.ids parameter.
* Tue Sep 15 2009 teheo@suse.de
  Backport patches from 2.6.32-rc to ease ossp testing.
- Update config files - SOUND_OSS_CORE_PRECLAIM is set to N.
- patches.drivers/implement-register_chrdev: chrdev: implement
  __register_chrdev().
- patches.drivers/sound-make-oss-device-number-claiming-optional:
  sound: make OSS device number claiming optional and schedule
  its removal.
- patches.drivers/sound-request-char-major-aliases-for-oss-devices:
  sound: request char-major-* module aliases for missing OSS
  devices.
* Mon Sep 14 2009 sdietrich@suse.de
- patches.suse/novfs-client-module: Update header todo list with
  locking nits (semaphore used as mutex / completion)
* Mon Sep 14 2009 jeffm@suse.com
- Revert back to CONFIG_M586TSC from CONFIG_M686 for default flavor
  (bnc#538849)
* Fri Sep 11 2009 jbeulich@novell.com
- patches.suse/crasher-26.diff: Add capability to also trigger a
  kernel warning.
* Fri Sep 11 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Seperate read
  and write statistics of in_flight requests (fate#306525).
* Thu Sep 10 2009 gregkh@suse.de
- patch fuzz removal now that 2.6.31 is the base.
* Thu Sep 10 2009 gregkh@suse.de
- Update config files.
    CONFIG_MOUSE_PS2_ELANTECH=y
    CONFIG_MOUSE_PS2_TOUCHKIT=y
    (bnc#525607)
* Thu Sep 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh: fix misc realtek
  issues, add another Nvidia HDMI device id
* Thu Sep 10 2009 jeffm@suse.de
- Updated to 2.6.31-final.
* Tue Sep  8 2009 gregkh@suse.de
- refresh patches for fuzz due to upstream changes
* Tue Sep  8 2009 gregkh@suse.de
- Update to 2.6.31-rc9
  - obsoletes:
  - patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708
  - patches.drivers/alsa-hda-fix-02-mbp31-hp-fix
* Tue Sep  8 2009 knikanth@suse.de
- patches.fixes/scsi_dh-Provide-set_params-interface-in-emc-device-handler.patch:
  scsi_dh: Provide set_params interface in emc device handler
  (bnc#521607).
- patches.fixes/scsi_dh-Use-scsi_dh_set_params-in-multipath.patch:
  scsi_dh: Use scsi_dh_set_params() in multipath. (bnc#521607).
- patches.fixes/scsi_dh-add-the-interface-scsi_dh_set_params.patch:
  scsi_dh: add the interface scsi_dh_set_params() (bnc#521607).
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: delete obsolete macro.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: require minimum versions of
  module-init-tools and perl-Bootloader, the %%post script is no
  longer compatible with ancient versions.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.31, the
  previous <= 2.6.30-1 didn't catch some cases obviously
  (bnc#533766).
* Fri Sep  4 2009 jeffm@suse.de
- Enabled CONFIG_SCSI_DEBUG=m (bnc#535923).
* Fri Sep  4 2009 mmarek@suse.cz
- kabi/severities, rpm/kabi.pl, rpm/kernel-binary.spec.in,
- rpm/kernel-source.spec.in: Use a simple script to check kabi by
  comparing Module.symvers files (similar to the old SLES9 one).
- rpm/built-in-where: Delete.
- rpm/symsets.pl: Delete.
- kabi/commonsyms: Delete.
- kabi/usedsyms: Delete.
* Fri Sep  4 2009 mmarek@suse.cz
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin:
  kbuild: rebuild fix for Makefile.modbuiltin.
* Thu Sep  3 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  Delete, it was wrong.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen config files.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc8 and c/s 931.
- patches.fixes/use-totalram_pages: use totalram_pages in favor
  of num_physpages for sizing boot time allocations (bnc#509753).
- patches.xen/xen-x86-per-cpu-vcpu-info: x86: use per-cpu storage
  for shared vcpu_info structure.
* Wed Sep  2 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh; merged fixes for
  IDT92HD73* codecs
* Tue Sep  1 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: Update to latest git.
* Tue Sep  1 2009 jeffm@suse.com
- patches.arch/add_support_for_hpet_msi_intr_remap.patch:
  intr-remap: generic support for remapping HPET MSIs
  (bnc#532758).
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  x86: arch specific support for remapping HPET MSIs (bnc#532758).
* Tue Sep  1 2009 mmarek@suse.cz
- rpm/package-descriptions: fix description of the x86_64
  kernel-desktop package (bnc#535457).
* Mon Aug 31 2009 jeffm@suse.com
- Update to 2.6.31-rc8.
  - Eliminated 1 patch.
* Mon Aug 31 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708:
  ALSA: hda - Add missing mux check for VT1708 (bnc#534904).
- patches.drivers/alsa-hda-fix-02-mbp31-hp-fix: ALSA: hda -
  Fix MacBookPro 3,1/4,1 quirk with ALC889A.
- patches.drivers/alsa-hda-2.6.32-pre: Refresh.
* Wed Aug 26 2009 tiwai@suse.de
- patches.drivers/alsa-hda-[0-9]*: Delete, fold into a single patch
  patches.drivers/alsa-hda-2.6.32-pre
* Tue Aug 25 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Delete.
* Tue Aug 25 2009 jbeulich@novell.com
- scripts/run_oldconfig.sh: Consistently use $prefix.
* Mon Aug 24 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.30-1
  (bnc#530752).
* Mon Aug 24 2009 jeffm@suse.com
- Update to 2.6.31-rc7.
  - Eliminated 3 patches.
* Mon Aug 24 2009 jeffm@suse.com
- Update config files: Enable CONFIG_PROC_EVENTS.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh: Do not call /sbin/module_upgrade, the rename
  happened before SLES10.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/module-renames: Delete, we don't need to care about modules
  renamed before SLES10. Also, current mkinitrd gets the list of
  storage drivers based on pci ids.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: drop support for SLE10, the package
  can't be installed on SLE10 as is, so why not make it more
  adventurous.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove product(openSUSE) supplements
  from the -extra subpackage which doesn't exist on openSUSE
  anymore.
* Thu Aug 20 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-0*: Backport from 2.6.31-rc fixes
  (to be merged)
- patches.drivers/alsa-hda-32-Reword-auto-probe-messages: Refresh.
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Thu Aug 20 2009 jbeulich@novell.com
- Update config files (modularize crypto again).
- supported.conf: Add resulting modules as supported.
* Wed Aug 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc6 and c/s 928.
* Wed Aug 19 2009 tiwai@suse.de
- patches.drivers/alsa-hda-48-alc268-oops-fix: ALSA: hda -
  Fix invalid capture mixers with some ALC268 models.
* Tue Aug 18 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  USB: storage: increase the bcd range in Sony's bad device
  table. (bnc#466554).
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: Change the range from
  0-255 to 0-7 to make it easier for HAL to handle the device without a
  need for custom scripts.
* Mon Aug 17 2009 jeffm@suse.com
- Updated to 2.6.31-rc6.
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: added N120 support
  and some other devices that were integrated into the driver from
  upstream.
* Sun Aug 16 2009 coly.li@suse.de
- supported.conf:
  set kernel/fs/dlm/dlm as unsupported, since fs/dlm is provided
  separately in the ocfs2 KMP package
* Sat Aug 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-47-idt92hd8x-fix: ALSA: hda - Fix /
  clean up IDT92HD83xxx codec parser (bnc#531533).
* Sat Aug 15 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Samsung
  backlight driver (bnc#527533, bnc#531297).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add some hints how to set the %%jobs
  macro (bnc#530535).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/modversions: for overriden functions, keep the keyword in
  - -pack.
* Thu Aug 13 2009 jeffm@suse.com
- Updated to 2.6.31-rc5-git9.
  - Eliminated 7 patches.
* Thu Aug 13 2009 tiwai@suse.de
- patches.drivers/alsa-hda-42-hp-more-quirk: ALSA: hda - Add
  quirks for some HP laptops (bnc#527284).
- patches.drivers/alsa-hda-4[35]-*: Improve Realtek codec mic
  support
- patches.drivers/alsa-hda-46-stac-lo-detect-fix: ALSA: hda -
  Enable line-out detection only with speakers (bnc#520975).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/split-modules, rpm/kernel-binary.spec.in: add the base files
  also to the main package. That way, kernel-$flavor-base is not
  needed in normal setups (fate#307154).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/find-provides: no rpm provides for drivers/staging. It's
  higly unlikely that any KMP would require them and they just
  take up space in the rpm metadata.
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-41-msi-white-list: ALSA: hda - Add
  a white-list for MSI option (bnc#529971).
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-39-dont-override-ADC-definitions:
  ALSA: hda - Don't override ADC definitions for ALC codecs
  (bnc#529467).
- patches.drivers/alsa-hda-40-auto-mic-support-for-realtek:
  ALSA: hda - Add auto-mic support for Realtek codecs.
* Tue Aug 11 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: do not rename kernel-source.rpmlintrc
  for the -rt variant.
* Mon Aug 10 2009 mmarek@suse.cz
- patches.rpmify/staging-rtl8192su-fix-build-error.patch: move to
  patches.rpmify to fix vanilla ppc builds.
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-38-fix-ALC269-vmaster: ALSA: hda -
  Add missing vmaster initialization for ALC269 (bnc#527361).
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Fri Aug  7 2009 jeffm@suse.com
- patches.fixes/recordmcount-fixup: recordmcount: Fixup wrong
  update_funcs() call.
* Fri Aug  7 2009 tiwai@suse.de
- patches.drivers/alsa-soc-fsl-build-fixes: ASoC: Add missing
  DRV_NAME definitions for fsl/* drivers (to fix PPC builds)
* Fri Aug  7 2009 tiwai@suse.de
- patches.arch/wmi-Fix-kernel-panic-when-stack-protection-enabled:
  wmi: Fix kernel panic when stack protection
  enabled. (bnc#529177).
- supported.conf: Update HD-audio modules
* Fri Aug  7 2009 mmarek@suse.cz
- make config/s390/vanilla a symlink again.
* Fri Aug  7 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: do not manually extract vmlinux
  debuginfo on ppc(64), rpm does it itself.
* Thu Aug  6 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Added kernel-spec-macros to Sources.
* Thu Aug  6 2009 jeffm@suse.de
- patches.suse/linux-2.6.29-even-faster-kms.patch: Disabled. It
  doesn't wake up the display on certain hardware.
* Wed Aug  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not split the -extra subpackage on
  openSUSE (bnc#528097).
* Wed Aug  5 2009 jeffm@suse.de
- Updated to 2.6.31-rc5-git3.
  - Eliminated 4 patches.
* Wed Aug  5 2009 gregkh@suse.de
- kernel-source.changes: remove old (pre 2008) messages, and move 2008
  to kernel-source.changes.old.  No need to spam email addresses that
  are no longer with the company for failed kernel builds.
* Wed Aug  5 2009 gregkh@suse.de
- patches.drivers/staging-rtl8192su-fix-build-error.patch:
  Staging: rtl8192su: fix build error.
* Wed Aug  5 2009 jeffm@suse.de
- patches.suse/supported-flag-enterprise: Make the supported
  flag configurable at build time (bnc#528097).
* Wed Aug  5 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910 for vanilla builds
* Tue Aug  4 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910
* Tue Aug  4 2009 jeffm@suse.de
- patches.rpmify/ttm-pgprot-fixes: ttm: Use pgprot_val for
  comparing pgprot_t.
* Tue Aug  4 2009 tiwai@suse.de
- patches.drivers/alsa-hda-3[0-8]*: ALSA HD-audio updates
- Update config files: enable CONFIG_SND_HDA_CIRRUS=y
* Mon Aug  3 2009 jeffm@suse.de
- Update config files: CONFIG_FRAME_WARN=2048 on all arches, fixes
  ppc build failures.
* Mon Aug  3 2009 jeffm@suse.de
- patches.xen/xen3-patch-2.6.31-rc4-rc5: Fixup pgtable port
* Mon Aug  3 2009 jeffm@suse.de
- Updated to 2.6.31-rc5.
  - Eliminated 11 patches.
* Mon Aug  3 2009 coly.li@suse.de
- Update config files to enable CONFIG_DLM_DEBUG.
* Fri Jul 31 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc4 and c/s 916.
- patches.xen/xen3-driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Delete.
- patches.xen/xen3-panic-on-io-nmi.diff: Delete.
- config.conf: Re-enable Xen.
- Update config files.
* Wed Jul 29 2009 tiwai@suse.de
- Update config files: revert to CONFIG_SND=m and enabled again
  CONFIG_SND_DEBUG=y
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_PRISM2_USB on ia64 and ppc.
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_FB_UDL on ia64.
* Tue Jul 28 2009 jbeulich@novell.com
- config.conf: Remove duplicate i386/desktop entry.
* Tue Jul 28 2009 tiwai@suse.de
- patches.drivers/alsa-hda-29-Add-quirk-for-Dell-Studio-1555:
  ALSA: hda - Add quirk for Dell Studio 1555 (bnc#525244).
* Mon Jul 27 2009 tiwai@suse.de
- patches.drivers/alsa-pcm-*: ALSA PCM fixes
- Fix/enhancement patches backported from ALSA tree
  * patches.drivers/alsa-core-Add-new-TLV-types-for-dBwith-min-max:
    ALSA: Add new TLV types for dBwith min/max (for usb).
  * patches.drivers/alsa-ctxfi-*: SB X-Fi support (FATE#306935).
  * patches.drivers/alsa-hda-*: More HD-audio fixes
  * patches.drivers/alsa-ice-*: ICE17xx fixes
  * patches.drivers/alsa-midi-*: MIDI fixes
  * patches.drivers/alsa-usb-*: USB-audio/MIDI fixes
- Remove obsoleted patches: patches.drivers/alsa-ad1984a-hp-quirks,
  patches.drivers/alsa-ca0106-capture-bufsize-fix,
  patches.drivers/alsa-ctxfi
- Update config files.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, scripts/tar-up.sh: really drop
  config-subst from the package.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: manually create a -devel-debuginfo
  subpackage with vmlinux.debug to fix build with new rpm. This
  works for ix86 and x86_64, other archs might need further fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: more ia64 fixes
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Sun Jul 26 2009 jeffm@suse.de
- config.conf: Re-enabled trace flavor.
* Fri Jul 24 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on i386 and x86_64
  across all flavors.
* Fri Jul 24 2009 jeffm@suse.de
- Update to 2.6.31-rc4.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: cleanup %%cpu_arch_flavor definition,
  make %%symbols a variable and only use it for selecting patches.
  Also drop the RT symbol as there are not rt patches currently.
* Thu Jul 23 2009 mmarek@suse.cz
- Change the s390(x) config layout so that each arch has its own
  subdirectory, as it is done for other archs. s390/vanilla is a
  symlink to s390x/vanilla.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/kernel-spec-macros: move some common
  macros to kernel-spec-macros.
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-bufsize-fix: ALSA: ca0106 -
  Fix the max capture buffer size (bnc#521890).
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi: Add SoundBlaster X-Fi support
  (FATE#306935).
- Update config files.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  Delete.
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  Delete.
- patches.drivers/cpufreq_change_load_calculation_2.patch: Delete.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  Delete.
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  Delete.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  Delete.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Delete.
- patches.arch/thinkpad_fingers_off_backlight_igd.patch: Delete.
* Tue Jul 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove double-slash from include2/asm
  symlink.
* Tue Jul 21 2009 mmarek@suse.cz
- config.conf, rpm/mkspec: exclude trace, kdump and ia64/debug from
  the kernel-syms package. These flavor are often excluded in KMPs,
  so excluding them from kernel-syms reduces useless build
  dependencies. KMPs can buildrequire kernel-$flavor-devel
  explicitely if desired.
* Tue Jul 21 2009 mmarek@suse.cz
  Delete obsolete apparmor patches.
- patches.apparmor/add-path_permission.diff: Delete.
- patches.apparmor/add-security_path_permission: Delete.
- patches.apparmor/apparmor-2.6.25.diff: Delete.
- patches.apparmor/apparmor-audit.diff: Delete.
- patches.apparmor/apparmor-intree.diff: Delete.
- patches.apparmor/apparmor-lsm.diff: Delete.
- patches.apparmor/apparmor-main.diff: Delete.
- patches.apparmor/apparmor-misc.diff: Delete.
- patches.apparmor/apparmor-module_interface.diff: Delete.
- patches.apparmor/apparmor-network.diff: Delete.
- patches.apparmor/apparmor-path_permission: Delete.
- patches.apparmor/apparmor-ptrace-2.6.27.diff: Delete.
- patches.apparmor/apparmor-rlimits.diff: Delete.
- patches.apparmor/d_namespace_path.diff: Delete.
- patches.apparmor/d_namespace_path_oops_fix.diff: Delete.
- patches.apparmor/do_path_lookup-nameidata.diff: Delete.
- patches.apparmor/export-security_inode_permission-for-aufs:
  Delete.
- patches.apparmor/file-handle-ops.diff: Delete.
- patches.apparmor/fix-complain.diff: Delete.
- patches.apparmor/fix-vfs_rmdir.diff: Delete.
- patches.apparmor/fork-tracking.diff: Delete.
- patches.apparmor/fsetattr-reintro-ATTR_FILE.diff: Delete.
- patches.apparmor/fsetattr-restore-ia_file.diff: Delete.
- patches.apparmor/fsetattr.diff: Delete.
- patches.apparmor/remove_suid.diff: Delete.
- patches.apparmor/security-create.diff: Delete.
- patches.apparmor/security-getxattr.diff: Delete.
- patches.apparmor/security-link.diff: Delete.
- patches.apparmor/security-listxattr.diff: Delete.
- patches.apparmor/security-mkdir.diff: Delete.
- patches.apparmor/security-mknod.diff: Delete.
- patches.apparmor/security-readlink.diff: Delete.
- patches.apparmor/security-removexattr.diff: Delete.
- patches.apparmor/security-rename.diff: Delete.
- patches.apparmor/security-rmdir.diff: Delete.
- patches.apparmor/security-setattr.diff: Delete.
- patches.apparmor/security-setxattr.diff: Delete.
- patches.apparmor/security-symlink.diff: Delete.
- patches.apparmor/security-unlink.diff: Delete.
- patches.apparmor/security-xattr-file.diff: Delete.
- patches.apparmor/sysctl-pathname.diff: Delete.
- patches.apparmor/unambiguous-__d_path.diff: Delete.
- patches.apparmor/vfs-getxattr.diff: Delete.
- patches.apparmor/vfs-link.diff: Delete.
- patches.apparmor/vfs-listxattr.diff: Delete.
- patches.apparmor/vfs-mkdir.diff: Delete.
- patches.apparmor/vfs-mknod.diff: Delete.
- patches.apparmor/vfs-notify_change.diff: Delete.
- patches.apparmor/vfs-removexattr.diff: Delete.
- patches.apparmor/vfs-rename.diff: Delete.
- patches.apparmor/vfs-rmdir.diff: Delete.
- patches.apparmor/vfs-setxattr.diff: Delete.
- patches.apparmor/vfs-symlink.diff: Delete.
- patches.apparmor/vfs-unlink.diff: Delete.
* Tue Jul 21 2009 npiggin@suse.de
- Update config files for bnc#522686 -- set
  CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR=65536.
* Mon Jul 20 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on all flavors
  (FATE#305694)
* Mon Jul 20 2009 jeffm@suse.de
- Update config files.
* Mon Jul 20 2009 jeffm@suse.com
- Update to 2.6.30.2
  - lots of security and bug fixes
  - Obsoleted patches.fixes/firmware-memmap-64bit.diff
* Mon Jul 20 2009 mmarek@suse.cz
- rpm/split-modules: set LC_COLLATE=C
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64 (FATE#305694)
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Fri Jul 17 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: simplify the add_dirs_to_filelist
  function and make it less chatty in build logs.
* Fri Jul 17 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 jeffm@suse.com
- patches.apparmor/security-default-lsm: security: Define default
  LSM (bnc#442668).
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.rpmify/sgi-hotplug-fixup: hotplug: fix sgi-hotplug
  attribute handling.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: drop the config-subst script, use
  scripts/config instead.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix debugsource generation.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/split-modules: fix last change.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/split-modules: fix for module names with underscores or
  dashes.
* Wed Jul 15 2009 jeffm@suse.de
- Update to 2.6.31-rc3.
  - Eliminated 2 patches.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: annotate in which products the
  obsoleted kmps were last used, remove "ralink-rt2860-kmp" which
  I couldn't find anywhere.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete btusb-kmp (bnc#514375).
* Tue Jul 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/split-modules: move generating of
  the base / main / unsupported module lists to a separate script.
  Avoids 6k modinfo calls and fixes module dependencies
  (bnc#512179).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix include2/asm symlink (bnc#509680).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of function symbols.
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of unknown symbols.
* Tue Jul  7 2009 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Delete the leftover debugging patches for e1000e EEPROM corruption
  that are not needed anymore.
* Tue Jul  7 2009 aj@suse.de
- README.BRANCH: Update, kotd will become 11.2 eventually.
* Mon Jul  6 2009 jeffm@suse.com
- Update to 2.6.31-rc2.
* Fri Jul  3 2009 jeffm@suse.com
- Update to 2.6.31-rc1-git10.
  - Eliminated 28 patches.
  - Xen is disabled.
* Fri Jul  3 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: kbuild: generate
  modules.builtin.
- rpm/kernel-binary.spec.in: package modules.builtin for use by
  modprobe / mkinitrd.
* Fri Jul  3 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: simplify
  the patch applying loops to reduce noise in build logs.
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: chmod +x find-provides
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not "annotate" the packaged
  Modules.symvers
- patches.suse/modpost-filter-out-built-in-depends: Delete.
* Tue Jun 30 2009 jbeulich@novell.com
- patches.arch/ia64-page-migration: Fix compiler warning.
* Mon Jun 29 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/symvers* files back to
  - base, these are needed during KMP installation.
* Mon Jun 29 2009 mmarek@suse.cz
- patches.fixes/kbuild-fix-generating-of-.symtypes-files: kbuild:
  fix generating of *.symtypes files.
- patches.suse/genksyms-add-override-flag.diff: Refresh.
- rpm/kernel-binary.spec.in: create the *.symref files in the build
  directory
* Fri Jun 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add Provides: kernel-{base,extra} to
  the subpackages (bnc#516827).
* Wed Jun 24 2009 gregkh@suse.de
- Update config files.
  revert the ACPI and thermal config changes:
    config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=m
  CONFIG_ACPI_BATTERY=m
  CONFIG_ACPI_BUTTON=m
  CONFIG_ACPI_VIDEO=m
  CONFIG_ACPI_FAN=m
  CONFIG_ACPI_PROCESSOR=m
  CONFIG_ACPI_THERMAL=m
  CONFIG_ACPI_CONTAINER=m
  CONFIG_X86_ACPI_CPUFREQ=m
  CONFIG_THERMAL=m
* Wed Jun 24 2009 gregkh@suse.de
- patches.suse/ec_merge_irq_and_poll_modes.patch: Delete.
- patches.suse/linux-2.6.29-retry-root-mount.patch: Delete.
* Wed Jun 24 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30 and c/s 908.
- Update Xen config files.
- patches.xen/tmem: Transcendent memory ("tmem") for Linux.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=y
  CONFIG_ACPI_BATTERY=y
  CONFIG_ACPI_BUTTON=y
  CONFIG_ACPI_VIDEO=y
  CONFIG_ACPI_FAN=y
  CONFIG_ACPI_PROCESSOR=y
  CONFIG_ACPI_THERMAL=y
  CONFIG_ACPI_CONTAINER=y
  CONFIG_X86_ACPI_CPUFREQ=y
  CONFIG_THERMAL=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_SND_TIMER=y
  CONFIG_SND_PCM=y
  CONFIG_SND_SEQUENCER=y
  CONFIG_SND_MIXER_OSS=y
  CONFIG_SND_PCM_OSS=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  fix up config mistake in x86-64/default made in last commit.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_VIDEO_OUTPUT_CONTROL=y
  CONFIG_SOUND=y
  CONFIG_SND=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_I2C=y
  CONFIG_HWMON=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_IPV6=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_HID=y
  CONFIG_USB_STORAGE=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ATA_PIIX=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_USB_EHCI_HCD=Y
  CONFIG_USB_OHCI_HCD=Y
  CONFIG_USB_UHCI_HCD=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_CFG80211=Y
  CONFIG_LIB80211=Y
  CONFIG_MAC80211=Y
  CONFIG_ATH5K=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_X86_MSR=Y
  CONFIG_X86_CPUID=Y
* Fri Jun 19 2009 gregkh@suse.de
- comment out broken acpi patch for the moment.
* Fri Jun 19 2009 gregkh@suse.de
- move the "preload" branch into master to get 2.6.30 working
  for Moblin.
- Update config files.
- patches.drivers/alsa-ad1984a-hp-quirks: ALSA: update HP
  quirks for Zenith & co (bnc#472789, bnc#479617, bnc#502425,
  bnc#503101).
- patches.suse/driver-core-add-nodename-callbacks.patch: Driver
  Core: add nodename callbacks.
- patches.suse/driver-core-aoe-add-nodename-for-aoe-devices.patch:
  Driver Core: aoe: add nodename for aoe devices.
- patches.suse/driver-core-block-add-nodename-support-for-block-drivers.patch:
  Driver Core: block: add nodename support for block drivers..
- patches.suse/driver-core-bsg-add-nodename-for-bsg-driver.patch:
  Driver Core: bsg: add nodename for bsg driver.
- patches.suse/driver-core-devtmpfs-driver-core-maintained-dev-tmpfs.patch:
  Driver Core: devtmpfs - kernel-maintained tmpfs-based /dev.
- patches.suse/driver-core-drm-add-nodename-for-drm-devices.patch:
  Driver Core: drm: add nodename for drm devices.
- patches.suse/driver-core-dvb-add-nodename-for-dvb-drivers.patch:
  Driver Core: dvb: add nodename for dvb drivers.
- patches.suse/driver-core-input-add-nodename-for-input-drivers.patch:
  Driver Core: input: add nodename for input drivers.
- patches.suse/driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Driver Core: misc: add nodename support for misc devices..
- patches.suse/driver-core-raw-add-nodename-for-raw-devices.patch:
  Driver Core: raw: add nodename for raw devices.
- patches.suse/driver-core-sound-add-nodename-for-sound-drivers.patch:
  Driver Core: sound: add nodename for sound drivers.
- patches.suse/driver-core-usb-add-nodename-support-for-usb-drivers.patch:
  Driver Core: usb: add nodename support for usb drivers..
- patches.suse/driver-core-x86-add-nodename-for-cpuid-and-msr-drivers.patch:
  Driver Core: x86: add nodename for cpuid and msr drivers..
- patches.suse/ec_merge_irq_and_poll_modes.patch: ACPI: EC:
  Merge IRQ and POLL modes.
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: fastboot:
  remove "wait for all devices before mounting root" delay.
- patches.suse/linux-2.6.29-enable-async-by-default.patch:
  enable async_enabled by default.
- patches.suse/linux-2.6.29-even-faster-kms.patch: speed up kms
  even more.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval.
- patches.suse/linux-2.6.29-kms-after-sata.patch: make kms happen
  after sata.
- patches.suse/linux-2.6.29-retry-root-mount.patch: fastboot:
  retry mounting the root fs if we can't find init.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Silence
  acer wmi driver on non-acer machines.
- patches.suse/linux-2.6.29-touchkit.patch: some new touch screen
  device ids
  .
- patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch:
  uvcvideo: ignore hue control for 5986:0241 (bnc#499152).
- patches.suse/devtmpfs.patch: Delete.
* Fri Jun 12 2009 greg@suse.de
- scripts/sequence-patch.sh: fix bug in ketchup usage
* Wed Jun 10 2009 jeffm@suse.com
- Update to 2.6.30-final.
* Wed Jun 10 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30-rc8 and c/s 898.
- Update Xen config files.
- patches.xen/pci-reserve: linux/pci: reserve io/memory space
  for bridge.
- patches.xen/xen-x86-exports: Delete.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: update copyright header and
  change indentation to what autobuild enforces on checkin. No
  functional change.
* Tue Jun  9 2009 jbeulich@novell.com
- patches.suse/stack-unwind-add-declaration.patch: Fold into ...
- patches.suse/stack-unwind: ... this one.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/vmlinux-*.gz to -devel
  again.
- rpm/find-provides: don't generate the ksym() provides ourself,
  let rpm do it. Add a workaround for vmlinux-*.gz in -devel.
* Mon Jun  8 2009 jeffm@suse.com
- patches.suse/reiser4-set_page_dirty_notag: mm: Add
  set_page_dirty_notag() helper for reiser4.
* Fri Jun  5 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: add Enhances: kernel-$flavor to
  kmps (bnc#502092).
* Thu Jun  4 2009 jeffm@suse.de
- Update to 2.6.30-rc8.
* Thu Jun  4 2009 sdietrich@suse.de
- supported.conf: remove duplicate kernel/drivers/md/dm-log
* Thu Jun  4 2009 teheo@suse.de
  Conver ide major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Mon Jun  1 2009 jeffm@suse.de
- Update to 2.6.30-rc7-git4.
* Fri May 29 2009 teheo@suse.de
  Rename mangle_minor to mangle_devt and also cover sd major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Fri May 29 2009 teheo@suse.de
- Update config files to enable DEBUG_BLOCK_EXT_DEVT on all configs
  except for vanilla and ppc/ps3.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_minor parameter (fate#305584).
* Thu May 28 2009 jdelvare@suse.de
- patches.fixes/scsi-scan-blist-update: Add BLIST_REPORTLUN2 to
  EMC SYMMETRIX (bnc#185164, bnc#191648, bnc#505578).
* Wed May 27 2009 jeffm@suse.com
- Update to 2.6.30-rc7-git2.
* Wed May 27 2009 gregkh@suse.de
- patches.drivers/ath1e-add-new-device-id-for-asus-hardware.patch:
  ath1e: add new device id for asus hardware.
* Tue May 26 2009 mmarek@suse.cz
- rpm/mkspec: when using a custom release number, create a
  get_release_number.sh script for autobuild.
* Tue May 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround for bnc#507084: strip
  binaries in /usr/src/linux-obj/*/*/scripts.
* Tue May 26 2009 jdelvare@suse.de
- patches.drivers/r8169-allow-true-forced-mode-setting.patch:
  r8169: allow true forced mode setting (bnc#467518).
* Mon May 25 2009 mmarek@suse.cz
- switch i386 flavors back to -default (non-pae) and -pae for
  milestone2
* Sun May 24 2009 mmarek@suse.cz
- rpm/find-provides: fix for kernel-kdump.
* Sat May 23 2009 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in, rpm/symsets.pl:
  workaround to fix provides of built-in symbols: move vmlinux*.gz
  back to -base and extract the provides from it.
* Fri May 22 2009 teheo@suse.de
- patches.arch/i586-unwind-quick-fix: i586-relocs: ignore NONE
  relocation.
* Fri May 22 2009 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh, rpm/mkspec, scripts/tar-up.sh: avoid
  unpacking the patches tarballs in compute-PATCHVERSION.sh.
* Fri May 22 2009 mmarek@suse.cz
- rpm/mkspec: add --release option to set a custom release string.
- scripts/tar-up.sh: revive -rs option.
* Wed May 20 2009 mmarek@suse.cz
- patches.arch/acpi_thermal_passive_blacklist.patch,
  patches.suse/devtmpfs.patch: fix patches to apply with git-apply.
* Tue May 19 2009 sdietrich@suse.de
- patches.suse/stack-unwind-add-declaration.patch: Fix compile
  error when CONFIG_STACK_UNWIND is not set.
* Tue May 19 2009 jblunck@suse.de
- patches.rpmify/arm-arch_include_asm-fix.diff: ARM: move
  mach-types.h to arch/include/asm.
* Tue May 19 2009 jeffm@suse.com
- Set CONFIG_FRAMEBUFFER_CONSOLE=y
* Tue May 19 2009 jeffm@suse.com
- Restored CONFIG_BOOTSPLASH=y and CONFIG_FB_VESA=y on
  x86/x86_64 (bnc#504608)
* Tue May 19 2009 jbeulich@novell.com
- patches.xen/sfc-endianness: fix building with gcc 4.4.
* Tue May 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30/rc6-git3 and c/s 873.
* Mon May 18 2009 jeffm@suse.com
- Updated to 2.6.30-rc6-git3.
  - Eliminated 4 patches.
* Fri May 15 2009 jeffm@suse.de
- doc/README.SUSE: Updated to reflect building in an external
  directory so as not to contaminate /usr/src/linux
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix path in
  /usr/src/linux-obj/.../Makefile.
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: provide kernel-$flavor-devel =
  %%version-%%source_rel in the -devel packages (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also fix kernel-$flavor-devel requires
  (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/mkspec: fix kernel-syms requires (bnc#503280).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/dup2-retval-fix: dup2: Fix return value with
  oldfd == newfd and invalid fd (bnc#498042).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-fixup: reiserfs: clean up ifdefs.
- patches.fixes/reiserfs-xattr-root-fixup: reiserfs: deal with
  NULL xattr root w/ xattrs disabled.
- patches.fixes/reiserfs-xattrs-disabled-perms: reiserfs: fixup
  perms when xattrs are disabled.
- patches.fixes/reiserfs-expose-privroot: reiserfs: allow exposing
  privroot w/ xattrs enabled.
* Mon May 11 2009 jeffm@suse.de
- Updated to 2.6.30-rc5-git1.
  - Eliminated 4 patches.
* Wed May  6 2009 gregkh@suse.de
- Update config files. update vanilla configs so that the build works.
* Wed May  6 2009 gregkh@suse.de
- Update config files.
- patches.suse/devtmpfs.patch: driver-core: devtmpfs - driver-core
  maintained /dev tmpfs.
* Tue May  5 2009 jeffm@suse.com
- Update config files.
* Tue May  5 2009 jeffm@suse.com
- Update to 2.6.30-rc4-git1.
- patches.rpmify/fix-unexpected-non-allocable-warnings-with-suse-gcc:
  kbuild, modpost: fix "unexpected non-allocatable" warning with
  SUSE gcc.
* Tue May  5 2009 jbeulich@novell.com
- patches.fixes/iwl3945-build: iwl3945: fix ia64/ppc build.
* Tue May  5 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.30-rc4: Fix ia64 build.
* Tue May  5 2009 jbeulich@novell.com
- patches.suse/stack-unwind: Also initialize PT_GS() on 32-bit.
- patches.arch/x86_64-unwind-annotations: Refresh.
* Tue May  5 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc4 and c/s 867.
- Update i386 and x86_64 config files.
- config.conf: Re-enable Xen.
* Tue May  5 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: kbuild: add workaround
  for icecream bug (bnc#495786).
* Fri May  1 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
* Fri May  1 2009 jeffm@suse.com
- Update to 2.6.30-rc4.
  - Eliminated 2 patches.
* Fri May  1 2009 jeffm@suse.com
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
- patches.kernel.org/patch-2.6.30-rc3-rc4:
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch: Delete.
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: Delete.
* Thu Apr 30 2009 mmarek@suse.cz
- scripts/submit-to-bs: tentative script to submit a new kernel to
  openSUSE:Factory
* Tue Apr 28 2009 npiggin@suse.de
- patches.apparmor/unambiguous-__d_path.diff: Put a reminder in here
  to fix the lock order problem when the patch is updated to HEAD.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: Fix prepending EXTRAVERSION,
  rename the variable back to @RELEASE_PREFIX@.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: prepend the EXTRAVERSION to
  the rpm release string (note that this won't have any effect in
  the openSUSE:* projects).
* Fri Apr 24 2009 gregkh@suse.de
- Update config files.
  - build rtc_cmos driver into the kernel for i386 and x86-64 default
    kernels.  This should automatically take care of the rtc/system time
    syncing so we don't need to do it in a boot script and should speed
    up booting time a lot.
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change CONFIG_ATA=y and CONFIG_SATA_AHCI=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_EXT2_FS=y and CONFIG_EXT3_FS=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_SCSI=y and CONFIG_BLK_DEV_SD=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to use CONFIG_USB=y
* Thu Apr 23 2009 jeffm@suse.de
- Added legacy config.
* Thu Apr 23 2009 jeffm@suse.de
- Temporarily disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
* Thu Apr 23 2009 jeffm@suse.de
- Moved i386 kernel-default to kernel-legacy.
- Moved i386 kernel-pae config to kernel-default.
- Disabled CONFIG_ISA in i386 kernel-default to improve boot speed.
* Thu Apr 23 2009 jeffm@suse.de
- Update to 2.6.30-rc3.
* Thu Apr 23 2009 jeffm@suse.de
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: x86:
  hpet: fix periodic mode programming on AMD 81xx.
- patches.fixes/hpet-boot-fix: Delete.
* Mon Apr 20 2009 jeffm@suse.de
- patches.fixes/hpet-boot-fix: hpet: fix "IO-APIC + timer doesn't work!"
* Mon Apr 20 2009 jeffm@suse.de
- Update to 2.6.30-rc2-git6.
* Wed Apr 15 2009 jeffm@suse.de
- Update to 2.6.30-rc2.
  - trace and xen flavors disabled.
  - CONFIG_OTUS disabled on ppc.
  - request-based multipath could use some testing.
  - Eliminated 96 patches.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/devel-post.sh, rpm/kernel-binary.spec.in: Created i586 symlink
  for i386.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added /usr/src/linux-obj to -devel
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use xargs -r to fix case when no
  modules are supported.
* Fri Apr 10 2009 jeffm@suse.com
- Moved linux-obj symlink handling to kernel-$flavor-devel.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/package-descriptions: Add comment.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh: Rename the timestamp
  file to source-timestamp instead, so that autobuild does not add
  the timestamp verbatim.
* Thu Apr  9 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29 final and c/s 854.
- patches.xen/sfc-external-sram: enable access to Falcon's
  external SRAM (bnc#489105).
- patches.xen/sfc-sync-headers: sync Solarflare accelerator
  headers (bnc#489105).
- Update Xen config files.
* Wed Apr  8 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Fix last change: do not add the
  timestamp if it is already added verbatim (by prepare_spec during
  checkin)
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Add source timestamp to package
  descriptions.
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: add descriptions to
  generated spec files.
- rpm/package-descriptions: descriptions of binary packages.
* Mon Apr  6 2009 jeffm@suse.com
- Enabled STAGING on !x86 and disabled COMEDI.
* Mon Apr  6 2009 jeffm@suse.com
- patches.rpmify/split-package: Enable
* Mon Apr  6 2009 jeffm@suse.com
- Update config files: Fixed i386-vanilla.
* Mon Apr  6 2009 jeffm@suse.com
- patches.fixes/xfs-export-debug: xfs: export assertion handler.
* Mon Apr  6 2009 jeffm@suse.com
- Switch from SPARSEMEM to DISCONTIGMEM on i386.
* Sun Apr  5 2009 jeffm@suse.com
- scripts/tar-up_and_run_mbuild.sh: Added pae to the important
  specfiles list.
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Fix missing ia64-debug.
* Fri Apr  3 2009 jeffm@suse.com
- patches.xen/sfc-resource-driver: Fix uninitialized var warning.
* Fri Apr  3 2009 jeffm@suse.com
- Drop NR_CPUS back to 128 on i386.
* Fri Apr  3 2009 jeffm@suse.com
- rpm/kernel-binary.spec.in: Added CONFIG_SPLIT_PACKAGE.
* Fri Apr  3 2009 jeffm@suse.de
- Update config files: Enabled STAGING drivers on -vanilla.
* Fri Apr  3 2009 jblunck@suse.de
- patches.rpmify/rpm-kernel-config: Rediff.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: chmod +x mkspec arch-symbols
  compute-PATCHVERSION.sh
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Enabled STAGING drivers.
* Fri Apr  3 2009 jeffm@suse.com
- Sync up kernel configs for x86/x86_64 flavors.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: do not package the binary
  spec files anymore.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/modversions: keep the override keyword in --pack.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh: remove
  @TOLERATE_UNKNOWN_NEW_CONFIG_OPTIONS@ expansion, check for a file
  named TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS in sourcedir instead.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: set LC_ALL=C in rpm -q call
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add @FLAVOR@ again to avoid %%%%(...)
  expansion
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/mkspec: new script to generate spec files from *.spec.in
  templates
- rpm/compute-PATCHVERSION.sh, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in: add to the
  source rpm
- scripts/tar-up.sh: just tar up patches directories and call
  mkspec
* Tue Mar 31 2009 mmarek@suse.cz
- rpm/kernel-dummy.spec.in: Delete.
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
* Tue Mar 31 2009 mmarek@suse.cz
- config.conf, rpm/old-packages.conf, scripts/arch-symbols,
  scripts/run_oldconfig.sh, scripts/tar-up.sh: drop the arch
  symbols completely, only map the various ix86 archs to i386.
* Tue Mar 31 2009 mmarek@suse.cz
- doc/README.SUSE: allow_unsupported_modules needs to be set before
  installing the kernel (bnc#484664).
* Tue Mar 31 2009 jeffm@suse.de
- Add %%changelog to spec files
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Clean up %%build_$flavor macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in: Create kernel-source-vanilla
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-syms.spec.in, scripts/tar-up.sh: Depend on kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Create a %%using_buildservice macro
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/sequence-patch.sh, scripts/tar-up.sh:
  kernel-{binary,source}: Remove arch guards
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.SUSE, rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: Move development files from kernel-source to
  kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove $CONFIG_MODULES
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove duplicate CONFIG_DEBUG_INFO=y
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Use macros for cpu_arch
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in:
  kernel-{source,binary}: Use path-related rpm macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,  rpm/kernel-source.spec.in:
  Use a %%kernelrelease macro.
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in, rpm/source-post.sh, scripts/tar-up.sh:
  Use %%variant instead of $variant
* Tue Mar 31 2009 jeffm@suse.de
- kernel-source: Kill old obsoletes
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh:
  Use %%var instead of @VAR@ except where necessary
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Sort by flavor, not architecture
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Stop the architecture %%else madness
* Tue Mar 31 2009 jeffm@suse.de
- kernel-binary: Stop the architecture %%else madness
* Mon Mar 30 2009 jeffm@suse.de
- Removed -RT guards and a dead patch.
* Mon Mar 30 2009 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: Delete.
* Mon Mar 30 2009 jeffm@suse.de
- patches.suse/reiserfs-inode-init: Delete.
* Thu Mar 26 2009 mmarek@suse.cz
- rpm/config.sh: introduce rpm/config.sh, defining SRCVERSION and
  VARIANT variables.
* Tue Mar 24 2009 jeffm@suse.de
- Update to 2.6.29-final.
  - Eliminated 4 patches.
* Fri Mar 20 2009 jbeulich@novell.com
- Update Xen config files.
- Update Xen patches to 2.6.29-rc8 and c/s 821.
* Wed Mar 18 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, scripts/tar-up.sh: don't add "<RELEASE>"
  to the release, breaks plain rpmbuild.
* Tue Mar 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't generate symsets
- rpm/kernel-syms.spec.in: don't package symsets
- rpm/find-provides: disable symset provides
- rpm/macros.kernel-source: don't check for /boot/symsets*
  (fate#305945)
* Tue Mar 17 2009 knikanth@suse.de
- patches.fixes/loop-barriers: Delete.
- patches.fixes/loop-barriers2: Delete.
  Remove non-mainline patches to loop driver making it honour
  O_SYNC, sync requests and barriers. (bnc#485089), (bnc#471249)
* Mon Mar 16 2009 bphilips@suse.de
- README: add rough guide to updating KABI
* Sat Mar 14 2009 jeffm@suse.com
- Update to 2.6.29-rc8.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.fixes/fix-nf_conntrack_slp,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: fix build warnings.
* Thu Mar 12 2009 jbeulich@novell.com
- Update Xen patches addressing several issues in initial commit
- Update Xen config files (re-enable oprofile, disable novfs).
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind annotations
  in entry_64-xen.S.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: fix unwind annotations in
  entry_64.S.
* Thu Mar 12 2009 rgoldwyn@suse.de
- patches.suse/novfs-creds-change-2.6.29: Changing credential
  according to new task_struct.
* Wed Mar 11 2009 jblunck@suse.de
- rpm/kernel-binary.spec.in: Use split_packages only if supported.conf
  is not empty.
* Mon Mar  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: renamed modprobe config to
  /etc/modprobe.d/50-module-renames.conf (required by new
  module-init-tools).
* Mon Mar  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29-rc4: fix ia64 build.
* Mon Mar  9 2009 jbeulich@novell.com
- Update Xen config files (get tracing options back in sync with
  default).
* Fri Mar  6 2009 jeffm@suse.de
- Update config files: Enable CONFIG_FRAME_POINTER on Xen.
* Fri Mar  6 2009 jeffm@suse.de
- config.conf: Enabled Xen for building.
* Fri Mar  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc7.
* Fri Mar  6 2009 jbenc@suse.cz
- Update config files: enabled wireless debugging in -debug flavors.
* Fri Mar  6 2009 mmarek@suse.cz
- rpm/get_release_number.sh.in, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in,
  scripts/tar-up.sh, doc/README.SUSE: finally drop kernel-dummy
- rpm/prepare-build.sh: Delete.
* Wed Mar  4 2009 jeffm@suse.com
- Update to 2.6.29-rc7.
  - Eliminated 1 patch.
* Wed Mar  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround a bash bug (bnc#481817)
  in kernel-vanilla.spec.
* Wed Mar  4 2009 jeffm@suse.com
- patches.suse/export-security_inode_permission: Export
  security_inode_permission for aufs.
* Thu Feb 26 2009 jeffm@suse.com
- scripts/tar-up.sh: Add -u to update existing spec files.
* Thu Feb 26 2009 sven@suse.de
- rpm/kernel-binary.spec.in: Fix sub-package install-time conflict.
* Wed Feb 25 2009 mmarek@suse.cz
- scripts/tar-up.sh: create tarballs that don't change
  unnecessarily: set owner/group to nobody/nobody, mtime to time of
  the latest commit and sort the input files.
* Wed Feb 25 2009 jeffm@suse.com
- Update to 2.6.29-rc6-git1.
* Sat Feb 21 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: also check if the package versions match
  (bnc#478462)
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix 32-bit arch_unwind_init_running().
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix patch fuzz.
* Fri Feb 20 2009 jbeulich@novell.com
- misc/xen-port-patches.py: Adjust fro new x86 header placement.
- patches.arch/x86_64-unwind-annotations: fix unwind annotations
  (bnc#472783).
- patches.suse/stack-unwind: Properlz hook up unwinder again.
* Fri Feb 20 2009 jeffm@suse.de
- patches.suse/kdb-common: Build fix with -I directive.
* Fri Feb 20 2009 jeffm@suse.de
- Update config files.
* Fri Feb 20 2009 jeffm@suse.de
- Update to 2.6.29-rc5-git3.
  - Eliminated 1 patch.
* Thu Feb 19 2009 mmarek@suse.cz
- rpm/symsets.pl: allow passing only Module.symvers and no modules
* Wed Feb 18 2009 olh@suse.de
- disable ppc601 support, disable unused framebuffer drivers
* Wed Feb 18 2009 olh@suse.de
- disable kdump on ppc32
* Mon Feb 16 2009 jeffm@suse.com
- Update config files.
* Sat Feb 14 2009 jeffm@suse.de
- Update to 2.6.29-rc5.
* Fri Feb 13 2009 jeffm@suse.de
- Update to 2.6.29-rc4-git7.
  - Eliminated 2 patches.
* Mon Feb  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: spin_is_contended
  Kconfig fixes.
* Mon Feb  9 2009 jeffm@suse.de
- Updated to 2.6.29-rc4.
  - Eliminated 3 patches.
* Fri Feb  6 2009 jeffm@suse.com
- patches.fixes/fix-warning-while-mapping-0-1MB-range-with-dev-mem:
  x86, pat: fix warn_on_once() while mapping 0-1MB range.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: fix
  last change: don't pass -e to weak-modules2.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: pass
  down shell options like -x to weak-modules2 to make debugging
  with rpm -ivv easier.
* Tue Feb  3 2009 jeffm@suse.de
- patches.fixes/fix-nf_conntrack_slp: make nf_conntrack_slp
  actually work (bnc#470963).
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/tar-up.sh: fix branch name in KOTD packages.
* Tue Feb  3 2009 olh@suse.de
- config.conf: readde -debug flavor for ppc64
* Tue Feb  3 2009 olh@suse.de
- patches.fixes/scsi-ibmvfc_prli_initiator_fix.patch:
  Better handle other FC initiators (bnc#471217 - LTC51238)
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/wd-functions.sh: display master as "master", not "HEAD"
  or "".
* Mon Feb  2 2009 jeffm@suse.de
- patches.fixes/ath9k-fix-led_device_naming.diff: ath9k: fix
  led naming.
- patches.fixes/b43legacy-fix-led_device_naming.diff: b43legacy:
  fix led naming.
- patches.fixes/iwlwifi-fix-iwl-3945_led_device_naming.diff:
  iwlwifi: another led naming fix.
- patches.fixes/iwlwifi-fix-iwl-led_device_naming.diff: iwlwifi:
  fix led naming   .
- patches.fixes/rt2x00-fix-led_device_naming.diff: rt2x00:
  fix led naming.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3-git3.
  - Eliminated 6 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3.
  - AppArmor is disabled.
  - Xen is disabled.
  - Eliminated 745 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Enabled patches.suse/reiserfs_warning-reentrant
* Mon Feb  2 2009 rw@suse.de
- patches.fixes/xpc-pass-physical,
  patches.kabi/xpc-pass-physical:
  kABI: restore upstream patch, add ABI cover-up. (bnc#458811)
* Mon Feb  2 2009 olh@suse.de
- patches.fixes/serial-jsm-enable_ms.patch:
  Add enable_ms to jsm driver (bnc#471224 - LTC51066)
* Mon Feb  2 2009 olh@suse.de
- patches.arch/ppc-optimize-sync.patch:
  Optimise smp_{r,w}mb and mutex (bnc#471222 - LTC51356)
* Sat Jan 31 2009 gregkh@suse.de
- refresh patches for fuzz due to 2.6.27.14-rc1 import.
* Sat Jan 31 2009 gregkh@suse.de
- patches.kabi/abi-fix-add-epoll_devs-back-to-struct-user_struct.patch:
  ABI fix: add epoll_devs back to struct user_struct.
* Sat Jan 31 2009 gregkh@suse.de
- Update to 2.6.27.14-rc1
  - lots of security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.drivers/alsa-virtuoso-no-eeprom-overwrite
  - patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch
  - patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch
  - patches.fixes/sysfs-fix-problems-with-binary-files.patch
  - patches.fixes/xpc-fix-NULL-deref
  - patches.fixes/xpc-write-barrier
* Fri Jan 30 2009 olh@suse.de
- patches.arch/ppc-pseries-migration_hang_fix.patch:
  Fix partition migration hang under load (bnc#470563 - LTC51153)
* Fri Jan 30 2009 olh@suse.de
- disable CONFIG_DEBUG_STACKOVERFLOW and CONFIG_DEBUG_STACK_USAGE
  on ppc/ppc64
* Fri Jan 30 2009 teheo@suse.de
- patches.drivers/libata-fix-EH-device-failure-handling: libata:
  fix EH device failure handling (bnc#470845).
* Thu Jan 29 2009 jjolly@suse.de
- patches.arch/s390-08-08-add_qdio_utilization.patch: zfcp:
  queue_full is lacking the entry for qdio utilization
  (bnc#466462).
* Thu Jan 29 2009 gregkh@suse.de
- add ability to debug kernel using USB debug connector.
- Update config files.
- patches.suse/usb-move-ehci-reg-def.patch: usb: move ehci
  reg def.
- patches.suse/x86-usb-debug-port-early-console-v4.patch: x86:
  usb debug port early console, v4.
* Thu Jan 29 2009 mmarek@suse.cz
- patches.kabi/abi-fix-add-s_syncing-back-to-struct-super_block.patch
  patches.kabi/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch
  patches.kabi/export-iwl_rx_allocate
  patches.kabi/sched-kabi-compat-hack.patch: Introduce
  patches.kabi/ for patches that only work around kabi issues and
  can be safely dropped at the next SP.
* Wed Jan 28 2009 agruen@suse.de
- patches.xen/xen-x86-mark_rodata_rw.patch: Add missing pageattr.c
  changes to pageattr-xen.c (bnc#439348).
* Wed Jan 28 2009 agruen@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
- patches.xen/xen-x86-mark_rodata_rw.patch: xen specific part
  (bnc#439348).
* Wed Jan 28 2009 mmarek@suse.cz
- config/s390/s390: the -man package still fails for s390, disable
  it
* Wed Jan 28 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix build of the -man subpackage on
  31bit s390
* Wed Jan 28 2009 mmarek@suse.cz
- fix kernel-default.ppc64 reference symsets
* Wed Jan 28 2009 jslaby@suse.cz
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
  [cpu_mask_to_apicid bigsmp fix]
* Wed Jan 28 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-module_alias.patch:
  map scsi proc_name to module name (bnc#459933 - LTC50724)
* Wed Jan 28 2009 jeffm@suse.de
- Update config files: Disable ftrace in -debug on ppc64
* Wed Jan 28 2009 jeffm@suse.de
- config.conf: Added -debug flavor for ppc64.
* Tue Jan 27 2009 bwalle@suse.de
- patches.drivers/libfc-set-the-release-function.diff:
  Whitespace change.
* Tue Jan 27 2009 hare@suse.de
- patches.drivers/libfc-fix-read-IO-data-integrity: libfc:
  IO data integrity issue when a IO data frame lost (bnc#469536).
* Tue Jan 27 2009 jbeulich@novell.com
- re-enable patches.xen/xen3-e1000e_Export_set_memory_ro-rw.
* Tue Jan 27 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  include prototype for PFN_UP() (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls.
  readded to avoid kabi change
* Mon Jan 26 2009 jeffm@suse.de
- config.conf: Added kernel-vmi to i386.
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  use PFN_UP() for end_pfn (bnc#462546 - LTC50009)
* Mon Jan 26 2009 mmarek@suse.cz
- kabi: import FCoE changes
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: disable
  wrong debug message again.
* Mon Jan 26 2009 rw@suse.de
- patches.fixes/taskstats-alignment:
  IA64: fill 'struct taskstats' on stack and 'memcpy' result to skb.
  (bnc#448410)
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix calculation of reserve_size (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/disable-lro-per-default: Disable LRO per default
  in igb and ixgbe. (bnc#467519)
* Mon Jan 26 2009 jbeulich@novell.com
- Just comment out patches.xen/xen3-e1000e_* (to address build error)
  until disposition of their originals is known.
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/sctp_do_not_use_stale_copy_of_sk: Do not use
  stale copy of sk. (bnc#440104)
* Mon Jan 26 2009 jblunck@suse.de
  Renamed some patches so they get included in vanilla builds.
- patches.rpmify/firmware-path: Renamed.
- patches.rpmify/no-include-asm: Renamed.
- patches.suse/md-raid-metadata-PAGE_SIZE.patch: Renamed.
* Mon Jan 26 2009 olh@suse.de
- patches.suse/led_classdev.sysfs-name.patch: use correct name
  for /sys/devices/virtual/leds/ entries (bnc#468350)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Delete.
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_ioremap_sanity_check: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Remove not mainline e1000e patches which were added to help with
  the e1000e NVM corruption - root issue is fixed
* Mon Jan 26 2009 kkeil@suse.de
- patches.drivers/tg3_libphy_workaround: tg3 libphy workaround.
  (bnc#468725)
* Mon Jan 26 2009 hare@suse.de
- supported.conf: Correct spelling for dm-least-pending
  path checker.
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-check-info-before-access: Kernel Oops
  during path failover (bnc#458393).
* Sun Jan 25 2009 gregkh@suse.de
- refresh patch fuzz now that 2.6.27.13 is in tree
* Sun Jan 25 2009 gregkh@suse.de
- Update to final version of 2.6.27.13
* Sun Jan 25 2009 gregkh@suse.de
- dynamic debugging fixes backported from upstream:
- patches.drivers/driver-core-add-newlines-to-debugging-enabled-disabled-messages.patch:
  driver core: add newlines to debugging enabled/disabled
  messages.
- patches.drivers/driver-core-fix-dynamic_debug-cmd-line-parameter.patch:
  Driver core: fix 'dynamic_debug' cmd line parameter.
- patches.drivers/driver-core-fix-using-ret-variable-in-unregister_dynamic_debug_module.patch:
  driver core: fix using 'ret' variable in
  unregister_dynamic_debug_module.
* Sat Jan 24 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch:
  (fix return of an unitialized value (bnc#469017)
* Sat Jan 24 2009 mmarek@suse.cz
- update kabi files: ignore changes in struct pcie_link_state as
  it is an internal structure only.
* Sat Jan 24 2009 mmarek@suse.cz
- patches.suse/genksyms-add-override-flag.diff: genksyms: add
  - -override flag.
- rpm/kernel-binary.spec.in: set KBUILD_OVERRIDE=1
* Sat Jan 24 2009 ghaskins@suse.de
- patches.fixes/sched-kabi-compat-hack.patch: sched: leave
  RT_GROUP_SCHED structure components intact to preserve kABI.
  broke kabi with fix for 456542
* Sat Jan 24 2009 trenn@suse.de
- patches.fixes/cpufreq_export_latency.patch: CPUFREQ: Introduce
  /sys/devices/system/cpu/cpu*/cpufreq/cpuinfo_transition_latency
  (bnc#464461).
- patches.fixes/cpufreq_ondemand_adjust_sampling_rate_limit.patch:
  CPUFREQ: ondemand/conservative: sanitize sampling_rate
  restrictions (bnc#464461).
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
- patches.fixes/x86_cpufreq_powernow-k8_acpi_latency_values.patch:
  X86 powernow-k8 cpufreq: Get transition latency from acpi _PSS
  object (bnc#464461).
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/xfs-dmapi-fixes: xfs/dmapi: fix crash on mount
  (bnc#458027).
* Fri Jan 23 2009 ghaskins@suse.de
- Update config files: Disable RT_GROUP_SCHED (bnc#456542).
  The RT_GROUP_SCHED feature is experimental and clearly broken, so
  lets turn it off for now.
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/hpilo-open-close-fix: hpilo open/close fix
  (bnc#466517).
* Fri Jan 23 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: Handle I/O
  on stopped queues correctly (bnc#458393).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.suse/mnt-want-write-speedup.patch,
  patches.suse/mnt_clone_write.patch: modified not to break kABI,
  enabled (bnc#436953).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.fixes/iwlagn-fix-rfkill.patch: iwlagn: fix hw-rfkill
  while the interface is down (bnc#446158).
* Fri Jan 23 2009 mmarek@suse.cz
- kabi/severities: temporarily enable changes in FcOE modules.
* Fri Jan 23 2009 hare@suse.de
- patches.arch/s390-08-06-personality.patch: kernel: setting 32
  bit personality doesn't work (bnc#466462).
- patches.arch/s390-08-07-compat_wrappers.patch: kernel:
  Add missing wrapper functions for 31 bit compat
  syscalls. (bnc#466462,LTC#51229).
- patches.fixes/block-leave-the-request-timeout-timer-running:
  Delete obsolete patch.
* Fri Jan 23 2009 bwalle@suse.de
- patches.drivers/fcoe-change-fcoe_sw-sg_tablesi.diff: change
  fcoe_sw sg_tablesize to SG_ALL (bnc #459142).
- patches.drivers/fcoe-check-return-for-fc_set_m.diff: check
  return for fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-fix-frame-length-validati.diff: fix frame
  length validation in the early receive path (bnc #459142).
- patches.drivers/fcoe-fix-incorrect-use-of-struct-module.diff:
  fcoe: fix incorrect use of struct module (bnc #468051).
- patches.drivers/fcoe-improved-load-balancing-i.diff: improved
  load balancing in rx path (bnc #459142).
- patches.drivers/fcoe-logoff-of-the-fabric-when.diff: Logoff
  of the fabric when destroying interface (bnc #459142).
- patches.drivers/fcoe-remove-warn_on-in-fc_set.diff: remove
  WARN_ON in fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-user_mfs-is-never-used.diff: user_mfs is
  never used (bnc #459142).
- patches.drivers/libfc-add-fc_disc-c-locking-co.diff: Add
  fc_disc.c locking comment block (bnc #459142).
- patches.drivers/libfc-ensure-correct-device_pu.diff: libfc:
  Ensure correct device_put/get usage (round 2).
- patches.drivers/libfc-fix-rport-recursive-lock.diff: libfc:
  Fix rport recursive lock on rport mutex (bnc #459142).
- patches.drivers/libfc-handle-rrq-exch-timeout.diff: libfc:
  handle RRQ exch timeout (bnc #465596).
- patches.drivers/libfc-improve-fc_lport-c-locki.diff: Improve
  fc_lport.c locking comment block (bnc #459142).
- patches.drivers/libfc-improve-fc_rport-c-locki.diff: Improve
  fc_rport.c locking comment block (459142).
- patches.drivers/libfc-make-fc_disc-inline-with.diff: make
  fc_disc inline with the fc_lport structure (bnc #459142).
- patches.drivers/libfc-make-rscn-parsing-more-r.diff: make RSCN
  parsing more robust (bnc #459142).
- patches.drivers/libfc-make-sure-we-access-the.diff: make sure
  we access the CRC safely (bnc #459142).
- patches.drivers/libfc-pass-lport-in-exch_mgr_r.diff: libfc:
  Pass lport in exch_mgr_reset (bnc #465596).
- patches.drivers/libfc-remove-debug-print-state.diff: libfc:
  Remove debug print statement, too verbose (bnc #459142).
- patches.drivers/libfc-set-the-release-function.diff: Set
  the release function for the rport's kobject (round 2)
  (bnc #459142).
- patches.drivers/libfc-updated-comment-for-orde.diff: updated
  comment for order of em and ex locks (bnc #459142).
- patches.drivers/libfc-updated-libfc-fcoe-modul.diff: updated
  libfc fcoe module ver to 1.0.6 (bnc #459142).
- patches.drivers/libfc-use-an-operations-struct.diff: use an
  operations structure for rport callbacks (bnc #459142).
- patches.drivers/libfc-when-rport-goes-away-re.diff: libfc:
  when rport goes away (re-plogi), clean up exchanges to/from
  rport (bnc #465596).
- patches.drivers/libfc_locking.diff: libfc, fcoe: fixed locking
  issues with lport->lp_mutex around lport->link_status (bnc
  [#468053]).
- patches.drivers/libfc_rport.diff: libfc: rport retry on LS_RJT
  from certain ELS (bnc #468054).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/qla2xxx-check-fc-rport-validity:
  qla2xxx: added check for fcport is valid in
  qla2x00_terminate_rport_io(). (bnc#467624).
* Fri Jan 23 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-t1616-quirk: ALSA: hda -
  Add quirk for Gateway T1616 laptop (bnc#467597).
- patches.drivers/alsa-hda-hp-dv4-quirk: ALSA: hda - Add model
  entry for HP dv4.
- patches.drivers/alsa-hda-intel-d945-ref-quirk: ALSA: hda -
  Add model=ref for Intel board with STAC9221 (bnc#406529).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: block: Rediff
- patches.fixes/block-use-round_jiffies_up: Block: use
  round_jiffies_up() (bnc#464155).
- Add missing patches to series.conf:
  patches.fixes/round-jiffies-up
  patches.fixes/block-use-round_jiffies_up
  patches.fixes/block-fix-blk_start_queueing
  patches.fixes/suppress-buffer-IO-errors
  patches.fixes/block-optimizations-in-blk_rq_timed_out_timer
  patches.fixes/block-add-comment-in-blk_rq_timed_out
* Fri Jan 23 2009 olh@suse.de
- update patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  handle also drivers/scsi/ibmvscsi/ibmvfc.c
* Fri Jan 23 2009 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-on-ipv6-mount: cifs: make sure we
  allocate enough storage for socket address (467691).
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch:
  ABI fix: add WB_SYNC_HOLD enum writeback_sync_modes.
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-s_syncing-back-to-struct-super_block.patch:
  ABI fix: add s_syncing back to struct super_block.
* Fri Jan 23 2009 gregkh@suse.de
- update to 2.6.27.13-rc1:
  - security updates
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-fix_hugepage_check.patch
  - patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back
  - patches.drivers/alsa-hda-samsung-q45-quirk
  - patches.fixes/security-introduce-missing-kfree.patch
  - patches.fixes/xpc-fix-heartbeat
- Update config files.
* Fri Jan 23 2009 kkeil@suse.de
- patches.drivers/e1000-fix-shared-emc.patch: e1000: fix bug
  with shared interrupt during reset (bnc#396687)
* Thu Jan 22 2009 tonyj@suse.de
- patches.fixes/revert-bgcolor-line-feed-93f78da4.patch: Revert
  "vt: fix background color on line feed" (bnc#418613).
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/iwlwifi-fix-rs_get_rate-oops.patch: iwlwifi:
  fix rs_get_rate WARN_ON() (bnc#456002).
- Reordered wireless patches to group together patches touching the same
  driver.
* Thu Jan 22 2009 bphilips@suse.de
- patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch:
  disable catas_reset by default to avoid problems with EEH
  (bnc#456389).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  fixed kABI breakage. (bnc#458811)
* Thu Jan 22 2009 bwalle@suse.de
- scripts/tar-up_and_run_mbuild.sh: s390 (the 31 bit variant) is
  not an important spec file.
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: fixed kABI
  breakage, reenabled.
* Thu Jan 22 2009 mmarek@suse.cz
- rpm/modversions: eat the "override" keyword before parsing the
  symbol definition.
* Thu Jan 22 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  Correct VIO bus/device CMO accounting problems (bnc#468304 - LTC51205)
* Thu Jan 22 2009 olh@suse.de
- patches.suse/of_platform_driver.module-owner.patch:
  add missing module symlink to /sys/bus/*/driver/*
  in struct of_platform_driver.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix - new version from Intel  (bnc#465923)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
  (fix compilation on i386 and add hpet64 to kernel-parameters.txt)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  sgi-xpc: need to pass the physical address, not virtual. (bnc#458811)
- patches.fixes/xpc-fix-heartbeat:
  sgi-xpc: eliminate false detection of no heartbeat. (bnc#464545)
* Thu Jan 22 2009 jkosina@suse.de
- patches.fixes/input-add-nomux-dell-vostro-1510.patch: Input:
  add Dell Vostro 1510 to nomux list (bnc#404881).
* Thu Jan 22 2009 jblunck@suse.de
- scripts/compute-PATCHVERSION.sh: Fix SRCVERSION parsing (bnc#465113).
* Thu Jan 22 2009 tiwai@suse.de
- patches.drivers/alsa-hda-add-volume-offset: ALSA: hda - Add
  extra volume offset to standard volume amp macros (bnc#466428).
- patches.drivers/alsa-hda-stac-reduce-volume-scale: ALSA: hda -
  Halve too large volume scales for STAC/IDT codecs (bnc#466428).
* Thu Jan 22 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.12-update: Update lpfc from 8.2.8.11
  to 8.2.8.12 (bnc#467713).
* Thu Jan 22 2009 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: fix missing jl arg
* Wed Jan 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete duplicate error message in the
  kabi checks
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/remove_kernel_physical_mapping_init_from_init:
  move kernel_physical_mapping_init to __meminit (bnc#467474).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: disabled, as it changes
  kABI.
* Wed Jan 21 2009 gregkh@suse.de
- patches.fixes/security-introduce-missing-kfree.patch: security:
  introduce missing kfree (bnc#467322).
- patches.fixes/sysfs-fix-problems-with-binary-files.patch:
  sysfs: fix problems with binary files.
* Wed Jan 21 2009 rw@suse.de
- patches.arch/ia64-page-migration.fix:
  fix deadlock caused by cpe_migrate.ko and mark it supported.
  (bnc#464676)
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/sn-irq-affinity: sn2: preserve irq affinity set
  in PROM (bnc#457679).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/uv_zalias_support: uv: Support for non-nasid 0
  systems (bnc#458869).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/xpc-fix-NULL-deref: sgi-xpc: Remove NULL pointer
  dereference. (bnc#466563).
- patches.fixes/xpc-write-barrier: sgi-xpc: ensure flags are
  updated before bte_copy (bnc#466563).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/ipw2200-workaround-firmware-restarts-when-scanning.patch:
  ipw2200: fix scanning while associated (bnc#459067).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/iwl3945-fix-rfkill.patch: iwl3945: report
  killswitch changes even if the interface is down (bnc#446013).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: mac80211:
  add direct probe before association (bnc#461889).
* Wed Jan 21 2009 hare@suse.de
- patches.drivers/mptsas-discover-all-devices: mptsas driver
  fails to discover devices (bnc#459932).
* Wed Jan 21 2009 jbeulich@novell.com
- Update Xen patches to 2.6.27.12.
- patches.xen/764-netback-foreign-pages.patch: netback: handle
  non-netback foreign pages.
- patches.xen/769-evtchn-CPU-offline.patch: evtchn: Fix CPU offlining
  to switch all affected ports belonging to a particular /dev/evcthn
  user.
- patches.xen/gso-size-check.patch: gso: Ensure that the packet
  is long enough.
- patches.xen/xen-S3-MSI: fix Dom0 resume from S3 when MSI is
  in use (bnc#435596).
- patches.xen/xen3-e1000e_ioremap_sanity_check: ioremap sanity
  check to catch mapping requests exceeding the BAR sizes
  (bnc#425480).
- patches.xen/xen3-x86-fix-kmap-contig.patch: x86: contiguous
  kmap fix (bnc#449812).
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  implement correct model matching
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/dm-mpath-tracking-nr-bytes:
  lpp_end_io gets nr_bytes as third arg
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  match all JSxx/QSxx models based on the first 4 chars in 'model'
* Wed Jan 21 2009 olh@suse.de
- update patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  Fix MSI after kexec (bnc#467633)
* Tue Jan 20 2009 gregkh@suse.de
- clean up patch fuzz after 2.6.27.12 inclusion.
* Tue Jan 20 2009 gregkh@suse.de
- Update to the real 2.6.27.12
* Tue Jan 20 2009 jeffm@suse.de
- patches.suse/reiserfs_warning-reentrant: reiserfs: eliminate
  reiserfs_warning from uniqueness functions; Fixes deadlock.
* Tue Jan 20 2009 olh@suse.de
- patches.drivers/cxgb3-ser.patch:
  reset the adapter on fatal error (bnc#466062 - LTC51042)
* Tue Jan 20 2009 jjolly@suse.de
- patches.arch/s390-08-03-iucv-cpu-hotremove.diff: iucv: failing
  cpu hot remove for inactive iucv (bnc#466462,LTC#51104).
- patches.arch/s390-08-04-compat-sigaltstack.diff:
  kernel: 31 bit compat sigaltstack syscall fails with
  - EFAULT. (bnc#466462,LTC#50888).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch:
  af_iucv: System hang if recvmsg() is used with MSG_PEEK
  (bnc#466462,LTC#51136).
* Tue Jan 20 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Only accept
  non-existing paths when adding failed paths (bnc#467579)
* Tue Jan 20 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: set CONFIG_DEBUG_INFO=y in the
  packaged .configs if builfing debug packages (bnc#460887)
* Mon Jan 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: set %%tolerate_kabi_changes to 6
* Mon Jan 19 2009 mmarek@suse.cz
- patches.suse/export-iwl_rx_allocate: reintroduce
  EXPORT_SYMBOL(iwl_rx_allocate).
* Mon Jan 19 2009 mmarek@suse.cz
- import SLE11 RC2 reference kabi
* Mon Jan 19 2009 hare@suse.de
- patches.drivers/mpt-return-all-sense-data: MPT Fusion doesn't
  return all sense data (bnc#466179).
* Sat Jan 17 2009 gregkh@suse.de
- Update to 2.6.27.12-rc2
* Fri Jan 16 2009 od@suse.de
- patches.arch/x86-call-boot-IRQ-quirks-at-end-of-device-init-and-during-resume.patch:
  call boot IRQ quirks at end of device init and during resume.
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch:
  update to upstream variant of this patch:
  - integrate an older quirk to make IO-APIC mode work on AMD
    8131 rev. A0 and B0
  - fix boot IRQ disabling logic for AMD 813x
  - remove unneeded code for AMD SB700S
* Fri Jan 16 2009 jbeulich@novell.com
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Fri Jan 16 2009 olh@suse.de
- enable mptsas in kdump kernel to allow crashdump on QS2x blades
* Fri Jan 16 2009 tiwai@suse.de
  Fix STAC925x patch again
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  (yet more) STAC925x issues (bnc#460478).
* Fri Jan 16 2009 jjolly@suse.de
- patches.arch/s390-08-01-cio-fix-mp-mode.diff: cio: fix
  subchannel multipath mode setup (bnc#466462,LTC#51047).
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: zfcp: fix
  memory alignment for GPN_FT requests. (bnc#466462).
* Fri Jan 16 2009 gregkh@suse.de
- Update config files for vanilla kernel versions due to new config
  option added in 2.6.27.12-rc1.
* Fri Jan 16 2009 gregkh@suse.de
- Update to 2.6.27.12-rc1:
  - security fixes
  - fixes CVE-2009-0029
  - bug fixes all over the place.
  - obsoletes the following patches:
  - patches.arch/ppc-cmm_no_kdump.patch
  - patches.drivers/alsa-caiaq-midi-oops-fix
  - patches.drivers/alsa-hda-hp-6730b-quirk
  - patches.drivers/ibmvfc-host_init_delay.patch
  - patches.drivers/ibmvfc-improve_sync_events.patch
  - patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch
  - patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch
  - patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch
  - patches.fixes/mm-lockless-pagecache-barrier.patch
  - patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch
  - patches.fixes/uv-remove-erroneous-BAU-init
- Update config files.
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-virtuoso-no-eeprom-overwrite: sound:
  virtuoso: do not overwrite EEPROM on Xonar D2/D2X (bnc#462365).
* Thu Jan 15 2009 bwalle@suse.de
- patches.suse/s390-System.map.diff:
  Strip L2^B symbols (bnc #456682).
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-fix: ALSA: patch_sigmatel:
  Add missing Gateway entries and autodetection (bnc#460478).
- patches.drivers/alsa-hda-gateway-fix2: ALSA: hda - More fixes
  on Gateway entries (bnc#460478).
- patches.drivers/alsa-hda-hp-dv5-mic-fix: ALSA: hda - Fix HP
  dv5 mic input (bnc#462913).
- patches.drivers/alsa-hda-hp-dv5-quirk: ALSA: hda - Add quirk
  for another HP dv5 (bnc#462913).
- patches.drivers/alsa-hda-idt92hd83-fix-typo: ALSA: hda -
  Fix a typo.
- patches.drivers/alsa-hda-samsung-q45-quirk: ALSA: hda - Add
  automatic model setting for Samsung Q45.
- patches.drivers/alsa-hda-seek-for-codec-id: ALSA: hda - Add
  a new function to seek for a codec ID (bnc#460478).
- patches.drivers/alsa-hda-sigmatel-no-hp-reset: ALSA: hda -
  Don't reset HP pinctl in patch_sigmatel.c (bnc#460478).
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  missing initialization of NID 0x0e for STAC925x (bnc#460478).
* Thu Jan 15 2009 olh@suse.de
- patches.arch/ppc-fix_hugepage_check.patch:
  is_hugepage_only_range() must account for both 4kB and 64kB
  slices (bnc#466229 - LTC51063)
* Thu Jan 15 2009 jeffm@suse.de
- Update config files: Disabled PARAVIRT on vanilla and LGUEST.
* Thu Jan 15 2009 jeffm@suse.de
- Enabled patches.suse/unlock_page-speedup.patch
* Wed Jan 14 2009 rjw@suse.de
- patches.fixes/PCI-PM-Split-PCI-Express-port-suspend-resume.patch:
  PCI PM: Split PCI Express port suspend-resume (bnc#455926).
- patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch:
  PCI: Suspend and resume PCI Express ports with interrupts
  disabled (bnc#455926).
- patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch:
  PCI: handle PCI state saving with interrupts disabled
  (bnc#455926).
- patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch:
  PCI: Rework default handling of suspend and resume (bnc#455926).
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disable PARAVIRT.
* Wed Jan 14 2009 gregkh@suse.de
- refresh patches for fuzz due to update to 2.6.27.11
* Wed Jan 14 2009 gregkh@suse.de
- Update to final version of 2.6.27.11
* Wed Jan 14 2009 kkeil@suse.de
- patches.drivers/ixgbe-dcb-setstate.patch: Bugfix for ixgbe
  and kernel DCB netlink code. (bnc#458194)
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix. (bnc#465923)
- Update config files.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: Delete.
  It came out that this is an already fixed BIOS bug. The quirk
  is not needed anymore.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_fix_double_slash_root_prefix_handling.patch:
  In AcpiNsGetInternalNameLength, skip the redundant backslash
  of RootPrefix (http://bugzilla.kernel.org/show_bug.cgi?id=11541
  http://www.acpica.org/bugzilla/show_bug.cgi?id=739).
- patches.fixes/acpi_video_always_update_sys.patch: video: always
  update the brightness when poking "brightness" (bnc#450149).
- patches.fixes/acpi_video_handle_reversed_brightness_info.patch:
  ACPI: video: Fix reversed brightness behavior on ThinkPad SL
  series (bnc#450149).
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/sched-fix-__load_balance_iterator-for-cfs-with-on.patch:
  fix __load_balance_iterator() for cfs with only one task
  (bnc#457594 - LTC50544)
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/xfs-redirty-ENOSPC.patch: Re-dirty pages on
  ENOSPC when converting delayed allocations (bnc#433112 - LTC48749)
* Wed Jan 14 2009 npiggin@suse.de
- Added guarded patches:
- patches.suse/mnt-want-write-speedup.patch: fs: mnt_want_write
  speedup (bnc#436953).
- patches.suse/mnt_clone_write.patch: fs: introduce
  mnt_clone_write (bnc#436953).
- patches.suse/unlock_page-speedup.patch: mm: unlock_page speedup
  (bnc#436953).
* Wed Jan 14 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: add Via
  chrome9 drm support.
* Wed Jan 14 2009 gregkh@suse.de
- patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch:
  pata_via.c: Support VX855 and future chips whose IDE controller
  use 0x0571..
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Modify patch
  after suggestions from James Bottomley (bnc#465346).
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Restart
  scsi_device_lookup_by_target() (bnc#465346).
* Tue Jan 13 2009 olh@suse.de
- update patches.drivers/cxgb3-Allocate-multiqueues-at-init-time:
  Allow multiqueue setting in MSI-X mode only (bnc#464351 - LTC50966)
* Tue Jan 13 2009 olh@suse.de
- patches.drivers/cxgb3i-mainline.patch: fixes bug in tag release
  and sync-up cxgb3i with mainline state (bnc#464508 - LTC50816)
* Tue Jan 13 2009 gregkh@suse.de
- Update to 2.6.27.11-rc1:
  - lots of minor fixes
  - obsoletes:
  - patches.fixes/md-bitmap-read-do-not-overflow
  - patches.suse/scsi-scsi_transport_srp-shost_data.patch
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: add kernel/drivers/acpi/acpi_memhotplug as supported
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh: handle arch
  symlinks like i586 -> i386 in /usr/src/linux-obj.
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: updated staging and other drivers
* Mon Jan 12 2009 kkeil@suse.de
- patches.drivers/r8169-Tx-performance-tweak-helper: r8169:
  Tx performance tweak helper.
- patches.drivers/r8169-add-8168-8101-registers-description:
  r8169: add 8168/8101 registers description.
- patches.drivers/r8169-add-hw-start-helpers-for-the-8168-and-the-8101:
  r8169: add hw start helpers for the 8168 and the 8101.
- patches.drivers/r8169-additional-8101-and-8102-support: r8169:
  additional 8101 and 8102 support.
- patches.drivers/r8169-use-pci_find_capability-for-the-PCI-E-features:
  r8169: use pci_find_capability for the PCI-E features.
  (bnc#448168)
* Mon Jan 12 2009 dgollub@suse.de
- scripts/tar-up_and_run_mbuild.sh: use $BUILD_DIR instead of fixed
  "kernel-source" string, to stay in sync with with differet kernel
  variants.
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/source-pre.sh:
  replace the /usr/src/linux-obj symlink with a directory containing
  per-flavor symlinks instead. This allows us to install kernel-source /
  syms and kernel-source-rt / syms-rt in parallel and still find
  everything below /usr/src/linux-obj/.
- rpm/kernel-binary.spec.in: for -rt, install into
    /usr/src/linux-$version-rt-obj.
- rpm/kernel-syms.spec.in: fix kernel-source requires for -rt.
* Mon Jan 12 2009 jkosina@suse.de
- patches.drivers/input-usbtouchscreen-hw-calibration.patch:
  Input: usbtouchscreen - allow reporting calibrated data
  (bnc#444814).
* Fri Jan  9 2009 mmarek@suse.cz
- patches.suse/file-capabilities-add-file_caps-switch.diff:
  fix parsing of the file_caps commandline option (bnc#264075)
* Fri Jan  9 2009 trenn@suse.de
- patches.arch/x86_fix_llc_shared_map__cpu_llc_id_anomolies.patch:
  x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
  (bnc#464329).
* Fri Jan  9 2009 olh@suse.de
- patches.arch/ppc-cmm_no_kdump.patch:
  Disable Collaborative Memory Manager for kdump (bnc#460552 - LTC50789)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/cgroup-disable-memory.patch: memcg: disable the
  memory controller by default.
- patches.suse/add-enable_cgroup-parameter.patch: Delete.
- patches.suse/disable-cgroups.patch: Delete.
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch
  fix compile errors
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/ath5k-ignore-calibration-return-value.patch:
  ath5k: ignore the return value of
  ath5k_hw_noise_floor_calibration (bnc#446541).
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/cgroups-suppress-cloning-warning.patch: cgroups:
  suppress bogus warning messages (bnc#460961).
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch: Add quirk for
  the graphics adapter in some JSxx (bnc#461002 - LTC50817)
* Fri Jan  9 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: ACPI: Do not
  derive IRQ from parent bridge/device via boot param/dmi list
  (bnc#437211).
- patches.suse/acpi_osi_sle11_ident.patch: Provide possibility
  for vendors to fix BIOS issues for SLE11 only (none).
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/blk-request-based-multipath-update: Rediff.
- patches.fixes/scsi-refactor-busy-processing: refactor
  sdev/starget/shost busy checking; break out from
  blk-request-based-multipath-update.
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.11-update: Update lpfc from 8.2.8.10
  to 8.2.8.11 (bnc#464662).
- patches.fixes/scsi-call-unprep_request-under-lock: scsi_lib:
  only call scsi_unprep_request() under queue lock (bnc#464155).
- patches.fixes/scsi-fix-hang-in-starved-list-processing: Fix
  hang in starved list processing (bnc#464155).
* Fri Jan  9 2009 kkeil@suse.de
- patches.drivers/bnx2-Add-PCI-ID-for-5716S: bnx2: Add PCI ID
  for 5716S
- patches.drivers/bnx2-Fix-bug-in-bnx2_free_rx_mem_: bnx2:
  Fix bug in bnx2_free_rx_mem() (bnc#464130)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/disable-cgroups.patch: Disable all cgroups
  (bnc#436025).
* Fri Jan  9 2009 hare@suse.de
- Backporting block layer fixes (bnc#464155):
  * patches.fixes/block-add-comment-in-blk_rq_timed_out: add
    comment in blk_rq_timed_out() about why next can not be 0
  * patches.fixes/block-fix-blk_start_queueing: block: Fix
    blk_start_queueing() to not kick a stopped queue.
  * patches.fixes/block-leave-the-request-timeout-timer-running:
    block: leave the request timeout timer running even on an
    empty list.
  * patches.fixes/block-optimizations-in-blk_rq_timed_out_timer:
    block: optimizations in blk_rq_timed_out_timer().
  * patches.fixes/block-suppress-buffer-IO-errors: block: Supress
    Buffer I/O errors when SCSI REQ_QUIET flag set.
  * patches.fixes/block-use-round_jiffies_up: Block: use
    round_jiffies_up().
  * patches.fixes/round-jiffies-up: Add round_jiffies_up and
    related routines.
* Fri Jan  9 2009 jbeulich@novell.com
- patches.xen/xen3-acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
* Fri Jan  9 2009 hare@suse.de
- patches.fixes/scsi_dh-retry-on-UNIT_ATTENTION: scsi_dh_rdac
  does not retry MODE SENSE on UNIT ATTENTION (bnc#464155).
- patches.suse/scsi-check-removed-device-for-offline: Only check
  for SDEV_OFFLINE and SDEV_DEL, not SDEV_CANCEL.
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/add-enable_cgroup-parameter.patch: Add
  cgroup_enable parameter (bnc#436025).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- clean up patch fuzz
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aer-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe AER _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aspm-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe ASPM _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-remove-obsolete-_osc-capability-support-functions.patch:
  ACPI/PCI: remove obsolete _OSC capability support functions
  (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-call-_osc-support-during-root-bridge-discovery.patch:
  ACPI/PCI: call _OSC support during root bridge discovery
  (bnc#438941).
- patches.drivers/acpi-pci-change-pci_osc_control_set-to-query-control-bits-first.patch:
  ACPI/PCI: Change pci_osc_control_set() to query control bits
  first (bnc#438941).
- patches.drivers/acpi-pci-fix-possible-race-condition-on-_osc-evaluation.patch:
  ACPI/PCI: Fix possible race condition on _OSC evaluation
  (bnc#438941).
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
- patches.drivers/acpi-pci-pci-extended-config-_osc-support-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI extended config _OSC support called when root
  bridge added (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/bnx2x-version-update.patch: bnx2x: Version
  Update (bnc#439679).
* Thu Jan  8 2009 jjolly@suse.de
- patches.arch/s390-07-01-zfcp-port-failed-message.diff: zfcp:
  Remove message for failed port (bnc#464466).
- patches.arch/s390-07-02-zfcp-unchained-fsf.diff: zfcp: Add
  support for unchained FSF requests (bnc#464466).
- patches.arch/s390-07-03-topology-fix.diff: kernel: fix cpu
  topology support (bnc#464466).
- patches.arch/s390-07-04-dasd-failfast.patch: dasd: Add
  'failfast' device feature. (bnc#464466,LTC#43066).
* Thu Jan  8 2009 tiwai@suse.de
- patches.drivers/alsa-caiaq-midi-oops-fix: ALSA: caiaq - Fix
  Oops with MIDI.
* Thu Jan  8 2009 knikanth@suse.de
- patches.fixes/dm-avoid-put-table-dm_any_congested: dm: avoid
  destroying table in dm_any_congested (bnc#457205).
- patches.fixes/dm-table-ref-count: dm table: rework reference
  counting (bnc#457205).
- patches.fixes/dm-unbind-drop-ref: dm table: drop reference at
  unbind (bnc#457205).
* Thu Jan  8 2009 olh@suse.de
- update kdump config, disable some unused drivers
* Thu Jan  8 2009 olh@suse.de
- refresh config files, no functional changes
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  use separate table for module alias (bnc#435215 - LTC48564)
* Thu Jan  8 2009 tiwai@suse.de
  Backport fixes for HD-audio from the upstream:
- patches.drivers/alsa-hda-ad1882-id-typo-fix: ALSA: hda -
  Fix typos for AD1882 codecs.
- patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back: ALSA:
  hda - make laptop-eapd model back for AD1986A.
- patches.drivers/alsa-hda-hp2230s-quirk: ALSA: hda - Add quirk
  for HP 2230s (bnc#461660).
- patches.drivers/alsa-hda-sigmatel-add-missing-terminators:
  ALSA: hda - Add missing terminators in patch_sigmatel.c.
* Thu Jan  8 2009 bwalle@suse.de
- Update config files: Enable CONFIG_EHEA=m (and CONFIG_IBMEBUS=y)
  for ppc/kdump and ppc64/kdump (bnc #459119).
* Thu Jan  8 2009 jblunck@suse.de
- Make kernel-source.changes incremental again
* Thu Jan  8 2009 olh@suse.de
- supported.conf: rename dm-leastpending-path to dm-leastpending
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  add alias entry for portN properties (bnc#435215 - LTC48564)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-abort-response.patch:
  Fixup command response translation (bnc#459383 - LTC50695)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-improve_sync_events.patch:
  Improve async event handling (bnc#460567 - LTC50778)
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: via: Unichrome
  DRM bugfixes.
* Thu Jan  8 2009 coly.li@suse.de
- Move patch from patches.suse/dlm-fix-shutdown-cleanup.patch to
  patches.fixes/dlm-fix-shutdown-cleanup.patch
* Thu Jan  8 2009 coly.li@suse.de
- Fixes a regression from commit
  0f8e0d9a317406612700426fad3efab0b7bbc467,
  "dlm: allow multiple lockspace creates".
* Wed Jan  7 2009 olh@suse.de
- patches.arch/ppc-pseries-cpu-migrate.patch: Update
  default_server during migrate_irqs_away (bnc#460566 - LTC50723)
* Wed Jan  7 2009 jack@suse.cz
- patches.suse/mm-increase-dirty-limits.patch: Increase limits
  for starting writeback of dirty data (bnc#449662).
* Wed Jan  7 2009 ghaskins@suse.de
- Update config files (part of bnc#448412).
* Wed Jan  7 2009 ghaskins@suse.de
- patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch:
  configure HAVE_UNSTABLE_SCHED_CLOCK for SGI_SN systems (bnc#448412).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.10-update: Emulex 8.2.8.10 driver
  patches for SLE11 (bnc#460775).
* Wed Jan  7 2009 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Update Patch-mainline
  header. Patch is not refreshed as it breaks kabi (FATE#304489).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/cciss-driver-panic-on-volume-delete: cciss
  driver may panic if a logical volume is deleted (bnc#459553).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC to avoid deadlocks
  (bnc#461747).
* Wed Jan  7 2009 hare@suse.de
- patches.fixes/fc_transport-devloss-callback-restore: FC devloss
  callback not called when devloss timer fires (bnc#463289).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/dm-mpath-leastpending-path-update: Update
  least-pending-IO dynamic load balancer (bnc#444199).
- patches.suse/dm-mpath-queue-length-load-balancing: Rediff.
- patches.suse/dm-mpath-service-time-load-balancing: Rediff.
- patches.suse/dm-mpath-tracking-nr-bytes: Rediff.
- patches.suse/dm-mpath-leastpending-path: Delete.
* Tue Jan  6 2009 jeffm@suse.de
- patches.fixes/uv-remove-erroneous-BAU-init: UV: remove erroneous
  BAU initialization (bnc#463313).
* Tue Jan  6 2009 jjolly@suse.de
- patches.arch/s390-06-01-qeth-ext-src-mac-addr.patch: qeth:
  exploit source MAC address for inbound layer3 packets
  (bnc#458339).
- patches.arch/s390-06-02-qeth-layercrash.patch: qeth: avoid
  crash in case of layer mismatch for VSWITCH (bnc#458339).
- patches.arch/s390-06-03-dasd_sim_sense_condition.patch: Fix
  unsolicited SIM sense condition. (bnc#458339).
- patches.arch/s390-06-04-qdio_ssqd_memcpy.patch: qdio: fix
  broken memcpy (bnc#458339).
- patches.arch/s390-06-05-qdio_s390dbf.patch: qdio: rework
  s390dbf usage  (bnc#458339).
- patches.arch/s390-06-06-qdio_inbound_ack.patch: qdio: rework
  inbound buffer acknowledgement (bnc#458339).
- patches.arch/s390-06-07-cio-attach_detach.patch: cio: Crashes
  when repeatetly attaching/detaching devices. (bnc#458339).
* Tue Jan  6 2009 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: Jan's comments for
  contiguous kmap fix (bnc#449812).
* Tue Jan  6 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: update.
* Mon Jan  5 2009 mmarek@suse.cz
- patches.suse/modpost-filter-out-built-in-depends: modpost:
  filter out "built-in" depends (bnc#450085).
- patches.drivers/0002-Staging-add-TAINT_CRAP-flag-to-drivers-staging-modu.patch:
  refresh.
* Mon Jan  5 2009 npiggin@suse.de
- Fix ps3 config.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: mm lockless
  pagecache barrier fix.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch:
  fs symlink write_begin allocation context fix.
* Mon Jan  5 2009 npiggin@suse.de
- Update config files.
* Mon Jan  5 2009 npiggin@suse.de
- patches.suse/cgroup-freezer.patch: cgroup freezer update (bnc#417294,
  fate#304191, fate#201036).
* Wed Dec 31 2008 npiggin@suse.de
- patches.fixes/s390-lru_add_drain_all.patch: mm: remove UP
  version of lru_add_drain_all() (bnc#458380).
* Wed Dec 31 2008 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Tue Dec 30 2008 jeffm@suse.de
- patches.arch/thinkpad_acpi-hotkey-notify-fix: thinkpad_acpi:
  Fix oops with incompatible backlight interface.
* Mon Dec 22 2008 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix bootmem reservation on uninitialized node (bunc#457029 - LTC50483)
* Mon Dec 22 2008 olh@suse.de
- patches.fixes/scsi-ibmvscsi-can_queue_fix.patch: Make
  max_requests module parameter more accurate (bnc#458499 - LTC50637)
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-dv7-quirk: ALSA: hda - Add quirk
  for another HP dv7 (bnc#461108).
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: More fixes (bnc#447624).
* Fri Dec 19 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Print more info.
* Fri Dec 19 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-no-44khz: ALSA: disable
  44.1kHz capture on CA0106 (bnc#447624).
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-92hd73x-desktop-fixes: ALSA: Fix
  plaback problems on Intel desktops with IDT codecs.
* Fri Dec 19 2008 jbeulich@novell.com
- patches.arch/x86_sgi-uv-scir.patch,
  patches.suse/e1000e_ioremap_sanity_check,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: eliminate build warnings.
* Fri Dec 19 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rt2870-wireless-driver.patch:
  Staging: add rt2870 wireless driver.
* Fri Dec 19 2008 nfbrown@suse.de
- patches.fixes/md-bitmap-read-do-not-overflow: md: Don't read
  past end of bitmap when reading bitmap. (bnc#459557).
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Fixed ordering.
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: Delete.
* Thu Dec 18 2008 gregkh@suse.de
- Updated to final 2.6.27.10 release
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Use apic=bigsmp on specific xseries machines (bnc#440497).
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86_restrict_pci_early_quirks_to_root_bridges.patch:
  Only scan the root bus in early PCI quirks. (bnc#57886).
* Thu Dec 18 2008 jbeulich@novell.com
- patches.xen/746-pirq-status-page.patch: Merge in c/s 751.
- patches.xen/761-highpte.patch: blktap, gntdev: fix highpte handling.
- patches.xen/762-xencons-hvc.patch: add hvc compatibility mode to xencons.
- patches.xen/xen3-patch-2.6.27.7-8: Linux 2.6.27.8.
- patches.xen/xen3-patch-2.6.27.8-9: Linux 2.6.27.9.
- patches.xen/xen-x86-exports: export a few more symbols
  (bnc#458222).
- patches.xen/xen3-perfmon2_remove_syscalls.patch: Rename to ...
- patches.xen/xen3-perfmon2-remove_syscalls.patch: ... this.
* Thu Dec 18 2008 nfbrown@suse.de
- patches.fixes/md-disable-recovery-on-faulty-degraded-array:
  Disable recovery when degraded RAID1 array appears to be
  faulty. (bnc#447835).
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/symsets.pl: fix uninitialized variable
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - add genksyms reference files so that genksyms can explain why
    did checksums change
* Wed Dec 17 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Delete.  It
  oopses badly and is not needed for the HP2133 hardware, as
  it has switched to Intel chipsets.
* Wed Dec 17 2008 gregkh@suse.de
- Upate to 2.6.27.10-rc1, fixing lots of problems.
  - obsoletes:
  - patches.drivers/libata-update-ST-FLUSH-blacklist
  - patches.fixes/iwlwifi_fix_oops.patch
  - patches.fixes/v4l-dvb-avoid-writing-outside-array
* Wed Dec 17 2008 jeffm@suse.de
- patches.suse/reiserfs-barrier-default: Make reiserfs default
  to barrier=flush.
* Tue Dec 16 2008 mmarek@suse.cz
- addded symtypes-* files to the RC1 reference kabi
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/ext3-mark-super-uptodate: ext3: always mark
  super uptodate before dirty (bnc#457043).
* Tue Dec 16 2008 hare@suse.de
- patches.fixes/blk-dont-invoke-request_fn-on-stopped-queue:
  block: only call ->request_fn when the queue is not stopped
  (bnc#457041).
- patches.fixes/blk-get-extra-reference-before-unmap: block:
  hold extra reference to bio in blk_rq_map_user_iov().
- patches.fixes/blk-move-unplug_work-init: block: move
  q->unplug_work initialization.
- patches.fixes/blk-set-segment-boundary-mask: block: fix setting
  of max_segment_size and seg_boundary mask.
- patches.fixes/dm-mpath-send-activate-to-every-path: Handle
  multiple paths in a path group properly during pg_init.
- patches.fixes/scsi_dh-add-lsi-ids-to-rdac: Adding LSI vendor
  and product IDs to RDAC device handler.
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037,bnc#458393).
- patches.suse/scsi-check-removed-device-for-offline: Check if
  device is removed in scsi_device_online() (bnc#456747).
* Tue Dec 16 2008 hare@suse.de
- Enable 3270 console (bnc#457039)
* Tue Dec 16 2008 rjw@suse.de
- Update config files.
- patches.suse/mm-do-not-disable-memory-hotplug-when-hibernation-is-enabled.patch:
  mm: Do not disable memory hotplug when hibernation is enabled
  (bnc#438914).
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/iwlwifi_fix_oops.patch: iwlwifi: clean key table
  in iwl_clear_stations_table function (bnc#457062).
* Mon Dec 15 2008 jjolly@suse.de
- patches.drivers/cxgb3i_ddp.patch: cxgb3i - added pdu size
  check and fixed ddp page setup (bnc#449519).
* Mon Dec 15 2008 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-04-update: qla4xxx
  driver SLES 11 Beta6 update (bnc#458186).
* Mon Dec 15 2008 oneukum@suse.de
- patches.suse/usb_correct_config_ti_04b3_4543.diff: fix
  ti_usb_3410_5052 driver for device 04b3:4543 (bnc#395775).
* Sun Dec 14 2008 gregkh@suse.de
- Update to 2.6.27.9
  - obsoleted:
  - patches.fixes/applicom-fix-unchecked-ioctl-range
  - patches.fixes/watchdog-ib700wdt-buffer-underflow
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: reiserfs:
  ensure nonzero transaction (bnc#447406).
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Update to print accurate refcount.
* Fri Dec 12 2008 jblunck@suse.de
- .gitignore: Ignore backup files.
* Fri Dec 12 2008 hare@suse.de
- patches.fixes/scsi-check-host-lookup-failure: Correct
  scsi_host_lookup return value (bnc#456532).
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch: hso: rfkill type should
  be WWAN (bnc#458625).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch:
  fix hso rfkillswitch type to WWAN (bnc#458625)
* Fri Dec 12 2008 mmarek@suse.cz
- import SLE11 RC1 reference kabi
* Fri Dec 12 2008 gregkh@suse.de
- refresh patches to apply cleanly due to 2.6.27.9-rc addition.
* Fri Dec 12 2008 gregkh@suse.de
- remove patches that were obsoleted by 2.6.27.9-rc2
  - patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch
  - patches.arch/x86-hpet-use-WARN_ON_ONCE
  - patches.drivers/alsa-hda-acer-quirk
  - patches.drivers/alsa-hda-alc888-medion-add
  - patches.drivers/alsa-hda-dell-studio-15-quirk
  - patches.drivers/alsa-hda-dell-studio-1535-quirk
  - patches.drivers/alsa-hda-hp-6730s-quirk
  - patches.drivers/alsa-hda-hp-elitebook-8530p-quirk
  - patches.drivers/alsa-hda-hp-mobile-fix
  - patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch
  - patches.drivers/cell_edac.patch
  - patches.fixes/acpi-set-SCI_EN-on-MacBook.patch
  - patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch
  - patches.fixes/block-enforce-minimum-SG_IO-timeout
  - patches.fixes/cxgb3-remove-duplicate-tests-in-lro
  - patches.fixes/cxgb3_fix_race_in_EEH
  - patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch
  - patches.fixes/pci_aspm_check_endless_loop_safe.patch
  - patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch
  - patches.fixes/x86-arch_add_memory-remove-debug
  - patches.fixes/x86-memory-hotplug-off-by-one
* Fri Dec 12 2008 gregkh@suse.de
- update to 2.6.27.9-rc2:
  - lots of bugfixes
  - some security updates
* Fri Dec 12 2008 gregkh@suse.de
- intermediate commit as part of adding 2.6.27.9-rc1 to the tree.
* Thu Dec 11 2008 hare@suse.de
- Compile in zfcpdump module for S/390 (bnc#446367).
* Thu Dec 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: one more fix to make kabi checks work
* Thu Dec 11 2008 teheo@suse.de
- patches.drivers/libata-update-ST-FLUSH-blacklist: libata:
  fix Seagate NCQ+FLUSH blacklist (bnc#458192).
* Thu Dec 11 2008 nfbrown@suse.de
- patches.suse/SoN-fix-sync: Cope with racy nature of sync_page
  in swap_sync_page (441793).
* Wed Dec 10 2008 jjolly@suse.de
- patches.arch/s390-05-09-cleanup-of-portopen-requests.patch:
  zfcp: fix erp timeout cleanup for port open requests
  (bnc#450096).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/watchdog-ib700wdt-buffer-underflow: ib700wdt.c -
  fix buffer_underflow bug (bnc#457898).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/applicom-fix-unchecked-ioctl-range: applicom: Fix
  an unchecked user ioctl range and an error return (bnc#457897).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/block-enforce-minimum-SG_IO-timeout: Enforce a
  minimum SG_IO timeout (bnc#457896).
* Wed Dec 10 2008 mmarek@suse.cz
- rpm/find-provides: don't fail if a subpackage doesn't contain
  any modules (such as the -man subpackage on s390x)
* Wed Dec 10 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-6730b-quirk: ALSA: hda - Add quirk
  for HP6730B laptop (bnc#457909).
- patches.drivers/alsa-hda-hp-6730s-quirk: ALSA: hda - Add
  another HP model (6730s) for AD1884A.
- patches.drivers/alsa-hda-hp-elitebook-8530p-quirk: ALSA: hda -
  Make the HP EliteBook 8530p use AD1884A model laptop.
* Wed Dec 10 2008 olh@suse.de
- patches.drivers/ibmvfc-add_sync.patch:
  Fix errors due to inconsistent command data (bnc#456654 - LTC50451)
- patches.drivers/ibmvfc-host_init_delay.patch:
  Delay NPIV login retry and add retries (bnc#456654 - LTC50451)
* Wed Dec 10 2008 teheo@suse.de
- patches.drivers/libata-pata_hpt366-fix-cable-detection:
  pata_hpt366: fix cable detection, (bnc#362159).
- patches.drivers/libata-pata_hpt366-fix-clock-detection:
  pata_hpt366: fix clock detection (bnc#362159).
- patches.drivers/libata-pata_hpt366-no-ATAPI-DMA: pata_hpt366:
  no ATAPI DMA (bnc#362159).
- patches.drivers/libata-pata_hpt366-reimplement-mode-programming:
  pata_hpt366: reimplement mode programming (bnc#362159).
* Tue Dec  9 2008 agruen@suse.de
- supported.conf: Mark xfs_dmapi as supported (bnc#457668).
* Tue Dec  9 2008 jeffm@suse.de
- patches.fixes/x86-arch_add_memory-remove-debug: x86: remove
  debug code from arch_add_memory() (bnc#457526).
- patches.fixes/x86-memory-hotplug-off-by-one: x86, memory
  hotplug: remove wrong -1 in calling init_memory_mapping()
  (bnc#457526).
* Tue Dec  9 2008 agruen@suse.de
- rpm/{kernel-module-subpackage,macros.kernel-source}: Remove
  a leftover hardcoded dependency on the kernel-source package so
  that KMPs can alternatively be built against a kernel other
  than (kernel-source + kernel-syms), such as (kernel-source-rt +
  kernel-syms-rt).
* Tue Dec  9 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop_safe.patch: PCIe:
  ASPM: Break out of endless loop waiting for PCI config bits
  to switch (bnc#449799).
* Tue Dec  9 2008 mmarek@suse.cz
- rpm/symsets.pl:
  - add --required-modules option to tell which modules this
    subpackage requires via dependencies. This is needed to
    preserve symsets when modules move from one subpackage to
    another.
  - add POD help and --help option.
- rpm/kernel-binary.spec.in: make use of --required-modules
* Tue Dec  9 2008 nfbrown@suse.de
- patches.fixes/xfs-barrier-fix.patch: Fix propagation of
  EOPNOTSUPP when barriers are not supported. (bnc#438608).
* Tue Dec  9 2008 rjw@suse.de
- patches.fixes/tg3-fix-default-wol.patch: net (tg3): Fix failure
  to enable WoL by default when possible (bnc#447371).
* Mon Dec  8 2008 olh@suse.de
- patches.arch/ppc-valid-hugepage-size-hugetlb_get_unmapped_area.patch:
  Check for valid hugepage size in hugetlb_get_unmapped_area
  (bnc#456433 - LTC50170).
* Mon Dec  8 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop.patch: Delete.
* Mon Dec  8 2008 rw@suse.de
- patches.drivers/sgi-xp-no-uv:
  SGI SN: Eliminate dependency of the XP/XPC drivers on GRU. (bnc#442442)
* Mon Dec  8 2008 rw@suse.de
- Update config files for ia64:
  Disable PERMIT_BSP_REMOVE.  (bnc#386714)
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in: figure out what
  subpackage is being processed in find-provides and just print
  the symsets computed in the spec.
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: use flavor-rpmarch to match boards on powerpc
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: skip empty KMPs with a warning in
  the kmp %%%%postun
* Mon Dec  8 2008 jjohansen@suse.de
- Update config files.
- patches.apparmor/fix-complain.diff: fix enforcement of deny
  rules in complain mode (bnc#426159).
- patches.apparmor/fix-security-param.diff: fix recognition of
  security= boot parameter (bnc#442668).
- patches.apparmor/fork-tracking.diff: fix log messages to enable
  tools profile learning (bnc#447564).
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: update board detection to use rpmarch instead flavor
* Mon Dec  8 2008 hare@suse.de
- patches.fixes/block-integrity-update: Block integrity update
  (FATE#304345).
- patches.suse/dm-block-integrity: Block integrity support for
  DM and MD (FATE#304345).
- patches.suse/dm-mpath-add-start-io: dm-mpath: add a path
  selector interface (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-queue-length-load-balancing: dm-mpath: add
  queue-length dynamic load balancer (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-service-time-load-balancing:
  dm-mpath: add service-time oriented dynamic load balancer
  (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-tracking-nr-bytes: dm-mpath:
  interface change for service-time dynamic load balancer
  (FATE#303862,FATE#302108).
- supported.conf: Update to correctly reference dynamic load
  balancer modules (bnc#444199)
* Mon Dec  8 2008 tonyj@suse.de
- patches.suse/perfmon2-add_ioctl_interface.patch: switch to
  ioctl interface for perfmon2.
- patches.suse/perfmon2-fix_disabled.patch: fix initializion of
  perfmon disabled.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribyute.
- patches.suse/perfmon2-remove_syscalls.patch: drop additional
  perfmon2 syscalls.
- patches.xen/xen3-perfmon2_remove_syscalls.patch: drop additional
  perfmon2 syscalls.
* Sat Dec  6 2008 trenn@suse.de
- patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch:
  ACPI: EC: Don't degrade to poll mode at storm
  automatically. (bnc#446142).
- patches.fixes/pci_aspm_check_endless_loop.patch: PCIE Break
  out of endless loop waiting for PCI config bits to switch
  (bnc#449799).
* Sat Dec  6 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Sat Dec  6 2008 gregkh@suse.de
- Update to final 2.6.27.8 release
  - contains 2 changes from 2.6.27.8-rc1
* Fri Dec  5 2008 jbeulich@novell.com
- patches.xen/xen-configurable-guest-devices: fix a typo.
* Fri Dec  5 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  move crq_queue_create at the end of initialization (bnc#455929).
* Fri Dec  5 2008 hare@suse.de
- patches.drivers/open-fcoe-fnic-patches: Open-FCoE bugfixes
  for fnic.
- patches.drivers/open-fcoe-rc1-update: Update open-FCoE with
  latest patches from Intel (bnc#438954).
* Fri Dec  5 2008 jbeulich@novell.com
- Update Xen x86-64 config (2k guest devices, 1k outstanding transmits
  in netback).
* Fri Dec  5 2008 hare@suse.de
- patches.arch/s390-zfcp-synchronize-scsi-register: No udev
  events for zfcp online / offline (bnc#443667).
- patches.fixes/scsi-remove-scmd-timeout: Fix block timeout
  residue problems (bnc#447249,bnc#441335).
- patches.fixes/scsi-eh_stu-timeout: Delete obsolet patch.
* Fri Dec  5 2008 bphilips@suse.de
- patches.fixes/saa7134-fix-resource-map-sanity-check-conflict.patch:
  saa7134: fix resource map sanity check conflict (bnc#446733).
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rtl8187se-driver.patch: Staging:
  add rtl8187se driver.  Needed for MSI Wind and other netbooks.
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-serverengines-benet-10gb-ethernet-driver.patch:
  Staging: Add ServerEngines benet 10Gb ethernet driver.
* Fri Dec  5 2008 gregkh@suse.de
- update the wlan-ng driver to the latest upstream version, making
  it much more useful (it actually works now...)
* Fri Dec  5 2008 nfbrown@suse.de
- patches.fixes/sunrpc-module-refcount-fix: Add a reference to
  sunrpc in svc_addsock (443379).  This avoid a bug where
  refcount on sunrpc can go zero or negative.
* Thu Dec  4 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: reiserfs: print more
  information when an empty journal list is encountered
  (bnc#447406 bnc#399966).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch:
  ATM: duplicate listen() on socket corrupts the vcc table
  (CVE-2008-5079).
* Thu Dec  4 2008 jack@suse.cz
- Update config files.
* Thu Dec  4 2008 jack@suse.cz
  XFS update on request from SGI:
- patches.apparmor/vfs-notify_change.diff: Add a vfsmount
  parameter to notify_change(). (refreshed)
- patches.suse/xfs-account-for-allocated-blocks-when-expanding-directories:
  Account for allocated blocks when expanding directories
  (bnc#450658).
- patches.suse/xfs-check-for-valid-transaction-headers-in-recovery:
  XFS: Check for valid transaction headers in recovery
  (bnc#450658).
- patches.suse/xfs-dmapi-enable: VFS changes to support DMAPI
  (bnc#450658).
- patches.suse/xfs-dmapi-src: DMAPI Source  (bnc#450658).
- patches.suse/xfs-dmapi-xfs-enable: DMAPI support for xfs
  (bnc#450658).
- patches.suse/xfs-handle-memory-allocation-failures-during-log-initialisation:
  handle memory allocation failures during log initialisation
  (bnc#450658).
- patches.suse/xfs-nfsd-dmapi-aware: Make NFSD DMAPI aware
  (74107, 173874, bnc#450658).
- patches.suse/xfs-wait-for-all-IO-on-truncate-to-zero: Wait
  for all I/O on truncate to zero file size (bnc#450658).
- patches.suse/xfs-dmapi-2.6.27: Delete.
- patches.suse/xfs-dmapi-xfs-2.6.27: Delete.
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch:
  Don't reset affinity for secondary MPIC on boot (bnc#456408 - LTC50397).
* Thu Dec  4 2008 jjolly@suse.de
- Update config files.
- patches.arch/s390-05-04-fix_rport_status_check.patch: zfcp:
  fix remote port status check (bnc#450096).
- patches.arch/s390-05-05-stp-etr-stop-machine.patch: stp/etr:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-06-stp-etr-mutex.patch: stp/etr: serialize
  work. (bnc#450096).
- patches.arch/s390-05-07-generic-ipi.patch: kernel:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-08-topology.patch: kernel: disable cpu
  topology support by default (bnc#450096,LTC#50392).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-cell-gdb-watchpoints.patch:
  Fix GDB watchpoints on Cell (bnc#456405 - LTC50396).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-syscall-xer.so.1.patch: Fix system calls on
  Cell entered with XER.SO=1 (bnc#456406 - LTC50395).
* Thu Dec  4 2008 hare@suse.de
- patches.suse/genhd-disk-ro-uevents: Send uevents for
  write_protect changes (bnc#440959).
* Thu Dec  4 2008 mmarek@suse.cz
- supported.conf: mark kernel/net/ipv4/ipvs/ip_vs/* and
  kernel/net/ipv4/netfilter/ipt_CLUSTERIP as unsupported,
  a supported variant will be provided in a separate KMP
  (bnc#455959)
* Thu Dec  4 2008 schwab@suse.de
- Set CONFIG_IA64_CPE_MIGRATE=m.
* Thu Dec  4 2008 jbeulich@novell.com
- supported.conf: Mark pciback as support, sfc_resource, sfc_netback,
  and sfc_netutil as externally supported, add sfc_netfront, and mark
  xenscsi and xen-scsibk as unsupported.
* Thu Dec  4 2008 mszeredi@suse.de
- patches.suse/SoN-fix-uninitialized-variable.patch: Fix use of
  uninitialized variable in cache_grow() (bnc#444597).
* Thu Dec  4 2008 hare@suse.de
- patches.fixes/scsi-eh_stu-timeout: make scsi_eh_try_stu use
  block timeout (bnc#447249,bnc#441335).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/jbd2-create-proc-entry-fix.patch: Delete. It's not needed
  anymore now that 2.6.27.8-rc1 has a similar fix.
* Thu Dec  4 2008 gregkh@suse.de
- Update to 2.6.27.8-rc1:
  - lots of bugfixes
  - some security fixes as well.
  - obsoletes lots of existing patches:
  - patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
  - patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  - patches.drivers/libata-fix-ata_tf_read_block-overflow
  - patches.drivers/libata-fix-ata_tf_to_lba48-overflow
  - patches.drivers/libata-seagate-firmware-bug
  - patches.drivers/parport-serial-array-overflow-fix
  - patches.fixes/af_unix-soft-lockup-fix.patch
  - patches.fixes/cifs-add-cifs_sock_list
  - patches.fixes/cifs-cleanup-cifs_mount
  - patches.fixes/cifs-cleanup-proto-handling
  - patches.fixes/cifs-disable-sess-sharing
  - patches.fixes/cifs-fix-build-breakage
  - patches.fixes/cifs-fix-data-corruption
  - patches.fixes/cifs-fix-dead-tcon-check
  - patches.fixes/cifs-fix-oops-on-failed-mount
  - patches.fixes/cifs-fix-reconnection-flags
  - patches.fixes/cifs-fix-smb-send2
  - patches.fixes/cifs-fix-writepages
  - patches.fixes/cifs-reinstate-sess-sharing-sans-races
  - patches.fixes/cifs-reinstate-treecon-sharing
  - patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors
  - patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully
  - patches.fixes/ext4_fix_whitespace_checkpatch_issues
  - patches.fixes/ext4_update-flex-bg-counters-when-resizing
  - patches.fixes/fix-inotify-watch-removal-umount-races
  - patches.fixes/hpwdt-execute-page.diff
  - patches.fixes/hpwdt-kdump.diff
  - patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch
  - patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch
* Wed Dec  3 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.19: Fix a kernel warning during shutdown.
- patches.xen/xen3-patch-2.6.27,
  patches.xen/xen-netback-notify-multi,
  patches.xen/xen-virq-per-cpu-irq: Refresh.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch: change
  init order to fill in shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC for
  skb allocation.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  add debug for Scsi_Host->shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- supported.conf: mark dm-leastpending-path as supported
  (bnc#444199)
* Wed Dec  3 2008 teheo@suse.de
  Patch updated to remove strcmp() on NULL strings.
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Wed Dec  3 2008 jbeulich@novell.com
- Update Xen patches to c/s 728 (plus several indivual ones)
- patches.xen/735-balloon-exit.patch: remove sysfs files during balloon
  module exit.
- patches.xen/737-kexec-free.patch: kexec: Don't pass
  limit_pages_to_max_mfn() regions to xen_destroy_contiguous_region().
- patches.xen/740-blkback-resource-leak.patch: blkback, blktap: Fix
  potential resource leak.
- patches.xen/746-pirq-status-page.patch: use shared page indicating
  the need for an EOI notification
- patches.xen/747-x86-undo-mfn-limit.patch: revert the effect of
  xen_limit_pages_to_max_mfn()
- patches.xen/748-x86-ioapic-cleanup.patch: cleanup IO-APIC code
- patches.xen/panic-on-io-nmi-xen.diff: Rename to ...
- patches.xen/xen3-panic-on-io-nmi.diff: ... this.
- patches.xen/uv-sysfs-no-xen.diff: Replace by ...
- patches.xen/xen3-uv_setup_irq.diff: ... this.
- patches.xen/xen3-x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
- patches.xen/xen-fb-bad-irq: Delete.
* Wed Dec  3 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.9-update: Update Emulex lpfc driver
  to 8.2.8.9 (bnc#420767).
* Wed Dec  3 2008 knikanth@suse.de
- patches.suse/cfq-ioc-race: Exiting queue and task might race
  to free cic (bnc#444346).
* Wed Dec  3 2008 sjayaraman@suse.de
- patches.fixes/cifs-reinstate-sess-sharing-sans-races: Adjust as it
  didn't apply cleanly.
* Wed Dec  3 2008 sjayaraman@suse.de
- Fix data corruption issues (411655).
  patches.fixes/cifs-fix-data-corruption
  patches.fixes/cifs-fix-smb-send2
- Fix multiple oopses, memory corruption due to mount/umount races
  (https://bugzilla.samba.org/show_bug.cgi?id=5720).
  patches.fixes/cifs-add-cifs_sock_list
  patches.fixes/cifs-cleanup-cifs_mount
  patches.fixes/cifs-cleanup-proto-handling
  patches.fixes/cifs-disable-sess-sharing
  patches.fixes/cifs-fix-build-breakage
  patches.fixes/cifs-fix-dead-tcon-check
  patches.fixes/cifs-fix-oops-on-failed-mount
  patches.fixes/cifs-fix-reconnection-flags
  patches.fixes/cifs-fix-writepages
  patches.fixes/cifs-reinstate-sess-sharing-sans-races
  patches.fixes/cifs-reinstate-treecon-sharing
* Wed Dec  3 2008 jeffm@suse.de
- scripts/git-create-branch: Helper script to create a new
  branch.
* Tue Dec  2 2008 mmarek@suse.cz
- rpm/get_release_number.sh.in, scripts/tar-up.sh: append first
  eight digits of the commit id to the release string. This makes
  it easier to match rpm release numbers with commits.
* Tue Dec  2 2008 mszeredi@suse.de
- patches.fixes/af_unix-soft-lockup-fix.patch: net: Fix soft
  lockups/OOM issues w/ unix garbage collector (bnc#449739
  CVE-2008-5300).
* Tue Dec  2 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01.02.11.0-k9-update: qla2xxx:
  additional fixes/updates for SLES11 (bnc#450197).
- patches.fixes/scsi-fixup-failfast-definitions: fc_transport:
  fix old bug on bitflag definitions (bnc#447814).
* Tue Dec  2 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff
- patches.suse/novfs-merge-changes.diff: Modified to revert
  some changes in novfs_set_map_drive()
- patches.suse/novfs-clear-mappeddrives.patch: Unlink mapped
  drives on exit (bnc#449451).
* Tue Dec  2 2008 mmarek@suse.cz
- supported.conf: mark ocfs2 as unsupported, a supported variant
  will be provided in a separate KMP (bnc#449824)
* Tue Dec  2 2008 olh@suse.de
- patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch:
  update error message (bnc#448301 - LTC50134)
* Tue Dec  2 2008 hare@suse.de
- Update config files for S/390: Disable FCoE and sync
  default and s390.
- supported.conf: Mark KVM as supported.
* Tue Dec  2 2008 jjolly@suse.de
- ...and added the patches to the series.conf (bnc#450096)
* Tue Dec  2 2008 jjolly@suse.de
- patches.arch/s390-05-01-zfcp-message-linebreak.patch: zfcp:
  Wrong placement of linebreak in message (bnc#450096).
- patches.arch/s390-05-02-zfcp-invalid-non-null-return.patch:
  zfcp: invalid return value on failing fsf_req creation
  (bnc#450096).
- patches.arch/s390-05-03-zfcp-wka-port.patch: zfcp: Fix opening
  of wka ports (bnc#450096).
* Mon Dec  1 2008 kkeil@suse.de
- patches.drivers/cxgb3-Add-1G-fiber-support: cxgb3: Add 1G
  fiber support.
- patches.drivers/cxgb3-Allocate-multiqueues-at-init-time: cxgb3:
  Allocate multiqueues at init time.
- patches.drivers/cxgb3-More-flexible-support-for-PHY-interrupts:
  cxgb3: More flexible support for PHY interrupts..
- patches.drivers/cxgb3-Support-for-Aeluros-2005-PHY: cxgb3:
  Support for Aeluros 2005 PHY.
- patches.drivers/cxgb3-allow-for-PHY-reset-status: cxgb3:
  allow for PHY reset status.
- patches.drivers/cxgb3-commnonize-LASI-phy-code: cxgb3:
  commnonize LASI phy code.
- patches.drivers/cxgb3-eeprom-read-fixes.patch:
  cxgb3 - eeprom read fixes.
- patches.drivers/cxgb3-enable-lro-through-ethtool: cxgb3 -
  enable lro control through ethtool.
- patches.drivers/cxgb3-simplify-port-type-struct-and-usage:
  cxgb3: simplify port type struct and usage.
- patches.drivers/cxgb3-update-driver-version: cxgb3: update
  driver version. (bnc#446739)
* Mon Dec  1 2008 mmarek@suse.cz
- rpm/macros.kernel-source: one more fix to the flavor selection
  code (for some reason %%* contained a newline)
* Mon Dec  1 2008 trenn@suse.de
- patches.arch/acpi_x2APIC_madt_enhancements.patch: ACPICA:
  x2APIC support: changes for MADT and SRAT ACPI tables (fate
  303948 and fate 303984).
- patches.fixes/acpi_check_for_invalid_handle.patch: ACPICA:
  Add check for invalid handle in acpi_get_object_info
  (http://www.acpica.org/bugzilla/show_bug.cgi?id=474).
- patches.fixes/acpi_dereference_object_if_possible.patch:
  ACPICA: Add function to dereference returned reference objects
  (http://bugzilla.kernel.org/show_bug.cgi?id=11105).
- patches.fixes/acpi_do_not_load_acpi_cpufreq_acpioff.patch:
  ACPI: don't load acpi_cpufreq if acpi=off (no reference).
* Mon Dec  1 2008 trenn@suse.de
- patches.fixes/acpi_copy_tables_fix_suspend.patch: ACPICA:
  Copy dynamically loaded tables to local buffer (bnc#410726).
* Sat Nov 29 2008 nfbrown@suse.de
- patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch:
  SUNRPC: Fix autobind on cloned rpc clients.
  Importantly, this removes a 'BUG_ON' that fires. (450083).
* Sat Nov 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Sat Nov 29 2008 bwalle@suse.de
- UV updates from SGI (bnc#442455, #442455).
  o patches.fixes/ia64_uv_partition_id.diff:
    Add partition id, coherence id, and region size to UV
  o patches.fixes/ia64_uv_watchlist.diff:
    Add UV watchlist suppor
  o patches.fixes/null_irq_desc_name.diff:
    genirq: NULL struct irq_desc's member 'name' in
    dynamic_irq_cleanup()
  o patches.fixes/uv-bios_call_memprotect.diff:
    Add UV bios call to change memory protections
  o patches.fixes/uv-bios_call_partition.diff:
    x86: Add UV partition call
  o patches.fixes/uv-bios_call_reserve_page.diff:
    Add UV bios call to get the address of the reserved page
  o patches.fixes/uv-bios_call_watchlist.diff:
    Add UV bios calls to allocate and free watchlists
  o patches.fixes/uv-bios_common.diff:
    x86: Add UV bios call infrastructure
  o patches.fixes/uv-efi_bios.diff:
    x86: Add UV EFI table entry
  o patches.fixes/uv-sn_region_size.diff:
    Use consistent names for region size and conherence id on x86
    and ia64
  o patches.fixes/uv-sysfs.diff:
    x86: Add UV sysfs entries
  o patches.fixes/uv-xp-change_memprotect.diff:
    Define xp_expand_memprotect() and xp_restrict_memprotect()
  o patches.fixes/uv-xpc-get_sn_info.diff:
    Define xp_partition_id and xp_region_size
  o patches.fixes/uv-xpc_create_gru_mq_uv.diff:
    Add the code to create the activate and notify gru message
    queues
  o patches.fixes/uv-xpc_get_part_rsvd_page.diff:
    Add support for getting the address of a partition's reserved
    page
  o patches.fixes/uv_setup_irq.diff:
    x86, UV: add uv_setup_irq() and uv_teardown_irq() functions, v3
- Refresh Xen patches
  o patches.xen/xen3-auto-arch-x86.diff
  o patches.xen/xen3-patch-2.6.19
- patches.xen/xen-x86-no-lapic: Add uv_irq.o
- patches.xen/uv-sysfs-no-xen.diff:
  Don't build UV sysfs support on Xen.
* Sat Nov 29 2008 trenn@suse.de
- patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch:
  powernow-k8: ignore out-of-range PstateStatus value (no
  bug avail).
* Fri Nov 28 2008 sassmann@suse.de
- Update config files.
  activate ALTIVEC in ps3 config
* Fri Nov 28 2008 hare@suse.de
- patches.drivers/open-fcoe-beta4-update: rediff.
- patches.drivers/open-fcoe-beta6-update: Incremental Open-FCoE
  for Beta6 (bnc#438954).
* Fri Nov 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sony-vaio-vgn-sr19xn-quirk: ALSA:
  hda - Add quirk for Sony VAIO VGN-SR19XN (bnc#450080).
* Fri Nov 28 2008 olh@suse.de
- rpm/kernel-binary.spec.in: move Module.symvers creation into
  CONFIG_MODULES section, a static kernel exports nothing
* Fri Nov 28 2008 olh@suse.de
- rpm/post*.sh: kernel-vanilla has now vmlinux-vanilla symlink
* Fri Nov 28 2008 teheo@suse.de
  Block layer timer bug fixed.  Multipath patch update is just patch
  refresh.
- patches.drivers/block-internal-dequeue-shouldnt-start-timer:
  block: internal dequeue shouldn't start timer (bnc#449880).
- patches.drivers/blk-request-based-multipath-update: Block layer
  fixes for request-based multipathing (References: FATE#302108).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix no-op macro args
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix compile on ppc32
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: always create a dummy initrd because
  mkinitrd is called unconditionally
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: kernel-ps3 needs a suffix
* Thu Nov 27 2008 olh@suse.de
- remove last traces of kernel-um handling
* Thu Nov 27 2008 hare@suse.de
- patches.fixes/qla2xxx-disable-automatic-queue-tracking: qla2xxx:
  Conditionally disable queue_full tracking (bnc#449386).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: no sysrq on Cell QS21/QS22
  serial console (bnc#422987,bnc#96313 - LTC47675/LTC16841).
* Thu Nov 27 2008 olh@suse.de
- patches.arch/ppc-memoryless-nodes.patch: fix booting with
  memoryless nodes (443280 - LTC49675)
* Thu Nov 27 2008 teheo@suse.de
- patches.drivers/libata-seagate-firmware-bug: libata: blacklist
  Seagate drives which time out FLUSH_CACHE when used with NCQ
  (bnc#449531).
* Wed Nov 26 2008 agruen@suse.de
- rpm/macros.kernel-source: Fix the kernel flavor selection logic
  for the %%kernel_module_package macro.
* Wed Nov 26 2008 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: move to
  correct place in series.conf and rediff
- patches.drivers/cciss-newids.patch: Delete.
* Wed Nov 26 2008 hare@suse.de
- patches.drivers/cciss-newids.patch: Support for newcciss
  controller (bnc#448416).
- patches.fixes/blk-leave-sync-timer-running: block: leave
  request timeout timer running on an empty list (bnc#447249).
* Tue Nov 25 2008 mszeredi@suse.de
- patches.fixes/slab-alloc_slabmgmt-fix.patch: slab: remove
  GFP_THISNODE clearing from alloc_slabmgmt() (bnc#444597).
* Tue Nov 25 2008 sjayaraman@suse.de
- patches.suse/SoN-11-mm-page_alloc-emerg.patch: Fix accidental side-effect
  that this patch introduced by reverting patches.fixes/oom-warning
  (bnc #444597).
* Tue Nov 25 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-dell-92hd73xx-models: ALSA: hda -
  Check model for Dell 92HD73xx laptops (bnc#446025).
- patches.drivers/alsa-hda-dell-studio-1535-quirk: ALSA: hda -
  mark Dell studio 1535 quirk (bnc#446025).
- patches.drivers/alsa-hda-spdif-bits-cache-fix: ALSA: hda -
  Fix caching of SPDIF status bits.
- patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch: ALSA:
  hda - No 'Headphone as Line-out' swich without line-outs
  (bnc#446025).
- patches.drivers/alsa-hda-stac-yet-more-fixes: ALSA: hda -
  Fix AFG power management on IDT 92HD* codecs (bnc#446025).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/fix-inotify-watch-removal-umount-races: Fix
  inotify watch removal/umount races (bnc#446973 CVE-2008-5182).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/uv-redundant-creation-of-proc-dir: UV: redundant
  creation of sgi_uv (bnc#444799).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid45 depends on a few more modules
  (bnc#440208, bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Switch from a no_file_caps command line switch to file_caps={0,1}
  for enabling/disabling file capabilities, and make file_caps=0
  the default: we cannot get the no_file_caps option added to the
  kernel command line anymore (perl-Bootloader, bnc#418366).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid4-5 was renamed to dm-raid45 (bnc#440208,
  bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Update config files: switch from CONFIG_PREEMPT_VOLUNTARY to
  CONFIG_PREEMPT_NONE.
* Mon Nov 24 2008 ghaskins@suse.de
- patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch:
  sched: fix a bug in sched domain degenerate (bnc#442464).
* Mon Nov 24 2008 mmarek@suse.cz
- doc/README.SUSE: document that setting allow_unsupported_modules
  to 1 in /etc/modprobe.d/unsupported-modules is required to make
  self-compiled kernels work.
* Mon Nov 24 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff: Sync with latest upstream
  submission.
* Sun Nov 23 2008 trenn@suse.de
- patches.arch/x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
* Sat Nov 22 2008 olh@suse.de
- enable CONFIG_CGROUP_NS on ia64, s390 and powerpc (bnc#447507 - LTC50053)
* Sat Nov 22 2008 rjw@suse.de
- patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch:
  fix boot panic caused by offline CPUs (bnc#440386).
* Fri Nov 21 2008 agruen@suse.de
- config/x86_64/maxcpus: Delete.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: s/CVS/GIT/
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: fix module names in export lists
  (kernel/irq/built-in was printed as irq/built-in)
* Fri Nov 21 2008 agruen@suse.de
- Update x86_64/{debug,default,trace,vanilla} config files:
  increase NR_CPUS to 512.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: Replace the bash and awk scripts around symsets
  and kabi checking with a single script that generates symsets,
  reuses symsets from older kernels and checks for kabi changes for
  each of the split packages (kabi checking and symset reuse
  require a set of reference files, which does not exist yet)
- rpm/list-exported-symbols: Delete.
- rpm/split-into-symsets: Delete.
- scripts/kabi-checks: Delete.
- kabi/severities: table of kabi change severities
- rpm/built-in-where, rpm/find-provides,
  rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: update to use symsets.pl
* Fri Nov 21 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: include additional fixes from
  Intel (bnc#442411)
* Fri Nov 21 2008 kkeil@suse.de
- patches.fixes/igb_ethtool.patch: add missing ethtool hooks
  (bnc#435551)
* Fri Nov 21 2008 jjolly@suse.de
- patches.arch/s390-04-08-cio-ungroup-race-fix.patch:
  cio: ccwgroup online vs. ungroup race condition
  (bnc#445100,LTC#50092).
- patches.arch/s390-04-09-zfcp-host-busy-count-fix.patch: zfcp:
  prevent double decrement on host_busy counter (bnc#445100).
* Fri Nov 21 2008 agruen@suse.de
- rpm/macros.kernel-source:
  + Rename the -s option to -t in the %%kernel_module_package macro
    for improved cross-distro compatibility.
  + Define %%kernel_module_package_release as 1 for feature tests.
  + Define %%kernel_module_package_buildreqs for use by KMPs: that
    way, KMPs can either use this macro for compatibility, or
    they can substitute other packages for special cases.
* Fri Nov 21 2008 hare@suse.de
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3i-fixed-offload-array-size: cxgb3i -
  fixed offload wr array size (bnc#447409).
- patches.fixes/dm-table-switch-to-readonly: dm multipath devices
  are not getting created for readonly devices (bnc#382705).
- patches.suse/dm-mpath-null-pgs: Allow zero paths for multipath
  priority groups (bnc#372684).
- patches.suse/scsi-netlink-ml: Netlink interface for SCSI
  sense codes (FATE#303789).
* Fri Nov 21 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff: Fix oops in
  set_map_drive (bnc#446824, bnc#444469).
* Fri Nov 21 2008 jbeulich@novell.com
- patches.xen/xen3-x86-vmware-tsc-03-detect-from-hypervisor:
  Fix Xen pv driver build.
* Fri Nov 21 2008 olh@suse.de
- patches.arch/ppc-spufs-01-use-inc_nlink.patch: use inc_nlink
- patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
- patches.arch/ppc-spufs-03-sputrace-Only-enable-logging-on-open.patch
- patches.arch/ppc-spufs-04-sputrace-Don-t-block-until-the-read.patch
- patches.arch/ppc-spufs-05-Use-state_mutex-for-switch_log-lockin.patch
- patches.arch/ppc-spufs-06-Don-t-require-full-buffer-in-switch_l.patch
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch
- patches.arch/ppc-spufs-08-Use-kmalloc-rather-than-kzalloc-for-s.patch
- patches.arch/ppc-spufs-09-Improve-search-of-node-for-contexts-w.patch
- patches.arch/ppc-spufs-10-Explain-conditional-decrement-of-aff_.patch
- patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  update spufs to current mainline state (bnc#447133 - LTC50070)
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/parport-serial-array-overflow-fix: Fix array
  overflow in parport_serial.c (bnc#447067).
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-15-quirk: ALSA: hda -
  Add a quirk for Dell Studio 15 (bnc#446025).
- patches.drivers/alsa-hda-stac-dell-m4-3-quirk: ALSA: hda:
  Add STAC_DELL_M4_3 quirk (bnc#446025).
* Fri Nov 21 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap. Try again.
* Fri Nov 21 2008 gregkh@suse.de
- Refresh patches to apply cleanly after 2.6.27.7 update.
* Fri Nov 21 2008 gregkh@suse.de
- Update to 2.6.27.7
  - lots of bugfixes and security updates.
  - obsoletes:
  - patches.arch/s390-04-05-topology-lock.diff
  - patches.drivers/bnx2x-zero-PMF
  - patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch
  - patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch
  - patches.fixes/sony_laptop_fix_suspend.patch
  - patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch
  - patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch
  - patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
* Fri Nov 21 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: ata_piix:
  detect and clear spurious IRQs (bnc#445872).
* Fri Nov 21 2008 npiggin@suse.de
- patches.fixes/mm-madvise-fix.patch: mm: madvise correct return
  code (bnc#352998).
* Thu Nov 20 2008 jack@suse.cz
- patches.suse/ocfs2-Change-quotafile-names.patch: ocfs2: Change
  file names of local quota files to be consistent (fate#302681).
- patches.suse/ocfs2-Fix-hang-in-quota-recovery-code.patch:
  ocfs2: Fix hang in quota recovery code (fate#302681).
- patches.suse/ocfs2-Fix-oops-when-one-quotatype-enabled: ocfs2:
  Fix oops when only usrquota or grpquota feature is enabled
  (fate#302681).
* Thu Nov 20 2008 garloff@suse.de
- patches.suse/panic-on-io-nmi.diff
  patches.xen/panic-on-io-nmi-xen.diff:
  New kernel sysctl panic-on-io-nmi, which is set will cause a
  kernel panic on receiving an IOCK NMI (bnc#427979).
* Thu Nov 20 2008 jjolly@suse.de
- patches.arch/s390-04-06-cio-sac-update.diff: cio: update sac
  values (bnc#445100).
- patches.arch/s390-04-07-als.patch: kernel: Add processor type
  march=z10 and a processor type safety check. (bnc#445100).
* Thu Nov 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-gpio-switch-fix: ALSA: hda:
  STAC_DELL_M6 EAPD (bnc#446025).
* Thu Nov 20 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.6 and c/s 724.
- Update Xen config files.
- patches.xen/xen-fb-bad-irq: xenfb: don't use irq before it
  gets set up (bnc#445659).
- patches.xen/xen-netback-notify-multi: netback: use multicall
  for send multiple notifications.
- patches.xen/xen-netback-nr-irqs: netback: reduce overhead of
  IRQ recording.
* Thu Nov 20 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: removed (no SR-IOV) (bnc#440614)
* Thu Nov 20 2008 olh@suse.de
- disable patches.arch/ppc-efika-bestcomm-ata-dma.patch
  crashes the sound driver
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: excluded vanilla build from creating
  the man package
* Thu Nov 20 2008 hare@suse.de
- patches.drivers/ibmvfc-async-events-oops: ibmvfc oops while
  processing async events (bnc#445541).
- patches.drivers/mpt-fusion-4.16.00.00-update: MPT fusion driver
  update to 4.16.00.00 (bnc#425660).
- patches.fixes/dm-mpath-NULL-pgpath-in-activate_path: Do not
  call activate_path() if pgpath is NULL (bnc#442676).
- patches.fixes/scsi-dh-rdac-initialize-passive-path: Initialize
  path state to be passive when path is not owned (bnc#442676).
- patches.suse/dm-mpath-leastpending-path: Dynamic load balancing
  policy for device mapper multipath (bnc#444199).
* Thu Nov 20 2008 olh@suse.de
- patches.fixes/bug-437171_1_sched_clock_lock.patch: sched: only
  update rq->clock while holding rq->lock (437171 - LTC47404).
- patches.fixes/bug-437171_2_sched_delta_weight.patch: sched:
  revert back to per-rq vruntime (437171 - LTC47404).
- patches.fixes/bug-437171_3_rework_wakeup_preemption.patch:
  sched: rework wakeup preemption (437171 - LTC47404).
- patches.fixes/bug-437171_4_sched_reinstate_vruntime_wakeup.patch:
  sched: re-instate vruntime based wakeup preemption (437171 -
  LTC47404).
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  Fixed debug build, added dependent config option.
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  - > unified i386/x86_64 debug kernels:
  - added CONFIG_NO_HZ=y to i386-debug
  - added CONFIG_DEBUG_INFO to x86_64-debug
  Differ method to receive processor_id depending whether the processor
  got declared as a regular ACPI device or as a processor object:
- patches.arch/acpi_behave_uniquely_based_on_processor_declaration.patch:
  ACPI: Behave uniquely based on processor declaration definition
  type (bnc#440062).
- patches.arch/acpi_disambiguate_processor_declaration_type.patch:
  ACPI: Disambiguate processor declaration type (bnc#440062).
- patches.arch/acpi_processor_cleanups.patch: ACPI: 80 column
  adherence and spelling fix (no functional change) (bnc#440062).
- patches.xen/xen3-auto-common.diff: xen3 common.
  Fix missing bit for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
- patches.fixes/sony_laptop_fix_suspend.patch: sony-laptop:
  Ignore missing _DIS method on pic device (bnc#446487).
* Thu Nov 20 2008 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Do not detach hardware
  handler when removing multipath maps (bnc#435688).
- patches.fixes/scsi-dh-alua-send-stpg: Always send STPG for
  explicit tgps mode.
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: Added kernel man package for s390x
* Thu Nov 20 2008 olh@suse.de
- patches.arch/ppc-of-irq-map.patch: fix IRQ assignment if
  interrupts property is missing (bnc#446610 - LTC50006)
* Thu Nov 20 2008 rjw@suse.de
- patches.fixes/acpi-set-SCI_EN-on-MacBook.patch: ACPI suspend:
  Blacklist boxes that require us to set SCI_EN directly on resume
  (bnc#444786).
* Wed Nov 19 2008 tiwai@suse.de
- patches.arch/x86-hpet-pre-read: x86: workaround for mccreary
  HPET read problem (bnc#433746).
* Wed Nov 19 2008 trenn@suse.de
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
  - > Fix typo, must not invert logic at this point
* Wed Nov 19 2008 kkeil@suse.de
- patches.drivers/e1000e_add_ECC: e1000e: enable ECC (bnc#445829)
* Wed Nov 19 2008 mmarek@suse.cz
- scripts/tar-up.sh: record the git branch name in the spec files
  (no branch name means master)
* Wed Nov 19 2008 jkosina@suse.de
- patches.drivers/elousb.patch: fix values of maximum X and Y
  coordinates so that they are compliant with the values that
  the device contains in its descriptor (bnc#442865)
* Wed Nov 19 2008 goldwyn@suse.de
- patches.suse/novfs-merge-changes.diff: Merge changes left out
  during code pull (bnc#445000).
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-multinode.patch: Add support for
  multiple BSR nodes in the device tree. (bnc#443665 - LTC49817)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-cmm-pagecounter.patch:
  Update page in counter for CMM (bnc#445540 - LTC49942)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-4k.patch: Unable to Use Small
  BSR register on Power LPAR (bnc#443673 - LTC49749)
* Wed Nov 19 2008 jjolly@suse.de
- config/s390/s390: Update config files: added CONFIG_UTRACE=y and
  CONFIG_HAVE_ARCH_TRACEHOOK=y
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/ehca-fix-possible-nullpointer-access-v2.patch:
  ehca: fix a possible nullpointer access (bnc#441966).
* Wed Nov 19 2008 jjolly@suse.de
- patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  powerpc/cell/axon-msi: retry on missing interrupt (bnc#445964).
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/0001-IB-ehca-Fix-problem-with-max-number-of-QPs-and-CQs.patch:
  Fix problem with max number of QPs and CQs (bnc#441619).
* Tue Nov 18 2008 bwalle@suse.de
- Disable CONFIG_STRICT_DEVMEM for i386 and x86_64 (bnc#443852).
* Tue Nov 18 2008 jjolly@suse.de
- Update config files.
- patches.trace/s390-syscall-get-nr.diff: fix syscall_get_nr..
- patches.trace/s390-utrace-enablement.patch: Backport s390
  kernel components required for utrace enablement.
* Tue Nov 18 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: on s390(x) call dwarfextract to create the
  Kerntypes file for use with old lcrash debuggers.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-92hd71bxx-gpio-fix: ALSA:
  hda - Fix GPIO initialization in patch_stac92hd71bxx()
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-gpio-unsol-resume-fix:
  ALSA: hda - Fix resume of GPIO unsol event for STAC/IDT
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-hp-pavilion-quirks: ALSA: hda -
  Add quirks for HP Pavilion DV models (bnc#445321,bnc#445161).
* Tue Nov 18 2008 tiwai@suse.de
- patches.arch/x86-hpet-use-WARN_ON_ONCE: x86: HPET: convert
  WARN_ON to WARN_ON_ONCE (bnc#433746).
* Tue Nov 18 2008 sdietrich@suse.de
  RT development has moved to slert-devel branch.
- Remove RT patches from master branch.
  (itemized RT patch list suppressed)
* Tue Nov 18 2008 olh@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: use ATA DMA (bnc#445856)
* Tue Nov 18 2008 olh@suse.de
- config/ppc/ppc64: reenable 64k PAGE_SIZE to keep the config
  flavor on ppc and ppc64 in sync
  the last change had also no bug number to fix the possible bug
  in the Xserver.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-acer-dmic: ALSA: hda - Split
  ALC268 acer model (bnc#420048).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-04-01-qdio_prevent_double_shutdown.patch:
  qdio: prevent double qdio shutdown in case of I/O
  errors. (bnc#445100).
- patches.arch/s390-04-02-qdio-osa-port-count.patch: qdio:
  fix qeth port count detection. (bnc#445100).
- patches.arch/s390-04-03-kmsg.patch: kmsg: do not change pr_xyz
  messages without KMSG_COMPONENT (bnc#445100).
- patches.arch/s390-04-04-dasd_fatal_error_log_sense.patch:
  dasd: log sense for fatal errors. (bnc#445100).
- patches.arch/s390-04-05-topology-lock.diff: kernel: Fix locking
  in cpu topology code. (bnc#445100).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-personality-mask.patch: fix s390x_newuname.
* Tue Nov 18 2008 gregkh@suse.de
- patches.drivers/staging-rt2860-enable-wpa_supplicant-support.patch:
  Staging: rt2860: enable WPA_SUPPLICANT support (bnc#437959).
* Mon Nov 17 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.7-update: Update lpfc to 8.2.8.7
  (bnc#420767).
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Update
  qla4xxx to 5.01.00-k8_sles11-03     (bnc#444884).
- patches.fixes/dm-mpath-reattach-dh: Reattach device handler
  for multipath devices (bnc#435688).
- patches.fixes/scsi-add-tgps-setting: Add TGPS setting to
  scsi devices.
- patches.fixes/scsi-dh-alua-retry-UA: Retry ALUA device handler
  initialization on Unit Attention.
* Mon Nov 17 2008 jeffm@suse.de
- patches.fixes/v4l-dvb-avoid-writing-outside-array: V4L/DVB
  (9621): Avoid writing outside shadow.bytes array (bnc#445569).
* Mon Nov 17 2008 fseidel@suse.de
- patches.fixes/ipw2200-send-noassoc.patch: ipw2200: fix oops
  in ipw_tx_skb (bnc#397390).
* Sat Nov 15 2008 rjw@suse.com
- patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch:
  x86: Hibernate: Fix breakage on x86_32 with CONFIG_NUMA set
  (bnc#439126).
* Sat Nov 15 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-hp-m4-check-fix: ALSA:
  hda - Check model type instead of SSID in patch_92hd71bxx()
  (bnc#444349).
- patches.drivers/alsa-hda-sigmatel-vref-event-fix: ALSA: hda:
  STAC_VREF_EVENT value change (bnc#444349).
* Sat Nov 15 2008 gregkh@suse.de
- patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch:
  memory hotplug: fix page_zone() calculation in
  test_pages_isolated() (bnc#445163).
* Fri Nov 14 2008 gregkh@suse.de
- patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch:
  Input: ALPS - add signature for DualPoint found in Dell Latitude
  E6500 (bnc#436719).
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/hpwdt-execute-page.diff:
  [WATCHDOG] [hpwdt] Set the mapped BIOS address space as
  executable (bnc#430680).
* Fri Nov 14 2008 tiwai@suse.de
- patches.arch/x86-vmware-tsc-01-add-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-02-add-X86_FEATURE_HYPERVISOR,
  patches.arch/x86-vmware-tsc-03-detect-from-hypervisor,
  patches.arch/x86-vmware-tsc-04-use-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-05-skip-tsc-clocksource,
  patches.arch/x86-vmware-tsc-06-fix-vmware_get_tsc,
  patches.arch/x86-vmware-tsc-07-DMI-product-serial-key,
  patches.xen/xen-x86-vmware-tsc-fix:
    VMware tsc clocksource workaround (bnc#441338).
* Fri Nov 14 2008 tiwai@suse.de
- Fixed a typo in definition of X86_FEATURE_XTOPOLOGY (bnc#443293)
  in patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4
* Fri Nov 14 2008 agruen@suse.de
- Update CONFIG_X86_RESERVE_LOW_64K in config/x86_64/maxcpus as
  well.
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff:
  rename to patches.suse/mem_cgroup_stat-dynamic-alloc, and update
  to newer version.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/kdump-x86-sparsemem.diff: x86, kdump: fix invalid
  access on i386 sparsemem (bnc#440525).
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  Refresh.
* Fri Nov 14 2008 gregkh@suse.de
- patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch:
  iwlagn: avoid sleep in softirq context (bnc#444382).
* Fri Nov 14 2008 philips@suse.de
- patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch:
  cdc-acm.c: fix recursive lock in acm_start_wb error path.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K for i386 and x86-64 vanilla
  configs.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K on i386 and x86-64 to fix some
  suspend/resume issues (option added in 2.6.27.6)
* Thu Nov 13 2008 gregkh@suse.de
- refresh patches so that everything applies cleanly.
* Thu Nov 13 2008 gregkh@suse.de
- Update to 2.6.27.6:
  - fixes some security issues
  - lots of bugfixes
  - obsoletes:
  - patches.arch/acpi-dock-avoid-check-_STA-method.patch:
  - patches.arch/ppc-gigantic-page-fix2.patch:
  - patches.arch/ppc-gigantic-page-fix3.patch:
  - patches.drivers/alsa-hda-dell-eq-option:
  - patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  - patches.drivers/cciss-fix-sysfs-symlink.patch:
  - patches.drivers/libata-fix-last_reset-timestamp-handling:
  - patches.kernel.org/md-raid10-recovoery-fix.path:
* Thu Nov 13 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: package modules.order (bnc#441384)
* Thu Nov 13 2008 agruen@suse.de
- config.conf: Add x86_64/maxcpus as the 4096-cpu configuration
  and switch back to at most 128 cpus in the other configs. This
  avoids wasting memory on all but the most extreme x86_64
  systems.
- rpm/kernel-binary.spec.in: define a kernel-$flavor symbol to
  allow per-flavor patches. (Use this for testing only!)
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff: Add
  this patch conditionally for x86_64/maxcpus for now pending
  test results from bnc#425240.
* Thu Nov 13 2008 tiwai@suse.de
- patches.drivers/alsa-hda-beep-dig-switch: ALSA: hda - Add
  digital beep playback switch for STAC/IDT codecs (#444572).
- patches.drivers/alsa-hda-beep-null-check-fix: ALSA: hda -
  Missing NULL check in hda_beep.c.
* Thu Nov 13 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: fix to
  make it work with iSCSI (bnc#444234)
* Thu Nov 13 2008 olh@suse.de
- mark some powerpc device drivers as supported to move them out of
  kernel-extra, otherwise installation-images will not pick them up
- ps3vram, mtd, mtdblock, mtd_blkdevs (bnc#444220)
- PowerMac, Efika and Pegasos2 storage and network drivers
* Wed Nov 12 2008 bwalle@suse.de
- patches.fixes/firmware-memmap-64bit.diff: Always use 64 bit
  addresses for the firmware memory map.
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-powermac-ibook-g4-mic-fix: ALSA: powermac -
  Rename mic-analog loopback mixer element (bnc#444194).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-detect-fix: ALSA: hda -
  Fix IDT/STAC multiple HP detection (bnc#443267).
* Wed Nov 12 2008 agruen@suse.de
- patches.suse/module-ref-dynamic-alloc: fall back to vmalloc if
  kmalloc fails (bnc#425240).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac9200-missing-mux-capture: ALSA:
  hda - Add missing analog-mux mixer creation for STAC9200
  (bnc#443738).
- patches.drivers/alsa-hda-stac92xx-mic-pin-fix: ALSA: hda -
  Fix input pin initialization for STAC/IDT codecs (bnc#443738).
* Wed Nov 12 2008 philips@suse.de
- rpm/kernel-binary.spec.in: remove Recommends: kerneloops, opt-in will
  be implemented in the 11.2 installer
* Tue Nov 11 2008 jeffm@suse.de
- patches.fixes/reiserfs-error-buffer-locking: reiserfs: add
  locking around error buffer.
- patches.fixes/reiserfs-varargs-fix: reiserfs: prepare_error_buf
  wrongly consumes va_arg.
* Tue Nov 11 2008 tiwai@suse.de
- patches.suse/module-ref-dynamic-alloc: Allocate module.ref
  array dynamically (bnc#425240).
- Update config files: back to NR_CPUS=4096
* Tue Nov 11 2008 jblunck@suse.de
- Update config files: Set NR_CPUS on x86_64 back to 128 again for
  now: with NR_CPUS=4096, the size of eack .ko file increases by
  496 KiB because of the static struct module in
  .gnu.linkonce.this_module.
* Tue Nov 11 2008 schwab@suse.de
- patches.arch/ppc-select: Fix wrong error code from ppc32 select.
* Tue Nov 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also encode the architecture into the
  packageand supplements.
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-fix-ata_tf_read_block-overflow: libata:
  Avoid overflow in ata_tf_read_block() when tf->hba_lbal > 127
  (bnc#443661).
- patches.drivers/libata-fix-ata_tf_to_lba48-overflow: libata:
  Avoid overflow in ata_tf_to_lba48() when tf->hba_lbal > 127
  (bnc#443661).
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-pata_sch-slave-poss: pata_sch: slave
  devices (bnc#443657).
* Mon Nov 10 2008 schwab@suse.de
- config/ppc/ppc64: Disable 64k pages to work around X server bug.
* Mon Nov 10 2008 olh@suse.de
- rpm/kernel-binary.spec.in: fix variable assignment in last change
* Mon Nov 10 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: encode the architecture into
  subpackage dependencies (bnc#440961)
* Mon Nov 10 2008 olh@suse.de
- handle arch differences for cpu and kbuild correctly
* Mon Nov 10 2008 schwab@suse.de
- patches.arch/ia64-page-migration. patches.arch/mm-avoid-bad-page-on-lru:
  migrade pages off of pages with correctable errors.
* Mon Nov 10 2008 mmarek@suse.cz
- scripts/tar-up.sh: do not generate kernel-source-rt.spec and
  kernel-syms-rt.spec if RT is not enabled.
* Mon Nov 10 2008 sdietrich@suse.de
- config.conf: Suppress RT configurations.
* Sun Nov  9 2008 jeffm@suse.de
- config.conf: Removed previous workaround.
- rpm/kernel-binary.spec.in: Remove @FLAVOR@ from %%symbols.
* Sat Nov  8 2008 jeffm@suse.de
- config.conf: Workaround for kernel-ppc64 on head-ppc.
* Sat Nov  8 2008 gregkh@suse.de
- Update to the "real" 2.6.27.5.  No code changes from what we had
  in our tree previously, with the exception for the version number
  change.
* Fri Nov  7 2008 bwalle@suse.de
- patches.fixes/kdb-read-CR.diff:
  Support '\n' in KDB (bnc#442808).
* Fri Nov  7 2008 gregkh@suse.de
- disable perfmon support in the -trace kernels as it doesn't build
  properly.
* Fri Nov  7 2008 schwab@suse.de
- patches.arch/compat-sys-swapcontext: Fix msr check in sys_swapcontext.
* Fri Nov  7 2008 hare@suse.de
- patches.drivers/ixgbe-add-bcna-support: DCB: Add BCNA support
  to ixgbe.
- patches.drivers/open-fcoe-beta3-update: Open-FCoE update for
  Beta3 (bnc#438954).
- patches.drivers/open-fcoe-beta4-update: Open-FCoE: Update for
  Beta4 (bnc#438954).
- patches.drivers/open-fcoe-beta5-update: Open-FCoE: Update for
  Beta5 (bnc#438954).
- patches.fixes/dcb-fix-setpfcstate: Fix setpfcstate (bnc#438954).
- patches.fixes/dcb-setting-pg-will-cause-tx-hang: DCB: setting
  pg will cause tx unit hangs (bnc#438954).
- patches.fixes/multiq-requeue-should-rewind-current_band:
  multiq: requeue should rewind the current_band (bnc#438954).
- patches.fixes/scsi-dh-rdac-retry-mode-select: Retry mode select
  in RDAC device handler (bnc#441337).
- patches.fixes/scsi-dh-rdac-set-default-ownership: scsi_dh_rdac:
  make sure the ownership is set correctly (bnc#441337).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Update patch
  to check for ->bus instead of ->type (bnc#431294).
* Fri Nov  7 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-probe-fix: ALSA: hda -
  Fix probe errors on Dell Studio Desktop (bnc#440907).
- patches.drivers/alsa-hda-hp-3013-master-fix: ALSA: hda -
  Fix ALC260 hp3013 master switch (bnc#441068).
* Fri Nov  7 2008 jjolly@suse.de
- patches.arch/s390-03-07-qeth_hsi_mcl_string.patch:
  qeth: pre z9 systems return HiperSocket version string
  different. (bnc#440610,LTC#49052).
- patches.arch/s390-03-08-zfcp-abort-race.patch: zfcp: eliminate
  race between validation and locking. (bnc#440610).
- patches.arch/s390-03-09-zfcp-oops-during-target-scan.patch:
  zfcp: prevent SCSI target scan for vanished rport
  (bnc#440610,LTC#49373).
* Fri Nov  7 2008 olh@suse.de
- Update config files for RT
* Fri Nov  7 2008 olh@suse.de
- build a kernel-default in dist ppc64, its identical to kernel-ppc64
  otherwise unused
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-source.spec.in: map ppc/ppc64 to powerpc
* Fri Nov  7 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: VF enabled igb driver (fate#305004)
* Fri Nov  7 2008 olh@suse.de
- stop building kernel-default and kernel-ps3 in dist ppc64,
  they are openSuSE only packages
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: extracting debuginfo from vdso fails
  on powerpc, disable vdso_install for the time being
* Fri Nov  7 2008 jbeulich@novell.com
- patches.xen/xen3-intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
* Fri Nov  7 2008 olh@suse.de
- rpm/post.sh: reject legacy iSeries again
* Fri Nov  7 2008 olh@suse.de
- build a 32bit and a 64bit vanilla kernel on powerpc
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: no vdso in vanilla and ps3 kernel
* Fri Nov  7 2008 gregkh@suse.de
- patches.kernel.org/net-fix-recursive-descent-in-__scm_destroy.patch:
  net: Fix recursive descent in __scm_destroy()..
* Fri Nov  7 2008 olh@suse.de
- remove patches.arch/ppc64-rpanote-relocate-firmware.patch
  older firmware versions can handle relocation properly (bnc#427960)
* Fri Nov  7 2008 jjolly@suse.de
- patches.drivers/cxgb3-get_drvinfo-deadlock.patch: RDMA/cxgb3:
  deadlock in iw_cxgb3 can cause hang when configuring
  interface. (bnc#430998).
* Fri Nov  7 2008 gregkh@suse.de
- patches.suse/perfmon2.patch: perfmon2 (bnc#430298).
* Fri Nov  7 2008 nfbrown@suse.de
- patches.fixes/nfs-write.c-bug-removal.patch: Revert "NFS:
  Allow redirtying of a completed unstable write." (442267).
  It causes a BUG().
* Fri Nov  7 2008 nfbrown@suse.de
- patches.kernel.org/md-raid10-recovoery-fix.path: md: fix bug
  in raid10 recovery..
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped..:  Removed much of this patch as it turned out
  to be both buggy and unnecessary (the ioctl can be done from
  mdadm).
* Thu Nov  6 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: ixgbe driver update to add
  Longcove (SFP+) NIC support for FCoE needs (bnc#442411)
* Thu Nov  6 2008 gregkh@suse.de
- enable CONFIG_X86_SUMMIT, CONFIG_X86_ES7000, and CONFIG_X86_BIGSMP
  for the i386 default kernel, so that the installer can actually
  boot on "modern" multiprocessor i386 boxes (bnc#428247)
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install only on x86 and ppc.
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install to install the
  vdso shared objects for debugging.
* Thu Nov  6 2008 jjolly@suse.de
- patches.drivers/intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
- patches.drivers/intel-ibex-peak-device-support.patch: i2c-i801:
  Add support for Intel Ibex Peak (bnc#415383).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: Fixed patch for build
- patches.arch/s390-03-04-qdio_multicast_performance.patch: dasd:
  fix  message flood for unsolicited interrupts (bnc#440610).
- patches.arch/s390-03-05-dasd-block-uevent.patch: dasd: DASD
  uevents are not sent correctly (bnc#440610,LTC#49429).
- patches.arch/s390-03-06-zfcp-hexdump.patch: zfcp: fix hexdump
  data in s390dbf traces (bnc#440610).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: kernel: Fix
  initialization of stp. (bnc#440610,LTC#49639).
- patches.arch/s390-03-02-setup_memory.patch: kernel: Fix range
  for add_active_range() in setup_memory() (bnc#440610,LTC#49639).
- patches.arch/s390-03-03-dasd_unsolicited_interrupt.patch:
  dasd: fix  message flood for unsolicited interrupts
  (bnc#440610,LTC#49639).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-02-10-zfcp-scan-online.patch: wait for port
  scan when setting FCP device online (bnc#434333).
* Thu Nov  6 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.4 and c/s 718.
- Update Xen config files.
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch: Include
  pv-ops-Xen changes here
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: Delete.
- patches.xen/xen-configurable-guest-devices: allow number of
  guest devices to be configurable.
- patches.xen/xen-cpufreq-report: make /proc/cpuinfo track
  CPU speed.
- patches.xen/xen-ipi-per-cpu-irq: fold IPIs onto a single
  IRQ each.
- patches.xen/xen-rtl2860-build: Rename to ...
- patches.xen/xen-rt2860-build: ... this.
- patches.xen/xen-sysdev-suspend: use base kernel suspend/resume
  infrastructure.
- patches.xen/xen-virq-per-cpu-irq: fold per-CPU VIRQs onto a
  single IRQ each.
- patches.xen/xen-x86-mmu-batching: Delete.
- patches.xen/xen3-patch-2.6.27.3-4: Linux 2.6.27.4.
- patches.xen/xen3-x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.xen/xen3-x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.xen/xen3-x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
* Thu Nov  6 2008 sassmann@suse.de
- patches.arch/ppc-ps3-introduce-ps3_gpu_mutex.patch: required for
  new ps3vram patch
- patches.arch/ppc-ps3-ps3vram-mtd.patch: updated ps3vram patch
  that works with firmware 2.50 (bnc#442227)
* Thu Nov  6 2008 olh@suse.de
- remove unneeded BuildRequires for dtc
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: Feature removed
  (bnc#417299)
* Thu Nov  6 2008 gregkh@suse.de
- patches.suse/file-capabilities-add-no_file_caps-switch.patch:
  file capabilities: add no_file_caps switch (v4).
  add the patch back into the tree.
* Wed Nov  5 2008 jblunck@suse.de
- patches.suse/coredump_filter-add-elfhdr-default.patch: Dump
  elf headers to core per default.
* Wed Nov  5 2008 teheo@suse.de
  Fix !CONFIG_DMI case.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
* Wed Nov  5 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: update patch
  to skip all devices with no dma_parms (bnc#431294)
* Wed Nov  5 2008 agruen@suse.de
- rpm/kernel-module-subpackage: Remove the obsolete kernel-$flavor
  dependency (bnc#440961).
* Wed Nov  5 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Removed and replaced with
  v3 of the patch from IBM (bnc#417300)
- patches.arch/s390-01-05-kmsg-v3.patch: Kernel message catalog
  infrastucture and message generation (bnc#417300).
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Patch edited to allow new kmsg patch
* Wed Nov  5 2008 agruen@suse.de
- Update config files: set CONFIG_MODULE_FORCE_LOAD=y to allow
  ignoring ABI mismatches. (This is still unsafe to do!)
* Wed Nov  5 2008 tiwai@suse.de
  Backport fixes from 2.6.28-rc.
- patches.drivers/alsa-hda-acer-quirk: ALSA: hda - Add a quirk
  for another Acer Aspire (1025:0090) (bnc#426935).
- patches.drivers/alsa-hda-alc888-medion-add: ALSA: hda - Add
  a quirk for MEDION MD96630 (bnc#412548).
- patches.drivers/alsa-hda-dell-eq-option: ALSA: hda: make a
  STAC_DELL_EQ option.
- patches.drivers/alsa-hda-proc-gpio-fix: ALSA: hda - Limit the
  number of GPIOs show in proc.
* Wed Nov  5 2008 gregkh@suse.de
- refresh -rt patches to remove fuzz.
* Wed Nov  5 2008 teheo@suse.de
  Backport two more device specific workarounds from 2.6.28-rc.
- patches.drivers/libata-add-and-use-HORKAGE_ATAPI_MOD16_DMA:
  libata: implement ATA_HORKAGE_ATAPI_MOD16_DMA and apply it.
- patches.drivers/libata-whitelist-good-bridges: libata: add
  whitelist for devices with known good pata-sata bridges.
* Wed Nov  5 2008 gregkh@suse.de
- refresh patches to remove fuzz
* Wed Nov  5 2008 teheo@suse.de
  Backport double spin off workaround.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
- patches.drivers/libata-ahci-blacklist-double-spin-off: SATA
  AHCI: Blacklist system that spins off disks during ACPI power
  off (bnc#441721).
- patches.drivers/libata-ata_piix-blacklist-double-spin-off:
  SATA PIIX: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/libata-implement-NO_SPINDOWN: SATA: Blacklisting
  of systems that spin off disks during ACPI power off (rev. 2)
  (bnc#441721).
- patches.drivers/libata-sata_sil-blacklist-double-spin-off:
  SATA Sil: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/power-introduce-system_entering_hibernation:
  Hibernation: Introduce system_entering_hibernation (bnc#441721).
* Wed Nov  5 2008 gregkh@suse.de
- fix rt tree that was broken by 2.6.27.5-rc1
* Wed Nov  5 2008 olh@suse.de
- update patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix booting on ppc32 (bnc#439491 - LTC48584)
* Wed Nov  5 2008 teheo@suse.de
  Backport sata_via fixes from 2.6.28-rc.
- patches.drivers/libata-sata_via-fix-support-for-5287: sata_via:
  fix support for 5287 (bnc#441718).
- patches.drivers/libata-sata_via-load-DEVICE-register-when-CTL-changes:
  sata_via: load DEVICE register when CTL changes (bnc#441718).
- patches.drivers/libata-sata_via-restore-vt-_prepare_host-error-handling:
  sata_via: restore vt*_prepare_host error handling (bnc#441718).
* Wed Nov  5 2008 teheo@suse.de
  Backport laptop table and pci device ID table entries from 2.6.28-rc.
- patches.drivers/libata-ata_piix-add-Hercules-EC-900-mini-to-laptop-tbl:
  ata_piix: add Hercules EC-900 mini-notebook to ich_laptop
  short cable list.
- patches.drivers/libata-ata_piix-add-intel-ibex-pci-ids:
  ata_piix: IDE Mode SATA patch for Intel Ibex Peak DeviceIDs.
* Wed Nov  5 2008 teheo@suse.de
  Backport slave_link from 2.6.28-rc to fix ata_piix probing problem.
- patches.drivers/libata-ata_piix-use-slave_link: ata_piix:
  drop merged SCR access and use slave_link instead (bnc#441420).
- patches.drivers/libata-eh-fix-slave-link-EH-action-mask-handling:
  libata-eh: fix slave link EH action mask handling (bnc#441420).
- patches.drivers/libata-implement-slave_link: libata: implement
  slave_link (bnc#441420).
- patches.drivers/libata-make-SCR-access-ops-per-link: libata:
  make SCR access ops per-link (bnc#441420).
- patches.drivers/libata-misc-updates-to-prepare-for-slave-link:
  libata: misc updates to prepare for slave link (bnc#441420).
- patches.drivers/libata-reimplement-link-iterator: libata:
  reimplement link iterator (bnc#441420).
- patches.drivers/libata-set-device-class-to-NONE-if-phys_offline:
  libata: set device class to NONE if phys_offline (bnc#441420).
- patches.drivers/libata-transfer-EHI-control-flags-to-slave-ehc.i:
  libata: transfer EHI control flags to slave ehc.i (bnc#441420).
* Wed Nov  5 2008 gregkh@suse.de
- Update to 2.6.27.5-rc1:
  - fixes lots of things, including a few CVE entries
  - obsoletes, and caused to be deleted:
  - patches.arch/ppc-pseries_16g-numa.patch
  - patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  - patches.arch/ppc-pseries_mem-limit-16g.patch
  - patches.arch/s390-02-02-smp-sysdev.patch
  - patches.drivers/alsa-hda-reboot-notifier
  - patches.drivers/libata-sata_nv-hardreset-fix
  - patches.fixes/acpi-clear-wake-status.patch
  - patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch
  - patches.suse/file-capabilities-add-no_file_caps-switch.diff
  - patches.suse/file-capabilities-turn-on-by-default.diff
- Update config files.
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/bnx2-Add-bnx2_shutdown_chip: bnx2: Add
  bnx2_shutdown_chip()
- patches.drivers/bnx2-check-running.patch: Check netif_running
  in most ethtool operations    (bnc#440052)
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/ixgbe-copper_pond.patch: ixgbe: add device
  support for 82598AT (copper 10GbE) adapters (bnc#441471)
* Tue Nov  4 2008 tonyj@suse.de
- patches.rt/fork_init_nrcpus.patch: Fix oops in fork_init.
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix typo
* Tue Nov  4 2008 rw@suse.de
- patches.drivers/bnx2x-zero-PMF:
  bnx2x: Removing the PMF indication when unloading.  (bnc#439679)
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: make also -base and -extra x86
  subpackages not installable on x86_64
* Tue Nov  4 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-3-v2.patch: (kernel):FCP -
  Performance Data colletion & analysis patch update (bnc#417243).
- patches.arch/s390-01-04-fcpperf-3.patch: Removed for update
* Tue Nov  4 2008 miklos@szeredi.hu
- patches.apparmor/d_namespace_path_oops_fix.diff: fix oops in
  d_namespace_path (bnc#433504).
* Tue Nov  4 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: scsi_lib_dma.c :
  fix bug w/ dma on virtual fc ports (bnc#431294).
* Tue Nov  4 2008 sdietrich@suse.de
- Update RT config files: Enable CONFIG_NO_HZ on i386/rt_debug.
  - Refresh config files.
* Tue Nov  4 2008 teheo@suse.de
- patches.drivers/libata-fix-last_reset-timestamp-handling:
  libata: fix last_reset timestamp handling (bnc#441340).
* Tue Nov  4 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01-k9-update: Update qla2xxx to
  8.02.01-k9 (bnc#439208).
* Tue Nov  4 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Compile fix.
* Mon Nov  3 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy-fixes: ALSA: emu10k1 -
  Add more invert_shared_spdif flag to Audigy models (bnc#440862).
- patches.drivers/alsa-hda-alc269-fsc-amilo: ALSA: hda - Add
  ALC269 fujitsu model (bnc#440626).
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Update dmraid45.
* Mon Nov  3 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Fix dm table
  ref count (FATE#304489).
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach (bnc#440980).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach.
* Mon Nov  3 2008 olh@suse.de
- add patches.arch/ppc-clock_gettime-nanoseconds.patch
  update also nanoseconds (bnc#439908 - LTC49499)
* Mon Nov  3 2008 teheo@suse.de
- scripts/vc: s/GIT_COMMITER_EMAIL/GIT_COMMITTER_EMAIL and add
  SUSE_COMMITTER_EMAIL.
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression (bnc#429344).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files: enable more lock debugging,
  latency features, make x86_64 and i386 consistent.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/kprobes_make_pointer_decl_consistent.patch: Make
  kprobe locking consistent with lock-type declarations
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
  Use raw_smp_processor_id in __mem_cgroup_stat_add_safe.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/workqueue-introduce-create_rt_workqueue.patch:
  workqueue: introduce create_rt_workqueue. (from 2.6.28)
  Refresh to eliminate fuzz:
  - patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files:
  - Sync with SLES 11 default/debug configs
  - Limit CPUS to 32
  - Disable CONFIG_RADIX_TREE_CONCURRENT
  - Disable CONFIG_RADIX_TREE_OPTIMISTIC
  - Disable CONFIG_PREEMPT_RCU_BOOST
  - Enable CONFIG_RTMUTEX_CHECK
- Adapt RT patches to changes made by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/mitigate-resched-flood-update.patch: Update
    smp_send_reschedule_allbutself_cpumask mask parameter.
  - patches.rt/x86-nmi-send_IPI_mask-pointer-fix.patch: Update
    smp_send_nmi_allbutself  mask parameter.
  Resolve conflicts introduced by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/nmi-profiling-base.patch
  - patches.rt/send-nmi-all-preempt-disable.patch
  Refresh to eliminate fuzz
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 bwalle@suse.de
- patches.fixes/kdb-fix-stack-overflow.patch:
  kdb: fix stack overflow for large NR_CPUS count (bnc#440361).
* Fri Oct 31 2008 trenn@suse.de
  Fate 304268 and 304266. SGI scir driver (replaces the more intrusive
  leds one) and the rather intrusive x86_64 4096 CPU support patches:
- Update config files.
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
- patches.arch/x86_sgi-uv-scir.patch: SGI X86 UV: Provide a
  System Activity Indicator driver (FATE304268 bnc#426066).
- patches.arch/x86_sgi_cpus4096-01-fix-smp_call_function.patch:
  smp: reduce stack requirements for smp_call_function_mask
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
- patches.arch/x86_sgi_cpus4096-06-optimize-cpumask-in-sched_c.patch:
  Additional cpumask fixups (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-04-add-for_each_cpu_mask_and.patch:
  Add for_each_cpu_mask_and (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-07_pae_compile_fixups.patch:
  more cpumask cleanups for previous (x86_sgi_cpu4096..) patches
  (Additional cpumask fixups).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc8-x86-1 (FATE#303971).
- patches.xen/xen3-patch-2.6.27: Linux: Update to 2.6.27.
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: x86 cpumask xen:
  Updates to support NR_CPUS=4096 (Additional cpumask fixups).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-alc269-dmic: ALSA: hda -
  Add digital-mic for ALC269 auto-probe mode (bnc#440626).
- patches.drivers/alsa-hda-realtek-mic-automute-fix: ALSA: hda -
  Disable broken mic auto-muting in Realtek codes (bnc#440626).
* Fri Oct 31 2008 hare@suse.de
- Update config files.
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3-private-iscsi-ip-addresses: cxgb3 -
  manage private iSCSI IP addresses (FATE#304154,bnc#433500).
- patches.drivers/open-iscsi-offloading-support: support for iscsi
  pdu digest offload and payload DDP. (FATE#304154,bnc#433500).
- patches.fixes/cxgb3-remove-duplicate-tests-in-lro: cxgb3 -
  remove duplicate tests in lro (FATE#304154, bnc#430538).
- supported.conf: Mark cxgb3i as supported.
* Fri Oct 31 2008 bwalle@suse.de
- patches.suse/kdb-resolve-uv-conflict.diff:
  Resolve KDB conflicts with UV (bnc#440376).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-spdif-fix: ALSA: hda -
  Fix SPDIF mute on IDT/STAC codecs.
- patches.drivers/alsa-hda-reboot-notifier: ALSA: hda - Add
  reboot notifier.
* Fri Oct 31 2008 jack@suse.cz
- patches.suse/ocfs2-Fix-mount-cleanup-after-quota-failure.patch:
  ocfs2: Fix mount cleanup after quota failure (fate#302681).
- patches.suse/ocfs2-Fix-oop-in-recovery-without-quotas:
  ocfs2: Fix recovery of nodes when quota feature is disabled
  (fate#302681).
- patches.suse/ocfs2-Fix-grace-time-syncing.patch: ocfs2: Fix
  grace time syncing (fate#302681).
* Fri Oct 31 2008 teheo@suse.de
- patches.drivers/block-del-timer-after-dequeue: blk: move
  blk_delete_timer call in end_that_request_last (bnc#440076
  bnc#440173).
* Fri Oct 31 2008 trenn@suse.de
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Avoid oops
  on G33 in 1MB stolen Mem case (bnc#391261).
* Thu Oct 30 2008 gregkh@suse.de
- patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch:
  agp: Fix stolen memory counting on G4X. (bnc#437618).
* Thu Oct 30 2008 oneukum@suse.de
- patches.fixes/sd_liberal_28_sense_invalid.diff: fix medium
  presence misdetection in usb storage device  (bnc#362850).
* Thu Oct 30 2008 olh@suse.de
- add patches.fixes/scsi-ibmvscsi-show-config.patch
  use 4k buffer to transfer config data (439970 - LTC49349)
* Thu Oct 30 2008 teheo@suse.de
- patches.drivers/block-add-timeout-on-dequeue: block: add timer
  on blkdev_dequeue_request() not elv_next_request() (bnc#440076).
* Wed Oct 29 2008 sdietrich@suse.de
  Refresh RT patches:
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT (debug
  builds).
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/partreadd-lttng-instrumentation-irq.patch: readd
  RT compatible version of lttng-instrumentation-irq.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/start_irq_thread.patch: Linux-RT 2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
* Wed Oct 29 2008 gregkh@suse.de
- s/rtl2860/rt2860/
- remove driver from the Xen build as it's dying for some reason.
- add obsoletes for ralink-rt2860-kmp
* Wed Oct 29 2008 olh@suse.de
- update patches.arch/ppc-oprofile-spu.patch
  add missing ARRAY_SIZE(pm_signal_local)
* Wed Oct 29 2008 hare@suse.de
- patches.arch/s390-symmetrix-ioctl.patch: Add ioctl support
  for EMC Symmetrix Subsystem Control I/O (bnc#439221)
* Wed Oct 29 2008 jbeulich@suse.de
- patches.xen/xen-rtl2860-build: fix issue with Windows-style
  types used in rtl2680.
* Wed Oct 29 2008 olh@suse.de
- build af_packet as a module on powerpc (bnc#433540)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu-mutex-locking.patch
  Fix mutex locking for cell spu-oprofile (bnc#422501 - LTC47617)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu.patch
  fix local array size in activate spu profiling function (bnc#439553 - LTC48925)
* Wed Oct 29 2008 olh@suse.de
- update patches.drivers/ehea.patch
  Add hugepage detection (bnc#439599 - LTC48958)
* Wed Oct 29 2008 gregkh@suse.de
- patches.drivers/staging-add-agnx-wireless-driver.patch: Staging:
  add agnx wireless driver.
- patches.drivers/staging-add-otus-atheros-wireless-network-driver.patch:
  Staging: add otus Atheros wireless network driver.
- patches.drivers/staging-add-rtl2860-wireless-driver.patch:
  Staging: add rtl2860 wireless driver (bnc#437959).
- Update config files.
* Tue Oct 28 2008 jkosina@suse.de
- patches.suse/silent-stack-overflow-2.patch: disabled, as it
  causes kernel hangs triggered by grub (bnc#439448).
* Tue Oct 28 2008 kkeil@suse.de
- update patches.suse/SoN-17-net-ps_rx.patch
  fix i/o corruption on rx in ixgbe (bnc#438929)
* Tue Oct 28 2008 jdelvare@suse.de
- config/powerpc/*: Fixup configuration files after last change.
* Tue Oct 28 2008 jdelvare@suse.de
- config/*: Include many multimedia drivers which has been dropped
  accidentally. This includes the pwc, ivtv, zr36067 drivers and
  many old webcam drivers (bnc#439489).
- supported.conf: Add all these drivers again.
* Tue Oct 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-analog-update,
  patches.drivers/alsa-hda-atihdmi-update,
  patches.drivers/alsa-hda-beep,
  patches.drivers/alsa-hda-hp-mobile-fix,
  patches.drivers/alsa-hda-nvidia-hdmi,
  patches.drivers/alsa-hda-probe-fix,
  patches.drivers/alsa-hda-proc-fix,
  patches.drivers/alsa-hda-realtek-update,
  patches.drivers/alsa-hda-sigmatel-update,
  patches.drivers/alsa-hda-spdif-slave,
  patches.drivers/alsa-hda-via-rec-fix,
  patches.drivers/alsa-hda-via-update:
    ALSA updates, mostly taken from 2.6.28-rc1 patches
- Update config files.
* Tue Oct 28 2008 jdelvare@suse.de
- Actually CONFIG_SND_HDA_HWDEP is a boolean, sorry.
* Tue Oct 28 2008 jdelvare@suse.de
- config/ia64/vanilla, config/x86_64/vanilla: fix configuration
  discrepancy, CONFIG_SND_HDA_HWDEP=m.
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-pcibios_allocate_bus_resources.patch
  add patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix DLPAR on pseries (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-powerpc-fix-pci-unmap-io.patch
  Fix unmapping of IO space on 64-bit (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- update ps3 config, remove unneeded options to reduce vmlinux size
* Tue Oct 28 2008 neilb@suse.de
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped. (fate#303894).
* Tue Oct 28 2008 gregkh@suse.de
- use the panasonic laptop driver that was accepted by upstream, not the
  pcc-acpi driver, which was rejected:
  - patches.drivers/staging-add-pcc-acpi-driver.patch: Delete.
  - patches.drivers/panasonic-laptop-add-panasonic-let-s-note-laptop-extras-driver-v0.94.patch:
    panasonic-laptop: add Panasonic Let's Note laptop extras
    driver v0.94.
- Update config files.
* Tue Oct 28 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Via Framebuffer
  driver.
- Update config files.
* Mon Oct 27 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff:
  Don't change permission of sysfs file (did that accidentally
  when changing the default value).
* Mon Oct 27 2008 trenn@suse.de
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
* Mon Oct 27 2008 tj@suse.de
  Refresh the govault patch.
- patches.drivers/libata-add-waits-for-govault: libata: add
  waits for GoVault (bnc#246451).
* Sun Oct 26 2008 bwalle@suse.de
- patches.fixes/kdb-oops-panic.diff:
  Fix NULL pointer dereference when regs == NULL (bnc#439007).
- patches.fixes/hpwdt-kdump.diff:
  Fix kdump when using hpwdt (bnc#436786).
* Sun Oct 26 2008 gregkh@suse.de
- refresh patches to apply cleanly and properly.
* Sun Oct 26 2008 gregkh@suse.de
- Update to 2.6.27.4
* Sat Oct 25 2008 agruen@suse.de
- Fix the dependencies between the split kernel packages and KMPs
  (FATE 303631).
- Fix for kernel paclages which are not split.
- rpm/kernel-source.spec.in: Update list of scripts to include.
* Sat Oct 25 2008 jjolly@suse.de
- patches.arch/s390-02-02-smp-sysdev.patch: kernel: sysdev class
  file creation (bnc#434333)
- patches.arch/s390-02-03-zfcp.patch: Fix zfcp problems that have
  been found (bnc#434333)
- patches.arch/s390-02-04-qeth-mac.patch: qeth: use firmware
  MAC-address for layer2 hsi-devices (bnc#434333)
- patches.arch/s390-02-05-qeth-recovery.patch: qeth: qeth recovery
  fails (bnc#434333)
- patches.arch/s390-02-06-qeth-offset.patch: qeth: fix offset error
  in non prealloc header path (bnc#434333,LTC#48840)
- patches.arch/s390-02-07-qeth-ipv6check.patch: qeth: remove
  unnecessary support ckeck in sysfs route6 (bnc#434333)
- patches.arch/s390-02-08-qeth-panic.patch: qeth: avoid
  skb_under_panic for malformatted inbound data (bnc#434333)
- patches.arch/s390-02-09-tape-lock.patch: tape device driver:
  improve locking (bnc#434333)
* Sat Oct 25 2008 neilb@suse.de
- patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
  touch_mnt_namespace when the mount flags change (FATE#304218).
* Fri Oct 24 2008 gregkh@suse.de
- Updated to 2.6.27.4-rc3:
  - fixed ath5k suspend/resume regression
  - fixed pvrusb2 so it actually works
* Fri Oct 24 2008 jack@suse.cz
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681). - fixed 64-bit division
* Fri Oct 24 2008 jeffm@suse.de
- Update config files for -rt.
* Fri Oct 24 2008 hare@suse.de
- patches.suse/cgroup-freezer.patch: Add TIF_FREEZE for s390.
* Fri Oct 24 2008 olh@suse.de
- move patches.suse/md-raid-metadata-PAGE_SIZE.patch
  to patches.kernel.org/md-raid-metadata-PAGE_SIZE.patch
  to allow raid0 with 64k PAGE_SIZE
* Fri Oct 24 2008 jack@suse.cz
- Update config files.
- supported.conf: Added new quota module
- patches.suse/xfs-dmapi-enable: Enable XFS DMAPI. - Refreshed
  Quotas for OCFS2:
- patches.suse/quota-Add-callbacks-for-allocating-and-destroying-d.patch:
  quota: Add callbacks for allocating and destroying dquot
  structures (fate#302681).
- patches.suse/quota-Increase-size-of-variables-for-limits-and-ino.patch:
  quota: Increase size of variables for limits and inode usage
  (fate#302681).
- patches.suse/quota-Remove-bogus-optimization-in-check_idq-an.patch:
  quota: Remove bogus 'optimization' in check_idq() and
  check_bdq() (fate#302681).
- patches.suse/quota-Make-_SUSPENDED-just-a-flag.patch: quota:
  Make _SUSPENDED just a flag (fate#302681).
- patches.suse/quota-Allow-to-separately-enable-quota-accounting-a.patch:
  quota: Allow to separately enable quota accounting and enforcing
  limits (fate#302681).
- patches.suse/ext3-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext3: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/ext4-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext4: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/reiserfs-Use-sb_any_quota_loaded-instead-of-sb_an.patch:
  reiserfs: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled(). (fate#302681).
- patches.suse/quota-Remove-compatibility-function-sb_any_quota_en.patch:
  quota: Remove compatibility function sb_any_quota_enabled()
  (fate#302681).
- patches.suse/quota-Introduce-DQUOT_QUOTA_SYS_FILE-flag.patch:
  quota: Introduce DQUOT_QUOTA_SYS_FILE flag (fate#302681).
- patches.suse/quota-Move-quotaio_v-12-.h-from-include-linux-to-f.patch:
  quota: Move quotaio_v[12].h from include/linux/ to fs/
  (fate#302681).
- patches.suse/quota-Split-off-quota-tree-handling-into-a-separate.patch:
  quota: Split off quota tree handling into a separate file
  (fate#302681).
- patches.suse/quota-Convert-union-in-mem_dqinfo-to-a-pointer.patch:
  quota: Convert union in mem_dqinfo to a pointer (fate#302681).
- patches.suse/quota-Allow-negative-usage-of-space-and-inodes.patch:
  quota: Allow negative usage of space and inodes (fate#302681).
- patches.suse/quota-Keep-which-entries-were-set-by-SETQUOTA-quota.patch:
  quota: Keep which entries were set by SETQUOTA quotactl
  (fate#302681).
- patches.suse/quota-Add-helpers-to-allow-ocfs2-specific-quota-ini.patch:
  quota: Add helpers to allow ocfs2 specific quota initialization,
  freeing and recovery (fate#302681).
- patches.suse/quota-Implement-function-for-scanning-active-dquots.patch:
  quota: Implement function for scanning active dquots
  (fate#302681).
- patches.suse/ocfs2-Fix-check-of-return-value-of-ocfs2_start_tran.patch:
  ocfs2: Fix check of return value of ocfs2_start_trans()
  (fate#302681).
- patches.suse/ocfs2-Support-nested-transactions.patch: ocfs2:
  Support nested transactions (fate#302681).
- patches.suse/ocfs2-Fix-checking-of-return-value-of-new_inode.patch:
  ocfs2: Fix checking of return value of new_inode()
  (fate#302681).
- patches.suse/ocfs2-Let-inode-be-really-deleted-when-ocfs2_mknod_.patch:
  ocfs2: Let inode be really deleted when ocfs2_mknod_locked()
  fails (fate#302681).
- patches.suse/ocfs2-Assign-feature-bits-and-system-inodes-to-quot.patch:
  ocfs2: Assign feature bits and system inodes to quota feature
  and quota files (fate#302681).
- patches.suse/ocfs2-Mark-system-files-as-not-subject-to-quota-acc.patch:
  ocfs2: Mark system files as not subject to quota accounting
  (fate#302681).
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681).
- patches.suse/ocfs2-Add-quota-calls-for-allocation-and-freeing-of.patch:
  ocfs2: Add quota calls for allocation and freeing of inodes
  and space (fate#302681).
- patches.suse/ocfs2-Enable-quota-accounting-on-mount-disable-on.patch:
  ocfs2: Enable quota accounting on mount, disable on umount
  (fate#302681).
- patches.suse/ocfs2-Implement-quota-syncing-thread.patch: ocfs2:
  Implement quota syncing thread (fate#302681).
- patches.suse/ocfs2-Implement-quota-recovery.patch: ocfs2:
  Implement quota recovery (fate#302681).
* Fri Oct 24 2008 kkeil@suse.de
- patches.fixes/cxgb3_fix_race_in_EEH: cxgb3: fix race in EEH.
  (bnc#430093)
* Fri Oct 24 2008 jeffm@suse.de
- Refreshed context for -RT patches so they apply again.
* Fri Oct 24 2008 rw@suse.de
- patches.drivers/sgi-ioc4-request-submodules:
  Make ioc4 request dependant modules.  (bnc#429215)
* Fri Oct 24 2008 hare@suse.de
- Update config files: Disable FAIL_MAKE_REQUEST.
* Fri Oct 24 2008 tiwai@suse.de
- patches.drivers/alsa-usb-exclude-1st-slot: Delete this old ugly
  workaround patch.
* Fri Oct 24 2008 hare@suse.de
- Include patches from upstream:
  - patches.fixes/block-use-bio_has_data: Implement bio_has_data().
  - patches.fixes/block-git-fixes: Block layer fixes for 2.6.28.
  - patches.fixes/block-rq-affinity: Implement rq affinity.
  - patches.fixes/dm-mpath-remove-is_active: dm mpath: remove
    is_active from struct dm_path.
  - patches.fixes/block-discard-requests: Implement block discard.
  - patches.drivers/dm-abort-queue-on-failed-paths: dm: Call
    blk_abort_queue on failed paths (bnc#417544).
  - patches.drivers/block-call-sync-on-cleanup: block:
    blk_cleanup_queue() should call blk_sync_queue().
- Refaktor and update request-based multipath patches:
  - patches.drivers/blk-request-based-multipath-update:
    Update request-based multipathing patches to upstream version
    (bnc#434105).
  - patches.suse/rq-based-multipath: Update to latest version
    of request-based multipathing patchset (bnc#434105)
  - patches.drivers/block-abort-request-rq-complete-marking:
    use rq complete marking in blk_abort_request (bnc#434105).
  - patches.fixes/scsi-atomic-blk-timer-deletes: Delete.
  - patches.fixes/dm-mpath-abort-queue: Delete.
  - patches.suse/rq-based-block-layer: Delete.
  - patches.suse/rq-based-dm-interface: Delete.
  - patches.suse/rq-based-multipath-functions: Delete.
  - patches.suse/rq-based-init-crash: Delete.
- Update patches to upstream version:
  - patches.drivers/bdev-resize-check-for-device-resize
  - patches.drivers/bdev-resize-added-flush_disk
  - patches.drivers/bdev-resize-call-flush_disk
  - patches.drivers/bdev-resize-sd-driver-calls
  - patches.drivers/block-timeout-handling
  - patches.drivers/bdev-resize-adjust-block-device-size
  - patches.drivers/bdev-resize-wrapper-for-revalidate_disk
  - patches.drivers/block-abort-queue
  - patches.fixes/scsi-enhance-error-codes
- Rediff patches:
  - patches.fixes/scsi-misc-git-update
  - patches.suse/dm-barrier-single-device
  - patches.suse/kdb-common
  - patches.drivers/lpfc-8.2.8-update
  - patches.drivers/lpfc-8.2.8.3-update
  - patches.drivers/mpt-fusion-4.00.43.00-update
* Fri Oct 24 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch: Add sysctl also
  to kernel/sysctl_check.c.
* Fri Oct 24 2008 bwalle@suse.de
- Obsolete uvcvideo-kmp.
* Fri Oct 24 2008 jbeulich@suse.de
- rpm/kernel-binary.spec.in: Provide 'kernel' also for Xen (bnc#362918).
* Fri Oct 24 2008 jbeulich@suse.de
- patches.arch/x86_64-unwind-annotations: fix unwind annotations.
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind
  annotations.
* Fri Oct 24 2008 jbeulich@suse.de
- Update Xen patches to 2.6.27.3 and c/s 704
- patches.xen/xen3-x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.xen/xen3-x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.xen/xen-kconfig-compat-3.2.0: add 3.2.0-compatibility
  configure option.
- patches.xen/xen-x86-exit-mmap: be more aggressive about
  de-activating mm-s under destruction.
- patches.xen/xen-x86-machphys-prediction: properly predict
  phys<->mach translations.
- patches.xen/xen-x86-mmu-batching: utilize
  arch_{enter,leave}_lazy_cpu_mode().
- patches.xen/xen-x86-no-lazy-tlb: ensure inadvertent uses of
  lazy TLB data are caught during the build.
- Update Xen config files.
* Fri Oct 24 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - do not split kernel-kdump into -base and -extra
  - fix case when a build results in no unsupported modules
* Fri Oct 24 2008 bwalle@suse.de
- patches.fixes/kdb-kdump.diff:
  Fix CONFIG_KDB_KDUMP on xSeries (bnc#436454).
* Fri Oct 24 2008 agruen@suse.de
- supported.conf: Mark dmapi as supported (by SGI).
* Fri Oct 24 2008 olh@suse.de
- disable all unsupported drivers in kernel-kdump
* Fri Oct 24 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap (bnc#44807 bnc#211997).
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc2
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_SYSFS_DEPRECATED_V2 from powerpc/rt config file
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc1
  - lots of bugfixes, and obsoletes some current patches:
  - patches.fixes/ext3-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/ext2-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/wdm_autoload.diff: Delete.
* Fri Oct 24 2008 npiggin@suse.de
- Fix ppc and ps3 configs
* Fri Oct 24 2008 npiggin@suse.de
- Update config files.
- patches.suse/cgroup-freezer.patch: cgroup freezer (bnc#417294,
  fate#304191, fate#201036).
* Fri Oct 24 2008 npiggin@suse.de
- Update config files. Enable cgroups for all archs (bnc#417527)
* Fri Oct 24 2008 npiggin@suse.de
- patches.arch/ppc-gigantic-page-fix2.patch: powerpc gigantic
  pages fix 2 (bnc#434026).
- patches.arch/ppc-gigantic-page-fix3.patch: powerpc gigantic
  pages fix 3 (bnc#434026).
- patches.trace/lttng-instrumentation-hugetlb.patch: de-fuzz
* Fri Oct 24 2008 gregkh@suse.de
- disabled CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64
  vanilla kernel.
* Fri Oct 24 2008 gregkh@suse.de
- patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  cciss: fix procfs firmware regression (bnc435644).
- patches.drivers/cciss-fix-sysfs-symlink.patch: cciss: fix
  sysfs symlink (bnc435644).
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64.  To use
  Calgary iommu systems, you now must manually pass "iommu=calgary" to
  get this hardware support back enabled.  This is the recommended
  proceedure right now, from IBM, otherwise the hardware crashes.
  bnc#436450.
* Fri Oct 24 2008 gregkh@suse.de
- clean up all fuzz in patches to get them to apply cleanly.
* Fri Oct 24 2008 gregkh@suse.de
- delete patches.arch/s390-01-03-cmm2-v2.patch as it touched core
  kernel code and was rejected from upstream.
  - patches.arch/s390-01-03-cmm2-v2.patch: Delete.
  - patches.arch/s390-01-03-cmm2-v2a.patch: Delete.
* Fri Oct 24 2008 gregkh@suse.de
- Update to version 3.4 of squashfs:
  - patches.suse/squashfs3.3-patch: Delete.
  - patches.suse/squashfs-patch-2.6.25: Delete.
  - patches.suse/squashfs-patch-2.6.27: Delete.
  - patches.suse/squashfs-3.4.patch: squashfs v3.4.
* Thu Oct 23 2008 jeffm@suse.de
- patches.fixes/block-sanitize-invalid-partition-table-entries:
  block: sanitize invalid partition table entries (bnc#371657).
* Thu Oct 23 2008 olh@suse.de
- add patches.arch/ppc-pseries_mem-limit-16g.patch
  Don't use a 16G page if beyond mem= limits (bnc#438111 - LTC49329)
* Thu Oct 23 2008 kkeil@suse.de
- Update x86 64bit config files to include WAN support (bnc#437692)
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/cell_edac.patch
  Fix incorrect edac_mode in csrow causing oops (bnc#437757 - LTC49143)
* Thu Oct 23 2008 olh@suse.de
- update patches.suse/nameif-track-rename.patch
  print also application and pid
* Thu Oct 23 2008 jkosina@suse.de
- patches.fixes/hid-rdesc-quirk-for-sony-vaio-VGX-TP1E.patch:
  HID: Fix Sony Vaio VGX report descriptor (bnc#437758).
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch
  reject dynamic memory add/remove (bnc#434651 - LTC48744)
* Thu Oct 23 2008 npiggin@suse.de
- Update config files.
* Thu Oct 23 2008 npiggin@suse.de
- patches.suse/x86-gb-linear-map.patch: Enable GB mapped linear
  KVA on x86 (bnc#437674).
- patches.xen/xen3-patch-2.6.26: merge
* Thu Oct 23 2008 gregkh@suse.de
- update to 2.6.27.3
  - lots of bugfixes
  - CVE-2008-3831 fix
* Wed Oct 22 2008 jeffm@suse.de
- scripts/vc: Handle unset $EDITOR
* Wed Oct 22 2008 jeffm@suse.de
- patches.suse/export-release_open_intent: Export
  release_open_intent for NFS branches with aufs.
* Wed Oct 22 2008 jdelvare@suse.de
- supported.conf: Mark the ibmaem and ibmpex hwmon drivers as
  supported by IBM.
- supported.conf: Mark the i5k_amb hwmon driver as supported.
* Wed Oct 22 2008 olh@suse.de
- add patches.drivers/ehea.patch
  Fix memory hotplug support (436447 - LTC48713)
* Wed Oct 22 2008 olh@suse.de
- add patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  Cleanup hugepage pagetable allocation (bnc# 433503 - LTC48757)
* Wed Oct 22 2008 sassmann@suse.de
  Add PS3 audio patches:
- patches.arch/ppc-ps3-add-passthrough-support-for-non-audio-streams.patch:
  ps3: Add passthrough support for non-audio streams.
- patches.arch/ppc-ps3-add-ps3av-audio-mute-analog.patch:
  ps3: Add ps3av_audio_mute_analog().
- patches.arch/ppc-ps3-add-support-for-SPDIF-HDMI-passthrough.patch:
  ps3: Add support for SPDIF/HDMI passthrough.
* Tue Oct 21 2008 sdietrich@suse.de
- patches.rt/genirq-usb.patch: Make status_cache u32
- patches.rt/genirq-ohci1394.patch: Enable ohci1394 IRQ
  threading.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: rediff.
- patches.fixes/scsi-atomic-blk-timer-deletes: scsi: atomic blk
  timer deletes (LTC#48990, bnc#434105).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  rediff.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/scsi-inquiry-too-short-ratelimit: INQUIRY result
  too short (5) message flood (bnc#432535).
* Tue Oct 21 2008 npiggin@suse.de
- patches.suse/filp-slab-rcu: Delete.
* Tue Oct 21 2008 sdietrich@suse.de
  USB IRQ threading (experimental: guarded by genirq):
- patches.rt/genirq1-make-irqreturn_t-an-enum: genirq: make
  irqreturn_t an enum.
- patches.rt/genirq2-add-quick-check-handler.patch: genirq:
  add a quick check handler.
- patches.rt/genirq3-add-threaded-irq-handler-support: genirq:
  add threaded interrupt handler support.
- patches.rt/genirq4-add-helper-to-check-whether-irq-thread-should-run:
  genirq: add a helper to check whether the irqthread should run.
- patches.rt/genirq5-make-irq-threading-robust: genirq: make
  irq threading robust.
- patches.rt/genirq-usb.patch: genirq threading for ehci, ohci
  and uhci USB hosts..
- patches.rt/genirq-wlan-ng-compat.patch: Remove redundant,
  obsolete 2.4 compatibility code in wlan-ng.
  Ack:
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
* Mon Oct 20 2008 gregkh@suse.de
- patches.arch/x2APIC_PATCH_x86-mach_apicdef.h-need-to-include-before-smp.h.patch:
  x86: mach_apicdef.h need to include before smp.h.
  fixes build error on i386 pae kernels.
* Mon Oct 20 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch:
  Add dump_after_notifier sysctl (bnc#436678).
* Mon Oct 20 2008 gregkh@suse.de
- scripts/wd-functions.sh: reverse git and cvs checks (check for
  cvs before git).  This solves the problem if you are using a cvs
  tree, yet it happens to live in a directory that way up the
  directory chain is in a git tree (like for people who keep portions
  of their $HOME in git).
* Mon Oct 20 2008 gregkh@suse.de
- Update config files: enable CONFIG_GENERICARCH and CONFIG_BIGSMP
  on i386-pae kernels. (bnc#428247)
* Mon Oct 20 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: fix the order of arguments in
  /proc/$pid/syscall on x86_64.
* Mon Oct 20 2008 bwalle@suse.de
- Update config files: Enable CONFIG_KVM_KMP for RT config, run
  oldconfig.
* Mon Oct 20 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff: Correct to reflect mainline
  state.
* Mon Oct 20 2008 hare@suse.de
- Update config files.
- patches.suse/kvm-as-kmp: Allow KVM to be built as KMP
  (FATE#303679).
* Mon Oct 20 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Instrument the kernel
  components such that a kernel message catalog as well as related
  man pages can be automatically generated. (bnc#417300)
- patches.arch/s390-01-06-zfcp-cleanup-v2.patch: Update patch to
  fit on recent kmsg patch changes. (bnc#417550)
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Update patch to fit on recent kmsg patch changes.
- config/s390/{default,s390}: Added CONFIG_KMSG_IDS=y
* Mon Oct 20 2008 bwalle@suse.de
- supported.conf: Mark 'crasher' as supported to avoid installing
  the "extra" package only for that module.
* Mon Oct 20 2008 olh@suse.de
- add patches.arch/ppc-pseries_16g-numa.patch
  fix crash with more 2 numa nodes and 16G hugepage (bnc#436452 - LTC48839)
* Sat Oct 18 2008 gregkh@suse.de
- Update to 2.6.27.2.
  - lots of bugfixes
* Sat Oct 18 2008 tonyj@suse.de
- patches.rt/fix-preempt-none.patch: Fix preempt-none build
  errors
* Fri Oct 17 2008 jeffm@suse.de
- patches.suse/SoN-20-netvm-reserve-inet.patch-fix: SoN: Fix
  initialization of ipv4_route_lock (bnc#435994).
* Fri Oct 17 2008 kkeil@suse.de
- patches.drivers/tg3-Add-57780-ASIC-revision.patch: tg3: Add
  57780 ASIC revision. (bnc#434147)
- patches.drivers/broadcom-Add-support-for-the-57780-integrated-PHY.patch:
  broadcom: Add support for the 57780 integrated PHY. (bnc#434147)
- patches.drivers/bnx2x-eeh.patch: bnx2x: EEH recovery fix.(bnc#433875)
* Fri Oct 17 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: Add the auto-generated (by mkdumprd)
  kdump initrd to %%ghost so that the file gets removed when
  uninstalling the kernel.
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 ACL / security attribute support
  - patches.suse/ocfs2-Remove-unused-function-restore_extent_block.patch
  - patches.suse/ocfs2-Merge-transactions-during-xattr-set.patch
  - patches.suse/ocfs2-xattr.-ch-definition-cleanups.patch
  - patches.suse/ocfs2-Add-security-xattr-support-in-ocfs2.patch
  - patches.suse/ocfs2-Add-POSIX-ACL-support-in-ocfs2.patch
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 fixes / updates from 2.6.28 merge window
  - patches.suse/ocfs2-xattr.c-Fix-a-bug-when-inserting-xattr.patch
  - patches.suse/ocfs2-Add-empty-bucket-support-in-xattr.patch
  - patches.suse/ocfs2-Remove-pointless.patch
  - patches.suse/ocfs2-make-la_debug_mutex-static.patch
  - patches.suse/ocfs2-Documentation-update-for-user_xattr-nouser_.patch
  - patches.suse/ocfs2-use-smaller-counters-in-ocfs2_remove_xattr_cl.patch
  - patches.suse/ocfs2-Don-t-check-for-NULL-before-brelse.patch
  - patches.suse/ocfs2-Uninline-ocfs2_xattr_name_hash.patch
  - patches.suse/ocfs2-Move-trusted-and-user-attribute-support-into.patch
  - patches.suse/ocfs2-Calculate-EA-hash-only-by-its-suffix.patch
  - patches.suse/ocfs2-Refactor-xattr-list-and-remove-ocfs2_xattr_ha.patch
  - patches.suse/ocfs2-Separate-out-sync-reads-from-ocfs2_read_block.patch
  - patches.suse/ocfs2-Require-an-inode-for-ocfs2_read_block-s.patch
  - patches.suse/ocfs2-Simplify-ocfs2_read_block.patch
  - patches.suse/ocfs2-Move-ocfs2_bread-into-dir.c.patch
  - patches.suse/ocfs2-Kill-the-last-naked-wait_on_buffer-for-cach.patch
  - patches.suse/ocfs2-Make-cached-block-reads-the-common-case.patch
  - patches.suse/ocfs2-fix-build-error.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 dynamic local alloc patches
* Thu Oct 16 2008 jslaby@suse.de
- patches.drivers/tpm-bcm0102-workaround.patch: tpm: work around
  bug in Broadcom BCM0102 chipset (bnc#425747 FATE304221).
- patches.drivers/tpm-correct-timeouts.patch: tpm: correct tpm
  timeouts to jiffies conversion (bnc#425747 FATE304221).
* Thu Oct 16 2008 ihno@suse.de
- added patches.arch/s390-01-03-cmm2-v2a.patch
  fix the sequence of initilisations.
* Thu Oct 16 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Make the kernel-$flavor-extra packages
  supplement kernel-$flavor on openSUSE and SLED so that those
  packages will get installed by default, using the product(...)
  dependencies provided by the *-release packages.
* Thu Oct 16 2008 tonyj@suse.de
- Previous checkin was totally broken wrt rt config files.
  Revert to previous versions and incorporate any changes from
  run_oldconfig. Sole changes to previous versions is to remove
  CONFIG_DYNAMIC_FTRACE from rt_debug configs which is consistent
  with change in 2.6.27.1
* Thu Oct 16 2008 gregkh@suse.de
- Update to 2.6.27.1
  - disables a problem config option, only affected the vanilla,
    debug, and rt kernel variants.
* Wed Oct 15 2008 olh@suse.de
- add patches.arch/ppc-pseries_pfn-mem-rm.patch
  fix hotplug memory remove (bnc#435181 - LTC48640)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: run weak-modules, depmod and mkinitrd
  on older distros (bnc#435246)
  Fixed fix for bnc#435104 ("/boot/" was missing in some places)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't recommend the -extra subpackage
  (fate#303631)
- rpm/postun.sh, rpm/post.sh: remove the temporary workaround
* Wed Oct 15 2008 olh@suse.de
- drop patches.arch/ppc-iseries-remove-AVAILABLE_VETH.patch
  not needed anymore
* Wed Oct 15 2008 nfbrown@suse.de
- patches.fixes/nfs-file-cred-context-null: nfs_file_cred should
  cope if 'file' hasn't been opened properly (bnc#431785).
* Wed Oct 15 2008 tonyj@suse.de
- Update RT patches to latest .27 Windriver version (all patches)
- Disable patches.rt/swap-spinlock-fix.patch
- Guard filp-slab-rcu for RT
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: Input:
  Add Acer Aspire 5710 to nomux blacklist (bnc#404881).
* Tue Oct 14 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: Delete.
  in mainline now. done to the right tree.
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/postun.sh, rpm/post.sh: temporarily ignore errors from
  weak-modules2 --{add,remove}-kernel-modules until
  module-init-tools has rebuilt
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Delete.
  The patch is already upstream in 2.6.27
* Tue Oct 14 2008 jeffm@suse.de
- patches.suse/osync-error: Update position after check for -EIO
  (bnc#434910).
* Tue Oct 14 2008 npiggin@suse.de
- patches.suse/rlimit-memlock-64k.patch: Increase default
  RLIMIT_MEMLOCK to 64k (bnc#329675).
* Tue Oct 14 2008 sjayaraman@suse.de
- Update config files: CIFS_EXPERIMENTAL=y and CIFS_DFS_UPCALL=y
  (FATE#303758).
* Tue Oct 14 2008 jbeulich@novell.com
- patches.xen/xen-irq-probe: restrict IRQ probing (bnc#431572).
* Tue Oct 14 2008 ptesarik@suse.cz
- patches.trace/utrace-core: undo overzealous #ifdef's, which
  removed too much code in case UTRACE_CONFIG was unset.
* Tue Oct 14 2008 jbeulich@novell.com
- patches.fixes/reiserfs-commit-ids-unsigned-ints: Remove L suffix
  from constant compared against.
* Tue Oct 14 2008 olh@suse.de
- call bootloader_entry without leading /boot/ (bnc#435104)
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/functions.sh:
  kill functions.sh, put the relink() function to source-post.sh
  directly
- rpm/postun.sh, rpm/pre.sh, rpm/preun.sh, rpm/post.sh,
  rpm/kernel-binary.spec.in: unify generation of the scriptlets,
  switch to the new weak-modules2 script
* Tue Oct 14 2008 olh@suse.de
- disable unused ide_platform driver
* Tue Oct 14 2008 jdelvare@suse.de
- supported.conf: Remove i2c-core and i2c-piix4 from base.
* Tue Oct 14 2008 gregkh@suse.de
- supported.conf: remove ide-core and ide-cdrom from base on request
  from Tejun.
* Tue Oct 14 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-pcc-acpi-driver.patch: Staging:
  add pcc-acpi driver.
- rpm/kernel-binary.spec.in: Obsoletes pcc-acpi-kmp
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: it's pcc-acpi and it's not obsolete, yet.
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes at76_usb-kmp
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes et131x-kmp, ivtv-kmp, and
  ppc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-at76_usb-wireless-driver.patch: staging:
  at76_usb wireless driver.
* Mon Oct 13 2008 gregkh@suse.de
- refresh all patches (except xen and rt) to apply cleanly
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: add Obsoletes: wlan-ng-kmp as the needed
  driver is now included from the staging tree.
* Mon Oct 13 2008 gregkh@suse.de
- put proper Patch-mainline: markings on staging patches
* Mon Oct 13 2008 gregkh@suse.de
- patches.drivers/staging-workaround-build-system-bug.patch:
  Staging: workaround build system bug.
* Mon Oct 13 2008 aj@suse.de
- rpm/post.sh: Fix typo that breaks script.
* Mon Oct 13 2008 gregkh@suse.de
- disabled staging drivers for -rt trees
* Mon Oct 13 2008 gregkh@suse.de
- Add -staging tree:
  - added TAINT_CRAP flag
  - added eth131x network driver
  - added slicoss network driver
  - added sgx network driver
  - added me4000 data collection driver
  - added go7007 video capture driver
  - added USB/IP host and client driver
  - added w35und wifi network driver
  - added prism2 usb wifi network driver
  - added echo cancellation driver
- only enabled these on x86 platforms
* Mon Oct 13 2008 jjolly@suse.de
- patches.arch/s390-02-01-xpram.patch: xpram: per device block
  request queues (bnc#434333,LTC#49030)
* Mon Oct 13 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Updated supported.conf checker to
  eliminate false positives.
* Mon Oct 13 2008 sjayaraman@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Fix a compiler warning.
* Mon Oct 13 2008 jbenc@suse.cz
- supported.conf: mark drivers/net/wireless/b43* and
  driver/net/wireless/rt2x00/* as unsupported because of known
  problems we cannot fix.
* Mon Oct 13 2008 oneukum@suse.de
- patches.fixes/wdm_autoload.diff:  add MODULE_DEVICE_TABLE to
  cdc-wdm driver to compute a proper alias (bnc#433817).
* Mon Oct 13 2008 ptesarik@suse.cz
- Update config files (CONFIG_UTRACE for rt flavours).
* Mon Oct 13 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27-rc3: Fix uninitialized data issue.
* Mon Oct 13 2008 ptesarik@suse.cz
- patches.trace/utrace-core: utrace core (FATE#304321).
  CONFIG_UTRACE enabled only for kernel-trace.
- Update config files.
* Mon Oct 13 2008 aj@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Add cast to fix compiler warning.
* Mon Oct 13 2008 sjayaraman@suse.de
- Remove another stale swap-over-nfs patch.
  patches.suse/SoN-29-nfs-alloc-recursions.patch: Delete.
* Fri Oct 10 2008 jeffm@suse.de
- Updated to 2.6.27 final.
* Fri Oct 10 2008 tonyj@suse.de
- Update config files
- Fix conflicts, remove most -RT guards added in recent RT update
  patches.rt/apic-dumpstack.patch: refresh
  patches.rt/preempt-irqs-core.patch: refresh
  patches.rt/print-might-sleep-hack.patch: refresh
  patches.rt/partrevert-lttng-instrumentation-irq.patch: add
  patches.rt/partreadd-lttng-instrumentation-irq.patch: add
- Drop unused RT patches
  patches.rt/mips-change-raw-spinlock-type.patch
  patches.rt/nmi-watchdog-disable.patch
  patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
  patches.rt/lockstat-fix-contention-points.patch
  patches.rt/sched-cpupri-priocount.patch
  patches.rt/nmi-watchdog-fix-1.patch
  patches.rt/cache_pci_find_capability.patch
  patches.rt/fix-emac-locking-2.6.16.patch
  patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch
  patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch
  patches.rt/tie-pi-into-task.patch
  patches.rt/idle2-fix.patch
  patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch
  patches.rt/rtmutex-initialize-waiters.patch
  patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch
  patches.rt/add-generalized-pi-interface.patch
  patches.rt/warn-on-rt-scatterlist.patch
  patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch
  patches.rt/trace-eip2ip.patch
  patches.rt/sched_rt-fixup.patch
  patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch
  patches.rt/trace_hist-latediv.patch
  patches.rt/sched-cpupri-hotplug-support.patch
  patches.rt/idle-fix.patch
  patches.rt/ftrace-fix-get-kprobe-wreckage.patch
  patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch
  patches.rt/ftrace-function-record-nop.patch
  patches.rt/ftrace-document-update1.patch
  patches.rt/26-rt1-chirag.patch
  patches.rt/trace_hist-divzero.patch
  patches.rt/latency-tracing-ppc.patch
  patches.rt/rtmutex-defer-pi-until-sleepy.patch
  patches.rt/pmtmr-override.patch
  patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
  patches.rt/rtmutex-use-runtime-init.patch
  patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch
  patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch
  patches.rt/lockdep-lock_set_subclass.patch
  patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch
  patches.rt/rt-mutex-irq-flags-checking.patch
  patches.rt/ftrace-upstream.patch
  patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch
  patches.rt/ftrace-preempt-trace-check.patch
  patches.rt/rtmutex-add_readers.patch
  patches.rt/lockdep-avoid-fork-waring.patch
  patches.rt/arm-omap-02.patch
  patches.rt/fix-acpi-build-weirdness.patch
  patches.rt/cycles-to-ns-trace-fix.patch
  patches.rt/ftrace-compile-fixes.patch
  patches.rt/ftrace-wakeup-rawspinlock.patch
  patches.rt/rtmutex-convert-to-libpi.patch
  patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch
  patches.rt/ftrace-trace-sched.patch
* Fri Oct 10 2008 mfasheh@suse.com
- supported.conf: mark kernel/fs/gfs2 unsupported
* Fri Oct 10 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-cs5530 unsupported due
  to sb16 dependancy issues
* Fri Oct 10 2008 jeffm@suse.de
- patches.fixes/account-reserved-pages: Delete.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Updated to build with
  CONFIG_MODULES=n.
* Thu Oct  9 2008 jeffm@suse.de
- Updated to 2.6.27-rc9, but still disabled:
  - patches.suse/silent-stack-overflow
  - patches.xen/xen3-silent-stack-overflow
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: thermal_sys, not thermal_sysfs.
* Thu Oct  9 2008 jeffm@suse.de
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Updated against
  2.6.27-rc9.
* Thu Oct  9 2008 jdelvare@suse.de
- supported.conf: Fix the name of the thermal_sys module.
- config/x86_64/rt_timing: THERMAL_HWMON is a boolean.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/netfilter-ipv4options: Updated to 2.6.27-rc9,
  enabled, and marked supported (bnc#131728 - FATE#182).
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/serial8250_console_write-ier: Delete.
- patches.fixes/fix-serial-8250-UART_BUG_TXEN-test: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-als4000 unsupported due
  to dependancy on isa sb16 driver.
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/dont-writeback-fd-bdev-inodes.patch: Delete.
- patches.arch/s390-ccwgroup-attribute-ignore-newline: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark drivers/net/wan/hdlc_x25 unsupported due to
  symbol dependancy tree.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/osync-error: make sure O_SYNC writes properly
  return -EIO (bnc#58622).
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff:
  Add additional symbols to /sys/kernel/vmcoreinfo data for
  ppc(64).
* Thu Oct  9 2008 trenn@suse.de
- patches.xen/xen-x2APIC_build_fix.patch: Adopt Xen to x2APIC
  patchset (fate#303984 and fate#303948).
- Update config files.
  Disable interrupt remapping for Xen -> this is something for
  the hypervisor.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y in vanilla configs.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y; is boolean and enables
  functionality in the already modular THERMAL module.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Export supported status
  via sysfs.
* Thu Oct  9 2008 carnold@novell.com
- Update config files.  Disabled the in kernel KVM modules in
  preference to using them as KMPs.  See also brogers@novell.com
* Thu Oct  9 2008 jeffm@suse.de
- Added a -iu|--ignore-unsupported-deps option to allow builds
  with supported.conf problems.
* Thu Oct  9 2008 jdelvare@suse.de
- config/i386/*, config/x86_64/*, config/ia64/*, supported.conf:
  Build hwmon and thermal as modules.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark hdlc_ppp unsupported as syncppp is unsupported.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ubifs as unsupported as it relies on mtd/ubi/
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-dynamic-reconfiguration.diff:
  powerpc: Add support for dynamic reconfiguration memory in
  kexec/kdump kernels (bnc#431492).
* Thu Oct  9 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: package kernel-xen has dependency to
  xen (bnc#431215).
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark TPM drivers a supported, as IBM and others
  rely on them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: fix a dependancy link with the isa sb driver with
  unsupported symbols
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ieee80122 modules as supported, as other
  supported modules need them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark all of the mtd drivers as unsupported to fix
  the build errors (and to reflect our policy here.)
* Thu Oct  9 2008 bwalle@suse.de
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC to 0 (bnc#429910).
* Thu Oct  9 2008 jdelvare@suse.de
- Don't build the tps65010 driver, it's only used on OMAP at the
  moment.
* Thu Oct  9 2008 mmarek@suse.cz
- rpm/built-in-where: make it work with a four-column
  Modules.symvers (bnc#433533)
* Thu Oct  9 2008 bwalle@suse.de
- Update KDB to v4.4-2.6.27-rc8.
* Thu Oct  9 2008 olh@suse.de
- disable legacy iseries (bnc#433685 - LTC48946)
* Thu Oct  9 2008 olh@suse.de
- enable battery_pmu on ppc32
* Thu Oct  9 2008 trenn@suse.de
- supported.conf:
  Marked these unsupported:
  cpufreq-nforce2
  e_powersaver
  gx-suspmod
  longhaul
  longrun
  p4-clockmod
  powernow-k6
  powernow-k7
  speedstep-ich
  speedstep-smi
  Even Via CPUs are exporting cpu freq steps via ACPI and work fine
  with acpi-cpufreq. No need to support the old, some are known
  broken, drivers.
* Thu Oct  9 2008 olh@suse.de
- add patches.suse/md-raid-metadata-PAGE_SIZE.patch
  ignore PAGE_SIZE in md metadata, for raid0 (bnc#429490)
* Thu Oct  9 2008 teheo@suse.de
- patches.xen/xen3-auto-common.diff: minor patch apply fix after
  libata-prefer-over-ide.
* Thu Oct  9 2008 teheo@suse.de
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
* Wed Oct  8 2008 carnold@novell.com
- patches.xen/xen-op-packet: add support for new operation type
  BLKIF_OP_PACKET (fate#300964).
- patches.xen/xen-blkfront-cdrom: implement forwarding of CD-ROM
  specific commands (fate#300964).
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: major update.  Lots of new drivers added as this
  file hadn't been updated for a lot of kernel revisions.
  This should close out a lot of bugs about "unsupported" modules,
  like bnc#433541.
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: sorted the file correctly so we can start determining
  what we are not supporting easier.
* Wed Oct  8 2008 jeffm@suse.de
- Updated -rt for context against -rc9 and the x2APIC patches:
  - patches.rt/new-softirq-code.patch
  - patches.rt/preempt-irqs-core.patch
  - patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch
  - CONFIG_INTR_REMAP=n for now
  - patches.rt/preempt-softirqs-core.patch
  - patches.rt/rt-slab-new.patch
  - patches.rt/slab-irq-nopreempt-fix.patch
  - Update config files: NFS_SWAP=n
* Wed Oct  8 2008 trenn@suse.de
  x2APIC and interrupt remapping enablement.
  Xen needs further work to build again.
  Commit ids are from x86 tip git tree:
- patches.arch/x2APIC_fix_section_mismatch.patch: Fix several
  section mismatches (none).
- patches.arch/x2APIC_PATCH_01_0f4896665a02b465ddca59a560983b24ec28c64b:
  dmar: fix dmar_parse_dev() devices_cnt error condition check
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_01_of_41_e61d98d8dad0048619bb138b0ff996422ffae53b:
  x64, x2apic/intr-remap: Intel vt-d, IOMMU code reorganization
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_228324076234ca6a8cd34be89be78022773459f1:
  dmar: use list_for_each_entry_safe() in dmar_dev_scope_init()
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_of_41_c42d9f32443397aed2d37d37df161392e6a5862f:
  x64, x2apic/intr-remap: fix the need for sequential array
  allocation of iommus (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_03_3f1fdb3673bb5638fa94186dc391cbc4879590bc:
  dmar: initialize the return value in dmar_parse_dev() (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_03_of_41_1886e8a90a580f3ad343f2065c84c1b9e1dac9ef:
  x64, x2apic/intr-remap: code re-structuring, to be used by both
  DMA and Interrupt remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_f12c73e7fa7ebf9ad6defee2c4fb2664e743e970:
  dmar: fix using early fixmap mapping for DMAR table parsing
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_of_41_aaa9d1dd63bf89b62f4ea9f46de376ab1a3fbc6c:
  x64, x2apic/intr-remap: use CONFIG_DMAR for DMA-remapping
  specific code (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_05_7be42004065ce4df193aeef5befd26805267d0d9:
  x86, lguest: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_caf43bf7c6a55e89b6df5179df434d67e24aa32e:
  x86, xen: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_of_41_ad3ad3f6a2caebf56869b83b69e23eb9fa5e0ab6:
  x64, x2apic/intr-remap: parse ioapic scope under vt-d structures
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_511d9d34183662aada3890883e860b151d707e22:
  x86: apic_ops for lguest (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_of_41_cf1337f0447e5be8e66daa944f0ea3bcac2b6179:
  x64, x2apic/intr-remap: move IOMMU_WAIT_OP() macro to
  intel-iommu.h (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_08_of_41_fe962e90cb17a8426e144dee970e77ed789d98ee:
  x64, x2apic/intr-remap: Queued invalidation infrastructure
  (part of VT-d) (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_09_94a8c3c2437c8946f1b6c8e0b2c560a7db8ed3c6:
  x86: let 32bit use apic_ops too - fix (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_09_of_41_2ae21010694e56461a63bfc80e960090ce0a5ed9:
  x64, x2apic/intr-remap: Interrupt remapping infrastructure
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_10_of_41_b6fcb33ad6c05f152a672f7c96c1fab006527b80:
  x64, x2apic/intr-remap: routines managing Interrupt remapping
  table entries. (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_11_of_41_72b1e22dfcad1daca6906148fd956ffe404bb0bc:
  x64, x2apic/intr-remap: generic irq migration support from
  process context (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_12_of_41_d94d93ca5cc36cd78c532def62772c98fe8ba5d7:
  x64, x2apic/intr-remap: 8259 specific mask/unmask routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_13_of_41_4dc2f96cacd1e74c688f94348a3bfd0a980817d5:
  x64, x2apic/intr-remap: ioapic routines which deal with initial
  io-apic RTE setup (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_14_of_41_0c81c746f9bdbfaafe64322d540c8b7b59c27314:
  x64, x2apic/intr-remap: introduce read_apic_id() to genapic
  routines (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_15_of_41_2d7a66d02e11af9ab8e16c76d22767e622b4e3d7:
  x64, x2apic/intr-remap: Interrupt-remapping and x2apic support,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_16_of_41_1b374e4d6f8b3eb2fcd034fcc24ea8ba1dfde7aa:
  x64, x2apic/intr-remap: basic apic ops support (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_17_of_41_32e1d0a0651004f5fe47f85a2a5c725ad579a90c:
  x64, x2apic/intr-remap: cpuid bits for x2apic feature (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_18_of_41_1cb11583a6c4ceda7426eb36f7bf0419da8dfbc2:
  x64, x2apic/intr-remap: disable DMA-remapping if
  Interrupt-remapping is detected (temporary quirk) (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_19_of_41_13c88fb58d0112d47f7839f24a755715c6218822:
  x64, x2apic/intr-remap: x2apic ops for x2apic mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_21_of_41_12a67cf6851871ca8df42025c94f140c303d0f7f:
  x64, x2apic/intr-remap: x2apic cluster mode support (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_22_of_41_5c520a6724e912a7e6153b7597192edad6752750:
  x64, x2apic/intr-remap: setup init_apic_ldr for UV (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_23_of_41_89027d35aa5b8f45ce0f7fa0911db85b46563da0:
  x64, x2apic/intr-remap: IO-APIC support for interrupt-remapping
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_24_of_41_75c46fa61bc5b4ccd20a168ff325c58771248fcd:
  x64, x2apic/intr-remap: MSI and MSI-X support for interrupt
  remapping infrastructure (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_1_of_41_4c9961d56ec20c27ec5d02e49fd7427748312741:
  x86: make read_apic_id return final apicid (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_25_2_of_41_c535b6a1a685eb23f96e2c221777d6c1e05080d5:
  x86: let 32bit use apic_ops too (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_of_41_6e1cb38a2aef7680975e71f23de187859ee8b158:
  x64, x2apic/intr-remap: add x2apic support, including enabling
  interrupt-remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_26_of_41_2d9579a124d746a3e0e0ba45e57d80800ee80807:
  x64, x2apic/intr-remap: support for x2apic physical mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_28_1_of_41_f910a9dc7c865896815e2a95fe33363e9522f277:
  x86: make 64bit have get_apic_id (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_29_of_41_277d1f5846d84e16760131a93b7a67ebfa8eded4:
  x2apic: uninline uv_init_apic_ldr() (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_30_of_41_ad66dd340f561bdde2285992314d9e4fd9b6191e:
  x2apic: xen64 paravirt basic apic ops (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_34_of_41_1b9b89e7f163336ad84200b66a17284dbf26aced:
  x86: add apic probe for genapic 64bit, v2 (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_35_of_41_d25ae38b7e005af03843833bbd811ffe8c5f8cb4:
  x86: add apic probe for genapic 64bit - fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_36_of_41_276605dddb74cbf1b77696e32c4a947e42cec52d:
  x2apic: use x2apic id reported by cpuid during topology
  discovery (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_41_of_41_11c231a962c740b3216eb6565149ae5a7944cba7:
  x86: use x2apic id reported by cpuid during topology discovery,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_42_of_41_77322deb4bc676a5ee645444e7ed1a89f854473d:
  x86: io-apic - interrupt remapping fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_43_of_41_2c72d93f6593f386f5760ca8e7ac7026948c31d7:
  x2apic: fix reserved APIC register accesses in
  print_local_APIC() (fate #303948 and fate #303984).
- patches.drivers/sgi-uv-led: SGI UV: Provide a LED driver and
  some System Activity Indicators (FATE#304268).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc5-x86-1 (FATE#303971).
- patches.xen/xen-x86-no-lapic: Disallow all accesses to the
  local APIC page (191115).
- patches.xen/xen3-auto-arch-x86.diff: xen3 arch-x86.
- patches.xen/xen3-patch-2.6.19: Linux 2.6.19.
- patches.xen/xen3-patch-2.6.26: 2.6.26.
- Update config files:
  Added CONFIG_INTR_REMAP to all x86_64 flavors
* Wed Oct  8 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: added Obsoletes: atl2-kmp as this
  driver is now included in the kernel package.
* Wed Oct  8 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-4-v2.patch: Update for fcpperf-4
  patch to bring in sync with upstream version. (bnc#417243)
- patches.arch/s390-01-04-fcpperf-4.patch: Removed, replaced by
  updated patch
* Wed Oct  8 2008 sjayaraman@suse.de
- Remove stale swap-over-nfs patches.
- patches.suse/SoN-05-page_alloc-reserve.patch: Delete.
- patches.suse/SoN-06-reserve-slub.patch: Delete.
* Wed Oct  8 2008 agruen@suse.de
- No uml patches left, so remove the code referring to
  patches.uml.tar.bz2.
* Wed Oct  8 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
* Wed Oct  8 2008 agruen@suse.de
- Add DMAPI patches (supported by SGI).
- Update config files: enable DMAPI.
* Wed Oct  8 2008 sjayaraman@suse.de
- Doh, forgot to remove stale files from cvs
- Update config files NFS_SWAP=y.
* Wed Oct  8 2008 sjayaraman@suse.de
- Refreshed to -v19 of swap over nfs patchset.
  o netns, ipv6 fixes
  o patch ordering changes due to additional patches
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict.
* Wed Oct  8 2008 bwalle@suse.de
- Enable CONFIG_MFD_SM501_GPIO also for RT.
* Wed Oct  8 2008 bwalle@suse.de
- Refresh patches.rt/mips-remove-duplicate-kconfig.patch.
* Wed Oct  8 2008 bwalle@suse.de
- Update to 2.6.27-rc9.
- Enable new configuration option CONFIG_MFD_SM501_GPIO.
- Drop following patches (mainline):
  o patches.suse/e1000e_debug_contention_on_NVM_SWFLAG
  o patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context
  o patches.suse/e1000e_drop_stats_lock, e1000e_fix_lockdep_issues
  o patches.suse/e1000e_mmap_range_chk,
  o patches.suse/e1000e_reset_swflag_after_resetting_hardware
  o patches.suse/e1000e_update_versione1000e_write_protect_ichx_nvm
- Adjust/refresh following patches:
  o patches.arch/s390-01-03-cmm2-v2.patch
  o patches.drivers/e1000e_add_82574L.patch
  o patches.drivers/e1000e_add_ICH9_BM.patch
  o patches.drivers/e1000e_add_LOM_devices.patch
  o patches.suse/e1000e_allow_bad_checksum
  o patches.suse/e1000e_call_dump_eeprom
  o patches.suse/e1000e_ioremap_sanity_check
  o patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory
* Wed Oct  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: switch KMPs to the new
  weak-modules2 script, which handles running depmod and mkinitrd
* Wed Oct  8 2008 hare@suse.de
- supported.conf: mark igb as supported.
* Wed Oct  8 2008 agruen@suse.de
- kernel-source-rt must not provide a kernel-source symbol: this
  would break dependencies.
* Wed Oct  8 2008 olh@suse.de
- update patches.suse/ppc-no-LDFLAGS_MODULE.patch
  use suggested patch from kernel.org bugzilla
* Wed Oct  8 2008 olh@suse.de
- add patches.arch/ppc-pseries_remove_lmb-PAGE_SHIFTT.patch
  fix oops in pseries_remove_lmb with 64k PAGE_SIZE (bnc#431380)
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: mark efivars.ko as supported
* Wed Oct  8 2008 gregkh@suse.de
- enable yealink driver (bnc#432841)
* Tue Oct  7 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: fix hang in disable_periodic
  (bnc#403346).
* Tue Oct  7 2008 trenn@suse.de
- patches.fixes/fujisu_laptop_fix_section_mismatch.patch: Fix
  section mismatch in fujitsu_laptop driver (none).
* Tue Oct  7 2008 hare@suse.de
- patches.fixes/sd-needs-updating: Driver 'sd' needs updating
  (bnc#406656).
* Tue Oct  7 2008 agruen@suse.de
- rpm/post.sh: Catch mkinitrd error code indicating missing
  required modules. Only add a bootloader entry if an initrd
  could be created, but re-add the bootloader entry even if
  the initrd already existed before (bnc#431703).
* Tue Oct  7 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.4-update: Update lpfc to 8.2.8.4
  (bnc#420767).
- patches.drivers/qla4xxx-sles11-update: qla4xxx driver fixes
  for SLES11 (bnc#432976).
* Tue Oct  7 2008 olh@suse.de
- mark legacy iseries storage as supported
* Mon Oct  6 2008 jdelvare@suse.de
- supported.conf: Add the ad7414, adcxx and ibmaem hwmon drivers as
  unsupported.
* Mon Oct  6 2008 jdelvare@suse.de
- config/ia64/*: Don't built i2c-amd756-s4882 and i2c-nforce2-s4985
  on ia64, these are motherboard-specific drivers for x86_64
  motherboards.
- config/powerpc/*: Don't built i2c-isch on powerpc, it is a driver
  for x86 hardware.
- config/*: Don't built i2c-simtec on i386, x86_64 and ia64, there
  is no Simtec hardware based on these architectures.
* Sun Oct  5 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Fix the logic splitting up the symbols
  defined in vmlinux by subsystem. (Actually, per directory, under
  the assumption that there is enough of a correlation).
* Sun Oct  5 2008 greg@suse.de
- supported.conf: add ohci-hcd to base.  Fix up other USB drivers
  (USB network drivers had moved, others were missing)
* Sun Oct  5 2008 gregkh@suse.de
- patches.drivers/atl2-add-atl2-network-driver.patch: atl2:
  add atl2 network driver.
- Update config files (even the rt ones).
* Fri Oct  3 2008 jkosina@suse.de
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: fix bogus
  WARN_ON() condition, as per upstream commit 95b866d5a
* Fri Oct  3 2008 olh@suse.de
- mark ibmvfc as supported (bnc#417555 - fate#304178 - LTC46935)
* Fri Oct  3 2008 olh@suse.de
- compile windfarm_pm121 into the kernel
* Fri Oct  3 2008 jeffm@suse.de
- doc/README.SUSE, scripts/tar-up_and_run_mbuild.sh,
  scripts/run_oldconfig.sh,
  scripts/sequence-patch.sh: Eliminated defconfig.$flavor
* Fri Oct  3 2008 olh@suse.de
- mark Cell drivers as supported
* Fri Oct  3 2008 tonyj@suse.de
- Update config files
  rt configs not updated for per-module-dynamic-debug-messages.patch
* Fri Oct  3 2008 gregkh@suse.de
- change patches.suse/supported-flag to show which modules are
  unsupported and externally supported in oops messages.  Also change
  the taint values as the documentation was totally wrong.
* Fri Oct  3 2008 tonyj@suse.de
- Reenable RT debug builds, compile tested only
- Update config files
- Fix tracer issues
  patches.rt/event-trace-hrtimer-trace.patch
  patches.rt/trace-events-handle-syscalls.patch
  patches.rt/trace-ktime-scalar.patch
  patches.rt/tracer-event-trace.patch
- patches.rt/kdb-disable-ist.patch: Disable stackfault and debug stacks for kdb
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT
- patches.rt/novfs-rtmisc.patch: Misc NOVFS fixes for RT
* Fri Oct  3 2008 gregkh@suse.de
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  driver core: basic infrastructure for per-module dynamic
  debug messages.
- refresh patches.trace/tracepoints.patch: Kernel Tracepoints.
- Update config files.
* Thu Oct  2 2008 agruen@suse.de
- Introduce kernel-source-rt and kernel-syms-rt packages, needed
  for building real-time KMPs.
* Thu Oct  2 2008 schwab@suse.de
- Don't clean <asm/nr-irqs.h>.
* Thu Oct  2 2008 jblunck@suse.de
- supported.conf: add qeth_l2 and qeth_l3 as supported modules
* Thu Oct  2 2008 jkosina@suse.de
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: update to
  the latest version of the patch as provided by Intel
* Thu Oct  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc8 and c/s 684.
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Replace by ...
- patches.xen/xen3-e1000e_Export_set_memory_ro-rw: this, and put
  in proper place in series.conf.
- patches.xen/xen-rwlocks-enable-interrupts: Replace by ...
- patches.xen/xen3-rwlocks-enable-interrupts: this, and put in
  proper place in series.conf.
* Wed Oct  1 2008 jeffm@suse.de
- scripts/sequence-patch.sh
- scripts/run_oldconfig.sh: x86 defconfigs go under arch/x86.
* Wed Oct  1 2008 olh@suse.de
- enable msi on ppc64 (bnc#430937)
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Remove /lib/modules from file list
  as it's already in filesystem
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Fixed missing endif
* Wed Oct  1 2008 tiwai@suse.de
- Update config files: make floppy module on i386, too
* Wed Oct  1 2008 tiwai@suse.de
- supported.conf: update sound drivers
* Wed Oct  1 2008 tonyj@suse.de
- update RT to 2.6.27-rc8
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
* Wed Oct  1 2008 agruen@suse.de
- Update -rt config files.
* Tue Sep 30 2008 gregkh@suse.de
- update to 2.6.27-rc8
  - obsoletes these patches:
  - patches.arch/ia64-kdump_proc_iomem.diff
  - patches.drivers/qla2xxx-defer-risc-interrupt-enablement
  - patches.fixes/usb-hcd-interrupt-shared.patch
* Tue Sep 30 2008 jkosina@suse.de
- additional patches to track down and fix e1000e NVM corruption
- patches.suse/e1000e_ioremap_sanity_check: ioremap sanity check
  to catch mapping requests exceeding the BAR sizes (bnc#425480).
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: write
  protect ICHx NVM to prevent malicious write/erase (bnc#425480).
* Tue Sep 30 2008 hare@suse.de
- Update config files.
* Tue Sep 30 2008 hare@suse.de
- patches.drivers/mpt-fusion-4.00.43.00-update: Update MPT Fusion
  driver to v4.00.43.00 (bnc#425660).
- patches.kernel.org/gdth-section-conflict: Add missing annotations.
* Tue Sep 30 2008 sassmann@suse.de
- Update config files: Disabled everything unnecessary in
  ps3 config file
* Tue Sep 30 2008 olh@suse.de
- disable ninja32 and ns87415 pata drivers on ppc64
* Tue Sep 30 2008 sdietrich@suse.de
- config.conf: enable rt for i386/x86_64
- Update config files: Preliminary sync with default and debug configs.
- config/x86_64/rt_timing: Delete.
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.27-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.27-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.27-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.27-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.27-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.27-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.27-RT
  Fix a previously reverted "fix".
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.27-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.27-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.27-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.27-RT
  floppy: suspend/resume fix.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT rt: remove call to stop tracer.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: document updates.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.27-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: define function trace nop.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.27-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: only trace preempt off with
  preempt tracer.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.27-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.27-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: trace sched.c.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.27-RT
  ftrace: avoid lockdep recursion.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: user raw spin lock for wakeup
  function trace.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.27-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.27-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.27-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.27-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.27-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT lockdep: lock_set_subclass - reset a held
  lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.27-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.27-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.27-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.27-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.27-RT
  mapping_nrpages-fix.patch.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.27-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT RT: change from raw_spinlock_t to
  __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.27-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.27-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.27-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.27-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.27-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.27-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.27-RT
  nfs: fix missing preemption check.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT x86_64: do not enable the NMI watchdog
  by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.27-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT local_bh_enable() is safe for
  irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.27-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.27-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.27-RT.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT pmtmr: allow command line override of
  ioport.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.27-RT
  powerpc: ftrace stop on crash.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.27-RT
  don't trace early init functions for ppc32.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.27-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.27-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.27-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.27-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.27-RT
  lockdep: add +1 to radix tree array.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.27-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.27-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.27-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.27-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.27-RT
  rt: plist_head_splice.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.27-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.27-RT
  rtmutex-debug-fix.patch.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.27-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.27-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.27-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.27-RT
  rwlocks multi downgrade write.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.27-RT.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.27-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.27-RT
  rwlock: rwlock torture test.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.27-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.27-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.27-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.27-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.27-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.27-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Re: 2.6.25.4-rt4.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.27-RT
  ftrace: print ktime values in readable form.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.27-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.27-RT.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT remove warn on for scatterlist in preempt
  rt.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.27-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/26-rt1-chirag.patch: Linux-RT 2.6.27-RT
  This patch should solve some of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: Linux-RT
  2.6.27-RT
  add generalized priority-inheritance interface.
- patches.rt/rtmutex-add_readers.patch: Linux-RT 2.6.27-RT
  RT: wrap the rt_rwlock "add reader" logic.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: Linux-RT
  2.6.27-RT
  rtmutex: pi-boost locks as late as possible.
- patches.rt/rtmutex-initialize-waiters.patch: Linux-RT 2.6.27-RT
  rtmutex: formally initialize the rt_mutex_waiters.
- patches.rt/rtmutex-use-runtime-init.patch: Linux-RT 2.6.27-RT
  rtmutex: use runtime init for rtmutexes.
- patches.rt/tie-pi-into-task.patch: Linux-RT 2.6.27-RT
  sched: add the basic PI infrastructure to the task_struct.
- patches.rt/rtmutex-convert-to-libpi.patch: Linux-RT 2.6.27-RT
  rtmutex: convert rtmutexes to fully use the PI library.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  Linux-RT 2.6.27-RT
  ftrace: fix elevated preempt_count in wakeup-tracer.
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  Linux-RT 2.6.27-RT
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.27-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.27-RT.
- patches.rt/bit-spinlocks-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/compat_rwsem-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/drivers_base_mutex.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-ppc-define-mcount.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-report-failure.patch: Linux-RT 2.6.27-RT
  ftrace: warn on failure to disable mcount callers.
- patches.rt/ftrace-upstream-temp.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-trivial-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-atomic-fixup.patch: Linux-RT 2.6.27-RT.
- patches.rt/namespace-lock-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-prof-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/plist-fix-static-node-init.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-01-separate-the-irq-radix-tree-insertion.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-02-make-the-irq-reverse-mapping-radix-tree-lockless.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-fix-prev-revert-fix-again.patch: Linux-RT
  2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-apply-rcu_process_callbacks-from-mainline.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-tracing-preempt-disable-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rt-wq-flush_work.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-debug-magic.patch: Linux-RT 2.6.27-RT
  rtmutex: check integrity.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-generic-hide-smp-warning.patch: Linux-RT
  2.6.27-RT
  suppress warning of smp_processor_id use..
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-if-pushable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/seqlock-01-make-sure-that-raw_seqlock-retries.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-02-fix-elevated-preempt-count.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-serialize-against-writers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seqlocks-handle-rwlock-and-spin.patch: Linux-RT
  2.6.27-RT
  seqlock - fix for both PREEMPT_RT and non PREEMPT_RT.
- patches.rt/shorten-posix-cpu-timers-name.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sysctl-compile-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracepoint-backport.patch: Linux-RT 2.6.27-RT.
- patches.rt/x86-tlbstate-lock-raw.patch: Linux-RT 2.6.27-RT.
* Tue Sep 30 2008 olh@suse.de
- enable ipmi message handler on ppc64 (bnc#430705)
* Tue Sep 30 2008 olh@suse.de
- create flavor symlinks unconditionally
  they do not depend on presence of modules
* Mon Sep 29 2008 agruen@suse.de
- Update config files after Swap-over-NFS backout.
* Mon Sep 29 2008 agruen@suse.de
- kernel-vanilla and kernel-p3 are not split into main, -base, and
  - extra packages. Fix the bogus dependencies on those packages.
* Mon Sep 29 2008 jkosina@suse.de
- disabled the following Swap-over-NFS patches, as they cause panic
  in IPv6 code:
  - patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
    gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
    serialize access to min_free_kbytes (FATE#303834).
  - patches.suse/SoN-03-doc.patch: swap over network documentation
    (FATE#303834).
  - patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
    expose gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
    pages (FATE#303834).
  - patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
    of reserve pages (FATE#303834).
  - patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
    kmem_alloc_estimate() (FATE#303834).
  - patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
    PF_MEMALLOC from softirq context (FATE#303834).
  - patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
    pool (FATE#303834).
  - patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
    system wide ALLOC_NO_WATERMARK (FATE#303834).
  - patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
    __GFP_MEMALLOC (FATE#303834).
  - patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
    management (FATE#303834).
  - patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
    tag avc cache alloc as non-critical (FATE#303834).
  - patches.suse/SoN-14-net-backlog.patch: net: wrap
    sk->sk_backlog_rcv() (FATE#303834).
  - patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
    api (FATE#303834).
  - patches.suse/SoN-16-net-sk_allocation.patch: net:
    sk_allocation() - concentrate socket related allocations
    (FATE#303834).
  - patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
    infrastructure (FATE#303834).
  - patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
    reserves. (FATE#303834).
  - patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
    skb allocation to reserves (FATE#303834).
  - patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
    emergency skbs. (FATE#303834).
  - patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
    a stream specific deadlock (FATE#303834).
  - patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
    NF_QUEUE vs emergency skbs (FATE#303834).
  - patches.suse/SoN-23-netvm.patch: netvm: skb processing
    (FATE#303834).
  - patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
    non block device backed swap files (FATE#303834).
  - patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
    for teaching filesystems about PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
    client how to treat PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
    revalidation for swapfiles (FATE#303834).
  - patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
    (FATE#303834).
  - patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
    memory recursions possible with swap over NFS. (FATE#303834).
  - patches.xen/xen3-auto-common.diff: xen3 common.
* Mon Sep 29 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: x86 tracehook (FATE#304321).
  Provide the base infrastructure for utrace on x86.
* Mon Sep 29 2008 schwab@suse.de
- config/powerpc/vanilla: configure to 64bit.
* Mon Sep 29 2008 schwab@suse.de
- rpm/functions.sh: remove readlink emulation.
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.3-update: Update lpfc to 8.2.8.3
  (bnc#420767).
* Mon Sep 29 2008 rw@suse.de
- Update ia64 config files.  (bnc#429881)
* Mon Sep 29 2008 jjolly@suse.de
- patches.drivers/ehca-flush-cqe.patch: adds software flush CQE
  generation (bnc#430344)
* Mon Sep 29 2008 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: fix infinite loop bug in
  e1000_probe() in case the card has invalid EEPROM checksum
* Mon Sep 29 2008 agruen@suse.de
- Do not split kernels which have modules disabled (kernel-ps3)
  or which do not differentiate between supported and unsupported
  modules (kernel-vanilla).
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/open-fcoe-dcb-support: Fix section annotation
  for ixgbe.
- patches.fixes/scsi-enhance-error-codes: Add missing hunk.
- patches.fixes/open-iscsi-git-update: Open-iSCSI updates
  (FATE#304283).
- patches.kernel.org/gdth-section-conflict: Fixup gdth
  section annotations.
* Mon Sep 29 2008 aj@suse.de
- Silence /etc/rpm/macros.kernel-source via rpmlintrc.
* Mon Sep 29 2008 jbeulich@novell.com
- Enable Solarflare driver link and resource driver patches.
- Update x86 config files.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spc.in: Try to get rid of a hack that makes
  uname -r pretend in build environments that the kernel from
  the installed kernel-source package is the running kernel:
  packages assuming this are completely broken ans should really
  be fixed.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spec.in: Prepare for the upcoming introduction
  of kernel-source-rt (and kernel-syms-rt) for producing KMPs for
  real-time kernels.
- rpm/install-configs: Remove; this script didn't improve things.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.rpmlintrc: New file to silence warnings about
  zero size files
- rpm/kernel-source.spec.in: Install it.
- rpm/kernel-source.spec.in: Make /etc/rpm/macros.kernel-source
  a config file to silence rpmlint.
* Sun Sep 28 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-i810, i2c-prosavage and i2c-savage4 are gone.
  - i2c-isch and i2c-nforce2-s4985 are new, mark as supported.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.spec.in: Do not package .gitignore files.
* Sun Sep 28 2008 agruen@suse.de
- Fix CONFIG_MODULES=n case.
- config.conf: Some cleanups.
* Sat Sep 27 2008 agruen@suse.de
- Split the binary kernel packages into three parts:
  + kernel-$flavor-base: very reduced hardware support, intended
  to be used in virtual machine images
  + kernel-$flavor: extends the base package; contains all kernel
  modules we can support
  + kernel-$flavor-extra: all other kernel modules which may be
  useful, but which we cannot support.
* Sat Sep 27 2008 agruen@suse.de
- Hardlink duplicate files automatically: It doesn't save much,
  but it keeps rpmlint from breaking the package build.
* Sat Sep 27 2008 agruen@suse.de
- Add consistency check: supported modules must not depend on
  unsupported ones ... and guess what, there was a large number of
  such modules. Fix this by adding all the dependent modules to
  supported.conf.
* Sat Sep 27 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Implement barrier
  support for single device DM devices (FATE#304489).
* Fri Sep 26 2008 jeffm@suse.de
- scripts/tar-up_and_run_mbuild.sh: Added -xen flavor to default
  mbuild spec list.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls for xen. (bnc#425480).
* Fri Sep 26 2008 kkeil@suse.de
- patches.suse/e1000e_mmap_range_chk:check ranges in pci_mmap
  * updated version with better reporting (bnc#425480)
* Fri Sep 26 2008 kkeil@suse.de
- patches to track down and fix the e1000e NVM corruption
  (bnc#425480)
- patches.suse/e1000e_allow_bad_checksum: e1000e: allow bad
  checksum
- patches.suse/e1000e_call_dump_eeprom: e1000e: dump eeprom to
  dmesg for ich8/9
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: e1000e:
  debug contention on NVM SWFLAG
- patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context:
  e1000e: do not ever sleep in interrupt context
- patches.suse/e1000e_drop_stats_lock: e1000e: drop stats lock
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls
- patches.suse/e1000e_fix_lockdep_issues: e1000e: fix lockdep
  issues
- patches.suse/e1000e_mmap_range_chk: check ranges in pci_mmap
- patches.suse/e1000e_reset_swflag_after_resetting_hardware:
  e1000e: reset swflag after resetting hardware
- patches.suse/e1000e_update_version: update version
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  e1000e: Use set_memory_ro()/set_memory_rw() to protect flash
  memory
-   cleanup old not longer used patches
  * patches.drivers/e1000-7.6.5-napi-tail.patch
  * patches.drivers/e1000-7.6.9.2
  * patches.drivers/e1000-7.6.9.2-napi
* Fri Sep 26 2008 kkeil@suse.de
- Enable CONFIG_SGI_IOC4=m in x86_64 (bnc#430275)
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-export-hotplug_execute: acpi: export
  acpi_os_hotplug_execute.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-rwlocks-enable-interrupts: add missing
  __raw_{read,write}_lock_flags to xen's asm/spinlock.h.
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-bay-remove-from-makefile: acpi: remove bay.c
  from makefile.
* Fri Sep 26 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disabled sparse checking. Too many
  false positives.
* Fri Sep 26 2008 trenn@suse.de
  No functional change:
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
  Dock bug fixes (kacpid runs amok on Dells after suspend):
- patches.arch/acpi-dock-avoid-check-_STA-method.patch: avoid
  check _STA method (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-eject-request-process.patch: fix
  eject request process (fate#304731,bnc#401740).
  More Dock improvements, unrelated to above fixes:
- patches.arch/acpi-bay-remove-useless-code.patch: remove useless
  code (fate#304731,bnc#401740).
- patches.arch/acpi-dock-Fix-duplicate-notification-handler-register.patch:
  Fix duplicate notification handler register
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-_LCK-support-for-dock.patch: add _LCK
  support for dock (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-for-bay-in-a-dock-station.patch:
  fix for bay in a dock station (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-hotplug-race.patch: fix hotplug race
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-introduce-.uevent-for-devices-in-dock.patch:
  introduce .uevent for devices in dock (fate#304731,bnc#401740).
- patches.arch/acpi-libata-hotplug-to-align-with-dock-driver.patch:
  libata hotplug to align with dock driver
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-makeing-dock-driver-supports-bay-and-battery-hotplug.patch:
  makeing dock driver supports bay and battery hotplug
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-add-type-sysfs-file-for-dock.patch:
  add 'type' sysfs file for dock (fate#304731,bnc#401740).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
* Fri Sep 26 2008 jeffm@suse.de
- Update config files: NFS_SWAP=y
* Fri Sep 26 2008 ptesarik@suse.cz
- patches.suse/rwlocks-enable-interrupts: Allow rwlocks to
  re-enable interrupts (bnc#387784).
- patches.arch/ia64-rwlocks-enable-interrupts: ia64: re-enable
  interrupts when waiting for a rwlock (bnc#387784).
* Fri Sep 26 2008 sjayaraman@suse.de
- Add Swap over NFS patchset.
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict on skbuff.h
  as both xen and swap-over-nfs want to add some bits to the skbuff structure.
- patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
  gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
  serialize access to min_free_kbytes (FATE#303834).
- patches.suse/SoN-03-doc.patch: swap over network documentation
  (FATE#303834).
- patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
  expose gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
  pages (FATE#303834).
- patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
  of reserve pages (FATE#303834).
- patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
  kmem_alloc_estimate() (FATE#303834).
- patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
  PF_MEMALLOC from softirq context (FATE#303834).
- patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
  pool (FATE#303834).
- patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
  system wide ALLOC_NO_WATERMARK (FATE#303834).
- patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
  __GFP_MEMALLOC (FATE#303834).
- patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
  management (FATE#303834).
- patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
  tag avc cache alloc as non-critical (FATE#303834).
- patches.suse/SoN-14-net-backlog.patch: net: wrap
  sk->sk_backlog_rcv() (FATE#303834).
- patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
  api (FATE#303834).
- patches.suse/SoN-16-net-sk_allocation.patch: net:
  sk_allocation() - concentrate socket related allocations
  (FATE#303834).
- patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
  infrastructure (FATE#303834).
- patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
  reserves. (FATE#303834).
- patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
  skb allocation to reserves (FATE#303834).
- patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
  emergency skbs. (FATE#303834).
- patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
  a stream specific deadlock (FATE#303834).
- patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
  NF_QUEUE vs emergency skbs (FATE#303834).
- patches.suse/SoN-23-netvm.patch: netvm: skb processing
  (FATE#303834).
- patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
  non block device backed swap files (FATE#303834).
- patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
  for teaching filesystems about PG_swapcache pages (FATE#303834).
- patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
  client how to treat PG_swapcache pages (FATE#303834).
- patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
  revalidation for swapfiles (FATE#303834).
- patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
  (FATE#303834).
- patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
  memory recursions possible with swap over NFS. (FATE#303834).
- patches.xen/xen3-auto-common.diff: xen3 common.
* Fri Sep 26 2008 ptesarik@suse.cz
- split patches.arch/s390-01-01-self-ptrace-v3.patch to make it
  more obvious that the patch is not constrained to s390.
  The new series is:
    patches.suse/self-ptrace.patch: the generic pieces
    patches.arch/x86-self-ptrace.patch: implementation for x86
    patches.arch/s390-01-01-self-ptrace-v3.patch: dtto for s390
* Thu Sep 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc7 and c/s 676.
* Thu Sep 25 2008 olh@suse.de
- add patches.arch/ppc64-rpanote-relocate-firmware.patch
  update RPA note for firmware relocation (bnc#427960 - LTC48297)
* Wed Sep 24 2008 jblunck@suse.de
  This adds some tracepoint instrumentation taken from the LTTng patch
  series. Tracepoints are enabled for kernel-debug and kernel-trace only. I
  disabled ftrace for all flavors except kernel-debug and kernel-trace as well.
- Update config files.
- rpm/kernel-source.spec.in,kernel-binary.spec.in, config.conf: Add trace
  flavor
- patches.fixes/ia64-sparse-fixes.diff: ia64-kvm: fix sparse
  warnings.
- patches.xen/xen3-fixup-common: rediff
- patches.xen/xen3-auto-common.diff: rediff
- patches.xen/xen3-patch-2.6.21: rediff
- patches.xen/xen3-patch-2.6.26: rediff
- patches.trace/rcu-read-sched.patch
- patches.trace/markers-use-rcu-read-lock-sched.patch
- patches.trace/tracepoints.patch
- patches.trace/tracepoints-use-table-size-macro.patch
- patches.trace/tracepoints-documentation.patch
- patches.trace/tracepoints-tracepoint-synchronize-unregister.patch
- patches.trace/tracepoints-documentation-fix-teardown.patch
- patches.trace/tracepoints-samples.patch
- patches.trace/tracepoints-samples-fix-teardown.patch
- patches.trace/lttng-instrumentation-irq.patch
- patches.trace/lttng-instrumentation-scheduler.patch
- patches.trace/lttng-instrumentation-timer.patch
- patches.trace/lttng-instrumentation-kernel.patch
- patches.trace/lttng-instrumentation-filemap.patch
- patches.trace/lttng-instrumentation-swap.patch
- patches.trace/lttng-instrumentation-memory.patch
- patches.trace/lttng-instrumentation-page_alloc.patch
- patches.trace/lttng-instrumentation-hugetlb.patch
- patches.trace/lttng-instrumentation-net.patch
- patches.trace/lttng-instrumentation-ipv4.patch
- patches.trace/lttng-instrumentation-ipv6.patch
- patches.trace/lttng-instrumentation-socket.patch
- patches.trace/lttng-instrumentation-fs.patch
- patches.trace/lttng-instrumentation-ipc.patch
- patches.trace/ftrace-port-to-tracepoints.patch
- patches.trace/ftrace-framepointer.diff
* Tue Sep 23 2008 jjolly@suse.de
- patches.arch/s390-01-03-cmm2-v2.patch: kernel (new function):
  Collaborative Memory Management Stage II (bnc#417244)
- patches.xen/xen3-auto-common.diff: Modified patch to allow for
  the new patch
* Tue Sep 23 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Enable sparse checking and section
  mismatch checking.
* Tue Sep 23 2008 jeffm@suse.de
- patches.kernel.org/arch-include-asm-fixes: kbuild: Properly
  handle arch/$arch/include/asm (bnc#427473).
* Mon Sep 22 2008 jeffm@suse.de
- patches.fixes/ext2-avoid-printk-flood-with-dir-corruption:
  ext2: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
- patches.fixes/ext3-avoid-printk-flood-with-dir-corruption:
  ext3: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
* Mon Sep 22 2008 jeffm@suse.de
- Update to 2.6.27-rc7.
  - Eliminated 2 patches.
  - patches.arch/s390-01-04-fcpperf-4.patch: Fixed up context.
* Mon Sep 22 2008 trenn@suse.de
  Workaround for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
  Commented out for now, possibly to be included later
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  cpufreq: Add a cpu parameter to __cpufreq_driver_getavg()..
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  cpufreq,ondemand: Use get_cpu_idle_time_us() to get
  micro-accounted idle information.
- patches.drivers/cpufreq_change_load_calculation_2.patch:
  cpufreq, ondemand: Change the load calculation, optimizing
  for dependent cpus.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  export get_cpu_idle_time_us() .
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  cpufreq,ondemand: Prepare changes for doing micro-accounting.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  cpufreq, ondemand: Use a parameter for down differential.
  Added CONFIG_PCIEASPM for rt, xen, powerpc and IA64 to be more
  consistent across different kernel flavors as suggested on the
  kernel list:
- Update config files.
* Mon Sep 22 2008 hare@suse.de
- patches.drivers/open-fcoe-libfc: Fix build error on IA64.
- patches.fixes/scsi-terminate-target-reset: Target reset hangs
  (bnc#427267).
- supported.conf: Update to include supported SCSI adapters.
* Fri Sep 19 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Re-enable after removing FTRACE
  related change.
- Update x86 non-debug config files: Turn off FRAME_POINTER and FTRACE.
* Fri Sep 19 2008 nfbrown@suse.de
- patches.fixes/md-Allow-metadata_version-to-be-updated-for-externa.patch:
  md: Allow metadata_version to be updated for externally managed
  metadata. (FATE#304218).
- patches.fixes/md-Don-t-try-to-set-an-array-to-read-auto-if-it-i.patch:
  md: Don't try to set an array to 'read-auto' if it is already
  in that state. (FATE#304218).
* Thu Sep 18 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Disable.
- Re-enable CONFIG_FRAME_POINTER in x86 config files.
* Thu Sep 18 2008 jbeulich@novell.com
- Update i386 and x86-64 config files (disable CONFIG_FRAME_POINTER in
  non-debug configs).
- patches.suse/stack-unwind: Add missing put_cpu()-s for x86-64.
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
* Thu Sep 18 2008 hare@suse.de
- Update config files.
- patches.drivers/open-fcoe-driver: fcoe: Fibre Channel over
  Ethernet driver (FATE#303913).
- patches.drivers/open-fcoe-libfc: libfc: a modular software
  Fibre Channel implementation (FATE#303913).
- patches.drivers/open-fcoe-header-files: FC protocol definition
  header files (FATE#303913).
- patches.drivers/open-fcoe-dcb-support: FCoE: Add DCB support
  (FATE#303913).
- patches.drivers/ixgbe-fcoe-bugfixes: ixgbe: Bugfixes for FCoE.
- patches.fixes/vlan-gso-size-fix: vlan: device not reading gso
  max size of parent. (FATE#303913).
- patches.fixes/pkt_action-skbedit: pkt_action: add new action
  skbedit.
- patches.fixes/pkt_sched_multiq_support: pkt_sched: Add
  multiqueue scheduler support (FATE#303913).
- supported.conf: Update to include FCoE and device_handler
  modules
* Wed Sep 17 2008 jbeulich@novell.com
- supported.conf: adjust name of ide-cd (is now ide-cd_mod).
* Wed Sep 17 2008 hare@suse.de
- patches.drivers/qla2xxx-defer-risc-interrupt-enablement:
  qla2xxx: Defer enablement of RISC interrupts until ISP
  initialization completes (FATE#304113).
- patches.drivers/qla2xxx-8.02.01-k8-update: Update qla2xxx to
  8.02.01-k8 (FATE#304113).
* Wed Sep 17 2008 hare@suse.de
- patches.fixes/scsi-retry-hardware-error: make scsi_check_sense
  HARDWARE_ERROR return ADD_TO_MLQUEUE on retry (FATE#304042)
* Tue Sep 16 2008 olh@suse.de
- disable CONFIG_SPARSEMEM_VMEMMAP on ppc64 to allow memory remove
  (bnc#417537)
* Mon Sep 15 2008 jkosina@suse.de
- Update config files (build elousb driver as module)
- patches.drivers/elousb.patch: Elo USB touchscreen driver
  (FATE#304972).
* Mon Sep 15 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: Abort queued requests for
  multipath (FATE#304151).
* Mon Sep 15 2008 hare@suse.de
- Update config files: Disable CONFIG_OCFS2_COMPAT_JBD
* Mon Sep 15 2008 hare@suse.de
- patches.xen/xen-scsifront-block-timeout-update: Update XEN
  scsifront driver to request timeouts.
* Mon Sep 15 2008 sdietrich@suse.de
- Update config files: Enable GROUP_SCHED, FAIR_GROUP_SCHED,
  RT_GROUP_SCHED, CGROUP_SCHED
* Mon Sep 15 2008 hare@suse.de
- patches.drivers/block-timeout-handling: Fix typo.
* Fri Sep 12 2008 duwe@suse.de
- Add LED driver for SGI "UV" systems (FATE#304268)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/bdev-resize-added-flush_disk: Added
  flush_disk to factor out common buffer cache flushing code
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-adjust-block-device-size:
  Adjust block device size after an online resize of a
  disk. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-call-flush_disk: Call flush_disk()
  after detecting an online resize. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-check-for-device-resize:
  Check for device resize when rescanning partitions
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-sd-driver-calls: SCSI sd driver
  calls revalidate_disk wrapper (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-wrapper-for-revalidate_disk:
  Wrapper for lower-level revalidate_disk
  routines. (FATE#302348,FATE#303786).
- patches.drivers/block-timeout-handling: block: unify request
  timeout handling (FATE#304151,bnc#417544).
- patches.fixes/scsi-misc-git-update: SCSI misc fixes
  (FATE#303485,FATE#303484).
- patches.fixes/scsi-enhance-error-codes: Separate failfast into
  multiple bits (FATE#303485,FATE#303484).
- patches.suse/rq-based-block-layer: rediff.
- patches.suse/rq-based-multipath-functions: rediff.
- patches.suse/no-partition-scan: rediff.
* Fri Sep 12 2008 hare@suse.de
- patches.fixes/scsi-misc-git-update: SCSI misc fixes,
  required by the driver updates (FATE#303485,FATE#303484)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.1-update: Update lpfc to 8.2.8.1
  (bnc#420767).
- patches.drivers/lpfc-8.2.8-update: Emulex lpfc driver update
  to 8.2.8 (FATE#303485,bnc#420767).
* Fri Sep 12 2008 bwalle@suse.de
- patches.arch/ia64-kdump_proc_iomem.diff:
  IA64: assign a distinguishable label to uncached memory in
  /proc/iomem (to fix MCA on kdump boot).
* Thu Sep 11 2008 jack@suse.cz
  Latest ext4 fixes from ext4 patch queue:
- patches.fixes/ext4-Add-inode-to-journal-handle-after-block-alloca.patch:
  ext4: Don't add the inode to journal handle until after the
  block is allocated (fate#303783).
- patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors:
  ext4: add missing unlock in ext4_check_descriptors() on error
  path (fate#303783).
- patches.fixes/ext4-Add-percpu-dirty-block-accounting.patch:
  ext4: Add percpu dirty block accounting. (fate#303783).
- patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully:
  ext4: fix #11321: create /proc/ext4/*/stats more carefully
  (fate#303783).
- patches.fixes/ext4_fix_longlong_checkpatch_issues: ext4:
  Fix long long checkpatch warnings (fate#303783).
- patches.fixes/ext4_fix_printk_checkpatch_issues: ext4:
  Add printk priority levels to clean up checkpatch warnings
  (fate#303783).
- patches.fixes/ext4_fix_whitespace_checkpatch_issues: ext4:
  Fix whitespace checkpatch warnings/errors (fate#303783).
- patches.fixes/ext4_i_disksize_lock_race_fix.patch: ext4:
  Properly update i_disksize. (fate#303783).
- patches.fixes/ext4_invalidate_pages_when_delalloc_alloc_fail.patch:
  ext4: invalidate pages if delalloc block allocation
  fails. (fate#303783).
- patches.fixes/ext4-Make-sure-all-the-block-allocation-paths-reser.patch:
  ext4: Make sure all the block allocation paths reserve blocks
  (fate#303783).
- patches.fixes/ext4_nonmballoc_reservation_ENOSPC_fix.patch:
  ext4: Fix ext4 nomballoc allocator for ENOSPC (fate#303783).
- patches.fixes/ext4-Retry-block-allocation-if-we-have-free-blocks.patch:
  ext4: Retry block allocation if we have free blocks left
  (fate#303783).
- patches.fixes/ext4-Retry-block-reservation.patch: ext4: Retry
  block reservation (fate#303783).
- patches.fixes/ext4-Signed-arithematic-fix.patch: ext4: Signed
  arithematic fix (fate#303783).
- patches.fixes/ext4-Switch-to-non-delalloc-mode-when-we-are-low-on.patch:
  ext4: Switch to non delalloc mode when we are low on free
  blocks count. (fate#303783).
- patches.fixes/ext4_truncate_block_allocated_on_a_failed_ext4_write_begin.patch:
  ext4: truncate block allocated on a failed ext4_write_begin
  (fate#303783).
- patches.fixes/ext4_update-flex-bg-counters-when-resizing:
  Update flex_bg free blocks and free inodes counters when
  resizing. (fate#303783).
- patches.fixes/percpu_counter_sum_cleanup.patch: percpu counter:
  clean up percpu_counter_sum_and_set() (fate#303783).
* Thu Sep 11 2008 bwalle@suse.de
- Enable KDB for i386 and x86_64 in "default" and "pae"
  configuration with CONFIG_KDB_OFF set to "y" (FATE#303971).
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC=2 in all configurations
  that have KDB enabled.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  enable PID_NS and USER_NS
  (FATE#303785, FATE#304371)
* Thu Sep 11 2008 jeffm@suse.de
- Update config files.
  - Enabled CONFIG_XFRM_SUB_POLICY (FATE#303781)
* Thu Sep 11 2008 mfasheh@suse.com
- Added POSIX File Locks support for Ocfs2  (FATE#110294)
  - patches.suse/ocfs2-POSIX-file-locks-support.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 JBD2 Support  (FATE#302877)
  - patches.suse/ocfs2-Limit-inode-allocation-to-32bits.patch
  - patches.suse/ocfs2-Add-the-inode64-mount-option.patch
  - patches.suse/ocfs2-Switch-over-to-JBD2.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 Extended Attributes Support (FATE#302067)
  - patches.suse/ocfs2-Modify-ocfs2_num_free_extents-f.patch
  - patches.suse/ocfs2-Use-ocfs2_extent_list-instead-o.patch
  - patches.suse/ocfs2-Abstract-ocfs2_extent_tree-in-b.patch
  - patches.suse/ocfs2-Make-high-level-btree-extend-co.patch
  - patches.suse/ocfs2-Add-the-basic-xattr-disk-layout-in-ocf.patch
  - patches.suse/ocfs2-Add-helper-function-in-uptodate.patch
  - patches.suse/ocfs2-Add-extent-tree-operation-for-x.patch
  - patches.suse/ocfs2-reserve-inline-space-for-extend.patch
  - patches.suse/ocfs2-Add-extended-attribute-support.patch
  - patches.suse/ocfs2-Add-xattr-index-tree-operations.patch
  - patches.suse/ocfs2-Add-xattr-bucket-iteration-for.patch
  - patches.suse/ocfs2-Add-xattr-lookup-code-xattr-btr.patch
  - patches.suse/ocfs2-Optionally-limit-extent-size-in.patch
  - patches.suse/ocfs2-Enable-xattr-set-in-index-btree.patch
  - patches.suse/ocfs2-Delete-all-xattr-buckets-during.patch
  - patches.suse/ocfs2-Add-incompatible-flag-for-exten.patch
  - patches.suse/ocfs2-fix-printk-format-warnings.patch
  - patches.suse/ocfs2-Prefix-the-extent-tree-operations-structure.patch
  - patches.suse/ocfs2-Prefix-the-ocfs2_extent_tree-structure.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-get-put-instead-of-all.patch
  - patches.suse/ocfs2-Make-private-into-object-on-ocfs2_extent_.patch
  - patches.suse/ocfs2-Provide-the-get_root_el-method-to-ocfs2_ext.patch
  - patches.suse/ocfs2-Use-struct-ocfs2_extent_tree-in-ocfs2_num_fre.patch
  - patches.suse/ocfs2-Determine-an-extent-tree-s-max_leaf_clusters.patch
  - patches.suse/ocfs2-Create-specific-get_extent_tree-functions.patch
  - patches.suse/ocfs2-Add-an-insertion-check-to-ocfs2_extent_tree_o.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-the-first-class-repres.patch
  - patches.suse/ocfs2-Comment-struct-ocfs2_extent_tree_operations.patch
  - patches.suse/ocfs2-Change-ocfs2_get_-_extent_tree-to-ocfs2_ini.patch
  - patches.suse/ocfs2-bug-fix-for-journal-extend-in-xattr.patch
  - patches.suse/ocfs2-Resolve-deadlock-in-ocfs2_xattr_free_.patch
  - patches.suse/ocfs2-Add-xattr-mount-option-in-ocfs2_show_options.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/jbd2-create-proc-entry-fix.patch
  jbd2: Create proc entry with bdevname+i_ino.
  (FATE#302877)
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/dlm-allow-multiple-lockspaces.patch
  dlm: allow multiple lockspace creates
  (FATE#110294)
* Thu Sep 11 2008 schwab@suse.de
- Update kdb patches.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  change CONFIG_NODES_SHIFT from 6 to 9
  (FATE#304261)
* Wed Sep 10 2008 trenn@suse.de
- Update config files.
  Added: CONFIG_PCIEASPM
* Wed Sep 10 2008 kkeil@suse.de
- patches.drivers/e1000e_add_82574L.patch: e1000e: add support
  for new 82574L part.
- patches.drivers/e1000e_add_ICH9_BM.patch: e1000e: add support
  for the 82567LM-4 device.
- patches.drivers/e1000e_add_LOM_devices.patch: e1000e: add
  support for 82567LM-3 and 82567LF-3 (ICH10D).
  (FATE#303916)
* Wed Sep 10 2008 hare@suse.de
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697)
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/ipmi-section-conflict.diff: ipmi: Fix
  section type conflicts.
- patches.kernel.org/psmouse-section-conflict.diff: psmouse:
  fix section type conflict.
- patches.kernel.org/carmine-section-mismatch: video: Fix section
  mismatch in carminefb.
- patches.kernel.org/md-section-conflict: md: Fix section
  conflicts.
- patches.kernel.org/setup_APIC_timer-section-mismatch: x86:
  Fix section conflict with kvm_setup_secondary_clock.
* Wed Sep 10 2008 trenn@suse.de
- patches.arch/thinkpad_fingers_off_backlight_igd.patch:
  Serve ThinkPad IGD devices backlight functionality through
  thinkpad_acpi (fate #302883).
- supported.conf: Add most important laptop drivers as supported:
    kernel/drivers/misc/asus_laptop
    kernel/drivers/misc/eeepc-laptop
    kernel/drivers/misc/msi-laptop
    kernel/drivers/misc/fujitsu-laptop
    kernel/drivers/acpi/wmi
    kernel/drivers/misc/hp-wmi
* Wed Sep 10 2008 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Fixed up
  some section conflicts.
* Wed Sep 10 2008 jeffm@suse.de
- Update to 2.6.27-rc6.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Added missing netfilter modules.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Updated netfilter module names.
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: Updated header.
* Wed Sep 10 2008 jkosina@suse.de
- Update config files: support more than 4 serial ports
  (FATE#303314)
* Wed Sep 10 2008 olh@suse.de
- set CONFIG_CMM=y instead of =m to simplify virtual partition memory
  (bnc#417554)
* Tue Sep  9 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: add Recommends: kerneloops
* Tue Sep  9 2008 olh@suse.de
- Updated to 2.6.27-rc5-git10
* Mon Sep  8 2008 olh@suse.de
- Updated to 2.6.27-rc5-git9
* Fri Sep  5 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: system call
  notification with self_ptrace (bnc#417299)
- patches.arch/s390-01-02-dcss-64-v2.patch: dcssblk (new function):
  Add support for >2G DCSS and stacked contiguous DCSS support.
  (bnc#417246)
- patches.arch/s390-01-04-fcpperf-{1-4}.patch: (kernel):FCP -
  Performance Data colletion & analysis (bnc#417243)
* Fri Sep  5 2008 olh@suse.de
- add patches.fixes/usb-hcd-interrupt-shared.patch
  fix interrupt handling for shared irqs, for PS3 (bnc#409961)
* Fri Sep  5 2008 olh@suse.de
- Updated to 2.6.27-rc5-git7
* Thu Sep  4 2008 olh@suse.de
- build with CONFIG_POWER4_ONLY (bnc#417566)
  this disables support for POWER3 and RS64 cpus
* Thu Sep  4 2008 jkosina@suse.de
- switch from Reno to Cubic as default TCP congestion algorithm
  (bnc#422825)
* Thu Sep  4 2008 bwalle@suse.de
- Update KDB patches. Fix build on x86_64-debug.
* Wed Sep  3 2008 jeffm@suse.de
- mark crc-t10dif as supported
* Wed Sep  3 2008 olh@suse.de
- mark pata_pdc2027x as supported
* Wed Sep  3 2008 olh@suse.de
- mark spidernet as supported
* Wed Sep  3 2008 olh@suse.de
- mark ehea as supported
* Wed Sep  3 2008 trenn@suse.de
- supported.conf:
  Mark dock (libata depends on it), bay, acpi_memhotplug, hpilo
  as supported
  Remove or adjust supported laptop drivers that went from
  drivers/acpi to drivers/misc
* Wed Sep  3 2008 hare@suse.de
- supported.conf: Mark virtio modules as supported.
* Tue Sep  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc5 and c/s 651.
* Tue Sep  2 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v2.patch: kernel
  (new function): System call notification with self_ptrace
  (bnc#417299,FATE#304021)
* Mon Sep  1 2008 agruen@suse.de
- File capabilities: replace our no_file_caps patch with what is
  supposed to end up in 2.6.28.
* Mon Sep  1 2008 bwalle@suse.de
- patches.arch/ia64-node_mem_map-node_start_pfn.diff:
  Fix memory map for ia64/discontmem for kdump.
* Mon Sep  1 2008 olh@suse.de
- Updated to 2.6.27-rc5-git2
* Fri Aug 29 2008 jeffm@suse.de
- Updated to 2.6.27-rc5.
  - Eliminated 2 patches.
  - KDB has an incompatible change on x86_64, so kernel-debug
    will fail there.
* Fri Aug 29 2008 olh@suse.de
- update message in post.sh to display also the rpm FLAVOR
* Thu Aug 28 2008 olh@suse.de
- update patches.suse/dm-raid45-2.6.25-rc2_20080221.patch
  rename rh_init to region_hash_init to avoid conflict
  with existing powerpc symbol on powerpc
* Thu Aug 28 2008 olh@suse.de
- disable musb, not useful, does not compile
* Tue Aug 26 2008 trenn@suse.de
  Vendor specific drivers vs generic video driver.
  Distinguish which ACPI driver should do backlight switching.
  This patch series is queued up for 2.6.28 in the ACPI branch:
- patches.arch/0000-ACPI-video-Ignore-devices-not-present.patch:
  ACPI: video: Ignore devices that aren't present in hardware.
- patches.arch/0001-Check-for-ACPI-backlight-support.patch: Check
  for ACPI backlight support otherwise use vendor ACPI drivers.
- patches.arch/0002-Acer-WMI-fingers-off-backlight-video.ko.patch:
  Acer-WMI: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0003-Asus-acpi-fingers-off-backlight.patch:
  asus-acpi: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0004-Compal-fingers-off-backlight.patch: compal:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0005-eeepc-laptop-fingers-off.patch: eeepc-laptop:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0006-fujitsu-laptop-fingers-off-backlight.patch:
  fujitsu-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0007-msi-laptop-fingers-off-backlight.patch:
  msi-laptop: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0009-thinkpad_acpi-fingers-off-backlight.patch:
  thinkpad_acpi: fingers off backlight if video.ko is serving
  this functionality.
  I had to refresh these. While one patch was broken,
  two lines were missing, "patch" from 11.0 still worked, while
  "patch" from 10.3 did not:
- patches.xen/add-console-use-vt: add console_use_vt.
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  kexec: Move asm segment handling code to the assembly file
  (i386).
* Mon Aug 25 2008 jeffm@suse.de
- Disabled patches.kernel.org/ia64-asm-nr-irqs
* Mon Aug 25 2008 jeffm@suse.de
- patches.fixes/pseries-compile-fix: pseries: compile fix.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/musb-powerpc-conflict: musb: compile fix
  for powerpc.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/ia64-asm-nr-irqs: ia64: nr-irqs.h generation
  should place it in arch/../asm.
* Mon Aug 25 2008 jeffm@suse.de
- Update config files.
* Mon Aug 25 2008 jeffm@suse.de
- Updated to 2.6.27-rc4.
  - Refreshed context.
* Mon Aug 25 2008 trenn@suse.de
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch:
  x86, pci: introduce pci=noioapicquirk kernel cmdline option.
  Mysterious patch problem in include/asm-x86/pci.h
- patches.fixes/acpi-clear-wake-status.patch: Clear wak_sts
  register on resume.
* Mon Aug 25 2008 trenn@suse.de
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  Delete.
* Mon Aug 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc4.
- patches.xen/xen-x86_64-dump-user-pgt: dump the correct page
  tables for user mode faults.
- patches.xen/xen-x86_64-pgd-alloc-order: don't require order-1
  allocations for pgd-s.
- patches.xen/xen-x86_64-pgd-pin: make pinning of pgd pairs
  transparent to callers.
- patches.xen/xen-blktap-write-barriers: blktap: Write Barriers.
- patches.xen/xen-x86-pmd-handling: consolidate pmd/pud/pgd entry
  handling.
- patches.xen/xen-x86-bigmem: fix issues with the assignment of
  huge amounts of memory.
- patches.xen/xen-msix-restore: print at least a message if MSI-X
  restore failed.
- config.conf: Re-enable Xen.
- patches.xen/sfc-i2c: Delete.
- Update config files.
* Fri Aug 22 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Adjust and re-enable.
- Update config files.
* Tue Aug 19 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: Delete.
* Tue Aug 19 2008 jeffm@suse.de
- Removed unused patches.
* Tue Aug 19 2008 tiwai@suse.de
- Update config files: Use CONFIG_INPUT_PCSPKR=m (bnc#225221)
* Mon Aug 18 2008 schwab@suse.de
- Update config files.
* Mon Aug 18 2008 schwab@suse.de
- Update kdb patches.
* Fri Aug 15 2008 tiwai@suse.de
- patches.arch/ppc-ipic-suspend-without-83xx-fix: Fix build_error
  without CONFIG_PPC_83xx.
- Update config files.
* Fri Aug 15 2008 tiwai@suse.de
- Update config files: disable CONFIG_IPIC for ppc/default and
  vanilla again to fix build
* Fri Aug 15 2008 tiwai@suse.de
- rpm/kernel-binary.spec.in: fix build without firmware files
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/no-include-asm: kbuild: correctly link
  include/asm in external builds.
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/ath9k-workaround-gcc-ICE-again-on-powerpc:
  ath9k: work around gcc ICE again.
* Thu Aug 14 2008 jeffm@suse.de
- patches.suse/novfs-gregorian-day-fix: novfs: Fix GregorianDay
  conflict.
* Thu Aug 14 2008 jeffm@suse.de
- Enabled patches.kernel.org/firmware-path
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Fixed duplicate
  export of security_inode_permission.
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Add missing
  stub for security_path_permission when CONFIG_SECURITY_APPARMOR=n
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: firmware: Allow
  release-specific firmware dir.
- rpm/kernel-binary.spec.in: Add firmware files.
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/ia64-export-cpu_core_map: ia64: Export
  cpu_core_map for topology_core_siblings.
* Thu Aug 14 2008 jeffm@suse.de
- Updated to 2.6.27-rc3.
  - AppArmor mostly merged. There may be some hiccups.
  - Xen and RT temporarily disabled for merging.
  - 17 patches eliminated.
* Thu Aug 14 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  ftrace: fix elevated preempt_count in wakeup-tracer.
* Fri Aug  8 2008 hare@suse.de
- Update config files for RT kernel to activate SCSI
  device handler.
* Fri Aug  8 2008 jbeulich@novell.com
- patches.xen/xen3-fixup-common, patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.24, patches.xen/xen3-patch-2.6.25: Fix
  a couple of bugs and inconsistencies.
* Fri Aug  8 2008 schwab@suse.de
- Fix reference to $RPM_BUILD_ROOT in makefiles.
* Fri Aug  8 2008 hare@suse.de
- patches.fixes/dm-mpath-hp-sw.patch: Delete.
- Update config files.
- patches.fixes/dm-2.6.27-update: Upstream device-mapper patches
  (FATE#302108).
- patches.fixes/scsi_dh-2.6.27-update: SCSI device handler update
  (FATE#302269,FATE#303696,FATE#303754,FATE#304125).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  block layer changes (FATE#302108).
- patches.suse/rq-based-dm-interface: rq-based multipathing:
  device-mapper interface (FATE#302108).
- patches.suse/rq-based-multipath-functions: rq-based
  multipathing: request-based functions to multipath
  (FATE#302108).
* Thu Aug  7 2008 jbeulich@novell.com
- Update Xen patches to c/s 623.
- patches.xen/sfc-network-driver: Delete.
- patches.xen/xen-balloon-hvm-min: Delete.
- patches.xen/xen-netfront-flip-prod: Delete.
- patches.xen/xen-x86_64-init-cleanup: Delete.
- patches.xen/sfc-i2c: sfc: Use kernel I2C system and i2c-algo-bit
  driver (disabled).
- patches.xen/sfc-driverlink: Solarflare: Resource driver (disabled).
- Update Xen config files.
* Wed Aug  6 2008 olh@suse.de
- add patches.suse/ppc-no-LDFLAGS_MODULE.patch
  do not link external modules against arch/powerpc/lib/crtsavres.o
* Tue Aug  5 2008 jeffm@suse.de
- patches.fixes/reiserfs-commit-ids-unsigned-ints: reiserfs:
  audit transaction ids to always be unsigned ints (bnc#410847).
* Tue Aug  5 2008 jeffm@suse.de
- README.BRANCH: Took ownership of 11.1 tree.
* Tue Aug  5 2008 jeffm@suse.de
- README: Changed w3d links to wiki links.
* Tue Aug  5 2008 ghaskins@suse.de
  Fixed misnamed rt_trace to rt_timing
- config/x86_64/rt_trace: Delete.
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Added x86_64/rt_trace kernel flavor (based on ftrace)
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Fix rtmutex-tester build problem with rt_debug
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Remove version.patch to stop build breakage
* Tue Aug  5 2008 jjohansen@suse.de
- update apparmor patches with fixes for
  - broken getcwd (bnc#413915)
  - ref counting bug in getcwd and d_namespace_path when used
    on disconnected paths (bnc#414607)
  - typeo in patches that keep selinux from compiling (bnc#414609)
  - incorporate smack patch into base apparmor patches, so
    that smack can be built (bnc#414610)
* Tue Aug  5 2008 jslaby@suse.de
- patches.fixes/ath5k-fix-memory-corruption.patch: Ath5k: fix
  memory corruption (bnc#414635).
- patches.fixes/ath5k-kill-tasklets-on-shutdown.patch: Ath5k:
  kill tasklets on shutdown (bnc#414638).
* Mon Aug  4 2008 gregkh@suse.de
- README.BRANCH: added file.
* Mon Aug  4 2008 olh@suse.de
- disable CONFIG_SECURITY_ROOTPLUG because /init in initrd will
  not run if USB is compiled in and a specific USB device is not
  present
* Mon Aug  4 2008 jslaby@suse.de
- patches.fixes/tpm-write-data-types.patch: tpm: Use correct
  data types for sizes in tpm_write() and tpm_read() (bnc#400211).
* Fri Aug  1 2008 ghaskins@suse.de
  PI rework v0.5 and a fix from upstream for 26-rt1
- patches.rt/26-rt1-chirag.patch: This patch should solve some
  of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: add generalized
  priority-inheritance interface.
- patches.rt/tie-pi-into-task.patch: sched: add the basic PI
  infrastructure to the task_struct.
- patches.rt/rtmutex-initialize-waiters.patch: rtmutex: formally
  initialize the rt_mutex_waiters.
- patches.rt/rtmutex-add_readers.patch: RT: wrap the rt_rwlock
  "add reader" logic.
- patches.rt/rtmutex-use-runtime-init.patch: rtmutex: use runtime
  init for rtmutexes.
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: rtmutex:
  pi-boost locks as late as possible.
* Fri Aug  1 2008 schwab@suse.de
- Reenable EFI_RTC.
* Fri Aug  1 2008 trenn@suse.de
- Update config files.
  Unset on forgotten archs:
  CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS
* Fri Aug  1 2008 trenn@suse.de
- patches.fixes/x86_hpet_amd_quirk.patch: Workaround a hpet BIOS
  bug which is common on latest AMD driven boards (bnc#387053).
* Fri Aug  1 2008 sassmann@suse.de
  Add boot interrupt patches from linux-2.6-tip
- patches.arch/x86-acpi-reroute-PCI-interrupt-to-legacy-boot-interrupt.patch
- patches.arch/x86-add-PCI-IDs-for-devices-that-need-boot-irq-quirk.patch
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch
- patches.arch/x86-disable-broadcomm-boot-interrupt-generation.patch
- patches.arch/x86-disable-intel-boot-interrupt-generation.patch
- patches.arch/x86-introduce-config-option-for-pci-reroute-quirks.patch
- patches.arch/x86-introduce-pci-ioapicreroute-kernel-cmdline.patch
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch
- Update config files.
  * reroute of boot interrupts is enabled for RT only!
* Thu Jul 31 2008 sdietrich@suse.de
  Update to 2.6.26-rt1:
- config.conf: Enable i386/x86_64 - RT / RT_debug
- Update config files:
  * Sync to default config.
  * Disable (broken):
  - Novell Netware Filesystem support (novfs) (EXPERIMENTAL) (NOVFS)
  - ISP 1760 HCD support (USB_ISP1760_HCD)
  - KDB
  - QLogic InfiniPath Driver (INFINIBAND_IPATH)
  Remove obsolete patches:
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-omap-03.patch: Delete.
- patches.rt/arm-omap-04.patch: Delete.
- patches.rt/disable-sched-rt-groups.patch: Delete.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch: Delete.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Delete.
- patches.rt/drivers-edac-new-amd64.patch: Delete.
- patches.rt/drivers-edac-new-k8-rev-f.patch: Delete.
- patches.rt/drivers-edac-prevent-potential-printk-storm: Delete.
- patches.rt/drivers-edac-test_device.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/fix-alternate_node_alloc.patch: Delete.
- patches.rt/fix-irq-flags-size.patch: Delete.
- patches.rt/foo.patch: Delete.
- patches.rt/ftrace-add-nr_syscalls.patch: Delete.
- patches.rt/ftrace-alloc-pages.patch: Delete.
- patches.rt/ftrace-cpu-clock-update.patch: Delete.
- patches.rt/ftrace-debug-use-preempt-disable-notrace.patch:
  Delete.
- patches.rt/ftrace-direct-calls.patch: Delete.
- patches.rt/ftrace-disable-daemon.patch: Delete.
- patches.rt/ftrace-dont-use-raw-irq-save.patch: Delete.
- patches.rt/ftrace-eventtrace-fixup.patch: Delete.
- patches.rt/ftrace-filter-functions.patch: Delete.
- patches.rt/ftrace-fix-ip.patch: Delete.
- patches.rt/ftrace-flip-fix.patch: Delete.
- patches.rt/ftrace-handle-time-outside-of-lockdep.patch: Delete.
- patches.rt/ftrace-irqsoff-smp-processor-id-fix.patch: Delete.
- patches.rt/ftrace-lockdep-notrace-annotations.patch: Delete.
- patches.rt/ftrace-max-update-fixes.patch: Delete.
- patches.rt/ftrace-move-memory-management-to-generic.patch:
  Delete.
- patches.rt/ftrace-nop-calls.patch: Delete.
- patches.rt/ftrace-peterz-cpu_clock.patch: Delete.
- patches.rt/ftrace-remove-max-printks.patch: Delete.
- patches.rt/ftrace-safe-traversal-hlist.patch: Delete.
- patches.rt/ftrace-stop-function-trace-fix.patch: Delete.
- patches.rt/ftrace-unlock-mutex-in-output.patch: Delete.
- patches.rt/ftrace-update-cnt-stat-fix.patch: Delete.
- patches.rt/ftracer-build-fix.patch: Delete.
- patches.rt/futex-performance-hack-sysctl-fix.patch: Delete.
- patches.rt/futex-performance-hack.patch: Delete.
- patches.rt/git-ignore-module-markers.patch: Delete.
- patches.rt/irq-flags-unsigned-long.patch: Delete.
- patches.rt/kernel-bug-after-entering-something-from-login.patch:
  Delete.
- patches.rt/kthread-cpus-allowed-init.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/netfilter-more-debugging.patch: Delete.
- patches.rt/page-alloc-use-real-time-pcp-locking-for-page-draining.patch:
  Delete.
- patches.rt/pcounter-percpu-protect.patch: Delete.
- patches.rt/percpu-locked-powerpc-fixups-a6.patch: Delete.
- patches.rt/powerpc-rearrange-thread-flags-to-work-with-andi-instruction.patch:
  Delete.
- patches.rt/ppc-add-mcount.patch: Delete.
- patches.rt/ppc-add-ppc32-mcount.patch: Delete.
- patches.rt/ppc-mark-notrace-mainline.patch: Delete.
- patches.rt/ppc-mcount-dummy-functions.patch: Delete.
- patches.rt/ppc-rename-xmon-mcount.patch: Delete.
- patches.rt/ppc-select-mcount.patch: Delete.
- patches.rt/preempt-irqs-ppc-celleb-beatic-eoi.patch: Delete.
- patches.rt/preempt-irqs-softirq-in-hardirq.patch: Delete.
- patches.rt/preempt-realtime-powerpc-a7.patch: Delete.
- patches.rt/preempt-realtime-ppc-more-resched-fixups.patch:
  Delete.
- patches.rt/preempt-realtime-ppc-need-resched-delayed.patch:
  Delete.
- patches.rt/preempt-realtime-sh.patch: Delete.
- patches.rt/preempt-realtime-supress-cpulock-warning.patch:
  Delete.
- patches.rt/rcu-preempt-trace-markers-1.patch: Delete.
- patches.rt/rcu-preempt-trace-markers-2.patch: Delete.
- patches.rt/rcu-various-fixups.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-delayed-resched.patch: Delete.
- patches.rt/rt-mutex-drop-generic-TIF_NEED_RESCHED_DELAYED.patch:
  Delete.
- patches.rt/rt-time-starvation-fix.patch: Delete.
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/sched-fix-rt-task-wakeup.patch: Delete.
- patches.rt/sched-fix-sched-fair-wakeup.patch: Delete.
- patches.rt/sched-rt-push-only-new.patch: Delete.
- patches.rt/schedule_on_each_cpu-enhance-rt.patch: Delete.
- patches.rt/tasklet-fix-preemption-race.patch: Delete.
- patches.rt/tasklet-more-fixes.patch: Delete.
- patches.rt/time-gcc-linker-error.patch: Delete.
- patches.rt/tracer-use-sched-clock.patch: Delete.
- patches.rt/write-try-lock-irqsave.patch: Delete.
- patches.rt/x86-delay-enable-preempt-tglx.patch: Delete.
  Introduce 2.6.26-RT1:
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.26-RT
  radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.26-RT
  mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.26-RT
  mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.26-RT
  mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.26-RT
  mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.26-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.26-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.26-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.26-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.26-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.26-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.26-RT
  Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.26-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.26-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.26-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.26-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.26-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.26-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.26-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.26-RT.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.26-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.26-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.26-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.26-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.26-RT
  floppy: suspend/resume fix.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.26-RT
  rt: remove call to stop tracer.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.26-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.26-RT
  ftrace: define function trace nop.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.26-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.26-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.26-RT
  ftrace: trace sched.c.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.26-RT
  ftrace: avoid lockdep recursion.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.26-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.26-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.26-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.26-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.26-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.26-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.26-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.26-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.26-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.26-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.26-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.26-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.26-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.26-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.26-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.26-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.26-RT
  ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.26-RT
  lockdep: lock_set_subclass - reset a held lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.26-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.26-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.26-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.26-RT
  lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.26-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.26-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.26-RT
  RT: change from raw_spinlock_t to __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.26-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.26-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.26-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.26-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.26-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.26-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.26-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.26-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.26-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.26-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.26-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.26-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.26-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.26-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.26-RT
  x86_64: do not enable the NMI watchdog by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.26-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.26-RT
  local_bh_enable() is safe for irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.26-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.26-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.26-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.26-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.26-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.26-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.26-RT.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.26-RT
  don't trace early init functions for ppc32.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.26-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.26-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.26-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.26-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.26-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.26-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.26-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.26-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.26-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.26-RT
  radix-tree: optimistic locking.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.26-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.26-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.26-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.26-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.26-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.26-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.26-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.26-RT
  rt: plist_head_splice.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.26-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.26-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.26-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.26-RT
  rwlocks multi downgrade write.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.26-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.26-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.26-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.26-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.26-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.26-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.26-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.26-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.26-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.26-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.26-RT.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.26-RT
  trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.26-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.26-RT.
- patches.rt/version.patch: Linux-RT 2.6.26-RT
  add -rt extra-version.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.26-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.26-RT
  event-tracer: add clockevent trace.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.26-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.26-RT
  ftrace: user raw spin lock for wakeup function trace.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.26-RT
  lockdep: add +1 to radix tree array.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.26-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.26-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.26-RT
  rwlock: rwlock torture test.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.26-RT
  Re: 2.6.25.4-rt4.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.26-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.26-RT
  Fix a previously reverted "fix".
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.26-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.26-RT
  ftrace: document updates.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.26-RT
  ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.26-RT
  ftrace: only trace preempt off with preempt tracer.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.26-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.26-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.26-RT
  mapping_nrpages-fix.patch.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.26-RT
  nfs: fix missing preemption check.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.26-RT
  pmtmr: allow command line override of ioport.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.26-RT
  powerpc: ftrace stop on crash.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch~: Linux-RT 2.6.26-RT.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.26-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.26-RT
  rtmutex-debug-fix.patch.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.26-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.26-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.26-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.26-RT.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.26-RT
  sched-fix-dequeued-race.patch.
- patches.rt/serial-locking-rt-cleanup.patch~: Linux-RT 2.6.26-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.26-RT
  rt: dont disable irqs in usb.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.26-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.26-RT
  ftrace: print ktime values in readable form.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.26-RT
  remove warn on for scatterlist in preempt rt.
* Tue Jul 29 2008 trenn@suse.de
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  ACPI: Provide a spec conform OSI interface to the BIOS.
* Tue Jul 29 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: uvcvideo merged.  Add Obsoletes.
* Fri Jul 25 2008 mszeredi@suse.cz
- supported.conf: Mark fuse as supported.
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_MARKERS
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_SECURITY_SELINUX
* Thu Jul 24 2008 agruen@suse.de
- Fix for using relative paths in /usr/src/linux-obj/$arch/
  $flavor/Makefile (bnc#409982).
* Fri Jul 18 2008 hare@suse.de
- Update config files for S/390.
* Thu Jul 17 2008 bwalle@suse.de
- patches.fixes/show-OSRELEASE-in-VMCOREINFO.diff:
  kdump: Report actual value of VMCOREINFO_OSRELEASE in VMCOREINFO
* Thu Jul 17 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Removed Supplements handling
  entirely. Use preamble instead.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.26: Fix 32-bit build.
* Thu Jul 17 2008 jbeulich@novell.com
- Update Xen patches for 2.6.26.
- patches.xen/540-blkif-nr-segments-check.patch: Delete.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: Delete.
- patches.xen/xen3-patch-2.6.25.1: Delete.
- Update i386 and x86-64 config files.
- config.conf: Re-enable Xen configs.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.fixes/seccomp-disable-tsc-option: Also handle x86-64 (191123).
- Update x86-64 config files.
- patches.suse/raw_device_max_minors_param.diff: Fix uninitialized
  return value.
- patches.apparmor/remove_suid.diff: Also handle fuse.
- supported.conf: Add e1000e, rtc-core, rtc-lib, and rtc-cmos.
* Mon Jul 14 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: Delete.
* Mon Jul 14 2008 olh@suse.de
- disable unused fsl-diu-fb driver
* Mon Jul 14 2008 jeffm@suse.de
- Updated to 2.6.26-final.
* Mon Jul 14 2008 bwalle@suse.de
- patches.fixes/move-crashkernel-reservation.diff:
  x86: Move crashkernel reservation before dma32_reserve_bootmem().
* Mon Jul 14 2008 rgoldwyn@suse.de
- Enable patches.suse/convert-novfs-to-open-soure-coding-standards.patch
  Fix oops in novfs_daemon_lib_ioctl
* Fri Jul 11 2008 jeffm@suse.de
- Updated squashfs to v3.3. (bnc#373285)
* Thu Jul 10 2008 jeffm@suse.de
- Update config files: Enable raw devices on s390.
* Thu Jul 10 2008 jack@suse.cz
- patches.suse/raw_device_max_minors_param.diff: Allow setting
  of number of raw devices as a module parameter (FATE 302178).
* Thu Jul 10 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: fsl-diu-fb:
  compile fix.
* Wed Jul  9 2008 jeffm@suse.de
- patches.suse/kdb-common: Removed obsolete file_lock_operations
  printing.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: Upstreamed with
  - git5.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: reiserfs:
  discard prealloc in reiserfs_delete_inode (bnc#389656).
* Wed Jul  9 2008 jeffm@suse.de
- Updated to 2.6.26-rc9-git5.
  - Eliminated 2 patches.
* Wed Jul  9 2008 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ip_conntrack_slp.patch: connection
  tracking helper for SLP (fate#301134).
* Wed Jul  9 2008 olh@suse.de
- enable PHYP-assisted OS dump (fate#304131)
* Mon Jul  7 2008 trenn@suse.de
- patches.fixes/acpi_thermal_passive_cleanup.patch: Delete.
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-gericom-bellagio-to-nomux.patch: Input:
  add Gericom Bellagio to nomux blacklist (bnc#404892).
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-1360-to-nomux.patch: Input:
  add Acer Aspire 1360 to nomux blacklist (bnc#216857).
* Wed Jul  2 2008 jeffm@suse.de
- patches.apparmor/__d_path-keep-connected.diff
  patches.apparmor/mount-consistent-__d_path.diff
  patches.suse/kdb-ia64: Edited to apply with --fuzz=0
- Added --fuzz=0 (-F0) to sequence-patch.sh and spec files
* Fri Jun 27 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: don't generate the makedumpfile.config
  any more, the new kernel, kexec-tools and makedumpfile is able to
  extract that information from the running kernel and pass it
  as ELF NOTE (in /proc/vmcore)
* Thu Jun 26 2008 olh@suse.de
- add patches.arch/ppc-ibmebus-modalias.patch
  autoload ehea and ehca (bnc#394602 - LTC44938)
* Thu Jun 26 2008 sdietrich@suse.de
- RT:  Update config files - enable CONFIG_CGROUPS
* Thu Jun 26 2008 sdietrich@suse.de
- Update config files - enable CPUSETs support:
  CONFIG_CGROUPS, CONFIG_CGROUP_NS, CONFIG_CGROUP_DEVICE,
  CONFIG_CPUSET, CONFIG_CGROUP_CPUACCT,
  CONFIG_RESOURCE_COUNTERS, CONFIG_MM_OWNER,
  CONFIG_CGROUP_MEM_RES_CTLR, CONFIG_PROC_PID_CPUSET
- debug only: CONFIG_CGROUP_DEBUG
* Thu Jun 26 2008 jeffm@suse.de
- Updated to 2.6.26-rc8
  - Eliminated 1 patch.
* Wed Jun 25 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Added Supplements tag copying and added
    coreutils and grep to Requires
- rpm/macros.kernel-source: Added kernel-syms to BuildRequires
* Wed Jun 25 2008 olh@suse.de
- enable 64K pages in config ppc64 (fate#304100)
- enable up to 1024 cpus in config ppc64 (fate#304180)
- enable up to 4 cpus in config kdump
- enable powermanagement in config ppc64
- enable cell be cpufreq
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-isa is gone.
  - i2c-i810, i2c-prosavage and i2c-savage4 are deprecated and will
    be removed soon, mark as unsupported.
  - i2c-voodoo3 has very limited usefulness, mark as unsupported.
  - i2c-powermac is new, mark as supported.
- supported.conf: Update the list of i2c chip drivers.
  - ds1337, ds1374, rtc8564 and x1205 are gone (RTC drivers, moved
    to drivers/rtc).
  - pca9539, pcf8574 and pcf8575 are deprecated (new GPIO drivers
    exist in drivers/gpio), mark as unsupported.
  - ds1682, max6875 and tsl2550 are new, mark as supported.
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Add two new hwmon drivers (dme1737 and thmc50,
  both unsupported.)
- supported.conf: Mark hwmon and hwmon-vid as supported. These are
  simple, software-only utility modules, it makes little sense
  to taint the kernel just because they are loaded.
* Mon Jun 23 2008 tiwai@suse.de
- disable CONFIG_SND_PCSP as it conflicts with input pcspkr and
  disturbs the order of sound devices
* Mon Jun 23 2008 agruen@suse.de
- genksyms: add support for checking against a reference ABI.
* Wed Jun 18 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git5.
  - Eliminated 2 patches.
* Fri Jun 13 2008 jeffm@suse.de
- Removed kABI reference symbols
- Restored make-symsets check for ignoring/tolerating kABI changes.
* Fri Jun 13 2008 jeffm@suse.de
- Update config files (vanilla).
* Fri Jun 13 2008 jeffm@suse.de
- Update config files.
* Fri Jun 13 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git1.
  - Eliminated 2 patches.
* Thu Jun 12 2008 sdietrich@suse.de
- config.conf: Suppress RT until forward-port is complete
* Thu Jun 12 2008 jeffm@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: Delete.
* Thu Jun 12 2008 olh@suse.de
- update ps3 config, disable unused drivers
- disable patches.arch/ppc-efika-slowdown.patch
* Thu Jun 12 2008 jeffm@suse.de
- Updated to 2.6.26-rc5-git5.
  - Eliminated 91 patches.
  - Disabled OCFS2 userspace heartbeat.
  - Disabled Xen.
* Thu Jun 12 2008 sdietrich@suse.de
  Build fix: drop patches merged into 2.6.25.5
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: Delete.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  Delete.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: Delete.
  Update to 2.6.25-RT6:
- Update config files: enable (M) CONFIG_RWLOCK_TORTURE_TEST
  Resolve conflicts:
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.25.4-RT.
  Add:
- patches.rt/trace-eip2ip.patch: Re: 2.6.25.4-rt4 Compile Fix.
- patches.rt/rwlock-prio-fix.patch: rwlock: reset prio on unlocks
  and wakeups.
- patches.rt/rwlock-fixes.patch: rwlock: fix pi_list race
  conditions.
- patches.rt/event-trace-hrtimer-trace.patch: event-tracer:
  add clockevent trace.
- patches.rt/rwlock-torture.patch: rwlock: rwlock torture test.
- patches.rt/ftrace-wakeup-rawspinlock.patch: ftrace: user raw
  spin lock for wakeup function trace.
- patches.rt/radix-tree-lockdep-plus1.patch: lockdep: add +1 to
  radix tree array.
- patches.rt/sched-cpupri-hotplug-support.patch: sched: fix
  cpupri hotplug support.
- patches.rt/sched-cpupri-priocount.patch: sched: fix cpupri
  priocount.
- patches.rt/ftrace-hotplug-fix.patch: ftrace: cpu hotplug fix.
* Wed Jun 11 2008 agruen@suse.de
- rpm/make-symsets: update to the latest version which will ignore
  symset changes if the symset includes a symbol marked to be
  ignored.
* Wed Jun 11 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: only generate symsets for kernels
  with CONFIG_MODULES=y.
- rpm/macros.kernel-source: remove the ps3 specific check: we
  really want to check whether the kernel mas modules enabled,
  which is covered by the symsets check already now.
* Wed Jun 11 2008 gregkh@suse.de
- patches.drivers/usb-don-t-use-reset-resume-if-drivers-don-t-support-it.patch:
  USB: don't use reset-resume if drivers don't support it.
* Wed Jun 11 2008 gregkh@suse.de
- comment out
  patches.suse/convert-novfs-to-open-soure-coding-standards.patch in the
  series file as it is reported to fail some regression tests.
* Wed Jun 11 2008 gregkh@suse.de
- patches.suse/convert-novfs-to-open-soure-coding-standards.patch:
  Convert novfs to open soure coding standards.
* Mon Jun  9 2008 gregkh@suse.de
- patches.fixes/mptbase-vmware-fix: Delete as it's not needed anymore
* Mon Jun  9 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Mon Jun  9 2008 gregkh@suse.de
- Update to 2.6.25.6
  - loads of bugfixes
  - remove the following patches that were already included in this release:
  - patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch
  - patches.drivers/libata-force-hardreset-if-link-pm
  - patches.fixes/input-hid-apple-numlock-emulation.patch
  - patches.arch/check-for-acpi-resource-conflicts-in-i2c-bus-drivers.patch
* Mon Jun  9 2008 gregkh@suse.de
- patches.drivers/usb-sierra-option.patch: USB: update sierra
  and option device ids (bnc#374637).
* Mon Jun  9 2008 teheo@suse.de
- patches.drivers/libata-ahci-mcp65-workarounds: ahci: workarounds
  for mcp65 (bnc#398573).
* Mon Jun  9 2008 jkosina@suse.de
- patches.fixes/input-i8042-add-ctr-resume-timeout.patch: Input:
  add retry logic to resume with respect to CTR (bnc#351119).
* Sat Jun  7 2008 gregkh@suse.de
- Update to 2.6.25.5.
  - fixes CVE-2008-1673
* Fri Jun  6 2008 tiwai@suse.de
- add missing patches.rt/ftrace-add-nr_syscalls.patch for fixing
  i386-rt_debug
* Thu Jun  5 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25: netfront (bnc#394575) and page table
  handling (bnc#396858) fixes.
- patches.xen/540-blkif-nr-segments-check.patch: Avoid theoretical
  TOCTTOU bug in block backend nr_segments checking.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: x86_64:
  Remove warning message about 'Breaking affinity for irq'.
- patches.xen/xen-netfront-flip-prod: fix updating of req_prod_pvt
  in the receive ring for the flipping case.
* Wed Jun  4 2008 jblunck@suse.de
- patches.drivers/libata-acpi-fix-hotplug: Don't call ata_port_freeze()
  in ata_acpi_detach_device().
* Wed Jun  4 2008 schwab@suse.de
- Don't clean asm-offsets.h.
* Wed Jun  4 2008 jjohanse@suse.de
- patches.apparmor/apparmor-module_interface.diff: AppArmor:
  Update patch to properly set profile name_table size (bnc#396993)
* Wed Jun  4 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Add
  Fujitsu-Siemens Amilo Pro 2010 and 2030 to nomux list
  (bnc#345699 bnc#389169)
* Tue Jun  3 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-auto-resume-fix: hda - Fix
  resume of auto-config mode with Realtek codecs (bnc#385473).
* Tue Jun  3 2008 bphilips@suse.de
  Backport: e1000e for montevina systems
- patches.drivers/e1000e-backport-0001-remove-no-longer-used-e1000e_read_nvm_spi.patch:
  e1000e: remove no longer used e1000e_read_nvm_spi.
- patches.drivers/e1000e-backport-0002-remove-irq_sem.patch:
  e1000e: remove irq_sem.
- patches.drivers/e1000e-backport-0003-rename-mc_addr_list_update.patch:
  e1000e: rename mc_addr_list_update.
- patches.drivers/e1000e-backport-0004-reorganize-PHY-and-flow-control-interface.patch:
  e1000e: reorganize PHY and flow control interface.
- patches.drivers/e1000e-backport-0005-Make-arrays-out-of-these-Rx-Tx-registers.patch:
  e1000e: Make arrays out of these Rx/Tx registers.
- patches.drivers/e1000e-backport-0006-rename-a-few-functions.patch:
  e1000e: rename a few functions.
- patches.drivers/e1000e-backport-0007-cleanup-several-stats-issues.patch:
  e1000e: cleanup several stats issues.
- patches.drivers/e1000e-backport-0008-Fix-HW-Error-on-es2lan-ARP-capture-issue-by.patch:
  e1000e: Fix HW Error on es2lan, ARP capture issue by BMC.
- patches.drivers/e1000e-backport-0009-Add-support-for-BM-PHYs-on-ICH9.patch:
  e1000e: Add support for BM PHYs on ICH9.
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: Delete.
- patches.drivers/alsa-hda-backport-2.6.26-rc4: Backport ALSA
  HDA-Intel patches from 2.6.26-rc4 (bnc#390473).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-asus-a9t-fix: ac97 - Fix ASUS A9T laptop
  output (bnc#363987).
* Mon Jun  2 2008 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: reiserfs: Use list_del_init
  in use_preallocated_list_if_available (bnc#378095).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hp2133-mic-fix: hda - Fix mic input on
  HP2133 (bnc#388540).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy2-digital-fix: emu10k1 - Fix
  inverted Analog/Digital mixer switch on Audigy2 (bnc#396204).
* Sat May 31 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt4 (refreshed patches suppressed)
- Update config files.
  Added:
- patches.rt/adapt-remove-extra-try-to-lock.patch
- patches.rt/adaptive-adjust-pi-wakeup.patch
- patches.rt/adaptive-earlybreak-on-steal.patch
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch
- patches.rt/adaptive-task-oncpu.patch
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch
- patches.rt/arm-omap-02.patch
- patches.rt/arm-omap-03.patch
- patches.rt/arm-omap-04.patch
- patches.rt/arm-omap-05.patch
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch
- patches.rt/ftrace-compile-fixes.patch
- patches.rt/ftrace-disable-daemon.patch
- patches.rt/ftrace-dont-trace-markers.patch
- patches.rt/ftrace-fix-header.patch
- patches.rt/ftrace-function-record-nop.patch
- patches.rt/ftrace-print-missing-cmdline.patch
- patches.rt/ftrace-record-comm-on-ctrl.patch
- patches.rt/ftrace-safe-traversal-hlist.patch
- patches.rt/ftrace-trace-sched.patch
- patches.rt/ftrace-update-cnt-stat-fix.patch
- patches.rt/git-ignore-module-markers.patch
- patches.rt/git-ignore-script-lpp.patch
- patches.rt/lockdep-avoid-fork-waring.patch
- patches.rt/lockstat-fix-contention-points.patch
- patches.rt/lockstat-output.patch
- patches.rt/nmi-show-regs-fix.patch
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch
- patches.rt/realtime-preempt-warn-about-tracing.patch
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch
- patches.rt/rwlock-implement-downgrade-write.patch
- patches.rt/rwlocks-fix-no-preempt-rt.patch
- patches.rt/sched-fix-rt-task-wakeup.patch
- patches.rt/sched-fix-sched-fair-wakeup.patch
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
- patches.rt/sched-wake_up_idle_cpu-rt.patch
- patches.rt/trace_hist-divzero.patch
- patches.rt/trace_hist-latediv.patch
- patches.rt/x86-delay-enable-preempt-tglx.patch
  Removed:
- patches.rt/rtmutex-optimize-wakeup.patch
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch
- patches.rt/rtmutex-remove-extra-try.patch
- patches.rt/ftrace-remove-print-of-max.patch
* Thu May 29 2008 sdietrich@suse.de
  RT: Update IBM EDAC and PRTM
- Update config files.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Add support for HS21XM SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Add support for HS21/LS21 SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Turn off unsupported EDAC check on the i5000 controller.
- patches.rt/drivers-edac-prevent-potential-printk-storm:
  Prevent potential EDAC printk storm.
- patches.rt/drivers-edac-test_device.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-k8-rev-f.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-amd64.patch:
  drivers-edac-new-amd64.patch (revision 108).
  Obsolete:
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: Delete.
- patches.rt/add-support-for-HS21XM-SMI-remediation: Delete.
- patches.rt/prevent-potential-EDAC-printk-storm: Delete.
* Thu May 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: ata_piix: fix
  macbook ich8m problems (bnc#395407).
* Thu May 29 2008 agruen@suse.de
- Obsolete some KMPs which have been integrated into mainline
  meanwhile (bnc#357799).
* Thu May 29 2008 jbeulich@novell.com
- supported.conf: Mark 8250_pnp as supported.
* Wed May 28 2008 teheo@suse.de
- patches.drivers/libata-acpi-fix-hotplug: libata: Handle bay
  devices in dock stations (bnc#390822 bnc#395082).
* Wed May 28 2008 jkosina@suse.de
- patches.fixes/input-add-i8042-nopnp-for-D845PESV.patch: Input:
  Add i8042.nopnp for Intel D845PESV (bnc#386952).
* Mon May 26 2008 sdietrich@suse.de
  RT: Update to 2.6.25.4-rt3 - add RWSEM / RWLOCK patches:
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.25.4-RT3.
- patches.rt/multi-reader-account.patch: map tasks to reader
  locks held.
- patches.rt/multi-reader-limit.patch: implement reader limit
  on read write locks.
- patches.rt/multi-reader-lock-account.patch: map read/write
  locks back to their readers.
- patches.rt/multi-reader-pi.patch: read lock Priority Inheritance
  implementation.
- patches.rt/native-sched-clock-booboo.patch: Re: 2.6.25.4-rt2
  (native_sched_clock() booboo).
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch:
- patches.rt/rwlocks-multiple-readers.patch: implement rwlocks
  management.
- patches.rt/rwsems-multiple-readers.patch: add framework for
  multi readers on rwsems.
* Mon May 26 2008 olh@suse.de
- add patches.arch/ppc-efika-slowdown.patch
  slow down hot code paths to avoid hangs during install (bnc#374309)
* Sun May 25 2008 tiwai@suse.de
- Update config files: forgot to update vanilla kernel configs
* Sat May 24 2008 tiwai@suse.de
- Update config files: disable group scheduler for normal kernels
  for openSUSE 11.0, too (this should be enabled again later for
  11.1 once after the bugs get fixed...)
* Fri May 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dma-pos-fix: hda - Fix DMA position
  inaccuracy (bnc#362775, bnc#364421).
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: hda - Fix noise
  on VT1708 codec (bnc#390473).
* Fri May 23 2008 sdietrich@suse.de
  RT: Update config files: Disable Group Scheduler
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-simg3726-nosrst: libata: SRST can't
  be trusted on PMP sil3726 (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: update config files: Disable SYSFS_DEPRECATED
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).  series.conf not
  updated.  Fix it.
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: build fix
- suppress adaptive locking patches that are not upstream.
- Update config files.
* Wed May 21 2008 jblunck@suse.de
- patches.fixes/acpi-bay-cleanup-and-exit.patch: bay: Exit if
  notify handler cannot be installed (bnc#390822).
* Wed May 21 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.25: Fix DomU boot issue.
* Wed May 21 2008 oneukum@suse.de
- patches.drivers/ehci_fix_remote_wakeup_regression.diff: EHCI:
  fix remote-wakeup regression. (bnc#373128)
* Tue May 20 2008 jblunck@suse.de
- doc/novell-kmp/novell-example-1.1.tar.bz2,
  doc/novell-kmp/novell-example.spec: Fix example spec and Kbuild
  because EXTRA_CFLAGS isn't taken from the environment anymore.
* Tue May 20 2008 sdietrich@suse.de
- Update config files: SLERT compatibility: SYSFS_DEPRECATED
* Tue May 20 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt2 (refreshed patches suppressed)
  Add:
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: x86: disable TSC
  for sched_clock() when calibration failed
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: x86: fix setup of cyc2ns
  in tsc_64.c.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  x86: distangle user disabled TSC from unstable
- patches.rt/adaptive-spinlock-lite-v2.patch: adaptive spinlocks
  lite.
- patches.rt/rtmutex-remove-xchg.patch: rtmutex - remove double
  xchg.
  Update:
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
  Resolve Conflicts:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- Update config files.
* Mon May 19 2008 sdietrich@suse.de
  RT: Adaptive locking patches:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/rtmutex-adaptive-timeout.patch: add a timeout
  mechanism to adaptive-locking.
- patches.rt/rtmutex-optimize-wakeup.patch: optimize rt lock
  wakeup.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch:
  adjust pi_lock usage in wakeup.
- patches.rt/rtmutex-remove-extra-try.patch: remove the extra
  call to try_to_take_lock.
- Update config files:
  CONFIG_RTLOCK_LATERAL_STEAL=y
  CONFIG_ADAPTIVE_RTLOCK=y
  CONFIG_IBM_RTL (disable temporarily to address build error)
* Mon May 19 2008 tiwai@suse.de
- Update config files (missing for rt*).
* Mon May 19 2008 tiwai@suse.de
- patches.drivers/alsa-hda-backport-2.6.25-rc3: Backport ALSA
  HDA-Intel patches from 2.6.25-rc3 (bnc#390473, bnc#386422,
  bnc#385473).
- patches.drivers/alsa-intel8x0-8ch: intel8x0 - Add support of
  8 channel sound.
- patches.drivers/alsa-mixer-oss-map-fix: Add more fallbacks to
  OSS PHONEOUT mixer map.
- patches.drivers/alsa-usb-audio-disconnect-oops-fix: Fix Oops
  with usb-audio reconnection.
- patches.drivers/alsa-hda-intel-new-ati-id: Delete.
- patches.drivers/alsa-hda-intel-new-nvidia-id: Delete.
- patches.drivers/alsa-hda-intel-use-PCI_DEVICE: Delete.
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Delete.
- Update config files.
* Mon May 19 2008 jbeulich@novell.com
- Update Xen patches to c/s 524 and 2.6.25.4.
- patches.xen/xen-balloon-hvm-min: don't allow ballooning down
  a HVM domain below a reasonable limit (172482).
- patches.xen/xen-swiotlb-heuristics: adjust Xen's swiotlb
  default size setting.
* Mon May 19 2008 jbeulich@novell.com
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Add missing list terminator for acpi_rsdt_dmi_table[] and move to
  __initdata.
* Mon May 19 2008 sdietrich@suse.de
  RT: SMI latency fixes from IBM.
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: [PATCH
  1/3] Add support for HS21/LS21 SMI Remediation.
- patches.rt/add-support-for-HS21XM-SMI-remediation: [PATCH 2/3]
  Add support for HS21XM SMI Remediation .
- patches.rt/prevent-potential-EDAC-printk-storm: [PATCH 3/3]
  Prevent potential EDAC printk storm.
- RT: Update config files.
* Mon May 19 2008 agruen@suse.de
- patches.suse/nfs4acl-ext3.diff: Fix compilation error when
  CONFIG_EXT3_FS_NFS4ACL is off.
* Mon May 19 2008 sdietrich@suse.de
- RT: Update config files.
* Mon May 19 2008 trenn@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: ACPI:
  initramfs DSDT override support.
  - > Did not make it into 2.6.25 again...
- Update config files.
* Sun May 18 2008 agruen@suse.de
- Update the nfs4acl patches (and split them out more explicitly).
  Export all new symbols als GPL only.
- patches.apparmor/parent-permission.diff: Rediff.
* Sun May 18 2008 sdietrich@suse.de
- RT: Update config files.
* Sun May 18 2008 sdietrich@suse.de
  RT: update to 2.6.25.4-rt1 patch queue.
* Sun May 18 2008 sdietrich@suse.de
  RT cleanup: Remove unused/obsolete RT patches.
* Sun May 18 2008 sdietrich@suse.de
- Update config files: update RT debug configs.
- config.conf: enable DEBUG flavors.
* Sat May 17 2008 sdietrich@suse.de
  Linux-RT 2.6.25-RT:
- Updated RT patch queue (not individually enumerated here)
- Update config files: RT
- config.conf: RT
* Fri May 16 2008 gregkh@suse.de
- Update config files.
- patches.drivers/usb-add-option-hso-driver.patch: USB: add
  option hso driver.
* Fri May 16 2008 gregkh@suse.de
- refresh patches due to fuzz
* Fri May 16 2008 gregkh@suse.de
- patches.fixes/bluetooth-wake-up-properly-after-ide-timeout-expires.patch:
  bluetooth: wake up properly after ide timeout expires
  (bnc#390839).
* Fri May 16 2008 olh@suse.de
- update patches.fixes/tg3-flowctrl.patch
  do not compare flow control settings in parallel detect mode
* Fri May 16 2008 trenn@suse.de
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Introduce acpi_root_table=rsdt boot param and dmi list to
  force rsdt (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_introduce_acpica_rsdt_global_variable.patch:
  ACPICA: Add acpi_gbl_force_rsdt variable
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_remove_R40e_c-state_blacklist.patch:
  Remove R40e c-state blacklist
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch:
  CPUFREQ: Check against freq changes from the BIOS.
* Fri May 16 2008 jblunck@suse.de
- patches.fixes/vfs-2.6.git-9bc300eae0400efdfae3fec3352896e10468a78f.patch:
  return to old errno choice for fix mkdir -p with ro-bind mounts
* Fri May 16 2008 jblunck@suse.de
- rpm/kernel-{binary,source}.spec.in: use localversion and set
  KBUILD_BUILD_VERSION (used for Kernel:Vanilla)
* Thu May 15 2008 gregkh@suse.de
- Update to final version of 2.6.25.4
* Thu May 15 2008 jblunck@suse.de
- rpm/macros.kernel-source: Let KMPs fail when flavors_to_build is empty
- rpm/kernel-{dummy,source,syms,binary}.spec.in, scripts/tar-up.sh:
  fix release number changes introduced by bnc#271712 for OBS (bnc#378933)
* Thu May 15 2008 olh@suse.de
- add patches.fixes/tg3-flowctrl.patch
  revert 'Fix supporting flowctrl code' to fix JS21 (bnc#390314)
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 teheo@suse.de
- patches.drivers/libata-force-hardreset-if-link-pm: libata:
  force hardreset if link is in powersave mode (bnc#381795).
- patches.drivers/libata-ahci-sb600-no-msi: ahci: SB600 ahci
  can't do MSI, blacklist that capability (bnc#384559).
* Tue May 13 2008 gregkh@suse.de
- Update config files for vanilla targets
* Tue May 13 2008 gregkh@suse.de
- Update to 2.6.25.4-rc1
  - lots of bug fixes
* Tue May 13 2008 sdietrich@suse.de
  Cleanup RT:
- patches.rt/*: Delete.
* Mon May 12 2008 jkosina@suse.de
- patches.fixes/input-hid-apple-numlock-emulation.patch:
  HID: split Numlock emulation quirk from
  HID_QUIRK_APPLE_HAS_FN. (bnc#381764).
* Sat May 10 2008 gregkh@suse.de
- Update to 2.6.25.3
  - fixes 2 security issues (one networking, one sparc, no CVE
    numbers issued just yet)
* Fri May  9 2008 jeffm@suse.de
- patches.apparmor/fsetattr-restore-ia_file: vfs: restore ia_file
  for compatibility with external modules. (bnc#381259)
* Fri May  9 2008 hare@suse.de
- patches.drivers/open-iscsi-git-update: Delete.
- patches.fixes/open-iscsi-nop-fixes: NOP timeout fixes.
* Thu May  8 2008 gregkh@suse.de
- patches.kernel.org/v4l-dvb-patch-for-various-dibcom-based-devices.patch:
  V4L/DVB (7473): PATCH for various Dibcom based devices
  (bnc#381632).
* Thu May  8 2008 gregkh@suse.de
- comment out vmware patch as it should no longer be needed
* Thu May  8 2008 gregkh@suse.de
- rediff patches to apply cleanly.
* Thu May  8 2008 gregkh@suse.de
- Update to 2.6.25.3-rc1
  - potential fix for increased power consumption and other bugs
* Thu May  8 2008 sassmann@suse.de
- Update config file ppc64.
- patches.arch/ppc-ps3-ps3vram-mtd.patch: ps3vram driver that
  allows you to access the extra ~240MB of DDR video.
* Wed May  7 2008 gregkh@suse.de
- patches.kernel.org/patch-2.6.25.1-2: Linux 2.6.25.2.
  - fixes CVE-2008-1669
* Tue May  6 2008 schwab@suse.de
- suse-ppc32-mol-semaphore: fix mol for 2.6.26-rc1.
* Mon May  5 2008 jack@suse.cz
  Bring UDF to state in 2.6.26-rc1 to support UDF 2.50.
- patches.suse/udf-10-simple-cleanup-of-truncate.c.patch: udf:
  simple cleanup of truncate.c (fate#303336).
- patches.suse/udf-11-truncate-create-function-for-updating-of-Alloc.patch:
  udf: truncate: create function for updating of Allocation Ext
  Descriptor (fate#303336).
- patches.suse/udf-12-replace-all-adds-to-little-endians-variables-wi.patch:
  udf: replace all adds to little endians variables with
  le*_add_cpu (fate#303336).
- patches.suse/udf-13-simplify-__udf_read_inode.patch: udf:
  simplify __udf_read_inode (fate#303336).
- patches.suse/udf-14-replace-udf_-_offset-macros-with-functions.patch:
  udf: replace udf_*_offset macros with functions (fate#303336).
- patches.suse/udf-15-convert-udf_count_free_bitmap-to-use-bitmap_wei.patch:
  udf: convert udf_count_free_bitmap to use bitmap_weight
  (fate#303336).
- patches.suse/udf-16-udf_get_block-inode_bmap-remove-unneeded-che.patch:
  udf: udf_get_block, inode_bmap - remove unneeded checks
  (fate#303336).
- patches.suse/udf-17-create-function-for-conversion-from-timestamp-t.patch:
  udf: create function for conversion from timestamp to timespec
  (fate#303336).
- patches.suse/udf-18-convert-udf_stamp_to_time-to-return-struct-time.patch:
  udf: convert udf_stamp_to_time to return struct timespec
  (fate#303336).
- patches.suse/udf-19-convert-udf_stamp_to_time-and-udf_time_to_stamp.patch:
  udf: convert udf_stamp_to_time and udf_time_to_stamp to use
  timestamps (fate#303336).
- patches.suse/udf-1-kill-udf_set_blocksize.patch: udf: kill
  udf_set_blocksize (fate#303336).
- patches.suse/udf-20-remove-unneeded-kernel_timestamp-type.patch:
  udf: remove unneeded kernel_timestamp type (fate#303336).
- patches.suse/udf-21-super.c-reorganization.patch: udf: super.c
  reorganization (fate#303336).
- patches.suse/udf-22-Mark-udf_process_sequence-as-noinline.patch:
  udf: Mark udf_process_sequence() as noinline (fate#303336).
- patches.suse/udf-23-Remove-checking-of-existence-of-filename-in-udf.patch:
  udf: Remove checking of existence of filename in udf_add_entry()
  (fate#303336).
- patches.suse/udf-24-Remove-declarations-of-arrays-of-size-UDF_NAME_.patch:
  udf: Remove declarations of arrays of size UDF_NAME_LEN (256
  bytes) (fate#303336).
- patches.suse/udf-25-fix-anchor-point-detection.patch: udf:
  fix anchor point detection (fate#303336).
- patches.suse/udf-26-Cleanup-volume-descriptor-sequence-processing.patch:
  udf: Cleanup volume descriptor sequence processing
  (fate#303336).
- patches.suse/udf-27-Improve-error-recovery-on-mount.patch:
  udf: Improve error recovery on mount (fate#303336).
- patches.suse/udf-28-Move-filling-of-partition-descriptor-info-into.patch:
  udf: Move filling of partition descriptor info into a separate
  function (fate#303336).
- patches.suse/udf-29-Move-processing-of-virtual-partitions.patch:
  udf: Move processing of virtual partitions (fate#303336).
- patches.suse/udf-2-kill-useless-file-header-comments-for-vfs-metho.patch:
  udf: kill useless file header comments for vfs method
  implementations (fate#303336).
- patches.suse/udf-30-Cleanup-anchor-block-detection.patch: udf:
  Cleanup anchor block detection. (fate#303336).
- patches.suse/udf-31-Improve-anchor-block-detection.patch: udf:
  Improve anchor block detection (fate#303336).
- patches.suse/udf-32-Silence-warning-about-accesses-beyond-end-of-de.patch:
  udf: Silence warning about accesses beyond end of device
  (fate#303336).
- patches.suse/udf-33-Fix-detection-of-VAT-version.patch: udf:
  Fix detection of VAT version (fate#303336).
- patches.suse/udf-34-Allow-loading-of-VAT-inode.patch: udf:
  Allow loading of VAT inode (fate#303336).
- patches.suse/udf-35-Handle-VAT-packed-inside-inode-properly.patch:
  udf: Handle VAT packed inside inode properly (fate#303336).
- patches.suse/udf-36-Mount-filesystem-read-only-if-it-has-pseudoover.patch:
  udf: Mount filesystem read-only if it has pseudooverwrite
  partition (fate#303336).
- patches.suse/udf-37-Fix-handling-of-multisession-media.patch:
  udf: Fix handling of multisession media (fate#303336).
- patches.suse/udf-38-Add-read-only-support-for-2.50-UDF-media.patch:
  udf: Add read-only support for 2.50 UDF media (fate#303336).
- patches.suse/udf-39-Fix-bug-in-VAT-mapping-code.patch: udf:
  Fix bug in VAT mapping code (fate#303336).
- patches.suse/udf-3-move-headers-out-include-linux.patch: udf:
  move headers out include/linux/ (fate#303336).
- patches.suse/udf-40-Fix-compilation-warnings-when-UDF-debug-is-on.patch:
  udf: Fix compilation warnings when UDF debug is on
  (fate#303336).
- patches.suse/udf-41-use-crc_itu_t-from-lib-instead-of-udf_crc.patch:
  udf: use crc_itu_t from lib instead of udf_crc (fate#303336).
- patches.suse/udf-42-fs-udf-partition.c-udf_get_pblock-mustn-t-be.patch:
  udf: fs/udf/partition.c:udf_get_pblock() mustn't be inline
  (fate#303336).
- patches.suse/udf-4-Use-DIV_ROUND_UP.patch: fs/udf: Use
  DIV_ROUND_UP (fate#303336).
- patches.suse/udf-5--udf_error-static.patch: make udf_error()
  static (fate#303336).
- patches.suse/udf-6-udf_CS0toUTF8-cleanup.patch: udf:
  udf_CS0toUTF8 cleanup (fate#303336).
- patches.suse/udf-7-fix-udf_build_ustr.patch: udf: fix
  udf_build_ustr (fate#303336).
- patches.suse/udf-8-udf_CS0toNLS-cleanup.patch: udf: udf_CS0toNLS
  cleanup (fate#303336).
- patches.suse/udf-9-constify-crc.patch: udf: constify crc
  (fate#303336).
* Fri May  2 2008 teheo@suse.de
- patches.drivers/libata-sata_inic162x-update-to-0.4:
  sata_inic162x: update to 0.4 (bnc#385599).
* Fri May  2 2008 gregkh@suse.de
- update to 2.6.25.1:
  - fixes CVE-2008-1375 and CVE-2008-1675
  - lots of other minor bugfixes
* Thu May  1 2008 agruen@suse.de
- Provide "kernel(flavor:symset) = version" instead of
  "kernel(symset) = version". This disambiguates the case where
  several kernel flavors end up with the same modver checksums
  (bnc#190163, bnc#355628).
* Thu May  1 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-verify-sidpr: ata_piix: verify
  SIDPR access before enabling it (bnc#385535).
* Wed Apr 30 2008 gregkh@suse.de
- novfs: fixes needed due to apparmor vfs core changes
  (extended attributes probably do not work now...)
* Wed Apr 30 2008 gregkh@suse.de
- patches.suse/novfs-add-the-novell-filesystem-client-kernel-module.patch:
  novfs: Add the Novell filesystem client kernel module.
- Update config files.
* Wed Apr 30 2008 jeffm@suse.de
- patches.suse/reiserfs-simplify-xattr-internal-file-lookups-opens.diff:
  removed fs.h changes, they weren't used.
* Mon Apr 28 2008 gregkh@suse.de
- Update config files.
  hopefully the build system is happy now
* Mon Apr 28 2008 gregkh@suse.de
- rpm/config-subst: add #!/bin/sh at start of script to keep future
  build issues (like bnc#382214) from causing problems.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete patches: ARM-ep93xx-timer, latency-tracing,
  RCU, KVM, mcount, PPC-gtod
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/kvm-fix-preemption-bug.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch: Delete.
- patches.rt/remove-unused-var-warning.patch: Delete.
- patches.rt/latency-tracing.patch: Delete.
- patches.rt/latency-tracing-remove-trace-array.patch: Delete.
- patches.rt/latency-tracer-disable-across-trace-cmdline.patch:
  Delete.
- patches.rt/latency-tracing-i386-paravirt-fastcall.patch: Delete.
- patches.rt/latency-tracing-i386.patch: Delete.
- patches.rt/latency-tracing-x86_64.patch: Delete.
- patches.rt/latency-tracing-ppc.patch: Delete.
- patches.rt/latency-tracer-printk-fix.patch: Delete.
- patches.rt/latency-tracing-exclude-printk.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/latency-tracer-one-off-fix.patch: Delete.
- patches.rt/smaller-trace.patch: Delete.
- patches.rt/trace-name-plus.patch: Delete.
- patches.rt/trace-with-caller-addr.patch: Delete.
- patches.rt/trace-sti-mwait.patch: Delete.
- patches.rt/latency-tracer-optimize-a-bit.patch: Delete.
- patches.rt/idle-stop-critical-timing.patch: Delete.
- patches.rt/latency-tracer-variable-threshold.patch: Delete.
- patches.rt/reset-latency-histogram.patch: Delete.
- patches.rt/undo-latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/random-driver-latency-fix.patch: Delete.
- patches.rt/latency-tracing-use-now.patch: Delete.
- patches.rt/preempt_max_latency-in-all-modes.patch: Delete.
- patches.rt/latency-hist-add-resetting-for-all-timing-options.patch:
  Delete.
- patches.rt/latency-trace-sysctl-config-fix.patch: Delete.
- patches.rt/latency-trace-convert-back-to-ms.patch: Delete.
- patches.rt/latency-trace-fix.patch: Delete.
- patches.rt/trace-cpuidle.patch: Delete.
- patches.rt/lockdep-show-held-locks.patch: Delete.
- patches.rt/lockdep-lock_set_subclass.patch: Delete.
- patches.rt/lockdep-prettify.patch: Delete.
- patches.rt/lockdep-more-entries.patch: Delete.
- patches.rt/latency-tracer-arch-low-address.patch: Delete.
- patches.rt/latency-tracer-dont-panic-on-failed-bootmem-alloc.patch:
  Delete.
- patches.rt/mcount-add-x86_64-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-x86-vdso-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-nmi-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-time-notrace-annotations.patch: Delete.
- patches.rt/mcount-lockdep-notrace-annotations.patch: Delete.
- patches.rt/mcount-preemptcount-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-fault-notrace-annotations.patch: Delete.
- patches.rt/mcount-irqs-notrace-annotations.patch: Delete.
- patches.rt/mcount-rcu-notrace-annotations.patch: Delete.
- patches.rt/latency-measurement-drivers-fix.patch: Delete.
- patches.rt/latency-measurement-drivers.patch: Delete.
- patches.rt/redo-regparm-option.patch: Delete.
- patches.rt/nmi-profiling-base.patch: Delete.
- patches.rt/ppc-gtod-notrace-fix.patch: Delete.
- patches.rt/ppc-gtod-support.patch: Delete.
- patches.rt/ppc-gtod-support-fix.patch: Delete.
- patches.rt/ppc-a-2.patch: Delete.
- patches.rt/ppc-fix-clocksource-timebase-shift.patch: Delete.
- patches.rt/ppc-remove-broken-vsyscall.patch: Delete.
- patches.rt/ppc-read-persistent-clock.patch: Delete.
- patches.rt/ppc-clockevents.patch: Delete.
- patches.rt/ppc-clockevents-fix.patch: Delete.
- patches.rt/ppc-highres-dyntick.patch: Delete.
- patches.rt/inet-hash-bits-ipv6-fix.patch: Delete.
- patches.rt/inet_hash_bits.patch: Delete.
- patches.rt/rcu-1.patch: Delete.
- patches.rt/rcu-2.patch: Delete.
- patches.rt/rcu-3.patch: Delete.
- patches.rt/rcu-4.patch: Delete.
- patches.rt/rcu-preempt-fix-nmi-watchdog.patch: Delete.
- patches.rt/rcu-preempt-fix-rcu-torture.patch: Delete.
- patches.rt/dynticks-rcu-rt-fixlet.patch: Delete.
- patches.rt/rcu-tasklet-softirq.patch: Delete.
- patches.rt/rcu-classic-fixup.patch: Delete.
- patches.rt/rcu-warn-underflow.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete Adaptive-locking patches
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
- patches.rt/rtmutex-lateral-steal.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/rtmutex-optimize-wakeup.patch: Delete.
- patches.rt/rtmutex-rearrange.patch: Delete.
- patches.rt/rtmutex-remove-extra-try.patch: Delete.
- patches.rt/x86-ticket-lock.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove ARM and MIPS RT patches
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-compile-fix.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-latency-tracer-support.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-preempt-config.patch: Delete.
- patches.rt/arm-trace-preempt-idle.patch: Delete.
- patches.rt/latency-tracing-arm.patch: Delete.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Delete.
- patches.rt/preempt-irqs-arm.patch: Delete.
- patches.rt/preempt-realtime-arm-bagde4.patch: Delete.
- patches.rt/preempt-realtime-arm-footbridge.patch: Delete.
- patches.rt/preempt-realtime-arm-integrator.patch: Delete.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Delete.
- patches.rt/preempt-realtime-arm-pxa.patch: Delete.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Delete.
- patches.rt/preempt-realtime-arm-shark.patch: Delete.
- patches.rt/preempt-realtime-arm.patch: Delete.
- patches.rt/preempt-irqs-mips.patch: Delete.
- patches.rt/preempt-realtime-mips.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-arm.patch: Delete.
- patches.rt/rt-mutex-mips.patch: Delete.
- patches.rt/mips-change-raw-spinlock-type.patch: Delete.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Delete.
- patches.rt/mips-remove-duplicate-kconfig.patch: Delete.
- patches.rt/mips-remove-finish-arch-switch.patch: Delete.
* Fri Apr 25 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: kernel-xen does not obsolete/provide
  kernel-xenpae (bnc#382309)
* Fri Apr 25 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  create /builtin/sound/cell-index, content == 1
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add newline to devspec files
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add devspec file for mac-io, it was created as a side effect
  in of/platform.c (bnc#374693)
* Thu Apr 24 2008 olh@suse.de
- use bzip2 instead of lzma as rpm compression method for vanilla
* Thu Apr 24 2008 olh@suse.de
- relax Conflicts for kernel-vanilla
  no version check for lvm, udev and apparmor
* Wed Apr 23 2008 olh@suse.de
- readd patches.arch/ppc-pegasos-console-autodetection.patch
  force speed 115200, device-tree has no current-speed property
* Wed Apr 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-intel-new-ati-id,
  patches.drivers/alsa-hda-intel-use-PCI_DEVICE,
  patches.drivers/alsa-hda-intel-new-nvidia-id: Add missing PCI
  ids for new ATI/Nvidia devices (bnc#370775)
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Fix Dell XPS M1330
  outputs
* Tue Apr 22 2008 jack@suse.cz
- patches.fixes/quota_reiserfs_tail_fix.diff: reiserfs: Unpack
  tails on quota files (375179).
* Tue Apr 22 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  fixes for 2.6.25
* Sat Apr 19 2008 schwab@suse.de
- Add compat handler for PTRACE_GETSIGINFO.
* Sat Apr 19 2008 aj@suse.de
- Conflict with apparmor-parser < 2.3 (not <=) in kernel-binary
  spec files.
* Sat Apr 19 2008 jeffm@suse.de
- Re-synced reiserfs patch set due to broken local repo.
* Sat Apr 19 2008 jeffm@suse.de
- Updated reiserfs patch set
  - Eliminated xattr interaction with AppArmor
  - Eliminated xattr deadlock under load between journal lock and
    xattr dir i_mutex
  - Properly annotated xattr i_mutex locking for lockdep
  - Code cleanup
* Fri Apr 18 2008 jjohanse@suse.de
- Update fsetattr.diff to EXPORT_SYMBOL_GPL(fnotify_change)
* Fri Apr 18 2008 jjohanse@suse.de
- patches.apparmor/__d_path-keep-connected.diff: Fix __d_path
  to allow for old and new behavior bnc#380763.
* Thu Apr 17 2008 gregkh@suse.de
- refresh patches to apply without fuzz
* Thu Apr 17 2008 gregkh@suse.de
- Update to 2.6.25-final
* Wed Apr 16 2008 jjohanse@suse.de
- Update to AppArmor 2.3 patch series
* Wed Apr 16 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Fixed accidental
  passing of -ENODATA to userspace during chown, and messages during
  chown and delete.
* Tue Apr 15 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc9 and c/s 517.
* Sat Apr 12 2008 gregkh@suse.de
- refresh patches to clean up fuzz
* Sat Apr 12 2008 gregkh@suse.de
- Update config files.
* Sat Apr 12 2008 gregkh@suse.de
- updat to 2.6.25-rc9
* Thu Apr 10 2008 gregkh@suse.de
- update to 2.6.25-rc8-git8
* Tue Apr  8 2008 gregkh@suse.de
- update to 2.6.25-rc8-git7
* Mon Apr  7 2008 gregkh@suse.de
- patches.kernel.org/pvrusb2-fix-broken-build-due-to-patch-order-dependency.patch:
  pvrusb2: fix broken build due to patch order dependency.
* Mon Apr  7 2008 gregkh@suse.de
- update to 2.6.25-rc8-git5
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Removed struct
  file use entirely.
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Eliminated use
  of vfsmount-less dentry_open().
* Thu Apr  3 2008 teheo@suse.de
- patches.drivers/libata-pata_ali-disable-ATAPI_DMA: pata_ali:
  disable ATAPI DMA (332588).
* Wed Apr  2 2008 gregkh@suse.de
- Update to 2.6.25-rc8
* Tue Apr  1 2008 jblunck@suse.de
- rpm/kernel-source.spec.in,kernel-binary.spec.in: Cleanup Requires
* Mon Mar 31 2008 jdelvare@suse.de
- supported.conf: Add new hwmon drivers, all unsupported.
* Thu Mar 27 2008 jeffm@suse.de
- Fixed up the rest of the reiserfs patch queue.
* Thu Mar 27 2008 jeffm@suse.de
- Updated reiserfs xattr patches.
* Thu Mar 27 2008 gregkh@suse.de
- fix merge error in patches.suse/supported-flag caused by me...
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7-git2
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7
  - note that reiserfs xattr patches are now disabled due to merge
    issues...
* Sun Mar 23 2008 teheo@suse.de
- patches.drivers/libata-improve-hpa-error-handling: libata:
  improve HPA error handling (365534).
* Thu Mar 20 2008 gregkh@suse.de
- fix up some EXPORT_SYMBOL() markings to be EXPORT_SYMBOL_GPL() as the
  code is not upstream and we aren't allowed to add non-GPL exports to
  our kernel tree.
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git5
- refresh patches to apply cleanly
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git4
- refresh patches to apply cleanly
* Thu Mar 20 2008 agruen@suse.de
- scripts/tar-up.sh: Rename --kbuild option to --source-timestamp.
  For generating the source timestamp, use HEAD as the branch
  name.
- rpm/get_release_number.sh.in: Don't try to synchronize release
  numbers with kernel-dummy if the release number has been
  specified explicitly (tar-up with --release-string, --timestamp,
  or --source-timestamp).
* Thu Mar 20 2008 olh@suse.de
- remove patches.kernel.org/powerpc-needs-uboot
  not needed without mpc51xx support
* Thu Mar 20 2008 olh@suse.de
- disable gianfar network driver and unused freescale drivers
* Wed Mar 19 2008 gregkh@suse.de
- patch refreshes due to version update
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6-git3
- Update config files.
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6
  - which deleted the following patches:
  - patches.fixes/hibernation-snapshot-numa-workaround.patch
  - patches.fixes/acpi-fix-double-log-level.patch
  - patches.fixes/acpi_fix_mem_corruption.patch
  - patches.kernel.org/patch-2.6.25-rc5
  - patches.kernel.org/patch-2.6.25-rc5-git3
- Update config files.
- delete patches.arch/x86-nvidia-timer-quirk as it is not being used.
* Wed Mar 19 2008 olh@suse.de
- remove patches.arch/ppc-efika-ipic.patch
  disable mpc51xx support instead
* Tue Mar 18 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Changed to just match %%ix86
* Tue Mar 18 2008 olh@suse.de
- add patches.arch/ppc-efika-ipic.patch
  fix a crash in init_ipic_sysfs on efika
* Mon Mar 17 2008 agruen@suse.de
- post.sh: Fix a syntax error when creating the initrd.
* Mon Mar 17 2008 jbeulich@novell.com
- patches.xen/xen-quicklist.patch: Delete.
- Update i386 Xen config file.
- patches.xen/xen3-patch-2.6.25-rc5-rc6: 2.6.25-rc6.
- patches.xen/xen3-auto-xen-kconfig.diff,
  patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.19,
  patches.xen/xen3-patch-2.6.20,
  patches.xen/xen3-patch-2.6.21,
  patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25-rc5,
  patches.xen/xen-x86-no-lapic,
  patches.xen/xen-x86-panic-no-reboot: Various adjustments.
* Sun Mar 16 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added an RPM conflict for 32-bit
  kernels and 64-bit glibc to avoid installing a 32-bit kernel
  with 64-bit userspace. (364433, et al)
* Fri Mar 14 2008 jeffm@suse.de
- scripts/tar-up.sh: Added --kbuild option to autogenerate
  release number based on branch and timestamp.
* Fri Mar 14 2008 jeffm@suse.de
- patches.apparmor/export-security_inode_permission-for-aufs:
  LSM: Export security_inode_permission for aufs (356902).
* Fri Mar 14 2008 agruen@suse.de
- Boot loader: do the same during initial installation as when
  updating a kernel package (FATE 302660).
* Thu Mar 13 2008 gregkh@suse.de
- Update to 2.6.25-rc5-git3
* Thu Mar 13 2008 olh@suse.de
- disable unuses pata platform and ibm newemac driver on powerpc
* Thu Mar 13 2008 olh@suse.de
- add patches.xen/xen-quicklist.patch
  fix kernel-xen compile, readd CONFIG_QUICKLIST for xen
* Wed Mar 12 2008 gregkh@suse.de
- remove alpha configs as they are no longer used
* Wed Mar 12 2008 gregkh@suse.de
- Enabled CONFIG_UNUSED_SYMBOLS for now.  It will be disabled
  after the next openSUSE alpha release.  It is being enabled
  for now to let some kmp packages still work while their
  maintainers are working to update them with the 2.6.25
  kernel changes.
* Wed Mar 12 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Wed Mar 12 2008 gregkh@suse.de
- update to 2.6.25-rc5-git2
* Wed Mar 12 2008 sassmann@suse.de
- patches.arch/ppc-ps3-rename-wireless-interface.patch:
  rename ps3 wireless interface from eth? to wlan? for better
  handling in udev
* Wed Mar 12 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc5 and c/s 471.
- patches.xen/xen3-aslr-i386-and-x86_64-randomize-brk.patch:
  Delete.
- patches.xen/xen3-aslr-pie-executable-randomization.patch:
  Delete.
- patches.xen/xen3-early-firewire.diff: Delete.
- Update x86 config files.
- config.conf: Re-enable Xen configs.
* Tue Mar 11 2008 gregkh@suse.de
- add usb persist for storage devices across suspend to ram.  This is going to
  be in 2.6.26, just missed the .25 merge window.
* Tue Mar 11 2008 gregkh@suse.de
- Update to 2.6.26-rc5-git1
- Update config files.
* Tue Mar 11 2008 gregkh@suse.de
- update to 2.6.25-rc5
* Mon Mar 10 2008 agruen@suse.de
- scripts/tar-up.sh: Don't lose the EXTRAVERSION when overriding
  the release number with --release-string or --timestamp.
* Sun Mar  9 2008 jeffm@suse.de
- patches.fixes/hibernation-snapshot-numa-workaround.patch:
  swsusp: workaround for crash on NUMA (kernel.org#9966).
* Sat Mar  8 2008 agruen@suse.de
- Encode the EXTRAVERSION part of kernel release numbers in the
  RPM release instead of in the version. This resolves the problem
  that kernel releases like 2.6.25-rc4 would result in a package
  with a higher version than 2.6.25 according to RPM's versioning
  scheme (bug 271712).
* Fri Mar  7 2008 schwab@suse.de
- Update kdb patches.
* Thu Mar  6 2008 trenn@suse.de
- patches.fixes/acpi_fix_mem_corruption.patch: ACPI: Fix mem
  corruption (350017).
- patches.fixes/acpi_thermal_passive_cleanup.patch: Warn user
  about a BIOS bug in asus boards (350017).
* Thu Mar  6 2008 gregkh@suse.de
- Update s390 config files.
* Thu Mar  6 2008 gregkh@suse.de
- update to 2.6.24-rc5-git1
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_GROUP_SCHED
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_HIGH_RES_TIMERS on i386
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_USB_PERSIST for vanilla config files
* Wed Mar  5 2008 gregkh@suse.de
- refresh patches to apply cleanly with no fuzz
- enable CONFIG_USB_PERSIST so that users can enable this if they want
* Wed Mar  5 2008 gregkh@suse.de
- update the vanilla config files for CONFIG_DEBUG_RODATA
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_DEBUG_RODATA (Not really a debug option, something
  we need in all of our kernels.)
* Wed Mar  5 2008 gregkh@suse.de
- Update vanilla config files.
* Wed Mar  5 2008 jbeulich@novell.com
- patches.fixes/parport-mutex,
  patches.suse/stack-unwind: Fix merge mistakes.
- Update i386 config files.
* Wed Mar  5 2008 gregkh@suse.de
- Update tree to 2.6.25-rc4
* Wed Mar  5 2008 fseidel@suse.de
- add patches.fixes/fat_detect_media_wo_parttable.patch and
  patches.fixes/fat_valid_media.patch:
  detect FAT formated medias without partition table correctly
  (bnc 364365)
* Tue Mar  4 2008 olh@suse.de
- add patches.kernel.org/s390-defkeymap.patch
  Build fix for drivers/s390/char/defkeymap.c
* Tue Mar  4 2008 olh@suse.de
- enable ext2/3 acl support in ps3 kernel
* Tue Mar  4 2008 olh@suse.de
- Update to 2.6.25-rc3-git5
* Tue Mar  4 2008 olh@suse.de
- use suffix -ps3 for PS3 kernel, it is only used in otheros.bld
* Mon Mar  3 2008 lmb@suse.de
- rpm/kernel-binary.spec.in: Require udev >= 118.
* Mon Mar  3 2008 ak@suse.de
- patches.arch/x86-nvidia-timer-quirk: Delete.
  PCI device ID list still not complete and let's have the same
  crap as mainline for now. It would be better to fix the PCI
  ID lists (#302327)
* Sun Mar  2 2008 olh@suse.de
- add patches.fixes/ibmvstgt-fixes.patch
  fix oops in ibmvstgt init function
* Fri Feb 29 2008 olh@suse.de
- add patches.arch/ppc-pci-bogus-resources.patch
  fix bogus test for unassigned resources
* Thu Feb 28 2008 olh@suse.de
- disable CONFIG_CRYPTO_DEV_HIFN_795X on ppc32 due to __divdi3 usage
- update patches.kernel.org/powerpc-needs-uboot
  disable mkimage call in arch/powerpc/boot/wrapper
* Thu Feb 28 2008 olh@suse.de
- update patches.kernel.org/fixed-phy-select
  add dependency on libphy=y
* Wed Feb 27 2008 jdelvare@suse.de
- patches.fixes/acpi-fix-double-log-level.patch: ACPI: Fix a
  duplicate log level.
* Wed Feb 27 2008 trenn@suse.de
- patches.fixes/acpi_force-fan-active.patch: Delete.
* Tue Feb 26 2008 sdietrich@suse.de
- remove obsolete adaptive-locks patches
  patches.rt/rtmutex-adaptive-locks.patch: Delete.
  patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
  patches.rt/rtmutex-optimize-wakeup.patch: Delete.
  patches.rt/rtmutex-rearrange.patch: Delete.
  patches.rt/rtmutex-remove-extra-try.patch: Delete.
  patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
  patches.rt/rtmutex-adaptive-timeout.patch: Delete.
  patches.rt/rtmutex-lateral-steal.patch: Delete.
  patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
* Tue Feb 26 2008 sassmann@suse.de
- remove patches included upstream
  patches.arch/ppc-ps3-gelic-cleanup.patch
  patches.arch/ppc-ps3-gelic-endianness.patch
  patches.arch/ppc-ps3-gelic-ethernet-linkstatus.patch
  patches.arch/ppc-ps3-gelic-fix-fallback.diff
  patches.arch/ppc-ps3-gelic-multiple-interface.patch
  patches.arch/ppc-ps3-gelic-remove-duplicate-ethtool-handlers.patch
  patches.arch/ppc-ps3-gelic-wireless-v2.patch
* Tue Feb 26 2008 jeffm@suse.de
- Update config files: Disabled CONFIG_INPUT_YEALINK per an old
  request from AJ.
* Tue Feb 26 2008 jeffm@suse.de
- Update to 2.6.25-rc3.
* Sun Feb 24 2008 sdietrich@suse.de
- patches.rt/0001-sched-count-of-queued-RT-tasks.patch: Delete.
- patches.rt/0002-sched-track-highest-prio-task-queued.patch:
  Delete.
- patches.rt/0003-sched-add-RT-task-pushing.patch: Delete.
- patches.rt/0004-sched-add-rt-overload-tracking.patch: Delete.
- patches.rt/0005-sched-pull-RT-tasks-from-overloaded-runqueues.patch:
  Delete.
- patches.rt/0006-sched-push-RT-tasks-from-overloaded-CPUs.patch:
  Delete.
- patches.rt/0007-sched-disable-standard-balancer-for-RT-tasks.patch:
  Delete.
- patches.rt/0008-sched-add-RT-balance-cpu-weight.patch: Delete.
- patches.rt/0009-sched-clean-up-this_rq-use-in-kernel-sched_rt.c.patch:
  Delete.
- patches.rt/0010-sched-de-SCHED_OTHER-ize-the-RT-path.patch:
  Delete.
- patches.rt/0011-sched-break-out-search-for-RT-tasks.patch:
  Delete.
- patches.rt/0012-sched-RT-balancing-include-current-CPU.patch:
  Delete.
- patches.rt/0013-sched-pre-route-RT-tasks-on-wakeup.patch:
  Delete.
- patches.rt/0014-sched-optimize-RT-affinity.patch: Delete.
- patches.rt/0015-sched-wake-balance-fixes.patch: Delete.
- patches.rt/0016-sched-RT-balance-avoid-overloading.patch:
  Delete.
- patches.rt/0017-sched-break-out-early-if-RT-task-cannot-be-migrated.patch:
  Delete.
- patches.rt/0018-sched-RT-balance-optimize.patch: Delete.
- patches.rt/0019-sched-RT-balance-optimize-cpu-search.patch:
  Delete.
- patches.rt/0020-sched-RT-balance-on-new-task.patch: Delete.
- patches.rt/0021-sched-clean-up-pick_next_highest_task_rt.patch:
  Delete.
- patches.rt/0022-sched-clean-up-find_lock_lowest_rq.patch:
  Delete.
- patches.rt/0023-sched-clean-up-overlong-line-in-kernel-sched_debug.patch:
  Delete.
- patches.rt/0024-sched-clean-up-kernel-sched_rt.c.patch: Delete.
- patches.rt/0025-sched-remove-rt_overload.patch: Delete.
- patches.rt/0026-sched-remove-leftover-debugging.patch: Delete.
- patches.rt/0027-sched-clean-up-pull_rt_task.patch: Delete.
- patches.rt/0028-sched-clean-up-schedule_balance_rt.patch:
  Delete.
- patches.rt/0029-sched-add-sched-domain-roots.patch: Delete.
- patches.rt/0030-sched-update-root-domain-spans-upon-departure.patch:
  Delete.
- patches.rt/0031-Subject-SCHED-Only-balance-our-RT-tasks-within-ou.patch:
  Delete.
- patches.rt/0032-sched-fix-sched_rt.c-join-leave_domain.patch:
  Delete.
- patches.rt/0033-sched-remove-unused-JIFFIES_TO_NS-macro.patch:
  Delete.
- patches.rt/0034-sched-style-cleanup-2.patch: Delete.
- patches.rt/0035-sched-add-credits-for-RT-balancing-improvements.patch:
  Delete.
- patches.rt/0036-sched-reactivate-fork-balancing.patch: Delete.
- patches.rt/0037-sched-whitespace-cleanups-in-topology.h.patch:
  Delete.
- patches.rt/0038-sched-no-need-for-affine-wakeup-balancing-in.patch:
  Delete.
- patches.rt/0039-sched-get-rid-of-new_cpu-in-try_to_wake_up.patch:
  Delete.
- patches.rt/0040-sched-remove-do_div-from-__sched_slice.patch:
  Delete.
- patches.rt/0041-sched-RT-balance-replace-hooks-with-pre-post-sched.patch:
  Delete.
- patches.rt/0042-sched-RT-balance-add-new-methods-to-sched_class.patch:
  Delete.
- patches.rt/0043-sched-RT-balance-only-adjust-overload-state-when-c.patch:
  Delete.
- patches.rt/0044-sched-remove-some-old-cpuset-logic.patch:
  Delete.
- Remove scheduler patches already upstream in 2.6.25-rc1
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/libertas-section-conflict: libertas: fix
  section conflict.
* Sat Feb 23 2008 jeffm@suse.de
- Enabled patches.kernel.org/ps3-lpm-include
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/spu_profiler-include: powerpc: spu_profiler
  build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: ps3: lpm build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/fixed-phy-select: powerpc: FSL_SOC requires
  FIXED_PHY.
- patches.kernel.org/lguest-fixups: lguest: Fix asm-offsets_32
  with correct config option.
* Sat Feb 23 2008 jeffm@suse.de
- Build fixes for ia64 and i386.
* Sat Feb 23 2008 jeffm@suse.de
- Update to 2.6.25-rc2-git6.
  - Removed:
  - patches.arch/ppc-pegasos-pata_via-fixup.patch: Delete.
  - patches.arch/ppc-pegasos-console-autodetection.patch: Delete.
  - patches.arch/ppc-ps3-make-dev_id-and-bus_id-u64.diff: Delete.
  - patches.arch/acpi_autoload_bay.patch: Delete.
  - patches.arch/small-acpica-extension-to-be-able-to-store-the-name-of.patch:
    Delete.
  - patches.arch/export-acpi_check_resource_conflict.patch: Delete.
  - patches.drivers/early-firewire.diff: Delete.
  - patches.drivers/scsi-throttle-SG_DXFER_TO_FROM_DEV-warning-better:
    Delete.
  - patches.drivers/libata-implement-force-parameter: Delete.
  - patches.drivers/igb-1.0.8-k2: Delete.
  - patches.drivers/always-announce-new-usb-devices.patch: Delete.
  - patches.drivers/nozomi.patch: Delete.
  - patches.drivers/libata-quirk_amd_ide_mode: Delete.
  - patches.fixes/acpi_autoload_baydock.patch: Delete.
  - patches.fixes/bluetooth_hci_dev_put.patch: Delete.
  - patches.fixes/bluetooth_hci_conn_childs.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan1.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan2.patch: Delete.
  - patches.fixes/libiscsi-missing-semicolon.diff: Delete.
  - patches.fixes/pci-quirk-enable-smbus-on-hp-xw4100.patch: Delete.
  - patches.kernel.org/patch-2.6.24.1: Delete.
  - patches.suse/acpi_dsdt_ssdt_initrd_initramfs.patch: Delete.
  - patches.suse/squashfs.patch.fixup: Delete.
  - patches.suse/aslr-pie-executable-randomization.patch: Delete.
  - patches.suse/aslr-i386-and-x86_64-randomize-brk.patch: Delete.
  - Xen and RT currently disabled.
  - SquashFS may not work.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: fixed and renabled check
* Fri Feb 22 2008 sdietrich@suse.de
- embargoed-patches: eliminate embargoed patches abuse.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: Disable check for non-existant patches.
* Fri Feb 22 2008 schwab@suse.de
- Update kdb patches.
* Fri Feb 22 2008 jbeulich@novell.com
- config/i386/xenpae: Rename to config/i386/xen.
- config.conf: Delete i386/xenpae.
* Thu Feb 21 2008 sdietrich@suse.de
- Update config files: update RT options for adaptive RT locks
* Thu Feb 21 2008 sdietrich@suse.de
- patches.rt/rtmutex-adaptive-mutexes.patch: cleanup.
- patches.rt/rtmutex-adaptive-timeout.patch: cleanup.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
* Thu Feb 21 2008 jbeulich@novell.com
- Update Xen patches to c/s 425.
- patches.xen/sfc-network-driver: Solarflare: Standard network driver
  (disabled until status clarified).
- patches.xen/sfc-resource-driver: Solarflare: Resource driver
  (disabled until status clarified).
- Update Xen config files.
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v20
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v19
* Wed Feb 20 2008 jeffm@suse.de
- Update config files for dmraid45.
* Wed Feb 20 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: add PAGESIZE detection for
  makedumpfile.config from the .config file also for PPC64
* Wed Feb 20 2008 fseidel@suse.de
- patches.fixes/bluetooth_hci_dev_put.patch,
  patches.fixes/bluetooth_hci_conn_childs.patch,
  patches.fixes/bluetooth_hci_unregister_sysfs.patch:
  fix kernel crash after removing bluetooth adapter (bnc 359546)
* Tue Feb 19 2008 jeffm@suse.de
- patches.suse/dm-raid45-2.6.24-20080602a.patch: DMRAID45 module.
* Fri Feb 15 2008 sdietrich@suse.de
- Update to latest patch set:
- patches.rt/rearrange_rtspinlock_sleep:
  [PATCH 02/10] rearrange rtspinlock sleep
- patches.rt/optimize_rtspinlock_wakeup:
  [PATCH 03/10] optimize rtspinlock wakeup
- patches.rt/adaptive_RT_spinlock_support:
  [PATCH 04/10] Adaptive RT spinlock support
- patches.rt/add_timeout_mechanism: [PATCH 05/10]
  add a loop counter based timeoutmechanism
- patches.rt/adaptive_mutexes: [PATCH 06/10] adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  [PATCH 07/10] Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: [PATCH 08/10]
  optimize the !printk fastpath throughthe lock acquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  [PATCH 09/10] remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: [PATCH 10/10] allow
  rt-mutex lock-stealing toinclude lateral priority
* Fri Feb 15 2008 sdietrich@suse.de
- embargoed-patches: (embargo development RT throughput patches)
- Update config files (RT config options)
- patches.rt/optimize_rtspinlock_wakeup: optimize rtspinlock
  wakeup.
- patches.rt/adaptive_RT_spinlock_support: Adaptive RT spinlock
  support.
- patches.rt/add_timeout_mechanism: add
  a loop counter based timeout mechanism
- patches.rt/adaptive_mutexes: adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: optimize
  the !printk fastpath through the lockacquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: allow rt-mutex
  lock-stealing to include lateralpriority
- patches.rt/rearrange_rtspinlock_sleep: cleanup rtspinlock sleep
* Thu Feb 14 2008 jeffm@suse.de
- Removed unused OCFS2 patches.
* Thu Feb 14 2008 jeffm@suse.de
- Removed old commented out ocfs2 patchset.
* Thu Feb 14 2008 teheo@suse.de
- patches.drivers/libata-quirk_amd_ide_mode: PCI: modify SATA
  IDE mode quirk (345124).
* Wed Feb 13 2008 jeffm@suse.de
- patches.suse/ocfs2-03-split-disk-heartbeat-out.diff: Fixed
  section conflict.
* Wed Feb 13 2008 jeffm@suse.de
- Update config files.
* Wed Feb 13 2008 jeffm@suse.de
- Merged and re-enabled OCFS2 userspace clustering
* Wed Feb 13 2008 jdelvare@suse.de
- config/*: Don't build i2c algorithm drivers that we do not use.
- supported.conf: Drop i2c-elektor and i2c-algo-pcf, we don't ship
  them.
* Tue Feb 12 2008 teheo@suse.de
  Build fix for section mismatch check.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Mon Feb 11 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: Delete.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Fri Feb  8 2008 gregkh@suse.de
- Update to 2.6.24.1
  - fixes CVE-2008-0007, CVE-2008-0009, CVE-2008-0010
  - lots of USB device ids updated
  - lots of other bugfixes
  - removed patches.fixes/bootstrap-memoryless-node.patch as it is now
    contained within.
* Fri Feb  8 2008 gregkh@suse.de
- Move ipv6-no-autoconf to xen directory as it is a Xen bugfix
* Fri Feb  8 2008 bwalle@suse.de
- patches.arch/ppc-fix-prpmc2800: remove patch since it's not needed
  with current binutils any more
* Fri Feb  8 2008 bwalle@suse.de
- patches.drivers/igb-2007-12-11: Delete.
- patches.drivers/igb-1.0.8-k2: Update to latest version which is
  also upstream now in the 2.6.25 tree.
* Fri Feb  8 2008 gregkh@suse.de
- Remove NO_BRP_NOEXECSTACK from the .spec files as it is obsolete
  and doesn't do anything anymore.
* Fri Feb  8 2008 jbeulich@novell.com
- patches.xen/xen3-auto-common.diff,
  patches.xen/xen3-patch-2.6.23: fix merge mistake.
* Fri Feb  8 2008 jbenc@suse.cz
- Update config files: disabled CONFIG_BCM43XX.
* Wed Feb  6 2008 jeffm@suse.de
- patches.apparmor/vfs-mkdir.diff: Added missing case in
  kernel/cgroup.c
* Wed Feb  6 2008 fseidel@suse.de
- updated patches.drivers/nozomi.patch: mainline info
* Wed Feb  6 2008 sdietrich@suse.de
- Update config files: RT@1KHz, sched groups & cpusets enabled.
* Wed Feb  6 2008 olh@suse.de
- enable bnx2 on ppc64 (bnc 359114 - LTC42106)
* Wed Feb  6 2008 gregkh@suse.de
- remove unused lockd patches:
  - patches.suse/lockd-switchable-statd
  - patches.suse/lockd-kernel-statd
  - patches.suse/lockd-suse-config
  - patches.suse/lockd-max-hosts-dynamic
* Wed Feb  6 2008 oneukum@suse.de
- patches.suse/usb_printer_no_auto.diff: Delete.
  Obsoleted by mainline change
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547) for RT kernels
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547)
* Thu Jan 31 2008 sdietrich@suse.de
- patches.rt/megasas_IRQF_NODELAY.patch: Convert megaraid sas
  IRQ to non-threaded IRQ.
- patches.rt/version.patch: Delete (unused).
* Thu Jan 31 2008 jbenc@suse.cz
- patches.fixes/mac80211-fix-hw-scan1.patch,
  patches.fixes/mac80211-fix-hw-scan2.patch: mac80211: hardware
  scan rework (bnc#307050).
* Thu Jan 31 2008 sdietrich@suse.de
- Remove a legacy tweak carried over from the 10.3 Kernel,
  enable the affinity load-balancing sysctl.
* Wed Jan 30 2008 sdietrich@suse.de
- patches.rt/x86-ticket-lock.patch: FIFO ticket lock spinlocks
  for x86 (RT).
- patches.rt/rt-mutex-i386.patch: Resolve conflicts.
* Tue Jan 29 2008 olh@suse.de
- really skip kernel-ps3 in suse_kernel_module_package rpm macro
* Tue Jan 29 2008 jbeulich@novell.com
- Update Xen patches to 2.6.24 final and c/s 399.
- patches.xen/xen3-seccomp-disable-tsc-option: [PATCH seccomp:
  make tsc disabling optional (191123).
* Sat Jan 26 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rt1 (many patches in patches.rt refreshed).
- patches.rt/series: Delete (unused).
* Sat Jan 26 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  use struct device_attribute to fix oops on boot
* Sat Jan 26 2008 jeffm@suse.de
- scripts/sequence-patch.sh: Updated to include $EXTRA_SYMBOLS in
  $PATCH_DIR (e.g.: --symbol=RT creates linux-2.6.24-RT)
* Fri Jan 25 2008 jeffm@suse.de
- patches.rt/rcu-new-1.patch: Updated context against 2.6.24.
* Fri Jan 25 2008 olh@suse.de
- add patches.fixes/bootstrap-memoryless-node.patch
  slab: fix bootstrap on memoryless node
* Fri Jan 25 2008 gregkh@suse.de
- refresh allmost all patches to apply cleanly and have a proper
  diffstat (except for the xen patches, they were left alone...)
* Fri Jan 25 2008 gregkh@suse.de
- Update to 2.6.24
* Thu Jan 24 2008 olh@suse.de
- always skip kernel-ps3 in suse_kernel_module_package rpm macro
* Thu Jan 24 2008 sdietrich@suse.de
- Update config files: set SYSFS_DEPRECATED for reverse
  compatibility with SLERT
* Tue Jan 22 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  simplify patch
* Tue Jan 22 2008 agruen@suse.de
- patches.rpmify/cloneconfig.diff: Adjust to upstream i386 + x86_64
  merge (347712).
* Tue Jan 22 2008 sassmann@suse.de
- add defconfig for ps3 kernel
- add entry for ps3 defconfig in config.conf
- add support for kernels without loadable modules to rpm/kernel-binary.spec.in
- include ps3 target in scripts/tar-up_and_run_mbuild.sh
* Mon Jan 21 2008 sdietrich@suse.de
- Update config files (RT)
* Mon Jan 21 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rc8-rt1
* Mon Jan 21 2008 olh@suse.de
- add patches.arch/ppc-pegasos-pata_via-fixup.patch
  call chrp_pci_fixup_vt8231_ata() later to allow pata_via usage
* Mon Jan 21 2008 aj@suse.de
- Remove unused config/s390/rt.
* Sat Jan 19 2008 jeffm@suse.de
- patches.rt/irq-flags-unsigned-long.patch: Delete.
* Sat Jan 19 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git2.
* Fri Jan 18 2008 jeffm@suse.de
- Enabled 2.6.24-rc8-git1.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: Delete. The patch
  is not correct, there exist two cards with different chipsets but
  the same USB ID.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: rt2x00: remove
  duplicate USB ID (350956).
* Fri Jan 18 2008 olh@suse.de
- sync powerpc vanilla with default .config to enable libata
* Fri Jan 18 2008 olh@suse.de
- add patches.arch/ppc-pegasos-mv643xx_eth-modalias.patch
  provide module alias platform:mv643xx_eth
* Thu Jan 17 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git1.
* Wed Jan 16 2008 jeffm@suse.de
- Update to 2.6.24-rc8.
* Sun Jan 13 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git5.
* Fri Jan 11 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git3.
* Fri Jan 11 2008 jbeulich@novell.com
- Update Xen patches to c/s 372 and 2.6.24-rc7.
- patches.xen/xen3-aux-at_vector_size.patch: Delete.
- Update Xen config files.
* Thu Jan 10 2008 olh@suse.de
- update patches.arch/ppc-efika-ethernet-phy.patch
  move Forth code to fixup_device_tree_efika
* Wed Jan  9 2008 schwab@suse.de
- Fix debug package build.
* Wed Jan  9 2008 oneukum@suse.de
- Update config files. CONFIG_USB_SUSPEND default
* Wed Jan  9 2008 schwab@suse.de
- Update kdb patches.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Another try...
* Wed Jan  9 2008 jeffm@suse.de
- Update config files: Enabled CONFIG_SCSI_SAS_ATA. (346990)
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Fix CONFIG_FRAME_POINTER build.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- patches.xen/xen3-stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- Update config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: Fixed so it only applies
  to i386, and updated config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: [PATCH] seccomp:
  make tsc disabling optional (191123).
* Tue Jan  8 2008 olh@suse.de
- add patches.arch/ppc-efika-ethernet-phy.patch
  drop patches.arch/ppc-efika-bestcomm-ethernet.patch
  provide phy-handle property for fec_mpc52xx (347234)
* Tue Jan  8 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: libata: implement
  libata.force_cbl parameter (337610).
* Mon Jan  7 2008 jeffm@suse.de
- Update to 2.6.24-rc7.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-disable-ADMA: sata_nv: disable
  ADMA by default (346508).
* Mon Jan  7 2008 teheo@suse.de
  Bug 347708.  port_info for vmw was being assigned to the wrong index.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Mon Jan  7 2008 teheo@suse.de
  As the rest of kernel has caught up now, this one is no longer
  necessary.
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Fri Jan  4 2008 jeffm@suse.de
- Update config files for -vanilla.
* Fri Jan  4 2008 jeffm@suse.de
- patches.rt/timer-freq-tweaks.patch: Adjusted context.
* Fri Jan  4 2008 jeffm@suse.de
- Update config files.
* Fri Jan  4 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git11.
* Wed Jan  2 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Copy debug sources to a proper location.
* Tue Jan  1 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git7.
* Tue Jan  1 2008 jeffm@suse.de
- scripts/run_oldconfig.sh: Removed RT symbol from EXTRA_SYMBOLS.
  We add it manually when building the patch list. This allows
  the script to work with the RT kernel without having to remove
  all the other configs from config.conf first.
